(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 9.0' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1063,         20]
NotebookDataLength[  19658352,     324911]
NotebookOptionsPosition[  19623865,     323924]
NotebookOutlinePosition[  19628238,     324030]
CellTagsIndexPosition[  19628154,     324025]
WindowTitle->Algae
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Predicting Algae Blooms", "Title",
 CellChangeTimes->{{3.520677779770745*^9, 3.5206777856383314`*^9}, {
   3.572201436467568*^9, 3.572201440184266*^9}, 3.574003889138953*^9, {
   3.574003929443994*^9, 3.5740039544898233`*^9}, {3.574084215345809*^9, 
   3.574084218047209*^9}, {3.5854080238545322`*^9, 3.5854080282497187`*^9}}],

Cell[TextData[{
 "This extended example is a prediction problem drawn from the COIL 1999 \
International Data Analysis Competition and is covered in Lu\[IAcute]s Torgo\
\[CloseCurlyQuote]s ",
 StyleBox["Data Mining with R:  Learning with Case Studies",
  FontSlant->"Italic"],
 " (Boca Raton:  Chapman & Hall/CRC, 2010)."
}], "Text",
 CellChangeTimes->{{3.585408062594426*^9, 3.585408228694294*^9}, {
  3.5854086945723953`*^9, 3.585408783362226*^9}, {3.585408870099296*^9, 
  3.585408894456398*^9}, {3.585480970244967*^9, 3.5854809887486897`*^9}}],

Cell["\<\
The dataset consists of chemical and algae level measurements in several \
European rivers over a period of about a year.  \
\>", "Text",
 CellChangeTimes->{{3.585408062594426*^9, 3.585408228694294*^9}, {
  3.5854086945723953`*^9, 3.585408783362226*^9}, {3.585408870099296*^9, 
  3.585408894456398*^9}, {3.585480970244967*^9, 3.585480989962386*^9}, {
  3.58591019490576*^9, 3.5859101955134563`*^9}}],

Cell[TextData[{
 "The task is to obtain a model that allows us to predict algae levels on the \
basis of the chemical measurements.  In the process we will touch on several \
data analysis techniques and their ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " implementations, including:"
}], "Text",
 CellChangeTimes->{{3.585408282276729*^9, 3.5854083308358793`*^9}, {
  3.585408968065626*^9, 3.585408989046122*^9}, {3.585481165823988*^9, 
  3.585481234614614*^9}, {3.585481273900173*^9, 3.5854813096119413`*^9}, {
  3.585910233960731*^9, 3.585910269798765*^9}}],

Cell[CellGroupData[{

Cell["Imputation", "Item",
 CellChangeTimes->{{3.585910275694837*^9, 3.585910281325943*^9}}],

Cell["Modeling", "Item",
 CellChangeTimes->{{3.585910275694837*^9, 3.58591028370125*^9}, {
  3.586003881335266*^9, 3.586003884198573*^9}}],

Cell["Cross-validation", "Item",
 CellChangeTimes->{{3.585910275694837*^9, 3.585910286510211*^9}}]
}, Open  ]],

Cell["The data is in the algae folder:", "Text",
 CellChangeTimes->{{3.585408484417417*^9, 3.585408493520567*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"names", "=", 
     RowBox[{"FileNames", "[", 
      RowBox[{"\"\<*\>\"", ",", "\"\<algae\>\""}], "]"}]}], "}"}], ",", 
   RowBox[{"TableForm", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"#", ",", 
        RowBox[{"FileByteCount", "[", "#", "]"}]}], "}"}], "&"}], "/@", 
     "names"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.585408496061782*^9, 3.585408513482985*^9}, {
  3.585408589702993*^9, 3.5854086180235157`*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"algae/Analysis.txt\"\>", "42018"},
    {"\<\"algae/Eval.txt\"\>", "17781"},
    {"\<\"algae/Sols.txt\"\>", "3276"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.585408514148731*^9, 3.585408618712206*^9, 
  3.5854945895699263`*^9, 3.5859967180031233`*^9, 3.586085420936298*^9, 
  3.5860886866834373`*^9}]
}, Open  ]],

Cell["\<\
These are our training set, our test set, and our solutions, respectively.  \
Don\[CloseCurlyQuote]t peek.\
\>", "Text",
 CellChangeTimes->{{3.585408629510253*^9, 3.585408647285087*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Import", "Title",
 CellChangeTimes->{{3.520677779770745*^9, 3.5206777856383314`*^9}, {
   3.572201436467568*^9, 3.572201440184266*^9}, 3.574003889138953*^9, {
   3.574003929443994*^9, 3.5740039544898233`*^9}, {3.574084215345809*^9, 
   3.574084218047209*^9}, {3.5854080238545322`*^9, 3.5854080282497187`*^9}, {
   3.585408994993483*^9, 3.585408996183156*^9}}],

Cell["\<\
Specifically, our task is to obtain predictions for the levels seven algae \
species in a set of 140 test samples, given 200 training samples.  Each \
sample has 11 features.\
\>", "Text",
 CellChangeTimes->{{3.585409007360567*^9, 3.585409022125017*^9}, {
  3.585910305647369*^9, 3.585910307342432*^9}, {3.5860199227452173`*^9, 
  3.586019945110879*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"raw", "[", "1", "]"}], "=", 
   RowBox[{"Import", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<algae\>\"", ",", "\"\<Analysis.txt\>\""}], "}"}], "]"}], 
     ",", "\"\<Data\>\""}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Dimensions", "@", 
  RowBox[{"raw", "[", "1", "]"}]}]}], "Input",
 CellChangeTimes->{{3.5741685507355185`*^9, 3.574168670263502*^9}, {
  3.5751302678824663`*^9, 3.575130284458878*^9}, {3.585413379506529*^9, 
  3.585413395068261*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"200", ",", "18"}], "}"}]], "Output",
 CellChangeTimes->{
  3.5741686714152994`*^9, 3.574617412252535*^9, 3.5746874129830294`*^9, 
   3.574689285584136*^9, 3.5747726802614384`*^9, 3.5750219978942137`*^9, 
   3.5751091998448315`*^9, 3.575130251563386*^9, 3.575130285900194*^9, 
   3.575130411999001*^9, 3.575204921214242*^9, 3.57651637385709*^9, 
   3.576859052053145*^9, {3.577545127094117*^9, 3.5775451338716173`*^9}, 
   3.5775457888513002`*^9, 3.577642961558783*^9, {3.5854133886846437`*^9, 
   3.5854133955822363`*^9}, 3.585494592405973*^9, 3.585494789252746*^9, 
   3.5859967471962*^9, 3.586085670964254*^9, 3.586088708288288*^9, 
   3.586088896383128*^9, 3.586098429091632*^9}]
}, Open  ]],

Cell["A few rows:", "Text",
 CellChangeTimes->{{3.585413458583481*^9, 3.585413459526998*^9}, {
  3.585481322028164*^9, 3.5854813242036333`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Take", "[", 
   RowBox[{
    RowBox[{"raw", "[", "1", "]"}], ",", 
    RowBox[{"-", "5"}]}], "]"}], "//", "TableForm"}]], "Input",
 CellChangeTimes->{{3.585413402310302*^9, 3.585413439775968*^9}, 
   3.585413564438445*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"autumn\"\>", "\<\"large\"\>", "\<\"medium\"\>", "8.4`", "8.4`", 
     "17.375`", "3.833`", "83.75`", "53.625`", "79.75`", "2.338`", "12.7`", 
     "21.7`", "5.6`", "0.`", "1.`", "0.`", "0.`"},
    {"\<\"spring\"\>", "\<\"large\"\>", "\<\"medium\"\>", "8.3`", "10.6`", 
     "14.32`", "3.2`", "125.333`", "35.333`", "75.904`", "4.667`", "18.`", 
     "7.`", "1.7`", "0.`", "4.8`", "10.3`", "1.`"},
    {"\<\"autumn\"\>", "\<\"large\"\>", "\<\"medium\"\>", "8.2`", "7.`", 
     "139.989`", "2.978`", "60.11`", "78.333`", "140.22`", "31.738`", "0.`", 
     "15.9`", "2.4`", "1.`", "0.`", "0.`", "0.`"},
    {"\<\"winter\"\>", "\<\"large\"\>", "\<\"medium\"\>", "8.`", 
     "7.6`", "\<\"XXXXXXX\"\>", "\<\"XXXXXXX\"\>", "\<\"XXXXXXX\"\>", \
"\<\"XXXXXXX\"\>", "\<\"XXXXXXX\"\>", "\<\"XXXXXXX\"\>", "0.`", "12.5`", 
     "3.7`", "1.`", "0.`", "0.`", "4.9`"},
    {"\<\"summer\"\>", "\<\"large\"\>", "\<\"medium\"\>", "8.5`", "6.7`", 
     "82.852`", "2.8`", "27.069`", "64.`", "140.517`", "18.3`", "2.4`", 
     "10.5`", "9.`", "7.8`", "0.`", "0.`", "5.8`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.585413407084055*^9, 3.585413439927696*^9}, 
   3.5854135646577597`*^9, 3.585494593601502*^9, 3.585996748628521*^9, 
   3.586085673081685*^9, 3.586098430253725*^9}]
}, Open  ]],

Cell[TextData[{
 "The \[OpenCurlyDoubleQuote]",
 StyleBox["XXXXXX", "Input"],
 "\[CloseCurlyDoubleQuote] pattern indicates missing data.  Convert this to a \
conventional ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " symbol:"
}], "Text",
 CellChangeTimes->{{3.585413574812828*^9, 3.585413597892089*^9}, {
  3.585481033187293*^9, 3.585481033897756*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"raw", "[", "2", "]"}], "=", 
   RowBox[{
    RowBox[{"raw", "[", "1", "]"}], "/.", 
    RowBox[{"\"\<XXXXXXX\>\"", "\[Rule]", 
     RowBox[{"Missing", "[", "]"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.585413599123238*^9, 3.585413611373889*^9}}],

Cell["\<\
The first three columns contain factorized variables.  Here are the values \
they take on:\
\>", "Text",
 CellChangeTimes->{{3.5854134849437227`*^9, 3.585413503621963*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Union", "/@", 
  RowBox[{"Transpose", "[", 
   RowBox[{
    RowBox[{"raw", "[", "2", "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", 
      RowBox[{"1", ";;", "3"}]}], "]"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5854135099672623`*^9, 3.585413553320232*^9}, {
  3.585413618873117*^9, 3.585413618989438*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"autumn\"\>", ",", "\<\"spring\"\>", ",", "\<\"summer\"\>", 
     ",", "\<\"winter\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"large\"\>", ",", "\<\"medium\"\>", ",", "\<\"small\"\>"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"high\"\>", ",", "\<\"low\"\>", ",", "\<\"medium\"\>"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.585413516363319*^9, 3.585413553668594*^9}, 
   3.585413619149852*^9, 3.585494596491387*^9, 3.585494812129961*^9, 
   3.58599675428979*^9, 3.586019987559762*^9, 3.586085677776396*^9, 
   3.586098434035915*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Column Identification", "Title",
 CellChangeTimes->{{3.520677779770745*^9, 3.5206777856383314`*^9}, {
   3.572201436467568*^9, 3.572201440184266*^9}, 3.574003889138953*^9, {
   3.574003929443994*^9, 3.5740039544898233`*^9}, {3.574084215345809*^9, 
   3.574084218047209*^9}, {3.5854080238545322`*^9, 3.5854080282497187`*^9}, {
   3.585408994993483*^9, 3.585408996183156*^9}, {3.585413910750842*^9, 
   3.585413915406839*^9}, {3.5854862006390257`*^9, 3.585486200990789*^9}}],

Cell[TextData[{
 "We could use ",
 StyleBox["Part", "Input"],
 " throughout our analysis to refer to the various columns.  For instance, \
the chlorine values are:"
}], "Text",
 CellChangeTimes->{{3.585409007360567*^9, 3.585409022125017*^9}, {
  3.585413920023147*^9, 3.585413990652582*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"raw", "[", "2", "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"All", ",", "6"}], "]"}], "]"}], "//", "Short"}]], "Input",
 CellChangeTimes->{{3.585413955891758*^9, 3.585413974725143*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"{", 
   RowBox[{
   "60.8`", ",", "57.75`", ",", "40.02`", ",", "77.364`", ",", "55.35`", ",", 
    RowBox[{"\[LeftSkeleton]", "190", "\[RightSkeleton]"}], ",", "17.375`", 
    ",", "14.32`", ",", "139.989`", ",", 
    RowBox[{"Missing", "[", "]"}], ",", "82.852`"}], "}"}],
  Short]], "Output",
 CellChangeTimes->{{3.585413966288527*^9, 3.585413974865452*^9}, 
   3.585494599609696*^9, 3.585996765345066*^9, 3.5860199947550783`*^9, 
   3.5860856807163067`*^9}]
}, Open  ]],

Cell["\<\
Although it adds some complexity up front, it will pay off later to invest in \
some column labeling infrastructure.  First, provide some column labels.  \
These don\[CloseCurlyQuote]t have to be strings;  we\[CloseCurlyQuote]ll see \
why in a minute:\
\>", "Text",
 CellChangeTimes->{{3.585414001924343*^9, 3.585414062538698*^9}, {
  3.5855068403059883`*^9, 3.585506841375886*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"columns", "=", 
   RowBox[{"{", 
    RowBox[{
    "season", ",", "size", ",", "speed", ",", "mxPH", ",", "mnO2", ",", "Cl", 
     ",", "NO3", ",", "NH4", ",", "oPO4", ",", "PO4", ",", "Chla", ",", "a1", 
     ",", "a2", ",", "a3", ",", "a4", ",", "a5", ",", "a6", ",", "a7"}], 
    "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"numberedColumns", "=", 
   RowBox[{"Rule", "@@@", 
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"columns", ",", 
       RowBox[{"Range", "[", 
        RowBox[{"Length", "@", "columns"}], "]"}]}], "}"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"responseColumns", "=", 
   RowBox[{"Take", "[", 
    RowBox[{"columns", ",", 
     RowBox[{"-", "7"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"featureColumns", "=", 
   RowBox[{"Take", "[", 
    RowBox[{"columns", ",", "11"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.57416969531166*^9, 3.5741696978203545`*^9}, 
   3.5741707218938475`*^9, {3.574766526846483*^9, 3.574766557677246*^9}, {
   3.585414079115511*^9, 3.5854140839631567`*^9}}],

Cell["\<\
Next, write a function that turns a raw dataset into a symbol that can be \
queried by column name.  (Don\[CloseCurlyQuote]t worry if you can\
\[CloseCurlyQuote]t follow this yet.)\
\>", "Text",
 CellChangeTimes->{{3.585414331933346*^9, 3.585414383092615*^9}, 
   3.5854813505724373`*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "@", "columnize"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"columnize", "[", "set_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"sym", ",", "registerCol"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"sym", "[", "All", "]"}], "=", "set"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"sym", "[", 
       RowBox[{"All", ",", "\"\<nominals\>\""}], "]"}], "=", 
      RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"sym", "[", 
       RowBox[{"All", ",", "\"\<columns\>\""}], "]"}], "=", "columns"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"registerCol", "[", "col_", "]"}], ":=", 
      RowBox[{"Module", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"i", "=", 
          RowBox[{"col", "/.", "numberedColumns"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"sym", "[", 
           RowBox[{"col", ",", "\"\<raw\>\""}], "]"}], ":=", 
          RowBox[{
           RowBox[{"sym", "[", "All", "]"}], "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "i"}], "]"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"sym", "[", 
           RowBox[{"col", ",", "\"\<missing\>\""}], "]"}], "=", 
          RowBox[{"Position", "[", 
           RowBox[{
            RowBox[{"sym", "[", 
             RowBox[{"col", ",", "\"\<raw\>\""}], "]"}], ",", 
            RowBox[{"Missing", "[", "]"}]}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"sym", "[", "col", "]"}], ":=", 
          RowBox[{
           RowBox[{"sym", "[", 
            RowBox[{"col", ",", "\"\<raw\>\""}], "]"}], "[", 
           RowBox[{"[", 
            RowBox[{"Complement", "[", 
             RowBox[{
              RowBox[{"Range", "[", 
               RowBox[{"Length", "@", "set"}], "]"}], ",", 
              RowBox[{"Flatten", "@", 
               RowBox[{"sym", "[", 
                RowBox[{"col", ",", "\"\<missing\>\""}], "]"}]}]}], "]"}], 
            "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"sym", "[", 
           RowBox[{"col", ",", "\"\<factorized\>\""}], "]"}], "=", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"MatchQ", "[", 
             RowBox[{
              RowBox[{"sym", "[", "col", "]"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"_", "?", "NumericQ"}], ".."}], "}"}]}], "]"}], ",", 
            "\[IndentingNewLine]", "False", ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"With", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"u", "=", 
                 RowBox[{"Union", "[", 
                  RowBox[{"sym", "[", "col", "]"}], "]"}]}], "}"}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{
                 RowBox[{"fordering", "[", 
                  RowBox[{"sym", ",", "col"}], "]"}], "=", 
                 RowBox[{"Range", "[", 
                  RowBox[{"Length", "@", "u"}], "]"}]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"sym", "[", 
                  RowBox[{"col", ",", "\"\<factors\>\""}], "]"}], ":=", 
                 RowBox[{"u", "[", 
                  RowBox[{"[", 
                   RowBox[{"fordering", "[", 
                    RowBox[{"sym", ",", "col"}], "]"}], "]"}], "]"}]}], 
                ";"}]}], "\[IndentingNewLine]", "]"}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"AppendTo", "[", 
              RowBox[{
               RowBox[{"sym", "[", 
                RowBox[{"All", ",", "\"\<nominals\>\""}], "]"}], ",", "col"}],
               "]"}], ";", "\[IndentingNewLine]", "True"}]}], 
           "\[IndentingNewLine]", "]"}]}], ";"}]}], "\[IndentingNewLine]", 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"registerCol", "/@", "columns"}], ";", "\[IndentingNewLine]", 
     "sym"}]}], "\[IndentingNewLine]", "]"}]}]}], "Input",
 CellChangeTimes->{{3.574168756526001*^9, 3.5741688847877235`*^9}, {
   3.574168917997714*^9, 3.574168932293578*^9}, {3.5741690660351114`*^9, 
   3.5741690773133492`*^9}, {3.574169255963372*^9, 3.574169284173337*^9}, {
   3.5741694052270594`*^9, 3.5741694507605753`*^9}, {3.5741695041907873`*^9, 
   3.5741695049031878`*^9}, {3.574169638342758*^9, 3.574169711433272*^9}, {
   3.574169799026409*^9, 3.5741698035982246`*^9}, {3.5741700931344833`*^9, 
   3.5741701049865513`*^9}, {3.5741706884418125`*^9, 3.574170693689212*^9}, {
   3.574171086713773*^9, 3.5741711739570637`*^9}, {3.5741712087846613`*^9, 
   3.5741712662940254`*^9}, {3.5741713046712065`*^9, 3.574171305946041*^9}, {
   3.57417133603463*^9, 3.5741713360846233`*^9}, {3.5741713830377293`*^9, 
   3.5741713923445787`*^9}, {3.57476570787364*^9, 3.574765838745126*^9}, {
   3.5747659530846653`*^9, 3.5747659651883583`*^9}, {3.5747660665291543`*^9, 
   3.574766070194364*^9}, {3.5747661053933773`*^9, 3.574766127543644*^9}, {
   3.57476618778109*^9, 3.5747661940904503`*^9}, {3.5747662579951057`*^9, 
   3.5747662835565677`*^9}, {3.574766328218122*^9, 3.5747665001499557`*^9}, {
   3.57476656193149*^9, 3.574766641498041*^9}, {3.574766683290431*^9, 
   3.574766741381754*^9}, {3.5747669827335587`*^9, 3.5747670589609184`*^9}, {
   3.574767119448378*^9, 3.5747672155668755`*^9}, {3.5747672504108686`*^9, 
   3.574767256128196*^9}, {3.5747673688046403`*^9, 3.5747673983503304`*^9}, 
   3.57476764101521*^9, 3.5747677151164484`*^9, {3.5747678048345795`*^9, 
   3.574767813896098*^9}, {3.574767903782239*^9, 3.5747679058153553`*^9}, {
   3.57476827007219*^9, 3.574768302612051*^9}, {3.574768390606084*^9, 
   3.5747683956543727`*^9}, {3.5747684573219*^9, 3.574768468930564*^9}, {
   3.574768509857905*^9, 3.5747685125100565`*^9}, {3.5747685999810596`*^9, 
   3.5747686435075493`*^9}, {3.5747691206598406`*^9, 
   3.5747691447622194`*^9}, {3.574769419545936*^9, 3.5747694236001678`*^9}, {
   3.5747694870387964`*^9, 3.5747695003655586`*^9}, {3.574769597027087*^9, 
   3.5747696003532777`*^9}, {3.574769708430459*^9, 3.574769711749649*^9}, {
   3.574769755173133*^9, 3.5747697556791615`*^9}, {3.5747706555666323`*^9, 
   3.5747707270587215`*^9}, {3.5747707929054875`*^9, 3.574770820876087*^9}, {
   3.574793591784502*^9, 3.5747935985358887`*^9}, {3.5747936388181925`*^9, 
   3.5747936758333097`*^9}, {3.5747938105120125`*^9, 3.574793865411153*^9}, {
   3.5747944905989113`*^9, 3.574794498043337*^9}, {3.5747946234885125`*^9, 
   3.5747946236895237`*^9}, {3.5747947837496786`*^9, 
   3.5747947846937327`*^9}, {3.575025666508046*^9, 3.575025719939102*^9}, {
   3.585414386279875*^9, 3.5854143867034893`*^9}, {3.585485734883456*^9, 
   3.5854857432855587`*^9}, {3.5854890967067013`*^9, 3.585489116341618*^9}, {
   3.585489348097411*^9, 3.585489419935848*^9}, 3.5854894938614597`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Create Columnized Representation", "Title",
 CellChangeTimes->{{3.520677779770745*^9, 3.5206777856383314`*^9}, {
   3.572201436467568*^9, 3.572201440184266*^9}, 3.574003889138953*^9, {
   3.574003929443994*^9, 3.5740039544898233`*^9}, {3.574084215345809*^9, 
   3.574084218047209*^9}, {3.5854080238545322`*^9, 3.5854080282497187`*^9}, {
   3.585408994993483*^9, 3.585408996183156*^9}, {3.585413910750842*^9, 
   3.585413915406839*^9}, {3.5854862006390257`*^9, 3.585486200990789*^9}, {
   3.585488834496768*^9, 3.5854888519915323`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"med", "=", 
   RowBox[{"columnize", "@", 
    RowBox[{"raw", "[", "2", "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.585415169456917*^9, 3.585415181751874*^9}}],

Cell["\<\
Set the appropriate factor ordering for our three factorized variables (the \
default is canonical sort order).\
\>", "Text",
 CellChangeTimes->{{3.5854881533275623`*^9, 3.5854881727675877`*^9}, {
   3.585488889270802*^9, 3.5854889099345903`*^9}, 3.585489310679449*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"#", ",", 
      RowBox[{"med", "[", 
       RowBox[{"#", ",", "\"\<factors\>\""}], "]"}]}], "}"}], "&"}], "/@", 
   RowBox[{"med", "[", 
    RowBox[{"All", ",", "\"\<nominals\>\""}], "]"}]}], "//", 
  "TableForm"}]], "Input",
 CellChangeTimes->{{3.585488207129388*^9, 3.58548823002899*^9}, {
  3.5854882842163677`*^9, 3.585488305659375*^9}, {3.585488880071899*^9, 
  3.58548888390351*^9}, {3.58548891422442*^9, 3.5854889309489927`*^9}}],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {"season", GridBox[{
       {"\<\"autumn\"\>"},
       {"\<\"spring\"\>"},
       {"\<\"summer\"\>"},
       {"\<\"winter\"\>"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]},
    {"size", GridBox[{
       {"\<\"large\"\>"},
       {"\<\"medium\"\>"},
       {"\<\"small\"\>"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]},
    {"speed", GridBox[{
       {"\<\"high\"\>"},
       {"\<\"low\"\>"},
       {"\<\"medium\"\>"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  TableForm[{{$CellContext`season, {
     "autumn", "spring", "summer", "winter"}}, {$CellContext`size, {
     "large", "medium", "small"}}, {$CellContext`speed, {
     "high", "low", "medium"}}}]]], "Output",
 CellChangeTimes->{{3.585488222741132*^9, 3.5854882306858253`*^9}, 
   3.585488306028277*^9, 3.585488884273045*^9, {3.585488915810055*^9, 
   3.585488931288856*^9}, 3.585489430692563*^9, {3.585489470764057*^9, 
   3.585489499636773*^9}, 3.585494607352086*^9, 3.5854948166513968`*^9, 
   3.585996776682472*^9, 3.5860856884672832`*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"fordering", "[", 
    RowBox[{"med", ",", "season"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"2", ",", "3", ",", "1", ",", "4"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"fordering", "[", 
    RowBox[{"med", ",", "size"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"3", ",", "2", ",", "1"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"fordering", "[", 
    RowBox[{"med", ",", "speed"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"2", ",", "3", ",", "1"}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.585488242944191*^9, 3.585488247650591*^9}, {
  3.585488945823132*^9, 3.585489018990509*^9}}],

Cell["These make human sense now:", "Text",
 CellChangeTimes->{{3.58548951333099*^9, 3.585489516609511*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"#", ",", 
      RowBox[{"med", "[", 
       RowBox[{"#", ",", "\"\<factors\>\""}], "]"}]}], "}"}], "&"}], "/@", 
   RowBox[{"med", "[", 
    RowBox[{"All", ",", "\"\<nominals\>\""}], "]"}]}], "//", 
  "TableForm"}]], "Input",
 CellChangeTimes->{{3.585488207129388*^9, 3.58548823002899*^9}, {
  3.5854882842163677`*^9, 3.585488305659375*^9}, {3.585488880071899*^9, 
  3.58548888390351*^9}, {3.58548891422442*^9, 3.5854889309489927`*^9}}],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {"season", GridBox[{
       {"\<\"spring\"\>"},
       {"\<\"summer\"\>"},
       {"\<\"autumn\"\>"},
       {"\<\"winter\"\>"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]},
    {"size", GridBox[{
       {"\<\"small\"\>"},
       {"\<\"medium\"\>"},
       {"\<\"large\"\>"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]},
    {"speed", GridBox[{
       {"\<\"low\"\>"},
       {"\<\"medium\"\>"},
       {"\<\"high\"\>"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  TableForm[{{$CellContext`season, {
     "spring", "summer", "autumn", "winter"}}, {$CellContext`size, {
     "small", "medium", "large"}}, {$CellContext`speed, {
     "low", "medium", "high"}}}]]], "Output",
 CellChangeTimes->{{3.585488222741132*^9, 3.5854882306858253`*^9}, 
   3.585488306028277*^9, 3.585488884273045*^9, {3.585488915810055*^9, 
   3.585488931288856*^9}, {3.585489430692563*^9, 3.5854895009078493`*^9}, 
   3.585494610077166*^9, {3.585494801074929*^9, 3.585494819426066*^9}, 
   3.585996779404904*^9, 3.586085690903776*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Columnized Usage", "Title",
 CellChangeTimes->{{3.520677779770745*^9, 3.5206777856383314`*^9}, {
   3.572201436467568*^9, 3.572201440184266*^9}, 3.574003889138953*^9, {
   3.574003929443994*^9, 3.5740039544898233`*^9}, {3.574084215345809*^9, 
   3.574084218047209*^9}, {3.5854080238545322`*^9, 3.5854080282497187`*^9}, {
   3.585408994993483*^9, 3.585408996183156*^9}, {3.585413910750842*^9, 
   3.585413915406839*^9}, {3.5854862006390257`*^9, 3.585486200990789*^9}, {
   3.585488834496768*^9, 3.5854888519915323`*^9}, {3.5854895433689327`*^9, 
   3.585489547905244*^9}}],

Cell["Contents of a column:", "Text",
 CellChangeTimes->{{3.5860962747460737`*^9, 3.586096278106172*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"med", "[", "Cl", "]"}], "//", "Short"}]], "Input",
 CellChangeTimes->{{3.58541518957712*^9, 3.5854151952789288`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"{", 
   RowBox[{
   "60.8`", ",", "57.75`", ",", "40.02`", ",", "77.364`", ",", "55.35`", ",", 
    RowBox[{"\[LeftSkeleton]", "180", "\[RightSkeleton]"}], ",", "12.444`", 
    ",", "17.375`", ",", "14.32`", ",", "139.989`", ",", "82.852`"}], "}"}],
  Short]], "Output",
 CellChangeTimes->{3.585415195661173*^9, 3.5854946189875517`*^9, 
  3.585996787746916*^9, 3.586085696113658*^9, 3.586088726328302*^9, 
  3.586089206651712*^9}]
}, Open  ]],

Cell["Note that doesn\[CloseCurlyQuote]t include missing values.", "Text",
 CellChangeTimes->{{3.5854813887631683`*^9, 3.5854813967943087`*^9}, {
  3.585492995810348*^9, 3.5854930026826677`*^9}}],

Cell["Positions of missing orthophosphate values:", "Text",
 CellChangeTimes->{{3.585481408385681*^9, 3.5854814133456182`*^9}, {
  3.585489825876638*^9, 3.585489829482848*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"med", "[", 
  RowBox[{"oPO4", ",", "\"\<missing\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.5854152139189053`*^9, 3.5854152250508413`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", "62", "}"}], ",", 
   RowBox[{"{", "199", "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.585415225419427*^9, 3.5854946258268023`*^9, 
  3.585996797064768*^9, 3.586085697716559*^9}]
}, Open  ]],

Cell["Ask for \[OpenCurlyDoubleQuote]raw\[CloseCurlyDoubleQuote] data to get \
the missing values too:", "Text",
 CellChangeTimes->{{3.585415346164249*^9, 3.585415366963999*^9}, {
  3.585481443274592*^9, 3.5854814452408648`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "/@", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"med", "[", 
     RowBox[{"oPO4", ",", "\"\<raw\>\""}], "]"}], ",", 
    RowBox[{"med", "[", "oPO4", "]"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.585415368972703*^9, 3.5854154095889177`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"200", ",", "198"}], "}"}]], "Output",
 CellChangeTimes->{{3.585415391109098*^9, 3.585415410173455*^9}, 
   3.585996798728787*^9, 3.586020045005466*^9, 3.586085699243034*^9}]
}, Open  ]],

Cell["How often is algae level a4 greater than zero?", "Text",
 CellChangeTimes->{{3.585489806403802*^9, 3.585489820787202*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{"Count", "[", 
    RowBox[{
     RowBox[{"med", "[", "a4", "]"}], ",", 
     RowBox[{"_", "?", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"#", ">", "0."}], "&"}], ")"}]}]}], "]"}], "/", 
   RowBox[{"Length", "[", 
    RowBox[{"med", "[", "a4", "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.58541518957712*^9, 3.5854151952789288`*^9}, {
  3.5854895680202847`*^9, 3.585489570616952*^9}, {3.585489776798877*^9, 
  3.5854898021749496`*^9}, {3.585996868046129*^9, 3.5859968846193047`*^9}}],

Cell[BoxData["0.455`"], "Output",
 CellChangeTimes->{
  3.585489570760001*^9, {3.585489789818405*^9, 3.58548980283502*^9}, 
   3.5854946245281467`*^9, 3.585996799945475*^9, {3.5859968812859373`*^9, 
   3.585996885007079*^9}, 3.586020046468508*^9, 3.586085700496708*^9}]
}, Open  ]],

Cell["Factorized/nominal variables are tagged:", "Text",
 CellChangeTimes->{{3.5854814657765293`*^9, 3.5854814760884027`*^9}, {
  3.5860963037230043`*^9, 3.586096304801279*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"med", "[", 
  RowBox[{"All", ",", "\"\<nominals\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.5854152702695427`*^9, 3.585415285318194*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"season", ",", "size", ",", "speed"}], "}"}]], "Output",
 CellChangeTimes->{{3.585415277403702*^9, 3.585415285667509*^9}, 
   3.585489840489599*^9, 3.585996801270741*^9, 3.586020047770822*^9, 
   3.586085701617024*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"med", "[", 
  RowBox[{"season", ",", "\"\<factorized\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.585415232055071*^9, 3.585415266926569*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.585415268796856*^9, 3.5854898391060753`*^9, 
  3.585996802015946*^9, 3.5860200486431313`*^9, 3.5860857029999228`*^9}]
}, Open  ]],

Cell["Note the specified factor ordering is applied:", "Text",
 CellChangeTimes->{{3.5854898440512*^9, 3.585489850851042*^9}, {
  3.585493014587887*^9, 3.585493015818585*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"med", "[", 
  RowBox[{"season", ",", "\"\<factors\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.585415298549553*^9, 3.585415304561652*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"spring\"\>", ",", "\<\"summer\"\>", ",", "\<\"autumn\"\>", 
   ",", "\<\"winter\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.585415304907926*^9, 3.585489839657154*^9, 
  3.5859968031344213`*^9, 3.586020049845796*^9, 3.586085704258259*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Summary Statistics", "Title",
 CellChangeTimes->{{3.585417299136742*^9, 3.585417302023638*^9}}],

Cell["\<\
A statistical summary of the training set is a useful entry point.  Construct \
a table showing counts, mean, standard deviation, quartiles, min, and max, \
for each column.  For factorized variables, show a frequency table.\
\>", "Text",
 CellChangeTimes->{{3.585409007360567*^9, 3.585409022125017*^9}, {
  3.585413920023147*^9, 3.585413990652582*^9}, {3.5854155138898907`*^9, 
  3.585415564335779*^9}, {3.5854817914031487`*^9, 3.585481799721176*^9}, {
  3.58548183960981*^9, 3.585481866751459*^9}, {3.58548627810157*^9, 
  3.585486308588544*^9}, {3.585996966355702*^9, 3.585997016743228*^9}}],

Cell[CellGroupData[{

Cell["Summary statistics code", "Subsubsection",
 CellChangeTimes->{{3.5854827328220177`*^9, 3.5854827366375837`*^9}},
 FontColor->GrayLevel[0.5]],

Cell[TextData[{
 StyleBox["DataArray", "Input"],
 " (M10) contains a convenience function for this purpose.  Note the use of \
symbolic heads (FactorizedStats, NumericStats) to identify different column \
types."
}], "Text",
 CellChangeTimes->{{3.585485594403891*^9, 3.585485607314774*^9}, {
  3.5854858828386106`*^9, 3.585485925268175*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "@", "assembleColumnStats"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"assembleColumnStats", "[", 
   RowBox[{"set_", ",", "col_"}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"set", "[", 
     RowBox[{"col", ",", "\"\<factorized\>\""}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"FactorizedStats", "@@", 
     RowBox[{"Tally", "[", 
      RowBox[{"set", "[", "col", "]"}], "]"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"(*", " ", "else", " ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{"NumericStats", "@@", 
     RowBox[{"Join", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Length", "@", 
          RowBox[{"set", "[", "col", "]"}]}], ",", 
         RowBox[{"Length", "@", 
          RowBox[{"set", "[", 
           RowBox[{"col", ",", "\"\<missing\>\""}], "]"}]}]}], "}"}], ",", 
       RowBox[{"Flatten", "@", 
        RowBox[{"Through", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "Mean", ",", "StandardDeviation", ",", "Min", ",", "Quartiles", 
            ",", "Max"}], "}"}], "[", 
          RowBox[{"set", "[", "col", "]"}], "]"}], "]"}]}]}], 
      "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.585482177846198*^9, 3.585482213666293*^9}, {
  3.58548226889695*^9, 3.585482287729803*^9}, {3.58548231926411*^9, 
  3.585482371550304*^9}, {3.585482416711478*^9, 3.585482417439797*^9}, {
  3.585482499268777*^9, 3.5854825158424873`*^9}, {3.58548254970142*^9, 
  3.585482558739298*^9}, {3.5854826323289824`*^9, 3.585482651961802*^9}, {
  3.585482699672*^9, 3.5854827560875597`*^9}, {3.585482845542501*^9, 
  3.58548285128528*^9}, {3.585483088494141*^9, 3.585483092488036*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "@", "presentColumnStats"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"presentColumnStats", "[", 
   RowBox[{
    RowBox[{"s", ":", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"_FactorizedStats", "|", "_NumericStats"}], ")"}], ".."}], 
      "}"}]}], ",", "cols_"}], "]"}], ":=", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"numericLabels", "=", 
      RowBox[{"{", 
       RowBox[{
       "\"\<Not Missing\>\"", ",", "\"\<Missing\>\"", ",", "\[Mu]", ",", 
        "\[Sigma]", ",", "Min", ",", 
        RowBox[{"1", "/", "4"}], ",", 
        RowBox[{"1", "/", "2"}], ",", 
        RowBox[{"3", "/", "4"}], ",", "Max"}], "}"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Grid", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Join", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"List", "@", 
         RowBox[{"Prepend", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Style", "[", 
              RowBox[{"#", ",", "Bold"}], "]"}], "&"}], "/@", "cols"}], ",", 
           RowBox[{"Invisible", "[", "\"\<\>\"", "]"}]}], "]"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"List", "/@", "numericLabels"}], ",", "\[IndentingNewLine]", 
          RowBox[{"Transpose", "[", 
           RowBox[{"s", "/.", 
            RowBox[{"{", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{
               RowBox[{"NumericStats", "[", "x__", "]"}], "\[RuleDelayed]", 
               RowBox[{"List", "@", "x"}]}], ",", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"FactorizedStats", "[", "x__", "]"}], "\[RuleDelayed]", 
               RowBox[{"PadRight", "[", 
                RowBox[{
                 RowBox[{"List", "[", 
                  RowBox[{"Item", "[", 
                   RowBox[{
                    RowBox[{"Framed", "@", 
                    RowBox[{"Style", "[", 
                    RowBox[{
                    RowBox[{"Grid", "[", 
                    RowBox[{"List", "@", "x"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"Brown", ",", "Smaller"}], "}"}]}], "]"}]}], ",", 
                    RowBox[{"Alignment", "\[Rule]", "Center"}]}], "]"}], 
                  "]"}], ",", 
                 RowBox[{"Length", "@", "numericLabels"}], ",", 
                 "SpanFromAbove"}], "]"}]}]}], "\[IndentingNewLine]", "}"}]}],
            "]"}], ",", "\[IndentingNewLine]", "2"}], "\[IndentingNewLine]", 
         "]"}]}], "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Alignment", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"Center", ",", 
          RowBox[{"{", "Right", "}"}]}], "}"}], "}"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Background", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Automatic", ",", 
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"White", ",", "LightBlue"}], "}"}], "}"}]}], "}"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"ItemSize", "\[Rule]", "Full"}]}], "\[IndentingNewLine]", 
     "]"}]}], "\[IndentingNewLine]", "]"}]}]}], "Input",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQB2IQ/WeuHfORba8cG35rC4Fose5OKRB9/+JXBRAt889E
FyyfamkGom9sX+MAohlcZZxA9CR7KzcQnaXY5AGizXKigkE02zXlTBD9QFa+
DESfOpcOpnceDmoA0RpH5oLpWSvOt4HoM4v5O0D0twvafSC6P994MoiuUeec
BaKPrNCcDaK5L+1cDqJZNJxWgOilG/S3g+hlqi5geuZ18d1gd1+WOAvWJ/L7
AojuEjJ+CqJj5s94CaINEw6C6SJNq/cg+sR5xg8gurjl1GcQ7fT75w8wPWUW
81GQ+7hs2EG0rNxacRCdp79NAkT3HHwuB6LFql8og+mJDRog+nr5KQMQ3cf4
PwREb2uJDwXRACoB0f8=
  "]],

Cell[BoxData[
 RowBox[{
  RowBox[{"summaryStats", "[", "set_", "]"}], ":=", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"stats", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"assembleColumnStats", "[", 
         RowBox[{"set", ",", "#"}], "]"}], "&"}], "/@", 
       RowBox[{"set", "[", 
        RowBox[{"All", ",", "\"\<columns\>\""}], "]"}]}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"presentColumnStats", "[", 
     RowBox[{"stats", ",", "columns"}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.585485705031239*^9, 3.585485713352837*^9}, {
  3.5854857894591827`*^9, 3.585485826855815*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Summary", "Subsubsection",
 CellChangeTimes->{{3.585485684834043*^9, 3.585485685721272*^9}}],

Cell["\<\
Note the frequency of missing data by feature, and the variance in the \
feature measurements.  The nominal variables are pretty evenly distributed, \
but we don\[CloseCurlyQuote]t have as much data on large, slow rivers.\
\>", "Text",
 CellChangeTimes->{{3.5854859723313828`*^9, 3.5854859983949003`*^9}, {
  3.585488057699121*^9, 3.585488098201132*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Style", "[", 
  RowBox[{
   RowBox[{"stylize", "@", 
    RowBox[{"summaryStats", "[", "med", "]"}]}], ",", "11"}], "]"}]], "Input",
 CellChangeTimes->{{3.585485228492116*^9, 3.585485249282999*^9}, {
  3.585485284850175*^9, 3.585485356681161*^9}, {3.5854854943343678`*^9, 
  3.585485494494488*^9}, {3.585485541542803*^9, 3.585485566590453*^9}, {
  3.585485627616864*^9, 3.585485627771282*^9}, {3.585485831561302*^9, 
  3.585485843630846*^9}}],

Cell[BoxData[
 StyleBox[
  StyleBox[
   TagBox[GridBox[{
      {
       StyleBox["\<\"\"\>",
        StripOnInput->False,
        ShowContents->False], 
       StyleBox["season",
        StripOnInput->False,
        FontWeight->Bold], 
       StyleBox["size",
        StripOnInput->False,
        FontWeight->Bold], 
       StyleBox["speed",
        StripOnInput->False,
        FontWeight->Bold], 
       StyleBox["mxPH",
        StripOnInput->False,
        FontWeight->Bold], 
       StyleBox["mnO2",
        StripOnInput->False,
        FontWeight->Bold], 
       StyleBox["Cl",
        StripOnInput->False,
        FontWeight->Bold], 
       StyleBox["NO3",
        StripOnInput->False,
        FontWeight->Bold], 
       StyleBox["NH4",
        StripOnInput->False,
        FontWeight->Bold], 
       StyleBox["oPO4",
        StripOnInput->False,
        FontWeight->Bold], 
       StyleBox["PO4",
        StripOnInput->False,
        FontWeight->Bold], 
       StyleBox["Chla",
        StripOnInput->False,
        FontWeight->Bold], 
       StyleBox["a1",
        StripOnInput->False,
        FontWeight->Bold], 
       StyleBox["a2",
        StripOnInput->False,
        FontWeight->Bold], 
       StyleBox["a3",
        StripOnInput->False,
        FontWeight->Bold], 
       StyleBox["a4",
        StripOnInput->False,
        FontWeight->Bold], 
       StyleBox["a5",
        StripOnInput->False,
        FontWeight->Bold], 
       StyleBox["a6",
        StripOnInput->False,
        FontWeight->Bold], 
       StyleBox["a7",
        StripOnInput->False,
        FontWeight->Bold]},
      {"\<\"Not Missing\"\>", 
       ItemBox[
        FrameBox[
         StyleBox[
          TagBox[GridBox[{
             {"\<\"winter\"\>", "62"},
             {"\<\"spring\"\>", "53"},
             {"\<\"autumn\"\>", "40"},
             {"\<\"summer\"\>", "45"}
            },
            AutoDelete->False,
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Grid"],
          StripOnInput->False,
          LineColor->RGBColor[0.6, 0.4, 0.2],
          FrontFaceColor->RGBColor[0.6, 0.4, 0.2],
          BackFaceColor->RGBColor[0.6, 0.4, 0.2],
          GraphicsColor->RGBColor[0.6, 0.4, 0.2],
          FontSize->Smaller,
          FontColor->RGBColor[0.6, 0.4, 0.2]],
         StripOnInput->False],
        Alignment->Center,
        StripOnInput->False], 
       ItemBox[
        FrameBox[
         StyleBox[
          TagBox[GridBox[{
             {"\<\"small\"\>", "71"},
             {"\<\"medium\"\>", "84"},
             {"\<\"large\"\>", "45"}
            },
            AutoDelete->False,
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Grid"],
          StripOnInput->False,
          LineColor->RGBColor[0.6, 0.4, 0.2],
          FrontFaceColor->RGBColor[0.6, 0.4, 0.2],
          BackFaceColor->RGBColor[0.6, 0.4, 0.2],
          GraphicsColor->RGBColor[0.6, 0.4, 0.2],
          FontSize->Smaller,
          FontColor->RGBColor[0.6, 0.4, 0.2]],
         StripOnInput->False],
        Alignment->Center,
        StripOnInput->False], 
       ItemBox[
        FrameBox[
         StyleBox[
          TagBox[GridBox[{
             {"\<\"medium\"\>", "83"},
             {"\<\"high\"\>", "84"},
             {"\<\"low\"\>", "33"}
            },
            AutoDelete->False,
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Grid"],
          StripOnInput->False,
          LineColor->RGBColor[0.6, 0.4, 0.2],
          FrontFaceColor->RGBColor[0.6, 0.4, 0.2],
          BackFaceColor->RGBColor[0.6, 0.4, 0.2],
          GraphicsColor->RGBColor[0.6, 0.4, 0.2],
          FontSize->Smaller,
          FontColor->RGBColor[0.6, 0.4, 0.2]],
         StripOnInput->False],
        Alignment->Center,
        StripOnInput->False], "199", "198", "190", "198", "198", "198", "198",
        "188", "200", "200", "200", "200", "200", "200", "200"},
      {"\<\"Missing\"\>", "\[SpanFromAbove]", "\[SpanFromAbove]", 
       "\[SpanFromAbove]", "1", "2", "10", "2", "2", "2", "2", "12", "0", "0",
        "0", "0", "0", "0", "0"},
      {"\[Mu]", "\[SpanFromAbove]", "\[SpanFromAbove]", "\[SpanFromAbove]", 
       "8.011733668341707`", "9.117777777777775`", "43.636278842105284`", 
       "3.282388888888888`", "501.29582838383845`", "73.59059595959597`", 
       "137.882100959596`", "13.971196808510639`", "16.923499999999997`", 
       "7.458500000000003`", "4.309500000000001`", "1.9924999999999995`", 
       "5.064500000000001`", "5.9639999999999995`", "2.4954999999999985`"},
      {"\[Sigma]", "\[SpanFromAbove]", "\[SpanFromAbove]", "\[SpanFromAbove]",
        "0.598305379968375`", "2.391252695326172`", "46.831311376846685`", 
       "3.7764740780536203`", "1962.5454605856032`", "91.13643579938112`", 
       "128.99373839563003`", "20.495919958364123`", "21.348376134213094`", 
       "11.028201753667638`", "6.948537299533988`", "4.417404334592474`", 
       "7.491401419369453`", "11.660710305299613`", "5.158564109162715`"},
      {"Min", "\[SpanFromAbove]", "\[SpanFromAbove]", "\[SpanFromAbove]", 
       "5.6`", "1.5`", "0.222`", "0.05`", "5.`", "1.`", "1.`", "0.2`", "0.`", 
       "0.`", "0.`", "0.`", "0.`", "0.`", "0.`"},
      {
       FractionBox["1", "4"], "\[SpanFromAbove]", "\[SpanFromAbove]", 
       "\[SpanFromAbove]", "7.7`", "7.7`", "10.975`", "1.288`", "38.111`", 
       "15.6`", "40.667`", "2.`", "1.5`", "0.`", "0.`", "0.`", "0.`", "0.`", 
       "0.`"},
      {
       FractionBox["1", "2"], "\[SpanFromAbove]", "\[SpanFromAbove]", 
       "\[SpanFromAbove]", "8.06`", "9.8`", "32.730000000000004`", "2.675`", 
       "103.1665`", "40.15`", "103.2855`", "5.475`", "6.95`", "3.`", "1.55`", 
       "0.`", "1.9`", "0.`", "1.`"},
      {
       FractionBox["3", "4"], "\[SpanFromAbove]", "\[SpanFromAbove]", 
       "\[SpanFromAbove]", "8.4`", "10.8`", "57.848`", "4.459`", "227.60001`",
        "100.`", "214.`", "18.314999999999998`", "24.8`", "11.45`", "4.95`", 
       "2.4`", "7.5`", "6.95`", "2.4`"},
      {"Max", "\[SpanFromAbove]", "\[SpanFromAbove]", "\[SpanFromAbove]", 
       "9.7`", "13.4`", "391.5`", "45.65`", "24064.`", "564.59998`", 
       "771.59998`", "110.456`", "89.8`", "72.6`", "42.8`", "44.6`", "44.4`", 
       "77.6`", "31.6`"}
     },
     AutoDelete->False,
     GridBoxAlignment->{"Columns" -> {Center, {Right}}},
     GridBoxBackground->{"Columns" -> {{Automatic}}, "Rows" -> {{
          GrayLevel[1], 
          RGBColor[0.87, 0.94, 1]}}},
     GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}}],
    "Grid"],
   StripOnInput->False,
   FontFamily->"Verdana"],
  StripOnInput->False,
  FontSize->11]], "Output",
 CellChangeTimes->{
  3.585485250387195*^9, {3.585485303833335*^9, 3.585485357340412*^9}, {
   3.5854854852525673`*^9, 3.5854854946800823`*^9}, {3.585485543151022*^9, 
   3.585485567021538*^9}, 3.585485627940187*^9, 3.5854858539353456`*^9, 
   3.5854946340593243`*^9, 3.5859970238748703`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Basic Visualization", "Title",
 CellChangeTimes->{{3.585417299136742*^9, 3.585417302023638*^9}, {
  3.585486190840365*^9, 3.585486194479013*^9}}],

Cell["A histogram of a column:", "Text",
 CellChangeTimes->{{3.585409007360567*^9, 3.585409022125017*^9}, {
  3.585413920023147*^9, 3.585413990652582*^9}, {3.5854155138898907`*^9, 
  3.585415564335779*^9}, {3.5854817914031487`*^9, 3.585481799721176*^9}, {
  3.58548183960981*^9, 3.585481866751459*^9}, {3.58548621549551*^9, 
  3.585486233782075*^9}, {3.585486368100177*^9, 3.585486375659062*^9}, {
  3.585487812111656*^9, 3.58548781331898*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"col", "=", "mxPH"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Histogram", "[", 
    RowBox[{
     RowBox[{"med", "[", "col", "]"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"col", ",", "None"}], "}"}]}]}], "]"}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.585486247750313*^9, 3.585486261360203*^9}, {
   3.585486343913625*^9, 3.585486349888166*^9}, 3.585910794161278*^9}],

Cell[BoxData[
 GraphicsBox[
  {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
   EdgeForm[Opacity[0.637]], {}, 
   {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
    EdgeForm[Opacity[0.637]], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{5.5, 0}, {6., 2}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{12.5, 47.45918367346934}, {82.51003819110079, 
         88.25388532420594}}],
       StatusArea[#, 2]& ,
       TagBoxNote->"2"],
      StyleBox["2", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[2, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{6., 0}, {6.5, 1}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{46.45918367346934, 81.41836734693874}, {
         84.88196175765337, 88.25388532420594}}],
       StatusArea[#, 1]& ,
       TagBoxNote->"1"],
      StyleBox["1", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[1, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{6.5, 0}, {7., 6}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{80.41836734693874, 115.37755102040813`}, {
         73.02234392489049, 88.25388532420594}}],
       StatusArea[#, 6]& ,
       TagBoxNote->"6"],
      StyleBox["6", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[6, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{7., 0}, {7.5, 21}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{114.37755102040813`, 149.33673469387753`}, {
         37.44349042660188, 88.25388532420594}}],
       StatusArea[#, 21]& ,
       TagBoxNote->"21"],
      StyleBox["21", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[21, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{7.5, 0}, {8., 54}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{148.33673469387753`, 
         183.29591836734693`}, {-40.829987269633065`, 88.25388532420594}}],
       StatusArea[#, 54]& ,
       TagBoxNote->"54"],
      StyleBox["54", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[54, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{8., 0}, {8.5, 73}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{182.29591836734693`, 
         217.25510204081633`}, {-85.89653503413196, 88.25388532420594}}],
       StatusArea[#, 73]& ,
       TagBoxNote->"73"],
      StyleBox["73", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[73, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{8.5, 0}, {9., 33}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{216.25510204081633`, 251.21428571428572`}, {
         8.980407627971005, 88.25388532420594}}],
       StatusArea[#, 33]& ,
       TagBoxNote->"33"],
      StyleBox["33", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[33, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{9., 0}, {9.5, 7}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{250.21428571428572`, 285.1734693877551}, {
         70.65042035833793, 88.25388532420594}}],
       StatusArea[#, 7]& ,
       TagBoxNote->"7"],
      StyleBox["7", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[7, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{9.5, 0}, {10., 2}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{284.1734693877551, 319.1326530612245}, {
         82.51003819110079, 88.25388532420594}}],
       StatusArea[#, 2]& ,
       TagBoxNote->"2"],
      StyleBox["2", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[2, {
        GrayLevel[0]}], "Tooltip"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["mxPH", TraditionalForm], None},
  AxesOrigin->{5.5, 0},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  PlotRange->{{5.5, 10.}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.1]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.585486261844644*^9, {3.5854863442207813`*^9, 3.58548635020151*^9}, 
   3.58549464081363*^9, 3.5859107626234207`*^9, 3.585910803995391*^9, 
   3.5859970426515923`*^9}]
}, Open  ]],

Cell["Select the (numeric) column interactively:", "Text",
 CellChangeTimes->{{3.585482025263282*^9, 3.585482035837803*^9}, {
  3.585482164579393*^9, 3.5854821655732803`*^9}, {3.585486437022361*^9, 
  3.585486446401904*^9}, {3.585487897525622*^9, 3.585487901932712*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Histogram", "[", 
    RowBox[{
     RowBox[{"med", "[", "col", "]"}], ",", "bins", ",", "\"\<Count\>\"", ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"col", ",", "None"}], "}"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"col", ",", 
       RowBox[{"columns", "[", 
        RowBox[{"[", "4", "]"}], "]"}], ",", "\"\<Column\>\""}], "}"}], ",", 
     RowBox[{"columns", "[", 
      RowBox[{"[", 
       RowBox[{"4", ";;"}], "]"}], "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"bins", ",", "Automatic", ",", "\"\<Bins\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Automatic", ",", "25", ",", "50"}], "}"}]}], "}"}], 
   "\[IndentingNewLine]", ",", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{{3.585486247750313*^9, 3.585486261360203*^9}, {
  3.585486343913625*^9, 3.585486349888166*^9}, {3.585486462155045*^9, 
  3.58548654609632*^9}, {3.5854865971915703`*^9, 3.585486598687907*^9}, {
  3.585487884494718*^9, 3.585487994652224*^9}, {3.5860888018347673`*^9, 
  3.586088808189536*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`bins$$ = 
    25, $CellContext`col$$ = $CellContext`mxPH, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`col$$], $CellContext`mxPH, 
       "Column"}, {$CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}}, {{
       Hold[$CellContext`bins$$], Automatic, "Bins"}, {Automatic, 25, 50}}}, 
    Typeset`size$$ = {360., {101., 106.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`col$3973$$ = 0, $CellContext`bins$3974$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`bins$$ = 
        Automatic, $CellContext`col$$ = $CellContext`mxPH}, 
      "ControllerVariables" :> {
        Hold[$CellContext`col$$, $CellContext`col$3973$$, 0], 
        Hold[$CellContext`bins$$, $CellContext`bins$3974$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Histogram[
        $CellContext`med[$CellContext`col$$], $CellContext`bins$$, "Count", 
        AxesLabel -> {$CellContext`col$$, None}], 
      "Specifications" :> {{{$CellContext`col$$, $CellContext`mxPH, 
          "Column"}, {$CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}}, \
{{$CellContext`bins$$, Automatic, "Bins"}, {Automatic, 25, 50}}}, 
      "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{405., {157., 162.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`med = $CellContext`sym$2505, 
       Attributes[$CellContext`sym$2505] = {
        Temporary}, $CellContext`sym$2505[$CellContext`a1] = Part[
         $CellContext`sym$2505[$CellContext`a1, "raw"], 
         Complement[
          Range[
           
           Length[{{
             "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 
              170., 50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
             "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 
              428.75, 558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
             "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
              125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
             "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
              61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
             "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 
              58.222, 97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
             "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25,
               56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
             "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25,
               111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
             "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
              44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
             "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 
              36.3, 71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
             "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6,
               0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
             "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
              20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
             "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 
              10.667, 19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
             "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 
              17., 41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
             "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 
              0.5, 31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
             "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
              0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
             "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
              98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
             "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 
              50., 1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
             "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
              57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
             "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 
              61.5, 0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
             "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
              564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
             "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 
              467.5, 586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
             "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
              0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
             "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 
              40., 7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
             "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 
              3., 27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
             "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 
              11.5, 1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
             "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
              44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
             "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6,
               0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
             "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
              Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
             "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 
              0.8, 17.1, 0., 19.6, 0., 0., 0., 2.5}, {
             "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 
              0.5, 33.9, 1., 14.6, 0., 0., 0., 0.}, {
             "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
              4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
             "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304.,
               2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
             "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
              130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
             "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 
              47., 2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
             "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 
              23., 0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
             "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
              58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
             "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 
              3., 0.2, 66., 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 8., 
              Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 
              0., 0.}, {
             "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
              196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
             "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001,
               182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
             "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 
              143.71001, 296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
             "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
              59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
             "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
              344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
             "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
              276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
             "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
              40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
             "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5,
               3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
             "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
              0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {
             "winter", "small", "low", 
              Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 
              0., 0., 0.}, {
             "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121.,
               2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
             "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
              20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
             "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 
              12.75, 49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
             "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3,
               22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
             "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
              11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 
              11.818, 0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
             "winter", "small", "high", 6.6, 10.8, 
              Missing[], 3.245, 10., 1., 6.5, 
              Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "medium", 5.6, 11.8, 
              Missing[], 2.22, 5., 1., 1., 
              Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
             "autumn", "small", "medium", 5.7, 10.8, 
              Missing[], 2.55, 10., 1., 4., 
              Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
             "spring", "small", "high", 6.6, 9.5, 
              Missing[], 1.32, 20., 1., 6., 
              Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
             "summer", "small", "high", 6.6, 10.8, 
              Missing[], 2.64, 10., 2., 11., 
              Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
             "autumn", "small", "medium", 6.6, 11.3, 
              Missing[], 4.17, 10., 1., 6., 
              Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
             "spring", "small", "medium", 6.5, 10.4, 
              Missing[], 5.97, 10., 2., 14., 
              Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
             "summer", "small", "medium", 6.4, 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 14., 
              Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
             "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
              6.667, 
              Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 
              6.75, 1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
             "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 
              7.2, 0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
             "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 
              6., 0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
             "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
              10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
             "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 
              2.5, 0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
             "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 
              220.75, 351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
             "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
              209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
             "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
              151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
             "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
              152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
             "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 
              55., 58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
             "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 
              136.75, 249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
             "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
              100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
             "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
              215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
             "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
              25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
             "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36.,
               105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
             "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 
              37.375, 111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
             "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 
              108., 1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
             "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
              56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
             "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 
              60., 4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
             "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 
              27.667, 104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
             "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32.,
               69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
             "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 
              111.25, 214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
             "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 
              137.60001, 254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
             "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 
              429.20001, 57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 
              16.7}, {"winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 
              5738.33008, 412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0.,
               2.4}, {"summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 
              4073.33008, 282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 
              9.9, 0.}, {
             "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
              197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
             "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
              267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
             "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
              191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
             "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 
              120.5, 232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
             "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
              144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
             "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
              218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
             "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23.,
               138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
             "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 
              104.222, 239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
             "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
              235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
             "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 
              51.75, 205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
             "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
              31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
             "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 
              28.625, 186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
             "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
              12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
             "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
              51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
             "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 
              104.5, 292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
             "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 
              38.625, 285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
             "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 
              24.667, 201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
             "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
              275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
             "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 
              39., 124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
             "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
              60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
             "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 
              71., 132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
             "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 
              9.667, 17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
             "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 
              26., 0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
             "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
              8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
             "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
              37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
             "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 
              37., 86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
             "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444,
               10.111, 
              Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
             "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
              16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
             "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 
              3.545, 13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
             "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
              261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
             "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 
              238.2, 320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
             "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499,
               144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
             "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
              166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
             "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 
              181., 222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
             "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
              36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
             "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 
              61.556, 127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
             "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625,
               89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
             "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
              55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
             "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
              102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
             "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
              75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
             "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 
              34.636, 72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
             "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
              48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
             "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
              48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
             "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 
              3466.65991, 23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
             "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173.,
               317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
             "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
              84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
             "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 
              213., 2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
             "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
              88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
             "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 
              115., 11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
             "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
              98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
             "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5,
               143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
             "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 
              132.5, 197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
             "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2,
               1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
             "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
              10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
             "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
              200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
             "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
              77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
             "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 
              47.5, 276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
             "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 
              46.667, 123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
             "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
              75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
             "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48.,
               116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
             "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
              188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
             "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39.,
               72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
             "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 
              116.2, 16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
             "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 
              44., 34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
             "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
              27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
             "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 
              24., 58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
             "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
              175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
             "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 
              236., 22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
             "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 
              125.8, 26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
             "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 
              20.667, 54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
             "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 
              75.333, 34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
             "spring", "large", "low", 9., 5.8, 
              Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 
              0., 0., 0.}, {
             "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
              151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
             "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 
              180.66701, 269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
             "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
              46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
             "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
              85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
             "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
              66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
             "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
              102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
             "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
              84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
             "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 
              221.89999, 246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 
              1.7}, {"autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 
              627.27301, 205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 
              0.}, {"winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 
              1168., 236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 
              17.2, 0.}, {
             "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
              1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0.,
               5.9, 1.7}, {
             "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
              82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
             "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
              64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
             "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
              87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
             "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
              159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
             "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
              21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
             "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 
              11., 0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
             "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 
              7.667, 14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
             "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 
              3.222, 7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
             "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2,
               0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
             "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
              7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
             "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16.,
               2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
             "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
              56.091, 
              Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
             "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625,
               52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
             "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
              104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
             "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3,
               85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
             "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
              87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
             "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
              101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
             "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
              50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
             "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 
              34.5, 81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
             "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
              19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
             "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 
              19.111, 120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
             "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
              51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
             "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
              19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
             "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 
              53.625, 79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
             "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 
              35.333, 75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
             "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 
              78.333, 140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
             "winter", "large", "medium", 8., 7.6, 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
             "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
              140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
          Flatten[
           $CellContext`sym$2505[$CellContext`a1, 
            "missing"]]]], $CellContext`sym$2505[$CellContext`a2] = Part[
         $CellContext`sym$2505[$CellContext`a2, "raw"], 
         Complement[
          Range[
           
           Length[{{
             "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 
              170., 50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
             "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 
              428.75, 558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
             "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
              125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
             "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
              61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
             "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 
              58.222, 97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
             "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25,
               56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
             "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25,
               111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
             "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
              44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
             "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 
              36.3, 71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
             "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6,
               0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
             "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
              20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
             "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 
              10.667, 19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
             "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 
              17., 41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
             "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 
              0.5, 31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
             "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
              0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
             "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
              98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
             "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 
              50., 1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
             "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
              57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
             "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 
              61.5, 0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
             "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
              564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
             "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 
              467.5, 586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
             "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
              0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
             "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 
              40., 7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
             "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 
              3., 27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
             "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 
              11.5, 1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
             "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
              44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
             "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6,
               0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
             "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
              Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
             "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 
              0.8, 17.1, 0., 19.6, 0., 0., 0., 2.5}, {
             "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 
              0.5, 33.9, 1., 14.6, 0., 0., 0., 0.}, {
             "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
              4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
             "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304.,
               2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
             "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
              130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
             "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 
              47., 2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
             "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 
              23., 0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
             "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
              58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
             "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 
              3., 0.2, 66., 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 8., 
              Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 
              0., 0.}, {
             "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
              196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
             "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001,
               182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
             "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 
              143.71001, 296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
             "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
              59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
             "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
              344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
             "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
              276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
             "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
              40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
             "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5,
               3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
             "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
              0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {
             "winter", "small", "low", 
              Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 
              0., 0., 0.}, {
             "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121.,
               2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
             "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
              20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
             "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 
              12.75, 49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
             "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3,
               22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
             "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
              11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 
              11.818, 0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
             "winter", "small", "high", 6.6, 10.8, 
              Missing[], 3.245, 10., 1., 6.5, 
              Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "medium", 5.6, 11.8, 
              Missing[], 2.22, 5., 1., 1., 
              Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
             "autumn", "small", "medium", 5.7, 10.8, 
              Missing[], 2.55, 10., 1., 4., 
              Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
             "spring", "small", "high", 6.6, 9.5, 
              Missing[], 1.32, 20., 1., 6., 
              Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
             "summer", "small", "high", 6.6, 10.8, 
              Missing[], 2.64, 10., 2., 11., 
              Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
             "autumn", "small", "medium", 6.6, 11.3, 
              Missing[], 4.17, 10., 1., 6., 
              Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
             "spring", "small", "medium", 6.5, 10.4, 
              Missing[], 5.97, 10., 2., 14., 
              Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
             "summer", "small", "medium", 6.4, 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 14., 
              Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
             "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
              6.667, 
              Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 
              6.75, 1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
             "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 
              7.2, 0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
             "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 
              6., 0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
             "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
              10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
             "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 
              2.5, 0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
             "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 
              220.75, 351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
             "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
              209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
             "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
              151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
             "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
              152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
             "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 
              55., 58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
             "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 
              136.75, 249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
             "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
              100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
             "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
              215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
             "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
              25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
             "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36.,
               105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
             "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 
              37.375, 111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
             "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 
              108., 1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
             "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
              56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
             "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 
              60., 4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
             "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 
              27.667, 104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
             "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32.,
               69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
             "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 
              111.25, 214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
             "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 
              137.60001, 254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
             "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 
              429.20001, 57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 
              16.7}, {"winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 
              5738.33008, 412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0.,
               2.4}, {"summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 
              4073.33008, 282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 
              9.9, 0.}, {
             "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
              197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
             "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
              267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
             "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
              191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
             "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 
              120.5, 232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
             "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
              144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
             "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
              218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
             "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23.,
               138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
             "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 
              104.222, 239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
             "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
              235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
             "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 
              51.75, 205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
             "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
              31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
             "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 
              28.625, 186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
             "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
              12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
             "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
              51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
             "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 
              104.5, 292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
             "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 
              38.625, 285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
             "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 
              24.667, 201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
             "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
              275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
             "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 
              39., 124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
             "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
              60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
             "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 
              71., 132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
             "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 
              9.667, 17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
             "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 
              26., 0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
             "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
              8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
             "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
              37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
             "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 
              37., 86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
             "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444,
               10.111, 
              Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
             "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
              16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
             "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 
              3.545, 13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
             "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
              261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
             "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 
              238.2, 320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
             "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499,
               144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
             "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
              166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
             "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 
              181., 222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
             "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
              36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
             "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 
              61.556, 127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
             "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625,
               89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
             "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
              55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
             "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
              102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
             "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
              75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
             "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 
              34.636, 72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
             "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
              48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
             "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
              48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
             "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 
              3466.65991, 23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
             "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173.,
               317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
             "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
              84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
             "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 
              213., 2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
             "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
              88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
             "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 
              115., 11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
             "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
              98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
             "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5,
               143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
             "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 
              132.5, 197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
             "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2,
               1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
             "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
              10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
             "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
              200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
             "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
              77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
             "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 
              47.5, 276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
             "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 
              46.667, 123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
             "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
              75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
             "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48.,
               116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
             "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
              188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
             "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39.,
               72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
             "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 
              116.2, 16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
             "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 
              44., 34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
             "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
              27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
             "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 
              24., 58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
             "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
              175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
             "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 
              236., 22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
             "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 
              125.8, 26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
             "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 
              20.667, 54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
             "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 
              75.333, 34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
             "spring", "large", "low", 9., 5.8, 
              Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 
              0., 0., 0.}, {
             "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
              151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
             "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 
              180.66701, 269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
             "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
              46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
             "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
              85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
             "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
              66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
             "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
              102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
             "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
              84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
             "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 
              221.89999, 246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 
              1.7}, {"autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 
              627.27301, 205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 
              0.}, {"winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 
              1168., 236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 
              17.2, 0.}, {
             "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
              1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0.,
               5.9, 1.7}, {
             "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
              82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
             "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
              64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
             "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
              87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
             "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
              159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
             "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
              21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
             "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 
              11., 0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
             "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 
              7.667, 14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
             "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 
              3.222, 7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
             "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2,
               0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
             "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
              7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
             "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16.,
               2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
             "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
              56.091, 
              Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
             "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625,
               52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
             "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
              104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
             "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3,
               85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
             "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
              87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
             "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
              101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
             "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
              50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
             "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 
              34.5, 81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
             "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
              19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
             "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 
              19.111, 120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
             "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
              51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
             "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
              19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
             "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 
              53.625, 79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
             "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 
              35.333, 75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
             "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 
              78.333, 140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
             "winter", "large", "medium", 8., 7.6, 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
             "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
              140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
          Flatten[
           $CellContext`sym$2505[$CellContext`a2, 
            "missing"]]]], $CellContext`sym$2505[$CellContext`a3] = Part[
         $CellContext`sym$2505[$CellContext`a3, "raw"], 
         Complement[
          Range[
           
           Length[{{
             "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 
              170., 50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
             "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 
              428.75, 558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
             "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
              125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
             "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
              61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
             "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 
              58.222, 97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
             "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25,
               56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
             "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25,
               111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
             "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
              44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
             "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 
              36.3, 71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
             "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6,
               0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
             "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
              20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
             "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 
              10.667, 19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
             "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 
              17., 41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
             "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 
              0.5, 31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
             "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
              0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
             "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
              98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
             "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 
              50., 1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
             "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
              57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
             "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 
              61.5, 0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
             "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
              564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
             "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 
              467.5, 586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
             "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
              0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
             "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 
              40., 7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
             "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 
              3., 27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
             "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 
              11.5, 1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
             "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
              44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
             "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6,
               0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
             "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
              Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
             "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 
              0.8, 17.1, 0., 19.6, 0., 0., 0., 2.5}, {
             "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 
              0.5, 33.9, 1., 14.6, 0., 0., 0., 0.}, {
             "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
              4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
             "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304.,
               2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
             "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
              130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
             "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 
              47., 2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
             "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 
              23., 0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
             "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
              58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
             "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 
              3., 0.2, 66., 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 8., 
              Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 
              0., 0.}, {
             "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
              196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
             "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001,
               182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
             "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 
              143.71001, 296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
             "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
              59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
             "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
              344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
             "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
              276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
             "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
              40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
             "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5,
               3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
             "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
              0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {
             "winter", "small", "low", 
              Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 
              0., 0., 0.}, {
             "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121.,
               2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
             "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
              20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
             "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 
              12.75, 49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
             "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3,
               22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
             "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
              11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 
              11.818, 0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
             "winter", "small", "high", 6.6, 10.8, 
              Missing[], 3.245, 10., 1., 6.5, 
              Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "medium", 5.6, 11.8, 
              Missing[], 2.22, 5., 1., 1., 
              Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
             "autumn", "small", "medium", 5.7, 10.8, 
              Missing[], 2.55, 10., 1., 4., 
              Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
             "spring", "small", "high", 6.6, 9.5, 
              Missing[], 1.32, 20., 1., 6., 
              Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
             "summer", "small", "high", 6.6, 10.8, 
              Missing[], 2.64, 10., 2., 11., 
              Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
             "autumn", "small", "medium", 6.6, 11.3, 
              Missing[], 4.17, 10., 1., 6., 
              Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
             "spring", "small", "medium", 6.5, 10.4, 
              Missing[], 5.97, 10., 2., 14., 
              Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
             "summer", "small", "medium", 6.4, 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 14., 
              Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
             "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
              6.667, 
              Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 
              6.75, 1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
             "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 
              7.2, 0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
             "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 
              6., 0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
             "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
              10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
             "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 
              2.5, 0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
             "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 
              220.75, 351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
             "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
              209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
             "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
              151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
             "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
              152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
             "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 
              55., 58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
             "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 
              136.75, 249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
             "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
              100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
             "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
              215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
             "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
              25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
             "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36.,
               105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
             "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 
              37.375, 111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
             "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 
              108., 1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
             "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
              56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
             "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 
              60., 4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
             "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 
              27.667, 104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
             "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32.,
               69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
             "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 
              111.25, 214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
             "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 
              137.60001, 254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
             "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 
              429.20001, 57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 
              16.7}, {"winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 
              5738.33008, 412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0.,
               2.4}, {"summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 
              4073.33008, 282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 
              9.9, 0.}, {
             "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
              197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
             "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
              267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
             "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
              191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
             "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 
              120.5, 232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
             "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
              144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
             "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
              218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
             "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23.,
               138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
             "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 
              104.222, 239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
             "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
              235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
             "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 
              51.75, 205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
             "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
              31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
             "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 
              28.625, 186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
             "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
              12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
             "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
              51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
             "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 
              104.5, 292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
             "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 
              38.625, 285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
             "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 
              24.667, 201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
             "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
              275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
             "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 
              39., 124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
             "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
              60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
             "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 
              71., 132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
             "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 
              9.667, 17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
             "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 
              26., 0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
             "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
              8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
             "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
              37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
             "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 
              37., 86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
             "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444,
               10.111, 
              Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
             "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
              16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
             "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 
              3.545, 13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
             "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
              261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
             "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 
              238.2, 320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
             "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499,
               144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
             "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
              166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
             "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 
              181., 222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
             "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
              36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
             "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 
              61.556, 127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
             "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625,
               89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
             "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
              55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
             "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
              102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
             "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
              75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
             "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 
              34.636, 72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
             "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
              48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
             "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
              48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
             "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 
              3466.65991, 23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
             "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173.,
               317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
             "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
              84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
             "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 
              213., 2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
             "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
              88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
             "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 
              115., 11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
             "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
              98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
             "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5,
               143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
             "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 
              132.5, 197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
             "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2,
               1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
             "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
              10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
             "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
              200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
             "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
              77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
             "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 
              47.5, 276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
             "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 
              46.667, 123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
             "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
              75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
             "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48.,
               116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
             "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
              188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
             "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39.,
               72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
             "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 
              116.2, 16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
             "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 
              44., 34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
             "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
              27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
             "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 
              24., 58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
             "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
              175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
             "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 
              236., 22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
             "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 
              125.8, 26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
             "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 
              20.667, 54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
             "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 
              75.333, 34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
             "spring", "large", "low", 9., 5.8, 
              Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 
              0., 0., 0.}, {
             "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
              151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
             "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 
              180.66701, 269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
             "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
              46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
             "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
              85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
             "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
              66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
             "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
              102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
             "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
              84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
             "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 
              221.89999, 246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 
              1.7}, {"autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 
              627.27301, 205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 
              0.}, {"winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 
              1168., 236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 
              17.2, 0.}, {
             "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
              1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0.,
               5.9, 1.7}, {
             "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
              82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
             "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
              64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
             "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
              87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
             "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
              159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
             "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
              21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
             "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 
              11., 0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
             "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 
              7.667, 14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
             "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 
              3.222, 7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
             "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2,
               0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
             "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
              7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
             "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16.,
               2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
             "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
              56.091, 
              Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
             "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625,
               52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
             "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
              104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
             "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3,
               85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
             "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
              87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
             "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
              101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
             "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
              50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
             "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 
              34.5, 81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
             "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
              19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
             "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 
              19.111, 120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
             "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
              51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
             "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
              19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
             "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 
              53.625, 79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
             "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 
              35.333, 75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
             "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 
              78.333, 140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
             "winter", "large", "medium", 8., 7.6, 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
             "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
              140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
          Flatten[
           $CellContext`sym$2505[$CellContext`a3, 
            "missing"]]]], $CellContext`sym$2505[$CellContext`a4] = Part[
         $CellContext`sym$2505[$CellContext`a4, "raw"], 
         Complement[
          Range[
           
           Length[{{
             "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 
              170., 50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
             "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 
              428.75, 558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
             "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
              125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
             "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
              61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
             "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 
              58.222, 97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
             "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25,
               56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
             "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25,
               111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
             "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
              44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
             "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 
              36.3, 71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
             "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6,
               0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
             "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
              20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
             "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 
              10.667, 19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
             "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 
              17., 41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
             "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 
              0.5, 31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
             "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
              0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
             "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
              98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
             "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 
              50., 1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
             "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
              57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
             "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 
              61.5, 0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
             "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
              564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
             "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 
              467.5, 586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
             "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
              0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
             "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 
              40., 7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
             "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 
              3., 27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
             "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 
              11.5, 1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
             "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
              44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
             "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6,
               0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
             "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
              Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
             "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 
              0.8, 17.1, 0., 19.6, 0., 0., 0., 2.5}, {
             "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 
              0.5, 33.9, 1., 14.6, 0., 0., 0., 0.}, {
             "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
              4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
             "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304.,
               2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
             "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
              130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
             "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 
              47., 2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
             "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 
              23., 0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
             "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
              58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
             "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 
              3., 0.2, 66., 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 8., 
              Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 
              0., 0.}, {
             "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
              196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
             "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001,
               182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
             "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 
              143.71001, 296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
             "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
              59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
             "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
              344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
             "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
              276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
             "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
              40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
             "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5,
               3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
             "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
              0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {
             "winter", "small", "low", 
              Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 
              0., 0., 0.}, {
             "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121.,
               2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
             "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
              20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
             "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 
              12.75, 49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
             "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3,
               22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
             "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
              11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 
              11.818, 0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
             "winter", "small", "high", 6.6, 10.8, 
              Missing[], 3.245, 10., 1., 6.5, 
              Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "medium", 5.6, 11.8, 
              Missing[], 2.22, 5., 1., 1., 
              Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
             "autumn", "small", "medium", 5.7, 10.8, 
              Missing[], 2.55, 10., 1., 4., 
              Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
             "spring", "small", "high", 6.6, 9.5, 
              Missing[], 1.32, 20., 1., 6., 
              Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
             "summer", "small", "high", 6.6, 10.8, 
              Missing[], 2.64, 10., 2., 11., 
              Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
             "autumn", "small", "medium", 6.6, 11.3, 
              Missing[], 4.17, 10., 1., 6., 
              Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
             "spring", "small", "medium", 6.5, 10.4, 
              Missing[], 5.97, 10., 2., 14., 
              Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
             "summer", "small", "medium", 6.4, 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 14., 
              Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
             "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
              6.667, 
              Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 
              6.75, 1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
             "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 
              7.2, 0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
             "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 
              6., 0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
             "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
              10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
             "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 
              2.5, 0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
             "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 
              220.75, 351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
             "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
              209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
             "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
              151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
             "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
              152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
             "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 
              55., 58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
             "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 
              136.75, 249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
             "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
              100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
             "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
              215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
             "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
              25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
             "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36.,
               105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
             "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 
              37.375, 111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
             "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 
              108., 1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
             "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
              56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
             "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 
              60., 4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
             "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 
              27.667, 104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
             "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32.,
               69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
             "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 
              111.25, 214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
             "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 
              137.60001, 254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
             "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 
              429.20001, 57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 
              16.7}, {"winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 
              5738.33008, 412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0.,
               2.4}, {"summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 
              4073.33008, 282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 
              9.9, 0.}, {
             "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
              197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
             "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
              267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
             "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
              191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
             "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 
              120.5, 232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
             "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
              144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
             "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
              218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
             "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23.,
               138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
             "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 
              104.222, 239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
             "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
              235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
             "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 
              51.75, 205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
             "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
              31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
             "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 
              28.625, 186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
             "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
              12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
             "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
              51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
             "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 
              104.5, 292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
             "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 
              38.625, 285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
             "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 
              24.667, 201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
             "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
              275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
             "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 
              39., 124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
             "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
              60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
             "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 
              71., 132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
             "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 
              9.667, 17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
             "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 
              26., 0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
             "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
              8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
             "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
              37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
             "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 
              37., 86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
             "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444,
               10.111, 
              Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
             "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
              16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
             "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 
              3.545, 13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
             "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
              261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
             "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 
              238.2, 320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
             "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499,
               144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
             "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
              166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
             "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 
              181., 222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
             "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
              36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
             "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 
              61.556, 127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
             "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625,
               89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
             "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
              55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
             "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
              102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
             "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
              75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
             "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 
              34.636, 72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
             "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
              48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
             "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
              48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
             "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 
              3466.65991, 23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
             "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173.,
               317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
             "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
              84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
             "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 
              213., 2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
             "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
              88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
             "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 
              115., 11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
             "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
              98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
             "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5,
               143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
             "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 
              132.5, 197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
             "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2,
               1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
             "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
              10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
             "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
              200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
             "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
              77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
             "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 
              47.5, 276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
             "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 
              46.667, 123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
             "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
              75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
             "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48.,
               116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
             "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
              188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
             "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39.,
               72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
             "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 
              116.2, 16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
             "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 
              44., 34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
             "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
              27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
             "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 
              24., 58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
             "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
              175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
             "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 
              236., 22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
             "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 
              125.8, 26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
             "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 
              20.667, 54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
             "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 
              75.333, 34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
             "spring", "large", "low", 9., 5.8, 
              Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 
              0., 0., 0.}, {
             "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
              151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
             "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 
              180.66701, 269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
             "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
              46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
             "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
              85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
             "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
              66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
             "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
              102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
             "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
              84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
             "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 
              221.89999, 246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 
              1.7}, {"autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 
              627.27301, 205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 
              0.}, {"winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 
              1168., 236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 
              17.2, 0.}, {
             "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
              1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0.,
               5.9, 1.7}, {
             "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
              82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
             "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
              64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
             "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
              87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
             "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
              159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
             "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
              21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
             "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 
              11., 0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
             "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 
              7.667, 14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
             "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 
              3.222, 7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
             "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2,
               0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
             "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
              7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
             "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16.,
               2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
             "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
              56.091, 
              Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
             "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625,
               52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
             "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
              104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
             "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3,
               85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
             "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
              87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
             "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
              101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
             "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
              50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
             "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 
              34.5, 81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
             "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
              19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
             "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 
              19.111, 120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
             "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
              51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
             "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
              19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
             "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 
              53.625, 79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
             "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 
              35.333, 75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
             "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 
              78.333, 140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
             "winter", "large", "medium", 8., 7.6, 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
             "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
              140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
          Flatten[
           $CellContext`sym$2505[$CellContext`a4, 
            "missing"]]]], $CellContext`sym$2505[$CellContext`a5] = Part[
         $CellContext`sym$2505[$CellContext`a5, "raw"], 
         Complement[
          Range[
           
           Length[{{
             "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 
              170., 50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
             "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 
              428.75, 558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
             "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
              125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
             "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
              61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
             "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 
              58.222, 97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
             "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25,
               56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
             "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25,
               111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
             "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
              44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
             "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 
              36.3, 71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
             "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6,
               0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
             "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
              20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
             "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 
              10.667, 19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
             "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 
              17., 41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
             "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 
              0.5, 31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
             "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
              0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
             "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
              98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
             "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 
              50., 1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
             "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
              57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
             "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 
              61.5, 0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
             "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
              564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
             "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 
              467.5, 586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
             "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
              0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
             "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 
              40., 7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
             "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 
              3., 27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
             "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 
              11.5, 1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
             "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
              44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
             "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6,
               0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
             "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
              Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
             "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 
              0.8, 17.1, 0., 19.6, 0., 0., 0., 2.5}, {
             "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 
              0.5, 33.9, 1., 14.6, 0., 0., 0., 0.}, {
             "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
              4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
             "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304.,
               2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
             "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
              130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
             "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 
              47., 2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
             "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 
              23., 0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
             "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
              58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
             "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 
              3., 0.2, 66., 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 8., 
              Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 
              0., 0.}, {
             "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
              196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
             "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001,
               182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
             "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 
              143.71001, 296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
             "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
              59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
             "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
              344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
             "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
              276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
             "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
              40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
             "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5,
               3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
             "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
              0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {
             "winter", "small", "low", 
              Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 
              0., 0., 0.}, {
             "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121.,
               2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
             "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
              20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
             "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 
              12.75, 49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
             "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3,
               22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
             "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
              11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 
              11.818, 0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
             "winter", "small", "high", 6.6, 10.8, 
              Missing[], 3.245, 10., 1., 6.5, 
              Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "medium", 5.6, 11.8, 
              Missing[], 2.22, 5., 1., 1., 
              Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
             "autumn", "small", "medium", 5.7, 10.8, 
              Missing[], 2.55, 10., 1., 4., 
              Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
             "spring", "small", "high", 6.6, 9.5, 
              Missing[], 1.32, 20., 1., 6., 
              Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
             "summer", "small", "high", 6.6, 10.8, 
              Missing[], 2.64, 10., 2., 11., 
              Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
             "autumn", "small", "medium", 6.6, 11.3, 
              Missing[], 4.17, 10., 1., 6., 
              Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
             "spring", "small", "medium", 6.5, 10.4, 
              Missing[], 5.97, 10., 2., 14., 
              Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
             "summer", "small", "medium", 6.4, 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 14., 
              Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
             "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
              6.667, 
              Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 
              6.75, 1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
             "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 
              7.2, 0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
             "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 
              6., 0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
             "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
              10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
             "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 
              2.5, 0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
             "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 
              220.75, 351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
             "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
              209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
             "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
              151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
             "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
              152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
             "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 
              55., 58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
             "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 
              136.75, 249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
             "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
              100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
             "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
              215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
             "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
              25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
             "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36.,
               105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
             "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 
              37.375, 111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
             "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 
              108., 1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
             "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
              56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
             "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 
              60., 4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
             "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 
              27.667, 104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
             "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32.,
               69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
             "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 
              111.25, 214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
             "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 
              137.60001, 254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
             "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 
              429.20001, 57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 
              16.7}, {"winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 
              5738.33008, 412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0.,
               2.4}, {"summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 
              4073.33008, 282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 
              9.9, 0.}, {
             "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
              197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
             "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
              267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
             "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
              191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
             "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 
              120.5, 232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
             "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
              144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
             "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
              218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
             "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23.,
               138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
             "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 
              104.222, 239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
             "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
              235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
             "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 
              51.75, 205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
             "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
              31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
             "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 
              28.625, 186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
             "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
              12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
             "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
              51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
             "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 
              104.5, 292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
             "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 
              38.625, 285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
             "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 
              24.667, 201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
             "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
              275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
             "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 
              39., 124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
             "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
              60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
             "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 
              71., 132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
             "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 
              9.667, 17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
             "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 
              26., 0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
             "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
              8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
             "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
              37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
             "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 
              37., 86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
             "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444,
               10.111, 
              Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
             "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
              16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
             "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 
              3.545, 13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
             "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
              261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
             "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 
              238.2, 320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
             "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499,
               144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
             "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
              166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
             "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 
              181., 222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
             "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
              36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
             "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 
              61.556, 127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
             "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625,
               89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
             "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
              55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
             "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
              102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
             "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
              75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
             "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 
              34.636, 72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
             "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
              48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
             "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
              48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
             "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 
              3466.65991, 23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
             "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173.,
               317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
             "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
              84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
             "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 
              213., 2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
             "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
              88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
             "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 
              115., 11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
             "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
              98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
             "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5,
               143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
             "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 
              132.5, 197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
             "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2,
               1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
             "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
              10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
             "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
              200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
             "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
              77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
             "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 
              47.5, 276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
             "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 
              46.667, 123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
             "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
              75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
             "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48.,
               116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
             "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
              188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
             "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39.,
               72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
             "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 
              116.2, 16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
             "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 
              44., 34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
             "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
              27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
             "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 
              24., 58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
             "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
              175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
             "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 
              236., 22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
             "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 
              125.8, 26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
             "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 
              20.667, 54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
             "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 
              75.333, 34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
             "spring", "large", "low", 9., 5.8, 
              Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 
              0., 0., 0.}, {
             "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
              151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
             "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 
              180.66701, 269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
             "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
              46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
             "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
              85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
             "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
              66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
             "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
              102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
             "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
              84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
             "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 
              221.89999, 246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 
              1.7}, {"autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 
              627.27301, 205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 
              0.}, {"winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 
              1168., 236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 
              17.2, 0.}, {
             "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
              1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0.,
               5.9, 1.7}, {
             "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
              82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
             "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
              64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
             "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
              87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
             "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
              159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
             "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
              21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
             "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 
              11., 0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
             "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 
              7.667, 14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
             "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 
              3.222, 7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
             "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2,
               0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
             "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
              7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
             "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16.,
               2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
             "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
              56.091, 
              Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
             "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625,
               52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
             "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
              104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
             "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3,
               85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
             "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
              87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
             "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
              101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
             "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
              50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
             "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 
              34.5, 81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
             "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
              19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
             "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 
              19.111, 120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
             "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
              51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
             "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
              19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
             "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 
              53.625, 79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
             "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 
              35.333, 75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
             "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 
              78.333, 140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
             "winter", "large", "medium", 8., 7.6, 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
             "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
              140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
          Flatten[
           $CellContext`sym$2505[$CellContext`a5, 
            "missing"]]]], $CellContext`sym$2505[$CellContext`a6] = Part[
         $CellContext`sym$2505[$CellContext`a6, "raw"], 
         Complement[
          Range[
           
           Length[{{
             "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 
              170., 50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
             "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 
              428.75, 558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
             "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
              125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
             "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
              61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
             "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 
              58.222, 97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
             "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25,
               56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
             "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25,
               111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
             "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
              44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
             "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 
              36.3, 71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
             "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6,
               0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
             "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
              20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
             "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 
              10.667, 19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
             "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 
              17., 41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
             "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 
              0.5, 31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
             "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
              0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
             "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
              98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
             "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 
              50., 1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
             "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
              57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
             "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 
              61.5, 0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
             "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
              564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
             "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 
              467.5, 586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
             "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
              0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
             "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 
              40., 7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
             "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 
              3., 27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
             "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 
              11.5, 1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
             "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
              44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
             "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6,
               0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
             "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
              Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
             "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 
              0.8, 17.1, 0., 19.6, 0., 0., 0., 2.5}, {
             "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 
              0.5, 33.9, 1., 14.6, 0., 0., 0., 0.}, {
             "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
              4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
             "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304.,
               2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
             "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
              130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
             "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 
              47., 2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
             "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 
              23., 0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
             "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
              58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
             "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 
              3., 0.2, 66., 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 8., 
              Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 
              0., 0.}, {
             "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
              196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
             "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001,
               182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
             "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 
              143.71001, 296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
             "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
              59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
             "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
              344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
             "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
              276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
             "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
              40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
             "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5,
               3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
             "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
              0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {
             "winter", "small", "low", 
              Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 
              0., 0., 0.}, {
             "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121.,
               2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
             "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
              20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
             "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 
              12.75, 49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
             "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3,
               22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
             "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
              11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 
              11.818, 0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
             "winter", "small", "high", 6.6, 10.8, 
              Missing[], 3.245, 10., 1., 6.5, 
              Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "medium", 5.6, 11.8, 
              Missing[], 2.22, 5., 1., 1., 
              Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
             "autumn", "small", "medium", 5.7, 10.8, 
              Missing[], 2.55, 10., 1., 4., 
              Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
             "spring", "small", "high", 6.6, 9.5, 
              Missing[], 1.32, 20., 1., 6., 
              Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
             "summer", "small", "high", 6.6, 10.8, 
              Missing[], 2.64, 10., 2., 11., 
              Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
             "autumn", "small", "medium", 6.6, 11.3, 
              Missing[], 4.17, 10., 1., 6., 
              Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
             "spring", "small", "medium", 6.5, 10.4, 
              Missing[], 5.97, 10., 2., 14., 
              Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
             "summer", "small", "medium", 6.4, 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 14., 
              Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
             "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
              6.667, 
              Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 
              6.75, 1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
             "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 
              7.2, 0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
             "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 
              6., 0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
             "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
              10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
             "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 
              2.5, 0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
             "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 
              220.75, 351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
             "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
              209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
             "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
              151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
             "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
              152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
             "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 
              55., 58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
             "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 
              136.75, 249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
             "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
              100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
             "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
              215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
             "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
              25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
             "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36.,
               105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
             "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 
              37.375, 111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
             "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 
              108., 1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
             "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
              56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
             "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 
              60., 4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
             "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 
              27.667, 104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
             "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32.,
               69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
             "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 
              111.25, 214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
             "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 
              137.60001, 254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
             "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 
              429.20001, 57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 
              16.7}, {"winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 
              5738.33008, 412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0.,
               2.4}, {"summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 
              4073.33008, 282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 
              9.9, 0.}, {
             "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
              197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
             "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
              267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
             "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
              191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
             "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 
              120.5, 232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
             "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
              144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
             "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
              218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
             "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23.,
               138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
             "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 
              104.222, 239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
             "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
              235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
             "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 
              51.75, 205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
             "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
              31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
             "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 
              28.625, 186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
             "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
              12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
             "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
              51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
             "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 
              104.5, 292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
             "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 
              38.625, 285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
             "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 
              24.667, 201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
             "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
              275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
             "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 
              39., 124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
             "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
              60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
             "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 
              71., 132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
             "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 
              9.667, 17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
             "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 
              26., 0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
             "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
              8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
             "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
              37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
             "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 
              37., 86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
             "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444,
               10.111, 
              Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
             "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
              16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
             "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 
              3.545, 13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
             "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
              261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
             "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 
              238.2, 320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
             "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499,
               144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
             "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
              166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
             "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 
              181., 222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
             "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
              36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
             "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 
              61.556, 127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
             "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625,
               89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
             "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
              55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
             "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
              102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
             "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
              75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
             "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 
              34.636, 72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
             "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
              48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
             "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
              48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
             "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 
              3466.65991, 23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
             "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173.,
               317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
             "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
              84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
             "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 
              213., 2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
             "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
              88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
             "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 
              115., 11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
             "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
              98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
             "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5,
               143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
             "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 
              132.5, 197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
             "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2,
               1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
             "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
              10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
             "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
              200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
             "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
              77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
             "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 
              47.5, 276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
             "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 
              46.667, 123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
             "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
              75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
             "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48.,
               116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
             "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
              188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
             "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39.,
               72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
             "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 
              116.2, 16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
             "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 
              44., 34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
             "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
              27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
             "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 
              24., 58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
             "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
              175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
             "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 
              236., 22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
             "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 
              125.8, 26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
             "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 
              20.667, 54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
             "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 
              75.333, 34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
             "spring", "large", "low", 9., 5.8, 
              Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 
              0., 0., 0.}, {
             "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
              151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
             "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 
              180.66701, 269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
             "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
              46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
             "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
              85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
             "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
              66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
             "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
              102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
             "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
              84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
             "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 
              221.89999, 246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 
              1.7}, {"autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 
              627.27301, 205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 
              0.}, {"winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 
              1168., 236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 
              17.2, 0.}, {
             "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
              1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0.,
               5.9, 1.7}, {
             "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
              82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
             "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
              64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
             "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
              87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
             "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
              159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
             "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
              21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
             "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 
              11., 0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
             "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 
              7.667, 14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
             "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 
              3.222, 7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
             "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2,
               0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
             "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
              7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
             "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16.,
               2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
             "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
              56.091, 
              Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
             "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625,
               52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
             "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
              104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
             "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3,
               85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
             "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
              87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
             "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
              101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
             "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
              50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
             "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 
              34.5, 81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
             "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
              19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
             "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 
              19.111, 120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
             "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
              51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
             "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
              19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
             "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 
              53.625, 79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
             "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 
              35.333, 75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
             "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 
              78.333, 140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
             "winter", "large", "medium", 8., 7.6, 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
             "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
              140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
          Flatten[
           $CellContext`sym$2505[$CellContext`a6, 
            "missing"]]]], $CellContext`sym$2505[$CellContext`a7] = Part[
         $CellContext`sym$2505[$CellContext`a7, "raw"], 
         Complement[
          Range[
           
           Length[{{
             "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 
              170., 50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
             "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 
              428.75, 558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
             "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
              125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
             "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
              61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
             "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 
              58.222, 97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
             "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25,
               56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
             "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25,
               111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
             "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
              44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
             "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 
              36.3, 71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
             "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6,
               0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
             "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
              20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
             "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 
              10.667, 19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
             "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 
              17., 41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
             "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 
              0.5, 31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
             "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
              0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
             "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
              98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
             "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 
              50., 1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
             "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
              57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
             "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 
              61.5, 0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
             "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
              564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
             "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 
              467.5, 586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
             "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
              0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
             "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 
              40., 7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
             "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 
              3., 27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
             "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 
              11.5, 1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
             "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
              44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
             "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6,
               0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
             "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
              Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
             "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 
              0.8, 17.1, 0., 19.6, 0., 0., 0., 2.5}, {
             "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 
              0.5, 33.9, 1., 14.6, 0., 0., 0., 0.}, {
             "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
              4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
             "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304.,
               2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
             "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
              130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
             "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 
              47., 2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
             "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 
              23., 0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
             "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
              58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
             "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 
              3., 0.2, 66., 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 8., 
              Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 
              0., 0.}, {
             "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
              196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
             "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001,
               182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
             "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 
              143.71001, 296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
             "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
              59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
             "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
              344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
             "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
              276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
             "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
              40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
             "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5,
               3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
             "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
              0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {
             "winter", "small", "low", 
              Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 
              0., 0., 0.}, {
             "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121.,
               2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
             "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
              20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
             "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 
              12.75, 49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
             "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3,
               22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
             "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
              11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 
              11.818, 0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
             "winter", "small", "high", 6.6, 10.8, 
              Missing[], 3.245, 10., 1., 6.5, 
              Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "medium", 5.6, 11.8, 
              Missing[], 2.22, 5., 1., 1., 
              Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
             "autumn", "small", "medium", 5.7, 10.8, 
              Missing[], 2.55, 10., 1., 4., 
              Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
             "spring", "small", "high", 6.6, 9.5, 
              Missing[], 1.32, 20., 1., 6., 
              Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
             "summer", "small", "high", 6.6, 10.8, 
              Missing[], 2.64, 10., 2., 11., 
              Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
             "autumn", "small", "medium", 6.6, 11.3, 
              Missing[], 4.17, 10., 1., 6., 
              Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
             "spring", "small", "medium", 6.5, 10.4, 
              Missing[], 5.97, 10., 2., 14., 
              Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
             "summer", "small", "medium", 6.4, 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 14., 
              Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
             "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
              6.667, 
              Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 
              6.75, 1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
             "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 
              7.2, 0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
             "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 
              6., 0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
             "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
              10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
             "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 
              2.5, 0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
             "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 
              220.75, 351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
             "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
              209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
             "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
              151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
             "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
              152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
             "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 
              55., 58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
             "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 
              136.75, 249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
             "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
              100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
             "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
              215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
             "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
              25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
             "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36.,
               105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
             "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 
              37.375, 111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
             "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 
              108., 1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
             "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
              56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
             "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 
              60., 4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
             "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 
              27.667, 104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
             "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32.,
               69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
             "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 
              111.25, 214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
             "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 
              137.60001, 254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
             "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 
              429.20001, 57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 
              16.7}, {"winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 
              5738.33008, 412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0.,
               2.4}, {"summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 
              4073.33008, 282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 
              9.9, 0.}, {
             "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
              197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
             "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
              267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
             "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
              191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
             "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 
              120.5, 232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
             "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
              144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
             "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
              218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
             "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23.,
               138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
             "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 
              104.222, 239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
             "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
              235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
             "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 
              51.75, 205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
             "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
              31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
             "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 
              28.625, 186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
             "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
              12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
             "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
              51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
             "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 
              104.5, 292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
             "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 
              38.625, 285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
             "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 
              24.667, 201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
             "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
              275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
             "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 
              39., 124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
             "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
              60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
             "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 
              71., 132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
             "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 
              9.667, 17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
             "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 
              26., 0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
             "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
              8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
             "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
              37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
             "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 
              37., 86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
             "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444,
               10.111, 
              Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
             "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
              16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
             "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 
              3.545, 13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
             "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
              261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
             "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 
              238.2, 320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
             "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499,
               144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
             "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
              166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
             "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 
              181., 222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
             "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
              36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
             "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 
              61.556, 127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
             "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625,
               89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
             "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
              55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
             "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
              102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
             "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
              75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
             "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 
              34.636, 72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
             "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
              48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
             "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
              48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
             "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 
              3466.65991, 23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
             "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173.,
               317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
             "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
              84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
             "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 
              213., 2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
             "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
              88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
             "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 
              115., 11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
             "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
              98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
             "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5,
               143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
             "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 
              132.5, 197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
             "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2,
               1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
             "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
              10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
             "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
              200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
             "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
              77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
             "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 
              47.5, 276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
             "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 
              46.667, 123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
             "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
              75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
             "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48.,
               116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
             "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
              188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
             "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39.,
               72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
             "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 
              116.2, 16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
             "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 
              44., 34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
             "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
              27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
             "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 
              24., 58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
             "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
              175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
             "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 
              236., 22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
             "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 
              125.8, 26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
             "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 
              20.667, 54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
             "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 
              75.333, 34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
             "spring", "large", "low", 9., 5.8, 
              Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 
              0., 0., 0.}, {
             "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
              151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
             "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 
              180.66701, 269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
             "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
              46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
             "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
              85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
             "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
              66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
             "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
              102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
             "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
              84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
             "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 
              221.89999, 246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 
              1.7}, {"autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 
              627.27301, 205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 
              0.}, {"winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 
              1168., 236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 
              17.2, 0.}, {
             "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
              1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0.,
               5.9, 1.7}, {
             "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
              82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
             "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
              64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
             "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
              87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
             "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
              159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
             "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
              21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
             "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 
              11., 0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
             "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 
              7.667, 14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
             "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 
              3.222, 7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
             "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2,
               0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
             "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
              7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
             "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16.,
               2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
             "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
              56.091, 
              Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
             "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625,
               52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
             "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
              104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
             "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3,
               85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
             "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
              87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
             "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
              101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
             "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
              50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
             "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 
              34.5, 81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
             "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
              19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
             "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 
              19.111, 120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
             "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
              51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
             "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
              19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
             "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 
              53.625, 79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
             "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 
              35.333, 75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
             "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 
              78.333, 140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
             "winter", "large", "medium", 8., 7.6, 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
             "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
              140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
          Flatten[
           $CellContext`sym$2505[$CellContext`a7, 
            "missing"]]]], $CellContext`sym$2505[
        All] = {{
         "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170., 
          50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
         "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
          558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
         "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
          125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
         "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
          61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
         "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222, 
          97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
         "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
          56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
         "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
          111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
         "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
          44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
         "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
          71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
         "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
          0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
         "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
          20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
         "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
          19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
         "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
          41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
         "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5, 
          31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
         "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 0.3,
           52.2, 5., 7.8, 0., 4., 0., 0.}, {
         "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 98.25,
           1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
         "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50., 
          1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
         "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 57.833,
           0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
         "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
          0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
         "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
          564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
         "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
          586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
         "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 0.5,
           15.5, 0., 0., 2.3, 0., 0., 0.}, {
         "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
          7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
         "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
          27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
         "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
          1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
         "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
          44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
         "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
          0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
         "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
          Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
         "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
          17.1, 0., 19.6, 0., 0., 0., 2.5}, {
         "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5, 
          33.9, 1., 14.6, 0., 0., 0., 0.}, {
         "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 4.9,
           3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
         "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
          2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
         "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
          130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
         "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47., 
          2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
         "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23., 
          0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
         "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 58.875,
           84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
         "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
          0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
          Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0., 
          0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
          196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
         "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
          182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
         "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001, 
          296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
         "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
          59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
         "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
          344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
         "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 276.85001,
           326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
         "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
          40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
         "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
          3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
         "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 0.8,
           54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
          Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
          0., 0.}, {
         "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
          2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
         "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
          20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
         "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
          49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
         "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
          22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
         "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
          11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
         "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818, 
          0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
         "winter", "small", "high", 6.6, 10.8, 
          Missing[], 3.245, 10., 1., 6.5, 
          Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
         "spring", "small", "medium", 5.6, 11.8, 
          Missing[], 2.22, 5., 1., 1., 
          Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
         "autumn", "small", "medium", 5.7, 10.8, 
          Missing[], 2.55, 10., 1., 4., 
          Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
         "spring", "small", "high", 6.6, 9.5, 
          Missing[], 1.32, 20., 1., 6., 
          Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
         "summer", "small", "high", 6.6, 10.8, 
          Missing[], 2.64, 10., 2., 11., 
          Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
         "autumn", "small", "medium", 6.6, 11.3, 
          Missing[], 4.17, 10., 1., 6., 
          Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
         "spring", "small", "medium", 6.5, 10.4, 
          Missing[], 5.97, 10., 2., 14., 
          Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
         "summer", "small", "medium", 6.4, 
          Missing[], 
          Missing[], 
          Missing[], 
          Missing[], 
          Missing[], 14., 
          Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
         "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
          6.667, 
          Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
         "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75, 
          1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
         "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2, 
          0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
         "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
          0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
         "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 10.75,
           2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
         "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
          0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
         "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75, 
          351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
         "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
          209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
         "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
          151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
         "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
          152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
         "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
          58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
         "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
          249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
         "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 100.,
           233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
         "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
          215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
         "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 25.167,
           102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
         "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
          105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
         "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
          111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
         "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
          1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
         "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
          56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
         "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
          4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
         "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
          104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
         "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
          69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
         "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
          214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
         "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
          254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
         "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
          57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
         "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
          412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
         "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
          282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
         "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
          197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
         "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
          267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
         "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 191.75,
           265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
         "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
          232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
         "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 144.66701,
           244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
         "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
          218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
         "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
          138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
         "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222, 
          239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
         "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
          235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
         "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75, 
          205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
         "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 31.333,
           211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
         "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625, 
          186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
         "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
          12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
         "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
          51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
         "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
          292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
         "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
          285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
         "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
          201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
         "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
          275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
         "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
          124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
         "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
          60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
         "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71., 
          132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
         "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
          17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
         "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
          0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
         "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
          8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
         "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
          37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
         "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
          86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
         "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
          10.111, 
          Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
         "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 16.833,
           18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
         "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545, 
          13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
         "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
          261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
         "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
          320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
         "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
          144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
         "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
          166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
         "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
          222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
         "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
          36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
         "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556, 
          127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
         "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
          89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
         "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 55.,
           284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
         "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
          102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
         "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 75.875,
           177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
         "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
          72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
         "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 48.667,
           82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
         "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 48.625,
           66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
         "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
          23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
         "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
          317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
         "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 84.,
           4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
         "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
          2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
         "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
          88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
         "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115., 
          11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
         "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
          98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
         "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
          143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
         "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
          197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
         "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 1.,
           19., 0., 22., 5., 1.1, 5.4, 0.}, {
         "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 10.583,
           23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
         "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
          200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
         "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
          77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
         "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5, 
          276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
         "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
          123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
         "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
          75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
         "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
          116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
         "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
          188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
         "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
          72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
         "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
          16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
         "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
          34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
         "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
          27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
         "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
          58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
         "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
          175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
         "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
          22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
         "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
          26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
         "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
          54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
         "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333, 
          34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
         "spring", "large", "low", 9., 5.8, 
          Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
          0., 0.}, {
         "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 151.33299,
           252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
         "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
          269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
         "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
          46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
         "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 85.,
           2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
         "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 66.4,
           171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
         "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 102.364,
           232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
         "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 84.3,
           146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
         "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
          246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
         "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
          205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
         "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
          236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
         "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 1081.66003,
           346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 5.9, 1.7}, {
         "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
          82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
         "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 64.389,
           137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
         "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
          87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
         "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
          159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
         "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
          21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
         "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
          0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
         "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
          14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
         "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222, 
          7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
         "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
          0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
         "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 7.654,
           4., 56.8, 5., 0., 0., 0., 0., 0.}, {
         "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
          2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
         "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
          56.091, 
          Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
         "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
          52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
         "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
          104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
         "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
          85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
         "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
          87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
         "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
          101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
         "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 50.889,
           127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
         "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
          81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
         "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
          19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
         "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111, 
          120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
         "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 51.111,
           91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
         "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 19.111,
           61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
         "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625, 
          79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
         "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333, 
          75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
         "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333, 
          140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
         "winter", "large", "medium", 8., 7.6, 
          Missing[], 
          Missing[], 
          Missing[], 
          Missing[], 
          Missing[], 
          Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
         "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
          140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 
          5.8}}, $CellContext`sym$2505[$CellContext`Chla] = Part[
         $CellContext`sym$2505[$CellContext`Chla, "raw"], 
         Complement[
          Range[
           
           Length[{{
             "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 
              170., 50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
             "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 
              428.75, 558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
             "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
              125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
             "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
              61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
             "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 
              58.222, 97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
             "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25,
               56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
             "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25,
               111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
             "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
              44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
             "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 
              36.3, 71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
             "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6,
               0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
             "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
              20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
             "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 
              10.667, 19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
             "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 
              17., 41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
             "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 
              0.5, 31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
             "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
              0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
             "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
              98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
             "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 
              50., 1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
             "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
              57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
             "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 
              61.5, 0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
             "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
              564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
             "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 
              467.5, 586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
             "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
              0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
             "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 
              40., 7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
             "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 
              3., 27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
             "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 
              11.5, 1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
             "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
              44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
             "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6,
               0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
             "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
              Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
             "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 
              0.8, 17.1, 0., 19.6, 0., 0., 0., 2.5}, {
             "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 
              0.5, 33.9, 1., 14.6, 0., 0., 0., 0.}, {
             "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
              4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
             "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304.,
               2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
             "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
              130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
             "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 
              47., 2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
             "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 
              23., 0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
             "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
              58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
             "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 
              3., 0.2, 66., 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 8., 
              Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 
              0., 0.}, {
             "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
              196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
             "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001,
               182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
             "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 
              143.71001, 296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
             "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
              59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
             "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
              344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
             "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
              276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
             "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
              40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
             "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5,
               3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
             "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
              0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {
             "winter", "small", "low", 
              Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 
              0., 0., 0.}, {
             "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121.,
               2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
             "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
              20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
             "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 
              12.75, 49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
             "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3,
               22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
             "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
              11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 
              11.818, 0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
             "winter", "small", "high", 6.6, 10.8, 
              Missing[], 3.245, 10., 1., 6.5, 
              Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "medium", 5.6, 11.8, 
              Missing[], 2.22, 5., 1., 1., 
              Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
             "autumn", "small", "medium", 5.7, 10.8, 
              Missing[], 2.55, 10., 1., 4., 
              Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
             "spring", "small", "high", 6.6, 9.5, 
              Missing[], 1.32, 20., 1., 6., 
              Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
             "summer", "small", "high", 6.6, 10.8, 
              Missing[], 2.64, 10., 2., 11., 
              Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
             "autumn", "small", "medium", 6.6, 11.3, 
              Missing[], 4.17, 10., 1., 6., 
              Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
             "spring", "small", "medium", 6.5, 10.4, 
              Missing[], 5.97, 10., 2., 14., 
              Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
             "summer", "small", "medium", 6.4, 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 14., 
              Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
             "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
              6.667, 
              Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 
              6.75, 1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
             "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 
              7.2, 0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
             "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 
              6., 0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
             "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
              10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
             "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 
              2.5, 0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
             "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 
              220.75, 351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
             "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
              209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
             "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
              151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
             "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
              152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
             "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 
              55., 58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
             "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 
              136.75, 249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
             "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
              100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
             "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
              215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
             "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
              25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
             "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36.,
               105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
             "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 
              37.375, 111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
             "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 
              108., 1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
             "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
              56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
             "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 
              60., 4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
             "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 
              27.667, 104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
             "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32.,
               69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
             "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 
              111.25, 214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
             "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 
              137.60001, 254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
             "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 
              429.20001, 57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 
              16.7}, {"winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 
              5738.33008, 412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0.,
               2.4}, {"summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 
              4073.33008, 282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 
              9.9, 0.}, {
             "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
              197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
             "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
              267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
             "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
              191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
             "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 
              120.5, 232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
             "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
              144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
             "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
              218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
             "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23.,
               138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
             "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 
              104.222, 239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
             "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
              235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
             "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 
              51.75, 205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
             "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
              31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
             "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 
              28.625, 186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
             "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
              12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
             "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
              51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
             "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 
              104.5, 292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
             "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 
              38.625, 285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
             "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 
              24.667, 201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
             "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
              275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
             "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 
              39., 124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
             "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
              60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
             "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 
              71., 132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
             "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 
              9.667, 17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
             "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 
              26., 0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
             "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
              8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
             "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
              37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
             "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 
              37., 86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
             "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444,
               10.111, 
              Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
             "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
              16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
             "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 
              3.545, 13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
             "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
              261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
             "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 
              238.2, 320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
             "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499,
               144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
             "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
              166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
             "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 
              181., 222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
             "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
              36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
             "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 
              61.556, 127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
             "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625,
               89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
             "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
              55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
             "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
              102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
             "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
              75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
             "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 
              34.636, 72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
             "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
              48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
             "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
              48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
             "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 
              3466.65991, 23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
             "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173.,
               317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
             "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
              84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
             "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 
              213., 2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
             "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
              88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
             "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 
              115., 11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
             "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
              98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
             "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5,
               143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
             "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 
              132.5, 197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
             "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2,
               1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
             "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
              10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
             "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
              200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
             "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
              77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
             "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 
              47.5, 276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
             "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 
              46.667, 123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
             "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
              75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
             "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48.,
               116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
             "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
              188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
             "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39.,
               72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
             "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 
              116.2, 16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
             "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 
              44., 34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
             "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
              27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
             "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 
              24., 58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
             "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
              175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
             "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 
              236., 22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
             "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 
              125.8, 26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
             "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 
              20.667, 54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
             "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 
              75.333, 34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
             "spring", "large", "low", 9., 5.8, 
              Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 
              0., 0., 0.}, {
             "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
              151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
             "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 
              180.66701, 269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
             "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
              46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
             "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
              85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
             "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
              66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
             "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
              102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
             "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
              84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
             "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 
              221.89999, 246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 
              1.7}, {"autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 
              627.27301, 205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 
              0.}, {"winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 
              1168., 236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 
              17.2, 0.}, {
             "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
              1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0.,
               5.9, 1.7}, {
             "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
              82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
             "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
              64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
             "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
              87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
             "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
              159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
             "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
              21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
             "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 
              11., 0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
             "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 
              7.667, 14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
             "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 
              3.222, 7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
             "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2,
               0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
             "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
              7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
             "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16.,
               2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
             "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
              56.091, 
              Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
             "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625,
               52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
             "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
              104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
             "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3,
               85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
             "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
              87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
             "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
              101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
             "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
              50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
             "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 
              34.5, 81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
             "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
              19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
             "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 
              19.111, 120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
             "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
              51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
             "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
              19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
             "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 
              53.625, 79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
             "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 
              35.333, 75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
             "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 
              78.333, 140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
             "winter", "large", "medium", 8., 7.6, 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
             "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
              140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
          Flatten[
           $CellContext`sym$2505[$CellContext`Chla, 
            "missing"]]]], $CellContext`sym$2505[$CellContext`Cl] = Part[
         $CellContext`sym$2505[$CellContext`Cl, "raw"], 
         Complement[
          Range[
           
           Length[{{
             "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 
              170., 50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
             "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 
              428.75, 558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
             "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
              125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
             "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
              61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
             "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 
              58.222, 97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
             "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25,
               56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
             "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25,
               111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
             "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
              44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
             "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 
              36.3, 71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
             "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6,
               0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
             "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
              20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
             "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 
              10.667, 19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
             "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 
              17., 41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
             "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 
              0.5, 31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
             "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
              0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
             "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
              98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
             "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 
              50., 1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
             "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
              57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
             "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 
              61.5, 0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
             "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
              564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
             "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 
              467.5, 586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
             "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
              0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
             "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 
              40., 7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
             "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 
              3., 27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
             "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 
              11.5, 1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
             "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
              44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
             "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6,
               0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
             "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
              Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
             "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 
              0.8, 17.1, 0., 19.6, 0., 0., 0., 2.5}, {
             "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 
              0.5, 33.9, 1., 14.6, 0., 0., 0., 0.}, {
             "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
              4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
             "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304.,
               2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
             "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
              130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
             "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 
              47., 2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
             "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 
              23., 0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
             "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
              58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
             "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 
              3., 0.2, 66., 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 8., 
              Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 
              0., 0.}, {
             "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
              196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
             "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001,
               182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
             "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 
              143.71001, 296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
             "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
              59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
             "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
              344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
             "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
              276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
             "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
              40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
             "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5,
               3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
             "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
              0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {
             "winter", "small", "low", 
              Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 
              0., 0., 0.}, {
             "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121.,
               2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
             "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
              20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
             "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 
              12.75, 49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
             "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3,
               22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
             "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
              11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 
              11.818, 0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
             "winter", "small", "high", 6.6, 10.8, 
              Missing[], 3.245, 10., 1., 6.5, 
              Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "medium", 5.6, 11.8, 
              Missing[], 2.22, 5., 1., 1., 
              Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
             "autumn", "small", "medium", 5.7, 10.8, 
              Missing[], 2.55, 10., 1., 4., 
              Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
             "spring", "small", "high", 6.6, 9.5, 
              Missing[], 1.32, 20., 1., 6., 
              Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
             "summer", "small", "high", 6.6, 10.8, 
              Missing[], 2.64, 10., 2., 11., 
              Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
             "autumn", "small", "medium", 6.6, 11.3, 
              Missing[], 4.17, 10., 1., 6., 
              Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
             "spring", "small", "medium", 6.5, 10.4, 
              Missing[], 5.97, 10., 2., 14., 
              Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
             "summer", "small", "medium", 6.4, 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 14., 
              Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
             "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
              6.667, 
              Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 
              6.75, 1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
             "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 
              7.2, 0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
             "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 
              6., 0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
             "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
              10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
             "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 
              2.5, 0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
             "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 
              220.75, 351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
             "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
              209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
             "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
              151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
             "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
              152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
             "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 
              55., 58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
             "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 
              136.75, 249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
             "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
              100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
             "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
              215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
             "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
              25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
             "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36.,
               105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
             "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 
              37.375, 111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
             "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 
              108., 1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
             "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
              56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
             "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 
              60., 4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
             "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 
              27.667, 104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
             "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32.,
               69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
             "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 
              111.25, 214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
             "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 
              137.60001, 254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
             "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 
              429.20001, 57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 
              16.7}, {"winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 
              5738.33008, 412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0.,
               2.4}, {"summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 
              4073.33008, 282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 
              9.9, 0.}, {
             "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
              197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
             "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
              267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
             "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
              191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
             "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 
              120.5, 232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
             "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
              144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
             "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
              218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
             "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23.,
               138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
             "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 
              104.222, 239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
             "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
              235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
             "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 
              51.75, 205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
             "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
              31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
             "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 
              28.625, 186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
             "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
              12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
             "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
              51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
             "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 
              104.5, 292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
             "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 
              38.625, 285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
             "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 
              24.667, 201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
             "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
              275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
             "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 
              39., 124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
             "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
              60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
             "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 
              71., 132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
             "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 
              9.667, 17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
             "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 
              26., 0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
             "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
              8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
             "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
              37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
             "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 
              37., 86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
             "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444,
               10.111, 
              Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
             "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
              16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
             "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 
              3.545, 13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
             "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
              261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
             "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 
              238.2, 320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
             "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499,
               144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
             "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
              166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
             "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 
              181., 222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
             "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
              36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
             "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 
              61.556, 127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
             "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625,
               89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
             "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
              55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
             "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
              102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
             "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
              75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
             "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 
              34.636, 72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
             "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
              48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
             "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
              48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
             "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 
              3466.65991, 23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
             "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173.,
               317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
             "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
              84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
             "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 
              213., 2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
             "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
              88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
             "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 
              115., 11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
             "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
              98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
             "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5,
               143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
             "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 
              132.5, 197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
             "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2,
               1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
             "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
              10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
             "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
              200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
             "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
              77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
             "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 
              47.5, 276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
             "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 
              46.667, 123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
             "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
              75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
             "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48.,
               116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
             "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
              188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
             "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39.,
               72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
             "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 
              116.2, 16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
             "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 
              44., 34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
             "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
              27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
             "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 
              24., 58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
             "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
              175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
             "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 
              236., 22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
             "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 
              125.8, 26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
             "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 
              20.667, 54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
             "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 
              75.333, 34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
             "spring", "large", "low", 9., 5.8, 
              Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 
              0., 0., 0.}, {
             "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
              151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
             "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 
              180.66701, 269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
             "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
              46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
             "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
              85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
             "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
              66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
             "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
              102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
             "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
              84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
             "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 
              221.89999, 246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 
              1.7}, {"autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 
              627.27301, 205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 
              0.}, {"winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 
              1168., 236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 
              17.2, 0.}, {
             "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
              1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0.,
               5.9, 1.7}, {
             "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
              82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
             "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
              64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
             "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
              87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
             "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
              159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
             "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
              21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
             "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 
              11., 0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
             "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 
              7.667, 14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
             "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 
              3.222, 7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
             "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2,
               0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
             "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
              7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
             "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16.,
               2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
             "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
              56.091, 
              Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
             "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625,
               52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
             "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
              104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
             "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3,
               85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
             "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
              87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
             "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
              101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
             "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
              50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
             "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 
              34.5, 81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
             "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
              19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
             "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 
              19.111, 120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
             "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
              51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
             "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
              19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
             "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 
              53.625, 79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
             "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 
              35.333, 75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
             "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 
              78.333, 140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
             "winter", "large", "medium", 8., 7.6, 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
             "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
              140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
          Flatten[
           $CellContext`sym$2505[$CellContext`Cl, 
            "missing"]]]], $CellContext`sym$2505[$CellContext`mnO2] = Part[
         $CellContext`sym$2505[$CellContext`mnO2, "raw"], 
         Complement[
          Range[
           
           Length[{{
             "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 
              170., 50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
             "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 
              428.75, 558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
             "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
              125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
             "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
              61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
             "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 
              58.222, 97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
             "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25,
               56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
             "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25,
               111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
             "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
              44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
             "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 
              36.3, 71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
             "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6,
               0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
             "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
              20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
             "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 
              10.667, 19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
             "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 
              17., 41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
             "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 
              0.5, 31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
             "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
              0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
             "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
              98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
             "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 
              50., 1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
             "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
              57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
             "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 
              61.5, 0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
             "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
              564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
             "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 
              467.5, 586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
             "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
              0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
             "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 
              40., 7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
             "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 
              3., 27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
             "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 
              11.5, 1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
             "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
              44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
             "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6,
               0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
             "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
              Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
             "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 
              0.8, 17.1, 0., 19.6, 0., 0., 0., 2.5}, {
             "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 
              0.5, 33.9, 1., 14.6, 0., 0., 0., 0.}, {
             "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
              4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
             "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304.,
               2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
             "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
              130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
             "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 
              47., 2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
             "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 
              23., 0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
             "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
              58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
             "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 
              3., 0.2, 66., 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 8., 
              Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 
              0., 0.}, {
             "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
              196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
             "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001,
               182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
             "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 
              143.71001, 296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
             "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
              59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
             "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
              344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
             "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
              276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
             "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
              40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
             "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5,
               3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
             "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
              0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {
             "winter", "small", "low", 
              Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 
              0., 0., 0.}, {
             "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121.,
               2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
             "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
              20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
             "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 
              12.75, 49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
             "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3,
               22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
             "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
              11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 
              11.818, 0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
             "winter", "small", "high", 6.6, 10.8, 
              Missing[], 3.245, 10., 1., 6.5, 
              Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "medium", 5.6, 11.8, 
              Missing[], 2.22, 5., 1., 1., 
              Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
             "autumn", "small", "medium", 5.7, 10.8, 
              Missing[], 2.55, 10., 1., 4., 
              Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
             "spring", "small", "high", 6.6, 9.5, 
              Missing[], 1.32, 20., 1., 6., 
              Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
             "summer", "small", "high", 6.6, 10.8, 
              Missing[], 2.64, 10., 2., 11., 
              Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
             "autumn", "small", "medium", 6.6, 11.3, 
              Missing[], 4.17, 10., 1., 6., 
              Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
             "spring", "small", "medium", 6.5, 10.4, 
              Missing[], 5.97, 10., 2., 14., 
              Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
             "summer", "small", "medium", 6.4, 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 14., 
              Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
             "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
              6.667, 
              Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 
              6.75, 1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
             "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 
              7.2, 0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
             "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 
              6., 0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
             "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
              10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
             "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 
              2.5, 0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
             "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 
              220.75, 351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
             "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
              209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
             "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
              151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
             "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
              152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
             "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 
              55., 58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
             "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 
              136.75, 249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
             "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
              100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
             "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
              215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
             "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
              25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
             "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36.,
               105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
             "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 
              37.375, 111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
             "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 
              108., 1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
             "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
              56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
             "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 
              60., 4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
             "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 
              27.667, 104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
             "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32.,
               69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
             "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 
              111.25, 214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
             "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 
              137.60001, 254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
             "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 
              429.20001, 57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 
              16.7}, {"winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 
              5738.33008, 412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0.,
               2.4}, {"summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 
              4073.33008, 282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 
              9.9, 0.}, {
             "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
              197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
             "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
              267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
             "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
              191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
             "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 
              120.5, 232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
             "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
              144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
             "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
              218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
             "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23.,
               138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
             "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 
              104.222, 239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
             "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
              235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
             "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 
              51.75, 205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
             "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
              31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
             "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 
              28.625, 186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
             "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
              12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
             "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
              51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
             "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 
              104.5, 292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
             "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 
              38.625, 285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
             "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 
              24.667, 201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
             "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
              275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
             "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 
              39., 124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
             "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
              60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
             "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 
              71., 132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
             "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 
              9.667, 17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
             "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 
              26., 0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
             "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
              8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
             "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
              37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
             "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 
              37., 86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
             "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444,
               10.111, 
              Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
             "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
              16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
             "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 
              3.545, 13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
             "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
              261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
             "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 
              238.2, 320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
             "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499,
               144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
             "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
              166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
             "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 
              181., 222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
             "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
              36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
             "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 
              61.556, 127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
             "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625,
               89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
             "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
              55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
             "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
              102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
             "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
              75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
             "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 
              34.636, 72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
             "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
              48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
             "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
              48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
             "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 
              3466.65991, 23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
             "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173.,
               317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
             "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
              84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
             "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 
              213., 2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
             "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
              88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
             "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 
              115., 11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
             "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
              98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
             "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5,
               143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
             "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 
              132.5, 197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
             "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2,
               1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
             "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
              10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
             "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
              200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
             "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
              77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
             "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 
              47.5, 276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
             "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 
              46.667, 123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
             "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
              75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
             "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48.,
               116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
             "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
              188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
             "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39.,
               72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
             "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 
              116.2, 16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
             "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 
              44., 34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
             "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
              27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
             "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 
              24., 58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
             "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
              175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
             "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 
              236., 22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
             "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 
              125.8, 26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
             "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 
              20.667, 54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
             "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 
              75.333, 34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
             "spring", "large", "low", 9., 5.8, 
              Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 
              0., 0., 0.}, {
             "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
              151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
             "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 
              180.66701, 269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
             "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
              46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
             "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
              85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
             "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
              66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
             "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
              102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
             "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
              84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
             "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 
              221.89999, 246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 
              1.7}, {"autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 
              627.27301, 205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 
              0.}, {"winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 
              1168., 236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 
              17.2, 0.}, {
             "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
              1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0.,
               5.9, 1.7}, {
             "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
              82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
             "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
              64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
             "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
              87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
             "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
              159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
             "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
              21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
             "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 
              11., 0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
             "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 
              7.667, 14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
             "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 
              3.222, 7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
             "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2,
               0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
             "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
              7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
             "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16.,
               2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
             "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
              56.091, 
              Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
             "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625,
               52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
             "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
              104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
             "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3,
               85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
             "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
              87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
             "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
              101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
             "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
              50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
             "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 
              34.5, 81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
             "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
              19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
             "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 
              19.111, 120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
             "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
              51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
             "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
              19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
             "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 
              53.625, 79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
             "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 
              35.333, 75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
             "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 
              78.333, 140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
             "winter", "large", "medium", 8., 7.6, 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
             "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
              140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
          Flatten[
           $CellContext`sym$2505[$CellContext`mnO2, 
            "missing"]]]], $CellContext`sym$2505[$CellContext`mxPH] = Part[
         $CellContext`sym$2505[$CellContext`mxPH, "raw"], 
         Complement[
          Range[
           
           Length[{{
             "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 
              170., 50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
             "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 
              428.75, 558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
             "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
              125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
             "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
              61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
             "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 
              58.222, 97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
             "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25,
               56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
             "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25,
               111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
             "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
              44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
             "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 
              36.3, 71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
             "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6,
               0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
             "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
              20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
             "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 
              10.667, 19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
             "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 
              17., 41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
             "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 
              0.5, 31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
             "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
              0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
             "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
              98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
             "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 
              50., 1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
             "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
              57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
             "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 
              61.5, 0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
             "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
              564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
             "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 
              467.5, 586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
             "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
              0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
             "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 
              40., 7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
             "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 
              3., 27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
             "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 
              11.5, 1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
             "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
              44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
             "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6,
               0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
             "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
              Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
             "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 
              0.8, 17.1, 0., 19.6, 0., 0., 0., 2.5}, {
             "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 
              0.5, 33.9, 1., 14.6, 0., 0., 0., 0.}, {
             "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
              4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
             "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304.,
               2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
             "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
              130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
             "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 
              47., 2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
             "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 
              23., 0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
             "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
              58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
             "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 
              3., 0.2, 66., 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 8., 
              Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 
              0., 0.}, {
             "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
              196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
             "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001,
               182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
             "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 
              143.71001, 296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
             "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
              59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
             "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
              344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
             "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
              276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
             "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
              40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
             "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5,
               3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
             "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
              0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {
             "winter", "small", "low", 
              Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 
              0., 0., 0.}, {
             "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121.,
               2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
             "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
              20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
             "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 
              12.75, 49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
             "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3,
               22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
             "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
              11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 
              11.818, 0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
             "winter", "small", "high", 6.6, 10.8, 
              Missing[], 3.245, 10., 1., 6.5, 
              Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "medium", 5.6, 11.8, 
              Missing[], 2.22, 5., 1., 1., 
              Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
             "autumn", "small", "medium", 5.7, 10.8, 
              Missing[], 2.55, 10., 1., 4., 
              Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
             "spring", "small", "high", 6.6, 9.5, 
              Missing[], 1.32, 20., 1., 6., 
              Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
             "summer", "small", "high", 6.6, 10.8, 
              Missing[], 2.64, 10., 2., 11., 
              Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
             "autumn", "small", "medium", 6.6, 11.3, 
              Missing[], 4.17, 10., 1., 6., 
              Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
             "spring", "small", "medium", 6.5, 10.4, 
              Missing[], 5.97, 10., 2., 14., 
              Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
             "summer", "small", "medium", 6.4, 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 14., 
              Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
             "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
              6.667, 
              Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 
              6.75, 1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
             "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 
              7.2, 0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
             "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 
              6., 0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
             "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
              10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
             "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 
              2.5, 0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
             "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 
              220.75, 351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
             "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
              209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
             "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
              151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
             "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
              152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
             "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 
              55., 58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
             "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 
              136.75, 249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
             "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
              100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
             "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
              215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
             "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
              25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
             "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36.,
               105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
             "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 
              37.375, 111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
             "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 
              108., 1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
             "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
              56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
             "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 
              60., 4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
             "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 
              27.667, 104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
             "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32.,
               69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
             "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 
              111.25, 214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
             "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 
              137.60001, 254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
             "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 
              429.20001, 57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 
              16.7}, {"winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 
              5738.33008, 412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0.,
               2.4}, {"summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 
              4073.33008, 282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 
              9.9, 0.}, {
             "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
              197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
             "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
              267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
             "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
              191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
             "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 
              120.5, 232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
             "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
              144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
             "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
              218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
             "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23.,
               138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
             "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 
              104.222, 239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
             "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
              235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
             "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 
              51.75, 205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
             "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
              31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
             "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 
              28.625, 186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
             "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
              12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
             "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
              51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
             "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 
              104.5, 292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
             "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 
              38.625, 285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
             "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 
              24.667, 201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
             "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
              275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
             "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 
              39., 124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
             "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
              60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
             "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 
              71., 132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
             "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 
              9.667, 17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
             "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 
              26., 0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
             "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
              8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
             "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
              37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
             "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 
              37., 86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
             "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444,
               10.111, 
              Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
             "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
              16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
             "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 
              3.545, 13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
             "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
              261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
             "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 
              238.2, 320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
             "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499,
               144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
             "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
              166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
             "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 
              181., 222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
             "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
              36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
             "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 
              61.556, 127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
             "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625,
               89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
             "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
              55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
             "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
              102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
             "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
              75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
             "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 
              34.636, 72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
             "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
              48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
             "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
              48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
             "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 
              3466.65991, 23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
             "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173.,
               317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
             "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
              84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
             "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 
              213., 2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
             "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
              88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
             "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 
              115., 11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
             "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
              98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
             "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5,
               143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
             "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 
              132.5, 197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
             "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2,
               1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
             "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
              10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
             "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
              200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
             "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
              77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
             "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 
              47.5, 276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
             "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 
              46.667, 123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
             "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
              75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
             "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48.,
               116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
             "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
              188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
             "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39.,
               72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
             "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 
              116.2, 16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
             "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 
              44., 34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
             "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
              27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
             "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 
              24., 58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
             "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
              175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
             "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 
              236., 22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
             "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 
              125.8, 26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
             "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 
              20.667, 54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
             "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 
              75.333, 34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
             "spring", "large", "low", 9., 5.8, 
              Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 
              0., 0., 0.}, {
             "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
              151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
             "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 
              180.66701, 269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
             "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
              46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
             "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
              85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
             "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
              66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
             "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
              102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
             "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
              84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
             "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 
              221.89999, 246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 
              1.7}, {"autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 
              627.27301, 205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 
              0.}, {"winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 
              1168., 236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 
              17.2, 0.}, {
             "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
              1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0.,
               5.9, 1.7}, {
             "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
              82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
             "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
              64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
             "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
              87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
             "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
              159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
             "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
              21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
             "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 
              11., 0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
             "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 
              7.667, 14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
             "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 
              3.222, 7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
             "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2,
               0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
             "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
              7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
             "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16.,
               2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
             "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
              56.091, 
              Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
             "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625,
               52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
             "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
              104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
             "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3,
               85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
             "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
              87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
             "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
              101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
             "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
              50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
             "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 
              34.5, 81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
             "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
              19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
             "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 
              19.111, 120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
             "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
              51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
             "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
              19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
             "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 
              53.625, 79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
             "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 
              35.333, 75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
             "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 
              78.333, 140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
             "winter", "large", "medium", 8., 7.6, 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
             "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
              140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
          Flatten[
           $CellContext`sym$2505[$CellContext`mxPH, 
            "missing"]]]], $CellContext`sym$2505[$CellContext`NH4] = Part[
         $CellContext`sym$2505[$CellContext`NH4, "raw"], 
         Complement[
          Range[
           
           Length[{{
             "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 
              170., 50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
             "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 
              428.75, 558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
             "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
              125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
             "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
              61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
             "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 
              58.222, 97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
             "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25,
               56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
             "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25,
               111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
             "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
              44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
             "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 
              36.3, 71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
             "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6,
               0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
             "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
              20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
             "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 
              10.667, 19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
             "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 
              17., 41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
             "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 
              0.5, 31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
             "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
              0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
             "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
              98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
             "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 
              50., 1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
             "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
              57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
             "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 
              61.5, 0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
             "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
              564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
             "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 
              467.5, 586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
             "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
              0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
             "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 
              40., 7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
             "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 
              3., 27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
             "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 
              11.5, 1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
             "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
              44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
             "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6,
               0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
             "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
              Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
             "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 
              0.8, 17.1, 0., 19.6, 0., 0., 0., 2.5}, {
             "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 
              0.5, 33.9, 1., 14.6, 0., 0., 0., 0.}, {
             "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
              4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
             "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304.,
               2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
             "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
              130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
             "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 
              47., 2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
             "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 
              23., 0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
             "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
              58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
             "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 
              3., 0.2, 66., 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 8., 
              Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 
              0., 0.}, {
             "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
              196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
             "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001,
               182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
             "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 
              143.71001, 296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
             "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
              59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
             "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
              344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
             "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
              276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
             "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
              40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
             "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5,
               3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
             "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
              0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {
             "winter", "small", "low", 
              Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 
              0., 0., 0.}, {
             "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121.,
               2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
             "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
              20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
             "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 
              12.75, 49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
             "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3,
               22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
             "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
              11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 
              11.818, 0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
             "winter", "small", "high", 6.6, 10.8, 
              Missing[], 3.245, 10., 1., 6.5, 
              Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "medium", 5.6, 11.8, 
              Missing[], 2.22, 5., 1., 1., 
              Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
             "autumn", "small", "medium", 5.7, 10.8, 
              Missing[], 2.55, 10., 1., 4., 
              Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
             "spring", "small", "high", 6.6, 9.5, 
              Missing[], 1.32, 20., 1., 6., 
              Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
             "summer", "small", "high", 6.6, 10.8, 
              Missing[], 2.64, 10., 2., 11., 
              Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
             "autumn", "small", "medium", 6.6, 11.3, 
              Missing[], 4.17, 10., 1., 6., 
              Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
             "spring", "small", "medium", 6.5, 10.4, 
              Missing[], 5.97, 10., 2., 14., 
              Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
             "summer", "small", "medium", 6.4, 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 14., 
              Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
             "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
              6.667, 
              Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 
              6.75, 1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
             "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 
              7.2, 0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
             "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 
              6., 0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
             "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
              10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
             "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 
              2.5, 0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
             "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 
              220.75, 351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
             "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
              209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
             "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
              151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
             "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
              152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
             "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 
              55., 58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
             "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 
              136.75, 249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
             "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
              100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
             "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
              215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
             "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
              25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
             "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36.,
               105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
             "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 
              37.375, 111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
             "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 
              108., 1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
             "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
              56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
             "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 
              60., 4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
             "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 
              27.667, 104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
             "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32.,
               69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
             "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 
              111.25, 214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
             "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 
              137.60001, 254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
             "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 
              429.20001, 57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 
              16.7}, {"winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 
              5738.33008, 412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0.,
               2.4}, {"summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 
              4073.33008, 282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 
              9.9, 0.}, {
             "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
              197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
             "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
              267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
             "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
              191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
             "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 
              120.5, 232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
             "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
              144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
             "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
              218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
             "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23.,
               138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
             "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 
              104.222, 239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
             "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
              235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
             "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 
              51.75, 205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
             "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
              31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
             "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 
              28.625, 186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
             "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
              12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
             "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
              51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
             "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 
              104.5, 292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
             "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 
              38.625, 285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
             "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 
              24.667, 201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
             "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
              275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
             "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 
              39., 124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
             "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
              60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
             "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 
              71., 132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
             "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 
              9.667, 17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
             "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 
              26., 0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
             "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
              8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
             "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
              37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
             "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 
              37., 86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
             "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444,
               10.111, 
              Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
             "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
              16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
             "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 
              3.545, 13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
             "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
              261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
             "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 
              238.2, 320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
             "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499,
               144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
             "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
              166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
             "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 
              181., 222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
             "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
              36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
             "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 
              61.556, 127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
             "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625,
               89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
             "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
              55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
             "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
              102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
             "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
              75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
             "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 
              34.636, 72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
             "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
              48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
             "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
              48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
             "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 
              3466.65991, 23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
             "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173.,
               317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
             "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
              84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
             "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 
              213., 2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
             "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
              88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
             "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 
              115., 11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
             "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
              98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
             "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5,
               143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
             "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 
              132.5, 197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
             "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2,
               1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
             "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
              10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
             "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
              200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
             "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
              77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
             "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 
              47.5, 276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
             "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 
              46.667, 123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
             "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
              75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
             "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48.,
               116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
             "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
              188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
             "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39.,
               72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
             "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 
              116.2, 16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
             "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 
              44., 34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
             "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
              27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
             "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 
              24., 58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
             "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
              175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
             "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 
              236., 22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
             "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 
              125.8, 26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
             "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 
              20.667, 54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
             "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 
              75.333, 34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
             "spring", "large", "low", 9., 5.8, 
              Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 
              0., 0., 0.}, {
             "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
              151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
             "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 
              180.66701, 269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
             "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
              46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
             "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
              85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
             "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
              66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
             "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
              102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
             "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
              84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
             "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 
              221.89999, 246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 
              1.7}, {"autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 
              627.27301, 205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 
              0.}, {"winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 
              1168., 236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 
              17.2, 0.}, {
             "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
              1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0.,
               5.9, 1.7}, {
             "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
              82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
             "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
              64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
             "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
              87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
             "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
              159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
             "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
              21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
             "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 
              11., 0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
             "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 
              7.667, 14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
             "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 
              3.222, 7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
             "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2,
               0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
             "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
              7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
             "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16.,
               2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
             "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
              56.091, 
              Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
             "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625,
               52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
             "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
              104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
             "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3,
               85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
             "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
              87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
             "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
              101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
             "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
              50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
             "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 
              34.5, 81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
             "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
              19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
             "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 
              19.111, 120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
             "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
              51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
             "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
              19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
             "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 
              53.625, 79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
             "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 
              35.333, 75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
             "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 
              78.333, 140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
             "winter", "large", "medium", 8., 7.6, 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
             "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
              140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
          Flatten[
           $CellContext`sym$2505[$CellContext`NH4, 
            "missing"]]]], $CellContext`sym$2505[$CellContext`NO3] = Part[
         $CellContext`sym$2505[$CellContext`NO3, "raw"], 
         Complement[
          Range[
           
           Length[{{
             "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 
              170., 50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
             "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 
              428.75, 558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
             "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
              125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
             "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
              61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
             "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 
              58.222, 97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
             "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25,
               56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
             "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25,
               111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
             "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
              44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
             "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 
              36.3, 71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
             "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6,
               0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
             "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
              20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
             "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 
              10.667, 19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
             "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 
              17., 41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
             "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 
              0.5, 31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
             "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
              0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
             "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
              98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
             "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 
              50., 1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
             "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
              57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
             "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 
              61.5, 0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
             "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
              564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
             "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 
              467.5, 586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
             "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
              0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
             "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 
              40., 7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
             "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 
              3., 27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
             "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 
              11.5, 1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
             "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
              44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
             "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6,
               0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
             "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
              Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
             "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 
              0.8, 17.1, 0., 19.6, 0., 0., 0., 2.5}, {
             "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 
              0.5, 33.9, 1., 14.6, 0., 0., 0., 0.}, {
             "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
              4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
             "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304.,
               2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
             "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
              130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
             "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 
              47., 2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
             "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 
              23., 0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
             "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
              58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
             "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 
              3., 0.2, 66., 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 8., 
              Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 
              0., 0.}, {
             "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
              196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
             "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001,
               182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
             "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 
              143.71001, 296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
             "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
              59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
             "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
              344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
             "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
              276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
             "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
              40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
             "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5,
               3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
             "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
              0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {
             "winter", "small", "low", 
              Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 
              0., 0., 0.}, {
             "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121.,
               2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
             "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
              20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
             "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 
              12.75, 49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
             "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3,
               22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
             "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
              11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 
              11.818, 0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
             "winter", "small", "high", 6.6, 10.8, 
              Missing[], 3.245, 10., 1., 6.5, 
              Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "medium", 5.6, 11.8, 
              Missing[], 2.22, 5., 1., 1., 
              Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
             "autumn", "small", "medium", 5.7, 10.8, 
              Missing[], 2.55, 10., 1., 4., 
              Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
             "spring", "small", "high", 6.6, 9.5, 
              Missing[], 1.32, 20., 1., 6., 
              Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
             "summer", "small", "high", 6.6, 10.8, 
              Missing[], 2.64, 10., 2., 11., 
              Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
             "autumn", "small", "medium", 6.6, 11.3, 
              Missing[], 4.17, 10., 1., 6., 
              Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
             "spring", "small", "medium", 6.5, 10.4, 
              Missing[], 5.97, 10., 2., 14., 
              Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
             "summer", "small", "medium", 6.4, 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 14., 
              Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
             "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
              6.667, 
              Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 
              6.75, 1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
             "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 
              7.2, 0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
             "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 
              6., 0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
             "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
              10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
             "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 
              2.5, 0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
             "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 
              220.75, 351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
             "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
              209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
             "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
              151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
             "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
              152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
             "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 
              55., 58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
             "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 
              136.75, 249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
             "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
              100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
             "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
              215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
             "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
              25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
             "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36.,
               105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
             "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 
              37.375, 111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
             "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 
              108., 1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
             "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
              56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
             "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 
              60., 4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
             "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 
              27.667, 104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
             "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32.,
               69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
             "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 
              111.25, 214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
             "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 
              137.60001, 254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
             "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 
              429.20001, 57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 
              16.7}, {"winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 
              5738.33008, 412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0.,
               2.4}, {"summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 
              4073.33008, 282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 
              9.9, 0.}, {
             "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
              197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
             "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
              267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
             "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
              191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
             "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 
              120.5, 232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
             "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
              144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
             "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
              218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
             "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23.,
               138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
             "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 
              104.222, 239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
             "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
              235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
             "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 
              51.75, 205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
             "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
              31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
             "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 
              28.625, 186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
             "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
              12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
             "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
              51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
             "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 
              104.5, 292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
             "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 
              38.625, 285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
             "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 
              24.667, 201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
             "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
              275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
             "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 
              39., 124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
             "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
              60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
             "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 
              71., 132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
             "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 
              9.667, 17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
             "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 
              26., 0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
             "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
              8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
             "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
              37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
             "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 
              37., 86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
             "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444,
               10.111, 
              Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
             "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
              16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
             "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 
              3.545, 13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
             "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
              261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
             "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 
              238.2, 320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
             "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499,
               144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
             "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
              166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
             "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 
              181., 222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
             "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
              36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
             "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 
              61.556, 127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
             "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625,
               89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
             "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
              55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
             "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
              102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
             "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
              75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
             "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 
              34.636, 72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
             "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
              48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
             "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
              48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
             "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 
              3466.65991, 23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
             "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173.,
               317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
             "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
              84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
             "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 
              213., 2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
             "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
              88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
             "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 
              115., 11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
             "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
              98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
             "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5,
               143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
             "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 
              132.5, 197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
             "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2,
               1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
             "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
              10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
             "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
              200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
             "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
              77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
             "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 
              47.5, 276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
             "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 
              46.667, 123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
             "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
              75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
             "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48.,
               116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
             "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
              188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
             "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39.,
               72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
             "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 
              116.2, 16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
             "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 
              44., 34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
             "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
              27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
             "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 
              24., 58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
             "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
              175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
             "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 
              236., 22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
             "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 
              125.8, 26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
             "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 
              20.667, 54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
             "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 
              75.333, 34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
             "spring", "large", "low", 9., 5.8, 
              Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 
              0., 0., 0.}, {
             "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
              151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
             "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 
              180.66701, 269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
             "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
              46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
             "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
              85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
             "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
              66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
             "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
              102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
             "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
              84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
             "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 
              221.89999, 246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 
              1.7}, {"autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 
              627.27301, 205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 
              0.}, {"winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 
              1168., 236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 
              17.2, 0.}, {
             "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
              1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0.,
               5.9, 1.7}, {
             "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
              82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
             "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
              64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
             "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
              87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
             "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
              159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
             "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
              21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
             "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 
              11., 0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
             "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 
              7.667, 14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
             "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 
              3.222, 7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
             "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2,
               0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
             "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
              7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
             "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16.,
               2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
             "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
              56.091, 
              Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
             "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625,
               52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
             "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
              104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
             "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3,
               85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
             "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
              87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
             "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
              101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
             "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
              50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
             "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 
              34.5, 81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
             "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
              19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
             "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 
              19.111, 120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
             "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
              51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
             "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
              19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
             "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 
              53.625, 79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
             "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 
              35.333, 75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
             "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 
              78.333, 140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
             "winter", "large", "medium", 8., 7.6, 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
             "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
              140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
          Flatten[
           $CellContext`sym$2505[$CellContext`NO3, 
            "missing"]]]], $CellContext`sym$2505[$CellContext`oPO4] = Part[
         $CellContext`sym$2505[$CellContext`oPO4, "raw"], 
         Complement[
          Range[
           
           Length[{{
             "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 
              170., 50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
             "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 
              428.75, 558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
             "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
              125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
             "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
              61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
             "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 
              58.222, 97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
             "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25,
               56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
             "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25,
               111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
             "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
              44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
             "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 
              36.3, 71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
             "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6,
               0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
             "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
              20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
             "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 
              10.667, 19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
             "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 
              17., 41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
             "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 
              0.5, 31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
             "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
              0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
             "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
              98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
             "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 
              50., 1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
             "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
              57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
             "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 
              61.5, 0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
             "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
              564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
             "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 
              467.5, 586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
             "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
              0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
             "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 
              40., 7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
             "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 
              3., 27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
             "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 
              11.5, 1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
             "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
              44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
             "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6,
               0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
             "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
              Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
             "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 
              0.8, 17.1, 0., 19.6, 0., 0., 0., 2.5}, {
             "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 
              0.5, 33.9, 1., 14.6, 0., 0., 0., 0.}, {
             "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
              4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
             "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304.,
               2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
             "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
              130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
             "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 
              47., 2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
             "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 
              23., 0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
             "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
              58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
             "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 
              3., 0.2, 66., 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 8., 
              Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 
              0., 0.}, {
             "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
              196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
             "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001,
               182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
             "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 
              143.71001, 296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
             "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
              59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
             "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
              344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
             "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
              276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
             "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
              40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
             "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5,
               3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
             "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
              0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {
             "winter", "small", "low", 
              Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 
              0., 0., 0.}, {
             "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121.,
               2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
             "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
              20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
             "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 
              12.75, 49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
             "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3,
               22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
             "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
              11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 
              11.818, 0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
             "winter", "small", "high", 6.6, 10.8, 
              Missing[], 3.245, 10., 1., 6.5, 
              Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "medium", 5.6, 11.8, 
              Missing[], 2.22, 5., 1., 1., 
              Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
             "autumn", "small", "medium", 5.7, 10.8, 
              Missing[], 2.55, 10., 1., 4., 
              Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
             "spring", "small", "high", 6.6, 9.5, 
              Missing[], 1.32, 20., 1., 6., 
              Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
             "summer", "small", "high", 6.6, 10.8, 
              Missing[], 2.64, 10., 2., 11., 
              Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
             "autumn", "small", "medium", 6.6, 11.3, 
              Missing[], 4.17, 10., 1., 6., 
              Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
             "spring", "small", "medium", 6.5, 10.4, 
              Missing[], 5.97, 10., 2., 14., 
              Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
             "summer", "small", "medium", 6.4, 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 14., 
              Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
             "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
              6.667, 
              Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 
              6.75, 1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
             "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 
              7.2, 0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
             "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 
              6., 0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
             "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
              10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
             "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 
              2.5, 0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
             "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 
              220.75, 351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
             "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
              209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
             "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
              151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
             "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
              152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
             "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 
              55., 58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
             "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 
              136.75, 249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
             "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
              100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
             "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
              215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
             "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
              25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
             "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36.,
               105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
             "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 
              37.375, 111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
             "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 
              108., 1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
             "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
              56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
             "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 
              60., 4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
             "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 
              27.667, 104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
             "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32.,
               69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
             "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 
              111.25, 214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
             "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 
              137.60001, 254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
             "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 
              429.20001, 57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 
              16.7}, {"winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 
              5738.33008, 412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0.,
               2.4}, {"summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 
              4073.33008, 282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 
              9.9, 0.}, {
             "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
              197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
             "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
              267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
             "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
              191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
             "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 
              120.5, 232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
             "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
              144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
             "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
              218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
             "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23.,
               138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
             "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 
              104.222, 239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
             "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
              235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
             "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 
              51.75, 205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
             "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
              31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
             "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 
              28.625, 186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
             "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
              12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
             "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
              51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
             "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 
              104.5, 292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
             "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 
              38.625, 285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
             "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 
              24.667, 201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
             "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
              275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
             "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 
              39., 124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
             "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
              60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
             "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 
              71., 132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
             "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 
              9.667, 17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
             "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 
              26., 0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
             "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
              8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
             "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
              37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
             "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 
              37., 86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
             "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444,
               10.111, 
              Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
             "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
              16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
             "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 
              3.545, 13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
             "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
              261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
             "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 
              238.2, 320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
             "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499,
               144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
             "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
              166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
             "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 
              181., 222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
             "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
              36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
             "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 
              61.556, 127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
             "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625,
               89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
             "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
              55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
             "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
              102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
             "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
              75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
             "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 
              34.636, 72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
             "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
              48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
             "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
              48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
             "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 
              3466.65991, 23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
             "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173.,
               317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
             "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
              84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
             "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 
              213., 2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
             "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
              88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
             "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 
              115., 11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
             "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
              98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
             "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5,
               143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
             "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 
              132.5, 197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
             "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2,
               1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
             "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
              10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
             "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
              200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
             "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
              77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
             "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 
              47.5, 276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
             "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 
              46.667, 123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
             "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
              75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
             "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48.,
               116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
             "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
              188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
             "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39.,
               72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
             "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 
              116.2, 16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
             "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 
              44., 34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
             "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
              27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
             "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 
              24., 58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
             "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
              175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
             "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 
              236., 22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
             "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 
              125.8, 26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
             "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 
              20.667, 54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
             "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 
              75.333, 34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
             "spring", "large", "low", 9., 5.8, 
              Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 
              0., 0., 0.}, {
             "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
              151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
             "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 
              180.66701, 269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
             "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
              46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
             "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
              85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
             "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
              66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
             "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
              102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
             "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
              84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
             "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 
              221.89999, 246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 
              1.7}, {"autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 
              627.27301, 205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 
              0.}, {"winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 
              1168., 236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 
              17.2, 0.}, {
             "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
              1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0.,
               5.9, 1.7}, {
             "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
              82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
             "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
              64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
             "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
              87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
             "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
              159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
             "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
              21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
             "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 
              11., 0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
             "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 
              7.667, 14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
             "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 
              3.222, 7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
             "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2,
               0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
             "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
              7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
             "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16.,
               2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
             "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
              56.091, 
              Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
             "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625,
               52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
             "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
              104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
             "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3,
               85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
             "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
              87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
             "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
              101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
             "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
              50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
             "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 
              34.5, 81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
             "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
              19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
             "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 
              19.111, 120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
             "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
              51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
             "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
              19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
             "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 
              53.625, 79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
             "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 
              35.333, 75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
             "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 
              78.333, 140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
             "winter", "large", "medium", 8., 7.6, 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
             "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
              140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
          Flatten[
           $CellContext`sym$2505[$CellContext`oPO4, 
            "missing"]]]], $CellContext`sym$2505[$CellContext`PO4] = Part[
         $CellContext`sym$2505[$CellContext`PO4, "raw"], 
         Complement[
          Range[
           
           Length[{{
             "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 
              170., 50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
             "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 
              428.75, 558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
             "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
              125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
             "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
              61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
             "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 
              58.222, 97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
             "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25,
               56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
             "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25,
               111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
             "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
              44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
             "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 
              36.3, 71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
             "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6,
               0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
             "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
              20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
             "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 
              10.667, 19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
             "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 
              17., 41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
             "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 
              0.5, 31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
             "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
              0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
             "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
              98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
             "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 
              50., 1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
             "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
              57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
             "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 
              61.5, 0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
             "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
              564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
             "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 
              467.5, 586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
             "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
              0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
             "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 
              40., 7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
             "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 
              3., 27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
             "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 
              11.5, 1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
             "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
              44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
             "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6,
               0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
             "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
              Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
             "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 
              0.8, 17.1, 0., 19.6, 0., 0., 0., 2.5}, {
             "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 
              0.5, 33.9, 1., 14.6, 0., 0., 0., 0.}, {
             "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
              4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
             "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304.,
               2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
             "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
              130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
             "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 
              47., 2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
             "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 
              23., 0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
             "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
              58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
             "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 
              3., 0.2, 66., 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 8., 
              Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 
              0., 0.}, {
             "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
              196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
             "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001,
               182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
             "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 
              143.71001, 296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
             "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
              59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
             "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
              344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
             "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
              276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
             "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
              40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
             "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5,
               3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
             "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
              0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {
             "winter", "small", "low", 
              Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 
              0., 0., 0.}, {
             "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121.,
               2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
             "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
              20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
             "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 
              12.75, 49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
             "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3,
               22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
             "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
              11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 
              11.818, 0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
             "winter", "small", "high", 6.6, 10.8, 
              Missing[], 3.245, 10., 1., 6.5, 
              Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "medium", 5.6, 11.8, 
              Missing[], 2.22, 5., 1., 1., 
              Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
             "autumn", "small", "medium", 5.7, 10.8, 
              Missing[], 2.55, 10., 1., 4., 
              Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
             "spring", "small", "high", 6.6, 9.5, 
              Missing[], 1.32, 20., 1., 6., 
              Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
             "summer", "small", "high", 6.6, 10.8, 
              Missing[], 2.64, 10., 2., 11., 
              Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
             "autumn", "small", "medium", 6.6, 11.3, 
              Missing[], 4.17, 10., 1., 6., 
              Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
             "spring", "small", "medium", 6.5, 10.4, 
              Missing[], 5.97, 10., 2., 14., 
              Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
             "summer", "small", "medium", 6.4, 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 14., 
              Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
             "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
              6.667, 
              Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 
              6.75, 1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
             "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 
              7.2, 0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
             "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 
              6., 0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
             "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
              10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
             "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 
              2.5, 0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
             "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 
              220.75, 351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
             "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
              209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
             "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
              151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
             "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
              152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
             "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 
              55., 58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
             "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 
              136.75, 249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
             "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
              100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
             "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
              215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
             "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
              25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
             "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36.,
               105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
             "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 
              37.375, 111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
             "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 
              108., 1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
             "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
              56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
             "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 
              60., 4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
             "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 
              27.667, 104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
             "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32.,
               69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
             "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 
              111.25, 214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
             "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 
              137.60001, 254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
             "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 
              429.20001, 57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 
              16.7}, {"winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 
              5738.33008, 412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0.,
               2.4}, {
             "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008,
               282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
             "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
              197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
             "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
              267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
             "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
              191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
             "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 
              120.5, 232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
             "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
              144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
             "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
              218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
             "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23.,
               138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
             "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 
              104.222, 239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
             "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
              235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
             "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 
              51.75, 205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
             "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
              31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
             "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 
              28.625, 186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
             "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
              12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
             "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
              51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
             "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 
              104.5, 292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
             "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 
              38.625, 285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
             "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 
              24.667, 201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
             "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
              275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
             "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 
              39., 124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
             "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
              60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
             "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 
              71., 132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
             "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 
              9.667, 17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
             "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 
              26., 0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
             "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
              8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
             "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
              37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
             "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 
              37., 86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
             "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444,
               10.111, 
              Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
             "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
              16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
             "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 
              3.545, 13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
             "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
              261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
             "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 
              238.2, 320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
             "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499,
               144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
             "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
              166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
             "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 
              181., 222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
             "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
              36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
             "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 
              61.556, 127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
             "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625,
               89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
             "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
              55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
             "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
              102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
             "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
              75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
             "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 
              34.636, 72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
             "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
              48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
             "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
              48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
             "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 
              3466.65991, 23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
             "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173.,
               317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
             "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
              84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
             "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 
              213., 2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
             "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
              88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
             "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 
              115., 11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
             "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
              98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
             "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5,
               143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
             "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 
              132.5, 197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
             "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2,
               1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
             "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
              10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
             "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
              200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
             "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
              77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
             "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 
              47.5, 276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
             "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 
              46.667, 123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
             "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
              75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
             "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48.,
               116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
             "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
              188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
             "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39.,
               72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
             "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 
              116.2, 16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
             "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 
              44., 34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
             "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
              27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
             "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 
              24., 58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
             "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
              175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
             "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 
              236., 22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
             "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 
              125.8, 26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
             "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 
              20.667, 54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
             "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 
              75.333, 34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
             "spring", "large", "low", 9., 5.8, 
              Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 
              0., 0., 0.}, {
             "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
              151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
             "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 
              180.66701, 269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
             "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
              46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
             "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
              85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
             "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
              66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
             "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
              102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
             "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
              84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
             "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 
              221.89999, 246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 
              1.7}, {"autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 
              627.27301, 205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 
              0.}, {"winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 
              1168., 236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 
              17.2, 0.}, {
             "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
              1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0.,
               5.9, 1.7}, {
             "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
              82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
             "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
              64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
             "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
              87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
             "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
              159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
             "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
              21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
             "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 
              11., 0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
             "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 
              7.667, 14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
             "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 
              3.222, 7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
             "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2,
               0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
             "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
              7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
             "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16.,
               2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
             "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
              56.091, 
              Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
             "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625,
               52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
             "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
              104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
             "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3,
               85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
             "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
              87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
             "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
              101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
             "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
              50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
             "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 
              34.5, 81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
             "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
              19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
             "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 
              19.111, 120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
             "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
              51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
             "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
              19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
             "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 
              53.625, 79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
             "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 
              35.333, 75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
             "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 
              78.333, 140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
             "winter", "large", "medium", 8., 7.6, 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
             "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
              140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
          Flatten[
           $CellContext`sym$2505[$CellContext`PO4, 
            "missing"]]]], $CellContext`sym$2505[$CellContext`season] = Part[
         $CellContext`sym$2505[$CellContext`season, "raw"], 
         Complement[
          Range[
           
           Length[{{
             "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 
              170., 50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
             "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 
              428.75, 558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
             "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
              125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
             "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
              61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
             "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 
              58.222, 97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
             "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25,
               56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
             "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25,
               111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
             "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
              44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
             "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 
              36.3, 71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
             "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6,
               0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
             "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
              20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
             "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 
              10.667, 19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
             "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 
              17., 41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
             "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 
              0.5, 31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
             "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
              0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
             "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
              98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
             "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 
              50., 1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
             "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
              57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
             "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 
              61.5, 0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
             "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
              564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
             "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 
              467.5, 586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
             "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
              0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
             "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 
              40., 7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
             "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 
              3., 27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
             "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 
              11.5, 1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
             "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
              44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
             "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6,
               0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
             "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
              Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
             "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 
              0.8, 17.1, 0., 19.6, 0., 0., 0., 2.5}, {
             "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 
              0.5, 33.9, 1., 14.6, 0., 0., 0., 0.}, {
             "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
              4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
             "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304.,
               2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
             "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
              130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
             "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 
              47., 2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
             "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 
              23., 0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
             "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
              58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
             "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 
              3., 0.2, 66., 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 8., 
              Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 
              0., 0.}, {
             "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
              196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
             "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001,
               182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
             "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 
              143.71001, 296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
             "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
              59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
             "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
              344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
             "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
              276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
             "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
              40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
             "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5,
               3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
             "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
              0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {
             "winter", "small", "low", 
              Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 
              0., 0., 0.}, {
             "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121.,
               2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
             "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
              20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
             "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 
              12.75, 49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
             "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3,
               22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
             "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
              11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 
              11.818, 0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
             "winter", "small", "high", 6.6, 10.8, 
              Missing[], 3.245, 10., 1., 6.5, 
              Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "medium", 5.6, 11.8, 
              Missing[], 2.22, 5., 1., 1., 
              Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
             "autumn", "small", "medium", 5.7, 10.8, 
              Missing[], 2.55, 10., 1., 4., 
              Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
             "spring", "small", "high", 6.6, 9.5, 
              Missing[], 1.32, 20., 1., 6., 
              Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
             "summer", "small", "high", 6.6, 10.8, 
              Missing[], 2.64, 10., 2., 11., 
              Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
             "autumn", "small", "medium", 6.6, 11.3, 
              Missing[], 4.17, 10., 1., 6., 
              Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
             "spring", "small", "medium", 6.5, 10.4, 
              Missing[], 5.97, 10., 2., 14., 
              Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
             "summer", "small", "medium", 6.4, 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 14., 
              Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
             "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
              6.667, 
              Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 
              6.75, 1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
             "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 
              7.2, 0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
             "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 
              6., 0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
             "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
              10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
             "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 
              2.5, 0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
             "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 
              220.75, 351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
             "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
              209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
             "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
              151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
             "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
              152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
             "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 
              55., 58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
             "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 
              136.75, 249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
             "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
              100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
             "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
              215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
             "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
              25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
             "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36.,
               105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
             "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 
              37.375, 111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
             "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 
              108., 1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
             "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
              56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
             "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 
              60., 4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
             "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 
              27.667, 104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
             "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32.,
               69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
             "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 
              111.25, 214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
             "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 
              137.60001, 254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
             "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 
              429.20001, 57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 
              16.7}, {"winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 
              5738.33008, 412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0.,
               2.4}, {"summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 
              4073.33008, 282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 
              9.9, 0.}, {
             "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
              197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
             "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
              267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
             "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
              191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
             "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 
              120.5, 232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
             "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
              144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
             "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
              218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
             "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23.,
               138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
             "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 
              104.222, 239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
             "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
              235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
             "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 
              51.75, 205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
             "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
              31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
             "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 
              28.625, 186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
             "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
              12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
             "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
              51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
             "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 
              104.5, 292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
             "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 
              38.625, 285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
             "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 
              24.667, 201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
             "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
              275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
             "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 
              39., 124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
             "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
              60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
             "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 
              71., 132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
             "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 
              9.667, 17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
             "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 
              26., 0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
             "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
              8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
             "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
              37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
             "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 
              37., 86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
             "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444,
               10.111, 
              Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
             "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
              16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
             "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 
              3.545, 13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
             "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
              261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
             "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 
              238.2, 320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
             "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499,
               144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
             "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
              166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
             "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 
              181., 222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
             "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
              36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
             "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 
              61.556, 127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
             "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625,
               89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
             "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
              55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
             "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
              102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
             "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
              75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
             "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 
              34.636, 72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
             "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
              48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
             "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
              48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
             "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 
              3466.65991, 23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
             "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173.,
               317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
             "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
              84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
             "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 
              213., 2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
             "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
              88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
             "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 
              115., 11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
             "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
              98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
             "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5,
               143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
             "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 
              132.5, 197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
             "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2,
               1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
             "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
              10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
             "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
              200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
             "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
              77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
             "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 
              47.5, 276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
             "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 
              46.667, 123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
             "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
              75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
             "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48.,
               116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
             "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
              188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
             "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39.,
               72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
             "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 
              116.2, 16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
             "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 
              44., 34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
             "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
              27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
             "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 
              24., 58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
             "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
              175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
             "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 
              236., 22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
             "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 
              125.8, 26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
             "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 
              20.667, 54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
             "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 
              75.333, 34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
             "spring", "large", "low", 9., 5.8, 
              Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 
              0., 0., 0.}, {
             "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
              151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
             "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 
              180.66701, 269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
             "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
              46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
             "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
              85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
             "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
              66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
             "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
              102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
             "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
              84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
             "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 
              221.89999, 246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 
              1.7}, {"autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 
              627.27301, 205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 
              0.}, {"winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 
              1168., 236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 
              17.2, 0.}, {
             "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
              1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0.,
               5.9, 1.7}, {
             "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
              82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
             "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
              64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
             "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
              87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
             "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
              159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
             "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
              21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
             "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 
              11., 0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
             "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 
              7.667, 14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
             "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 
              3.222, 7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
             "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2,
               0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
             "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
              7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
             "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16.,
               2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
             "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
              56.091, 
              Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
             "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625,
               52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
             "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
              104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
             "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3,
               85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
             "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
              87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
             "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
              101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
             "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
              50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
             "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 
              34.5, 81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
             "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
              19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
             "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 
              19.111, 120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
             "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
              51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
             "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
              19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
             "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 
              53.625, 79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
             "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 
              35.333, 75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
             "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 
              78.333, 140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
             "winter", "large", "medium", 8., 7.6, 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
             "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
              140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
          Flatten[
           $CellContext`sym$2505[$CellContext`season, 
            "missing"]]]], $CellContext`sym$2505[$CellContext`size] = Part[
         $CellContext`sym$2505[$CellContext`size, "raw"], 
         Complement[
          Range[
           
           Length[{{
             "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 
              170., 50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
             "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 
              428.75, 558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
             "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
              125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
             "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
              61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
             "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 
              58.222, 97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
             "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25,
               56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
             "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25,
               111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
             "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
              44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
             "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 
              36.3, 71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
             "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6,
               0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
             "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
              20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
             "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 
              10.667, 19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
             "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 
              17., 41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
             "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 
              0.5, 31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
             "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
              0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
             "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
              98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
             "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 
              50., 1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
             "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
              57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
             "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 
              61.5, 0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
             "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
              564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
             "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 
              467.5, 586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
             "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
              0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
             "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 
              40., 7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
             "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 
              3., 27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
             "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 
              11.5, 1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
             "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
              44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
             "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6,
               0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
             "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
              Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
             "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 
              0.8, 17.1, 0., 19.6, 0., 0., 0., 2.5}, {
             "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 
              0.5, 33.9, 1., 14.6, 0., 0., 0., 0.}, {
             "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
              4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
             "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304.,
               2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
             "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
              130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
             "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 
              47., 2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
             "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 
              23., 0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
             "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
              58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
             "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 
              3., 0.2, 66., 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 8., 
              Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 
              0., 0.}, {
             "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
              196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
             "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001,
               182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
             "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 
              143.71001, 296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
             "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
              59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
             "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
              344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
             "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
              276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
             "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
              40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
             "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5,
               3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
             "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
              0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {
             "winter", "small", "low", 
              Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 
              0., 0., 0.}, {
             "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121.,
               2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
             "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
              20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
             "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 
              12.75, 49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
             "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3,
               22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
             "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
              11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 
              11.818, 0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
             "winter", "small", "high", 6.6, 10.8, 
              Missing[], 3.245, 10., 1., 6.5, 
              Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "medium", 5.6, 11.8, 
              Missing[], 2.22, 5., 1., 1., 
              Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
             "autumn", "small", "medium", 5.7, 10.8, 
              Missing[], 2.55, 10., 1., 4., 
              Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
             "spring", "small", "high", 6.6, 9.5, 
              Missing[], 1.32, 20., 1., 6., 
              Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
             "summer", "small", "high", 6.6, 10.8, 
              Missing[], 2.64, 10., 2., 11., 
              Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
             "autumn", "small", "medium", 6.6, 11.3, 
              Missing[], 4.17, 10., 1., 6., 
              Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
             "spring", "small", "medium", 6.5, 10.4, 
              Missing[], 5.97, 10., 2., 14., 
              Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
             "summer", "small", "medium", 6.4, 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 14., 
              Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
             "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
              6.667, 
              Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 
              6.75, 1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
             "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 
              7.2, 0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
             "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 
              6., 0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
             "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
              10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
             "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 
              2.5, 0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
             "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 
              220.75, 351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
             "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
              209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
             "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
              151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
             "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
              152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
             "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 
              55., 58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
             "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 
              136.75, 249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
             "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
              100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
             "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
              215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
             "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
              25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
             "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36.,
               105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
             "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 
              37.375, 111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
             "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 
              108., 1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
             "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
              56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
             "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 
              60., 4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
             "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 
              27.667, 104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
             "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32.,
               69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
             "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 
              111.25, 214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
             "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 
              137.60001, 254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
             "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 
              429.20001, 57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 
              16.7}, {"winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 
              5738.33008, 412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0.,
               2.4}, {"summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 
              4073.33008, 282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 
              9.9, 0.}, {
             "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
              197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
             "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
              267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
             "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
              191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
             "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 
              120.5, 232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
             "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
              144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
             "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
              218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
             "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23.,
               138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
             "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 
              104.222, 239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
             "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
              235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
             "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 
              51.75, 205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
             "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
              31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
             "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 
              28.625, 186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
             "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
              12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
             "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
              51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
             "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 
              104.5, 292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
             "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 
              38.625, 285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
             "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 
              24.667, 201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
             "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
              275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
             "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 
              39., 124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
             "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
              60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
             "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 
              71., 132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
             "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 
              9.667, 17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
             "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 
              26., 0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
             "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
              8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
             "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
              37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
             "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 
              37., 86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
             "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444,
               10.111, 
              Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
             "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
              16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
             "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 
              3.545, 13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
             "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
              261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
             "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 
              238.2, 320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
             "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499,
               144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
             "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
              166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
             "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 
              181., 222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
             "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
              36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
             "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 
              61.556, 127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
             "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625,
               89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
             "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
              55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
             "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
              102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
             "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
              75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
             "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 
              34.636, 72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
             "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
              48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
             "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
              48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
             "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 
              3466.65991, 23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
             "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173.,
               317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
             "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
              84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
             "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 
              213., 2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
             "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
              88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
             "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 
              115., 11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
             "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
              98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
             "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5,
               143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
             "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 
              132.5, 197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
             "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2,
               1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
             "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
              10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
             "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
              200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
             "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
              77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
             "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 
              47.5, 276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
             "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 
              46.667, 123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
             "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
              75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
             "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48.,
               116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
             "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
              188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
             "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39.,
               72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
             "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 
              116.2, 16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
             "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 
              44., 34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
             "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
              27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
             "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 
              24., 58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
             "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
              175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
             "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 
              236., 22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
             "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 
              125.8, 26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
             "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 
              20.667, 54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
             "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 
              75.333, 34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
             "spring", "large", "low", 9., 5.8, 
              Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 
              0., 0., 0.}, {
             "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
              151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
             "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 
              180.66701, 269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
             "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
              46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
             "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
              85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
             "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
              66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
             "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
              102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
             "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
              84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
             "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 
              221.89999, 246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 
              1.7}, {"autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 
              627.27301, 205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 
              0.}, {"winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 
              1168., 236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 
              17.2, 0.}, {
             "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
              1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0.,
               5.9, 1.7}, {
             "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
              82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
             "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
              64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
             "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
              87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
             "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
              159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
             "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
              21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
             "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 
              11., 0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
             "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 
              7.667, 14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
             "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 
              3.222, 7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
             "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2,
               0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
             "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
              7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
             "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16.,
               2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
             "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
              56.091, 
              Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
             "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625,
               52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
             "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
              104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
             "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3,
               85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
             "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
              87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
             "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
              101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
             "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
              50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
             "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 
              34.5, 81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
             "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
              19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
             "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 
              19.111, 120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
             "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
              51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
             "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
              19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
             "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 
              53.625, 79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
             "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 
              35.333, 75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
             "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 
              78.333, 140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
             "winter", "large", "medium", 8., 7.6, 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
             "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
              140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
          Flatten[
           $CellContext`sym$2505[$CellContext`size, 
            "missing"]]]], $CellContext`sym$2505[$CellContext`speed] = Part[
         $CellContext`sym$2505[$CellContext`speed, "raw"], 
         Complement[
          Range[
           
           Length[{{
             "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 
              170., 50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
             "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 
              428.75, 558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
             "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
              125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
             "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
              61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
             "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 
              58.222, 97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
             "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25,
               56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
             "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25,
               111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
             "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
              44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
             "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 
              36.3, 71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
             "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6,
               0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
             "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
              20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
             "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 
              10.667, 19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
             "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 
              17., 41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
             "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 
              0.5, 31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
             "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
              0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
             "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
              98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
             "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 
              50., 1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
             "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
              57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
             "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 
              61.5, 0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
             "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
              564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
             "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 
              467.5, 586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
             "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
              0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
             "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 
              40., 7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
             "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 
              3., 27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
             "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 
              11.5, 1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
             "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
              44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
             "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6,
               0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
             "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
              Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
             "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 
              0.8, 17.1, 0., 19.6, 0., 0., 0., 2.5}, {
             "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 
              0.5, 33.9, 1., 14.6, 0., 0., 0., 0.}, {
             "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
              4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
             "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304.,
               2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
             "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
              130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
             "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 
              47., 2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
             "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 
              23., 0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
             "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
              58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
             "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 
              3., 0.2, 66., 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 8., 
              Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 
              0., 0.}, {
             "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
              196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
             "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001,
               182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
             "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 
              143.71001, 296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
             "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
              59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
             "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
              344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
             "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
              276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
             "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
              40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
             "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5,
               3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
             "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
              0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {
             "winter", "small", "low", 
              Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 
              0., 0., 0.}, {
             "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121.,
               2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
             "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
              20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
             "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 
              12.75, 49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
             "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3,
               22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
             "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
              11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 
              11.818, 0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
             "winter", "small", "high", 6.6, 10.8, 
              Missing[], 3.245, 10., 1., 6.5, 
              Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "medium", 5.6, 11.8, 
              Missing[], 2.22, 5., 1., 1., 
              Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
             "autumn", "small", "medium", 5.7, 10.8, 
              Missing[], 2.55, 10., 1., 4., 
              Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
             "spring", "small", "high", 6.6, 9.5, 
              Missing[], 1.32, 20., 1., 6., 
              Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
             "summer", "small", "high", 6.6, 10.8, 
              Missing[], 2.64, 10., 2., 11., 
              Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
             "autumn", "small", "medium", 6.6, 11.3, 
              Missing[], 4.17, 10., 1., 6., 
              Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
             "spring", "small", "medium", 6.5, 10.4, 
              Missing[], 5.97, 10., 2., 14., 
              Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
             "summer", "small", "medium", 6.4, 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 14., 
              Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
             "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
              6.667, 
              Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
             "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 
              6.75, 1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
             "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 
              7.2, 0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
             "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 
              6., 0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
             "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
              10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
             "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 
              2.5, 0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
             "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 
              220.75, 351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
             "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
              209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
             "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
              151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
             "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
              152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
             "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 
              55., 58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
             "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 
              136.75, 249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
             "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
              100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
             "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
              215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
             "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
              25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
             "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36.,
               105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
             "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 
              37.375, 111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
             "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 
              108., 1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
             "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
              56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
             "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 
              60., 4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
             "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 
              27.667, 104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
             "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32.,
               69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
             "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 
              111.25, 214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
             "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 
              137.60001, 254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
             "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 
              429.20001, 57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 
              16.7}, {"winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 
              5738.33008, 412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0.,
               2.4}, {"summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 
              4073.33008, 282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 
              9.9, 0.}, {
             "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
              197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
             "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
              267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
             "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
              191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
             "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 
              120.5, 232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
             "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
              144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
             "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
              218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
             "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23.,
               138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
             "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 
              104.222, 239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
             "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
              235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
             "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 
              51.75, 205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
             "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
              31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
             "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 
              28.625, 186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
             "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
              12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
             "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
              51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
             "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 
              104.5, 292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
             "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 
              38.625, 285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
             "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 
              24.667, 201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
             "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
              275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
             "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 
              39., 124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
             "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
              60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
             "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 
              71., 132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
             "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 
              9.667, 17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
             "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 
              26., 0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
             "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
              8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
             "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
              37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
             "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 
              37., 86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
             "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444,
               10.111, 
              Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
             "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
              16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
             "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 
              3.545, 13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
             "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
              261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
             "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 
              238.2, 320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
             "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499,
               144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
             "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
              166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
             "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 
              181., 222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
             "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
              36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
             "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 
              61.556, 127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
             "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625,
               89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
             "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
              55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
             "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
              102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
             "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
              75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
             "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 
              34.636, 72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
             "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
              48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
             "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
              48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
             "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 
              3466.65991, 23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
             "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173.,
               317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
             "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
              84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
             "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 
              213., 2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
             "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
              88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
             "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 
              115., 11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
             "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
              98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
             "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5,
               143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
             "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 
              132.5, 197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
             "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2,
               1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
             "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
              10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
             "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
              200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
             "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
              77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
             "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 
              47.5, 276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
             "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 
              46.667, 123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
             "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
              75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
             "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48.,
               116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
             "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
              188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
             "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39.,
               72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
             "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 
              116.2, 16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
             "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 
              44., 34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
             "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
              27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
             "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 
              24., 58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
             "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
              175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
             "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 
              236., 22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
             "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 
              125.8, 26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
             "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 
              20.667, 54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
             "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 
              75.333, 34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
             "spring", "large", "low", 9., 5.8, 
              Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 
              0., 0., 0.}, {
             "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
              151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
             "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 
              180.66701, 269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
             "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
              46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
             "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
              85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
             "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
              66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
             "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
              102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
             "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
              84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
             "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 
              221.89999, 246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 
              1.7}, {"autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 
              627.27301, 205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 
              0.}, {"winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 
              1168., 236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 
              17.2, 0.}, {
             "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
              1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0.,
               5.9, 1.7}, {
             "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
              82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
             "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
              64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
             "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
              87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
             "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
              159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
             "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
              21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
             "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 
              11., 0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
             "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 
              7.667, 14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
             "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 
              3.222, 7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
             "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2,
               0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
             "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
              7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
             "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16.,
               2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
             "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
              56.091, 
              Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
             "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625,
               52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
             "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
              104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
             "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3,
               85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
             "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
              87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
             "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
              101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
             "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
              50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
             "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 
              34.5, 81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
             "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
              19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
             "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 
              19.111, 120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
             "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
              51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
             "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
              19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
             "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 
              53.625, 79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
             "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 
              35.333, 75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
             "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 
              78.333, 140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
             "winter", "large", "medium", 8., 7.6, 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 
              Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
             "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
              140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
          Flatten[
           $CellContext`sym$2505[$CellContext`speed, 
            "missing"]]]], $CellContext`sym$2505[$CellContext`a1, 
         "factorized"] = 
       False, $CellContext`sym$2505[$CellContext`a1, 
         "missing"] = {}, $CellContext`sym$2505[$CellContext`a1, "raw"] = Part[
         $CellContext`sym$2505[All], 
         All, $CellContext`i$2517], $CellContext`sym$2505[$CellContext`a2, 
         "factorized"] = 
       False, $CellContext`sym$2505[$CellContext`a2, 
         "missing"] = {}, $CellContext`sym$2505[$CellContext`a2, "raw"] = Part[
         $CellContext`sym$2505[All], 
         All, $CellContext`i$2518], $CellContext`sym$2505[$CellContext`a3, 
         "factorized"] = 
       False, $CellContext`sym$2505[$CellContext`a3, 
         "missing"] = {}, $CellContext`sym$2505[$CellContext`a3, "raw"] = Part[
         $CellContext`sym$2505[All], 
         All, $CellContext`i$2519], $CellContext`sym$2505[$CellContext`a4, 
         "factorized"] = 
       False, $CellContext`sym$2505[$CellContext`a4, 
         "missing"] = {}, $CellContext`sym$2505[$CellContext`a4, "raw"] = Part[
         $CellContext`sym$2505[All], 
         All, $CellContext`i$2520], $CellContext`sym$2505[$CellContext`a5, 
         "factorized"] = 
       False, $CellContext`sym$2505[$CellContext`a5, 
         "missing"] = {}, $CellContext`sym$2505[$CellContext`a5, "raw"] = Part[
         $CellContext`sym$2505[All], 
         All, $CellContext`i$2521], $CellContext`sym$2505[$CellContext`a6, 
         "factorized"] = 
       False, $CellContext`sym$2505[$CellContext`a6, 
         "missing"] = {}, $CellContext`sym$2505[$CellContext`a6, "raw"] = Part[
         $CellContext`sym$2505[All], 
         All, $CellContext`i$2522], $CellContext`sym$2505[$CellContext`a7, 
         "factorized"] = 
       False, $CellContext`sym$2505[$CellContext`a7, 
         "missing"] = {}, $CellContext`sym$2505[$CellContext`a7, "raw"] = Part[
         $CellContext`sym$2505[All], 
         All, $CellContext`i$2523], $CellContext`sym$2505[
        All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$2505[
        All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed}, $CellContext`sym$2505[$CellContext`Chla, "factorized"] = 
       False, $CellContext`sym$2505[$CellContext`Chla, "missing"] = {{55}, {
        56}, {57}, {58}, {59}, {60}, {61}, {62}, {63}, {116}, {184}, {
        199}}, $CellContext`sym$2505[$CellContext`Chla, "raw"] = Part[
         $CellContext`sym$2505[All], 
         All, $CellContext`i$2516], $CellContext`sym$2505[$CellContext`Cl, 
         "factorized"] = 
       False, $CellContext`sym$2505[$CellContext`Cl, "missing"] = {{55}, {
        56}, {57}, {58}, {59}, {60}, {61}, {62}, {161}, {
        199}}, $CellContext`sym$2505[$CellContext`Cl, "raw"] = Part[
         $CellContext`sym$2505[All], 
         All, $CellContext`i$2511], $CellContext`sym$2505[$CellContext`mnO2, 
         "factorized"] = 
       False, $CellContext`sym$2505[$CellContext`mnO2, "missing"] = {{38}, {
        62}}, $CellContext`sym$2505[$CellContext`mnO2, "raw"] = Part[
         $CellContext`sym$2505[All], 
         All, $CellContext`i$2510], $CellContext`sym$2505[$CellContext`mxPH, 
         "factorized"] = 
       False, $CellContext`sym$2505[$CellContext`mxPH, "missing"] = {{
        48}}, $CellContext`sym$2505[$CellContext`mxPH, "raw"] = Part[
         $CellContext`sym$2505[All], 
         All, $CellContext`i$2509], $CellContext`sym$2505[$CellContext`NH4, 
         "factorized"] = 
       False, $CellContext`sym$2505[$CellContext`NH4, "missing"] = {{62}, {
        199}}, $CellContext`sym$2505[$CellContext`NH4, "raw"] = Part[
         $CellContext`sym$2505[All], 
         All, $CellContext`i$2513], $CellContext`sym$2505[$CellContext`NO3, 
         "factorized"] = 
       False, $CellContext`sym$2505[$CellContext`NO3, "missing"] = {{62}, {
        199}}, $CellContext`sym$2505[$CellContext`NO3, "raw"] = Part[
         $CellContext`sym$2505[All], 
         All, $CellContext`i$2512], $CellContext`sym$2505[$CellContext`oPO4, 
         "factorized"] = 
       False, $CellContext`sym$2505[$CellContext`oPO4, "missing"] = {{62}, {
        199}}, $CellContext`sym$2505[$CellContext`oPO4, "raw"] = Part[
         $CellContext`sym$2505[All], 
         All, $CellContext`i$2514], $CellContext`sym$2505[$CellContext`PO4, 
         "factorized"] = 
       False, $CellContext`sym$2505[$CellContext`PO4, "missing"] = {{28}, {
        199}}, $CellContext`sym$2505[$CellContext`PO4, "raw"] = Part[
         $CellContext`sym$2505[All], 
         All, $CellContext`i$2515], $CellContext`sym$2505[$CellContext`season,
          "factorized"] = 
       True, $CellContext`sym$2505[$CellContext`season, "factors"] = 
       Part[{"autumn", "spring", "summer", "winter"}, 
         $CellContext`fordering[$CellContext`sym$2505, $CellContext`season]], \
$CellContext`sym$2505[$CellContext`season, 
         "missing"] = {}, $CellContext`sym$2505[$CellContext`season, "raw"] = 
       Part[
         $CellContext`sym$2505[All], 
         All, $CellContext`i$2506], $CellContext`sym$2505[$CellContext`size, 
         "factorized"] = 
       True, $CellContext`sym$2505[$CellContext`size, "factors"] = 
       Part[{"large", "medium", "small"}, 
         $CellContext`fordering[$CellContext`sym$2505, $CellContext`size]], \
$CellContext`sym$2505[$CellContext`size, 
         "missing"] = {}, $CellContext`sym$2505[$CellContext`size, "raw"] = 
       Part[
         $CellContext`sym$2505[All], 
         All, $CellContext`i$2507], $CellContext`sym$2505[$CellContext`speed, 
         "factorized"] = 
       True, $CellContext`sym$2505[$CellContext`speed, "factors"] = 
       Part[{"high", "low", "medium"}, 
         $CellContext`fordering[$CellContext`sym$2505, $CellContext`speed]], \
$CellContext`sym$2505[$CellContext`speed, 
         "missing"] = {}, $CellContext`sym$2505[$CellContext`speed, "raw"] = 
       Part[
         $CellContext`sym$2505[All], All, $CellContext`i$2508], 
       Attributes[$CellContext`i$2517] = {Temporary}, $CellContext`i$2517 = 
       12, Attributes[$CellContext`i$2523] = {Temporary}, $CellContext`i$2523 = 
       18, Attributes[$CellContext`i$2513] = {Temporary}, $CellContext`i$2513 = 
       8, Attributes[$CellContext`i$2506] = {Temporary}, $CellContext`i$2506 = 
       1, Attributes[$CellContext`i$2516] = {Temporary}, $CellContext`i$2516 = 
       11, Attributes[$CellContext`i$2522] = {Temporary}, $CellContext`i$2522 = 
       17, Attributes[$CellContext`i$2511] = {Temporary}, $CellContext`i$2511 = 
       6, Attributes[$CellContext`i$2509] = {Temporary}, $CellContext`i$2509 = 
       4, Attributes[$CellContext`i$2519] = {Temporary}, $CellContext`i$2519 = 
       14, Attributes[$CellContext`i$2514] = {Temporary}, $CellContext`i$2514 = 
       9, Attributes[$CellContext`i$2520] = {Temporary}, $CellContext`i$2520 = 
       15, Attributes[$CellContext`i$2507] = {Temporary}, $CellContext`i$2507 = 
       2, $CellContext`fordering[$CellContext`sym$2505, $CellContext`season] = \
{1, 2, 3, 
        4}, $CellContext`fordering[$CellContext`sym$2505, $CellContext`size] = \
{1, 2, 3}, $CellContext`fordering[$CellContext`sym$2505, $CellContext`speed] = \
{1, 2, 3}, Attributes[$CellContext`i$2508] = {Temporary}, $CellContext`i$2508 = 
       3, Attributes[$CellContext`i$2512] = {Temporary}, $CellContext`i$2512 = 
       7, Attributes[$CellContext`i$2518] = {Temporary}, $CellContext`i$2518 = 
       13, Attributes[$CellContext`i$2510] = {Temporary}, $CellContext`i$2510 = 
       5, Attributes[$CellContext`i$2521] = {Temporary}, $CellContext`i$2521 = 
       16, Attributes[$CellContext`i$2515] = {Temporary}, $CellContext`i$2515 = 
       10}; Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.585486488343177*^9, 3.585486546546322*^9}, {
   3.585487885996788*^9, 3.5854879030599327`*^9}, {3.5854879451834383`*^9, 
   3.5854879948521852`*^9}, 3.585997051712687*^9, 3.586088812133189*^9}]
}, {2}]],

Cell["\<\
The pH and O2 are the only quantities that have something like a normal \
distribution.\
\>", "Text",
 CellChangeTimes->{{3.5854866128548527`*^9, 3.5854866399097967`*^9}, {
  3.585493055322296*^9, 3.5854930663929043`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Less Basic Visualization", "Title",
 CellChangeTimes->{{3.585417299136742*^9, 3.585417302023638*^9}, {
  3.585486190840365*^9, 3.585486194479013*^9}, {3.585493092664253*^9, 
  3.585493093144408*^9}}],

Cell["\<\
Add a quantile plot and a \[OpenCurlyDoubleQuote]rug.\[CloseCurlyDoubleQuote] \
 These will help in investigating the character of the feature distributions.\
\>", "Text",
 CellChangeTimes->{{3.585409007360567*^9, 3.585409022125017*^9}, {
  3.585413920023147*^9, 3.585413990652582*^9}, {3.5854155138898907`*^9, 
  3.585415564335779*^9}, {3.5854817914031487`*^9, 3.585481799721176*^9}, {
  3.58548183960981*^9, 3.585481866751459*^9}, {3.58548621549551*^9, 
  3.585486233782075*^9}, {3.585486368100177*^9, 3.585486375659062*^9}, {
  3.585487812111656*^9, 3.58548781331898*^9}, {3.585493145952731*^9, 
  3.585493163807169*^9}, {3.5859974285890493`*^9, 3.5859974657471533`*^9}, {
  3.585997534364046*^9, 3.5859975405217733`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"h", "=", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Histogram", "[", 
        RowBox[{
         RowBox[{"med", "[", "mxPH", "]"}], ",", "Automatic", ",", 
         "\"\<PDF\>\""}], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"SmoothHistogram", "[", 
        RowBox[{
         RowBox[{"med", "[", "mxPH", "]"}], ",", "Automatic", ",", 
         "\"\<PDF\>\""}], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"ListPlot", "[", 
        RowBox[{
         RowBox[{"Transpose", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"med", "[", "mxPH", "]"}], ",", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"-", "0.02"}], ",", 
              RowBox[{"{", 
               RowBox[{"Length", "@", 
                RowBox[{"med", "[", "mxPH", "]"}]}], "}"}]}], "]"}]}], "}"}], 
          "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"Filling", "\[Rule]", "Axis"}], ",", "\[IndentingNewLine]", 
         RowBox[{"FillingStyle", "\[Rule]", "Black"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"PlotMarkers", "\[Rule]", 
          RowBox[{"Invisible", "[", "\"\<\>\"", "]"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"AxesOrigin", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"Automatic", ",", 
            RowBox[{"-", "0.05"}]}], "}"}]}]}], "\[IndentingNewLine]", 
        "]"}]}], "\[IndentingNewLine]", "}"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "0.9"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "250"}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<mxPH Histogram\>\""}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"5.5", ",", "Automatic"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.05"}], ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"5.5", ",", 
        RowBox[{"-", "0.05"}]}], "}"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.574176367193636*^9, 3.5741764746606183`*^9}, {
   3.574176570660563*^9, 3.5741766121866455`*^9}, {3.574176654089429*^9, 
   3.574176655059352*^9}, {3.57417670060832*^9, 3.5741767408584166`*^9}, {
   3.5741768552410316`*^9, 3.5741768866913586`*^9}, {3.5741769173020735`*^9, 
   3.5741769192518005`*^9}, {3.574176959032671*^9, 3.5741769861530046`*^9}, 
   3.574177211984902*^9, {3.574177274689598*^9, 3.5741772951491566`*^9}, {
   3.5741773877513494`*^9, 3.5741773896131983`*^9}, {3.5741775999569197`*^9, 
   3.5741776187147803`*^9}, {3.574177782175913*^9, 3.574177815232283*^9}}],

Cell["\<\
Deviations from linearity in the quantile plot indicate the reference \
distribution (normal, by default) is an inappropriate description.\
\>", "Text",
 CellChangeTimes->{{3.585997582272715*^9, 3.5859976163361483`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"q", "=", 
   RowBox[{"QuantilePlot", "[", 
    RowBox[{
     RowBox[{"med", "[", "mxPH", "]"}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<mxPH Quantile Plot\>\""}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "0.9"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "250"}], ",", 
     RowBox[{"GridLines", "\[Rule]", "Automatic"}], ",", 
     RowBox[{"ReferenceLineStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Dashing", "[", 
          RowBox[{"{", "}"}], "]"}], ",", "Red"}], "}"}], "]"}]}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.574175791584878*^9, 3.574175829989406*^9}, {
  3.574175878903243*^9, 3.574175921727951*^9}, {3.5741760407439675`*^9, 
  3.5741760993561573`*^9}, {3.5741763588967137`*^9, 3.5741763603091154`*^9}, {
  3.574176634728495*^9, 3.5741766453901253`*^9}, {3.5741767621122875`*^9, 
  3.5741768401827497`*^9}, {3.57417762276412*^9, 3.574177622904011*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"h", ",", "q"}], "}"}], ",", 
   RowBox[{"Spacer", "[", "16", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5741763616190243`*^9, 3.574176363856369*^9}, {
  3.574177603491661*^9, 3.5741776630506287`*^9}, {3.585493547045309*^9, 
  3.5854935551760693`*^9}}],

Cell[BoxData[
 TemplateBox[{InterpretationBox[
    StyleBox[
     GraphicsBox[{}, ImageSize -> {16, 0}, BaselinePosition -> Baseline], 
     "CacheGraphics" -> False], 
    Spacer[16]],GraphicsBox[{{
      RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
      EdgeForm[
       Opacity[0.637]], {}, {
       RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[
        Opacity[0.637]], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{5.5, 0}, 
             NCache[{6., 
               Rational[4, 199]}, {6., 0.020100502512562814`}], 
             "RoundingRadius" -> 0]}, 
           ImageSizeCache -> {{15.499999999999972`, 41.17324251219159}, {
            84.61486930029076, 90.373329715978}}], 
          StatusArea[#, 0.020100502512562814`]& , TagBoxNote -> 
          "0.020100502512562814"], 
         StyleBox["0.020100502512562814`", {
           GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
         Style[0.020100502512562814`, {
           GrayLevel[0]}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{6., 0}, 
             NCache[{6.5, 
               Rational[2, 199]}, {6.5, 0.010050251256281407`}], 
             "RoundingRadius" -> 0]}, 
           ImageSizeCache -> {{40.17324251219159, 65.84648502438327}, {
            86.99409950813438, 90.373329715978}}], 
          StatusArea[#, 0.010050251256281407`]& , TagBoxNote -> 
          "0.010050251256281407"], 
         StyleBox["0.010050251256281407`", {
           GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
         Style[0.010050251256281407`, {
           GrayLevel[0]}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{6.5, 0}, 
             NCache[{7., 
               Rational[12, 199]}, {7., 0.06030150753768844}], 
             "RoundingRadius" -> 0]}, 
           ImageSizeCache -> {{64.84648502438327, 90.51972753657489}, {
            75.09794846891627, 90.373329715978}}], 
          StatusArea[#, 0.06030150753768844]& , TagBoxNote -> 
          "0.06030150753768844"], 
         StyleBox["0.06030150753768844`", {
           GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
         Style[0.06030150753768844, {
           GrayLevel[0]}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{7., 0}, 
             NCache[{7.5, 
               Rational[42, 199]}, {7.5, 0.21105527638190955`}], 
             "RoundingRadius" -> 0]}, 
           ImageSizeCache -> {{89.51972753657489, 115.19297004876657`}, {
            39.40949535126196, 90.373329715978}}], 
          StatusArea[#, 0.21105527638190955`]& , TagBoxNote -> 
          "0.21105527638190955"], 
         StyleBox["0.21105527638190955`", {
           GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
         Style[0.21105527638190955`, {
           GrayLevel[0]}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{7.5, 0}, 
             NCache[{8., 
               Rational[108, 199]}, {8., 0.542713567839196}], 
             "RoundingRadius" -> 0]}, 
           ImageSizeCache -> {{114.19297004876657`, 
            139.8662125609582}, {-39.10510150757756, 90.373329715978}}], 
          StatusArea[#, 0.542713567839196]& , TagBoxNote -> 
          "0.542713567839196"], 
         StyleBox["0.542713567839196`", {
           GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
         Style[0.542713567839196, {
           GrayLevel[0]}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{8., 0}, 
             NCache[{8.5, 
               Rational[146, 199]}, {8.5, 0.7336683417085427}], 
             "RoundingRadius" -> 0]}, 
           ImageSizeCache -> {{138.8662125609582, 
            164.5394550731498}, {-84.31047545660633, 90.373329715978}}], 
          StatusArea[#, 0.7336683417085427]& , TagBoxNote -> 
          "0.7336683417085427"], 
         StyleBox["0.7336683417085427`", {
           GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
         Style[0.7336683417085427, {
           GrayLevel[0]}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{8.5, 0}, 
             NCache[{9., 
               Rational[66, 199]}, {9., 0.3316582914572864}], 
             "RoundingRadius" -> 0]}, 
           ImageSizeCache -> {{163.5394550731498, 189.2126975853415}, {
            10.858732857138506`, 90.373329715978}}], 
          StatusArea[#, 0.3316582914572864]& , TagBoxNote -> 
          "0.3316582914572864"], 
         StyleBox["0.3316582914572864`", {
           GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
         Style[0.3316582914572864, {
           GrayLevel[0]}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{9., 0}, 
             NCache[{9.5, 
               Rational[14, 199]}, {9.5, 0.07035175879396985}], 
             "RoundingRadius" -> 0]}, 
           ImageSizeCache -> {{188.2126975853415, 213.8859400975331}, {
            72.71871826107265, 90.373329715978}}], 
          StatusArea[#, 0.07035175879396985]& , TagBoxNote -> 
          "0.07035175879396985"], 
         StyleBox["0.07035175879396985`", {
           GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
         Style[0.07035175879396985, {
           GrayLevel[0]}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          DynamicBox[{
            FEPrivate`If[
             CurrentValue["MouseOver"], 
             EdgeForm[{
               GrayLevel[0.5], 
               AbsoluteThickness[1.5], 
               Opacity[0.66]}], {}, {}], 
            RectangleBox[{9.5, 0}, 
             NCache[{10., 
               Rational[4, 199]}, {10., 0.020100502512562814`}], 
             "RoundingRadius" -> 0]}, 
           ImageSizeCache -> {{212.8859400975331, 238.5591826097248}, {
            84.61486930029076, 90.373329715978}}], 
          StatusArea[#, 0.020100502512562814`]& , TagBoxNote -> 
          "0.020100502512562814"], 
         StyleBox["0.020100502512562814`", {
           GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
         Style[0.020100502512562814`, {
           GrayLevel[0]}], "Tooltip"]& ]}, {}, {}}, {{}, {{}, {}, {
        RGBColor[0.24720000000000014`, 0.24, 0.6], 
        LineBox[CompressedData["
1:eJxde2c4FX74vmQ0hTjm4QxKIhpKUc+TQkNCkqKSkpGQmZHsnb2TzOwtITsi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         "]]}}, {}}, {{}, 
      GraphicsComplexBox[CompressedData["
1:eJztmS9sFEEUxi9IDOZyyV1vd2/vTNHVTXAgMDTBVZGAQVBsMTU1mBrMYYvB
1JypISRgi8ZgqkFgWs3tTt69zi/z3awmu+K2X97Mm/fnm7fzOvWLNwcv7w0G
g+frn+Ydntmjd8OLx9fHH77uNc8KeM/xp6P9+z8XjqvT388uS8etuhPHP67W
z1PHH5frZ+z4VfvUG3xZNgqreP5VCVxs8O3u4dm3G5dfHzd/lPF6ywr+lLDf
5W/X7p0flbDP13vYLLfr4w9ag2nvNI7HwOXh7fpbdYcub1/DCvIp7N+B/plc
P/hfyHwGTPtd3kRj//0M/tbQP5P2UM71k/aTL0uNaW/OnpDPEvkspDztTyVx
mD8BHsHeUWa8xsGeCdYfSz4+aTeE+/P9ptkwU2D3v6XbGflLzPiUyG8FeR3L
V9yPzA/5Mu/MnzRmPeB+KKScmPrIl7R+8oPxqyGvpb9BP+Waj8n434ln4CP3
M/Oj63FOnosX/eV87ud2u/5iPdLfE/IpHQ/Gi/oWGK/rH+sR10/zW+M0Hzle
5zf4M5fzGY+0fq6f45vej/SP+Uz7r+tFN/7r+s/54fuvvyet/K/Odzv9i+Zz
Lp60J1c/mP9u30PyY4Hxrq/5HV6QX7o+kn/t9+SBzw/nLWK3L7xx3jx3//+s
R5++zu1n6p8jfrq+Mn7Ul6snufNH+nun638yn+Narp+bT/vD+Ufry/EpHQ8d
H5MHPZ83/UaE9xxbv2HY+GK4VXfi2M6Phq3fMGzxMWz9RjR/vV9jXGyw9RuG
rd+I1ltW8KeE/S63fiO2z9ezfsOwne9i+6ZxPAYuD3F3/dZvGG7FwwryKezf
gf6ZXN/qgcqn1bN4vsut34j9raF/Ju2hnOsn7SdflhrT3pw9Vq/jfBZSnvan
ktj6gxiPYO8oM17jYM8E648lH63fMGz9Rozdf+s34vWIGZ8S+a0gr2P5ivuR
+SFf5p35k8asB9wPhZQTUx/5ktZPfjB+NeS19NfOA0o/+ZiM/514Wr+xvV7q
epyT5+JFfzmf+9nOpzHf9feEfErHg/GivgXG6/rHesT10/zWOM1Hjtf5tfPl
9vqo/Unvjxzf9H6kf8xn2n9dL7rxX9d/zrd+Q8XD+g2Vb+s3tu8XHU/ak6sf
zH+37yH5scB412f9Rtd6Sf5Zv2HY+o0Yu33Wbxi2fsOw9Rvb9zP1zxE/XV8Z
P+rL1ZN0vDW/0/Uqk89xLdfPzaf91m8ofTk+peOh42PyqP/q7zdgX3+/Efvb
328obP1BjPv7jbi+9PcbXf8/RX/tPKD0k4/J+Pf3Gxm+9vcb2/dHf7+h8t3f
b8T86+83tvM/Xa/+3/uNf0gOnf8=
       "], {{{}, {}, {}, {}, {
          GrayLevel[0], 
          LineBox[{200, 1}], 
          LineBox[{201, 2}], 
          LineBox[{202, 3}], 
          LineBox[{203, 4}], 
          LineBox[{204, 5}], 
          LineBox[{205, 6}], 
          LineBox[{206, 7}], 
          LineBox[{207, 8}], 
          LineBox[{208, 9}], 
          LineBox[{209, 10}], 
          LineBox[{210, 11}], 
          LineBox[{211, 12}], 
          LineBox[{212, 13}], 
          LineBox[{213, 14}], 
          LineBox[{214, 15}], 
          LineBox[{215, 16}], 
          LineBox[{216, 17}], 
          LineBox[{217, 18}], 
          LineBox[{218, 19}], 
          LineBox[{219, 20}], 
          LineBox[{220, 21}], 
          LineBox[{221, 22}], 
          LineBox[{222, 23}], 
          LineBox[{223, 24}], 
          LineBox[{224, 25}], 
          LineBox[{225, 26}], 
          LineBox[{226, 27}], 
          LineBox[{227, 28}], 
          LineBox[{228, 29}], 
          LineBox[{229, 30}], 
          LineBox[{230, 31}], 
          LineBox[{231, 32}], 
          LineBox[{232, 33}], 
          LineBox[{233, 34}], 
          LineBox[{234, 35}], 
          LineBox[{235, 36}], 
          LineBox[{236, 37}], 
          LineBox[{237, 38}], 
          LineBox[{238, 39}], 
          LineBox[{239, 40}], 
          LineBox[{240, 41}], 
          LineBox[{241, 42}], 
          LineBox[{242, 43}], 
          LineBox[{243, 44}], 
          LineBox[{244, 45}], 
          LineBox[{245, 46}], 
          LineBox[{246, 47}], 
          LineBox[{247, 48}], 
          LineBox[{248, 49}], 
          LineBox[{249, 50}], 
          LineBox[{250, 51}], 
          LineBox[{251, 52}], 
          LineBox[{252, 53}], 
          LineBox[{253, 54}], 
          LineBox[{254, 55}], 
          LineBox[{255, 56}], 
          LineBox[{256, 57}], 
          LineBox[{257, 58}], 
          LineBox[{258, 59}], 
          LineBox[{259, 60}], 
          LineBox[{260, 61}], 
          LineBox[{261, 62}], 
          LineBox[{262, 63}], 
          LineBox[{263, 64}], 
          LineBox[{264, 65}], 
          LineBox[{265, 66}], 
          LineBox[{266, 67}], 
          LineBox[{267, 68}], 
          LineBox[{268, 69}], 
          LineBox[{269, 70}], 
          LineBox[{270, 71}], 
          LineBox[{271, 72}], 
          LineBox[{272, 73}], 
          LineBox[{273, 74}], 
          LineBox[{274, 75}], 
          LineBox[{275, 76}], 
          LineBox[{276, 77}], 
          LineBox[{277, 78}], 
          LineBox[{278, 79}], 
          LineBox[{279, 80}], 
          LineBox[{280, 81}], 
          LineBox[{281, 82}], 
          LineBox[{282, 83}], 
          LineBox[{283, 84}], 
          LineBox[{284, 85}], 
          LineBox[{285, 86}], 
          LineBox[{286, 87}], 
          LineBox[{287, 88}], 
          LineBox[{288, 89}], 
          LineBox[{289, 90}], 
          LineBox[{290, 91}], 
          LineBox[{291, 92}], 
          LineBox[{292, 93}], 
          LineBox[{293, 94}], 
          LineBox[{294, 95}], 
          LineBox[{295, 96}], 
          LineBox[{296, 97}], 
          LineBox[{297, 98}], 
          LineBox[{298, 99}], 
          LineBox[{299, 100}], 
          LineBox[{300, 101}], 
          LineBox[{301, 102}], 
          LineBox[{302, 103}], 
          LineBox[{303, 104}], 
          LineBox[{304, 105}], 
          LineBox[{305, 106}], 
          LineBox[{306, 107}], 
          LineBox[{307, 108}], 
          LineBox[{308, 109}], 
          LineBox[{309, 110}], 
          LineBox[{310, 111}], 
          LineBox[{311, 112}], 
          LineBox[{312, 113}], 
          LineBox[{313, 114}], 
          LineBox[{314, 115}], 
          LineBox[{315, 116}], 
          LineBox[{316, 117}], 
          LineBox[{317, 118}], 
          LineBox[{318, 119}], 
          LineBox[{319, 120}], 
          LineBox[{320, 121}], 
          LineBox[{321, 122}], 
          LineBox[{322, 123}], 
          LineBox[{323, 124}], 
          LineBox[{324, 125}], 
          LineBox[{325, 126}], 
          LineBox[{326, 127}], 
          LineBox[{327, 128}], 
          LineBox[{328, 129}], 
          LineBox[{329, 130}], 
          LineBox[{330, 131}], 
          LineBox[{331, 132}], 
          LineBox[{332, 133}], 
          LineBox[{333, 134}], 
          LineBox[{334, 135}], 
          LineBox[{335, 136}], 
          LineBox[{336, 137}], 
          LineBox[{337, 138}], 
          LineBox[{338, 139}], 
          LineBox[{339, 140}], 
          LineBox[{340, 141}], 
          LineBox[{341, 142}], 
          LineBox[{342, 143}], 
          LineBox[{343, 144}], 
          LineBox[{344, 145}], 
          LineBox[{345, 146}], 
          LineBox[{346, 147}], 
          LineBox[{347, 148}], 
          LineBox[{348, 149}], 
          LineBox[{349, 150}], 
          LineBox[{350, 151}], 
          LineBox[{351, 152}], 
          LineBox[{352, 153}], 
          LineBox[{353, 154}], 
          LineBox[{354, 155}], 
          LineBox[{355, 156}], 
          LineBox[{356, 157}], 
          LineBox[{357, 158}], 
          LineBox[{358, 159}], 
          LineBox[{359, 160}], 
          LineBox[{360, 161}], 
          LineBox[{361, 162}], 
          LineBox[{362, 163}], 
          LineBox[{363, 164}], 
          LineBox[{364, 165}], 
          LineBox[{365, 166}], 
          LineBox[{366, 167}], 
          LineBox[{367, 168}], 
          LineBox[{368, 169}], 
          LineBox[{369, 170}], 
          LineBox[{370, 171}], 
          LineBox[{371, 172}], 
          LineBox[{372, 173}], 
          LineBox[{373, 174}], 
          LineBox[{374, 175}], 
          LineBox[{375, 176}], 
          LineBox[{376, 177}], 
          LineBox[{377, 178}], 
          LineBox[{378, 179}], 
          LineBox[{379, 180}], 
          LineBox[{380, 181}], 
          LineBox[{381, 182}], 
          LineBox[{382, 183}], 
          LineBox[{383, 184}], 
          LineBox[{384, 185}], 
          LineBox[{385, 186}], 
          LineBox[{386, 187}], 
          LineBox[{387, 188}], 
          LineBox[{388, 189}], 
          LineBox[{389, 190}], 
          LineBox[{390, 191}], 
          LineBox[{391, 192}], 
          LineBox[{392, 193}], 
          LineBox[{393, 194}], 
          LineBox[{394, 195}], 
          LineBox[{395, 196}], 
          LineBox[{396, 197}], 
          LineBox[{397, 198}], 
          LineBox[{398, 199}]}}, {{
          RGBColor[0.24720000000000014`, 0.24, 0.6], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           399], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           400], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           401], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           402], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           403], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           404], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           405], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           406], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           407], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           408], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           409], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           410], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           411], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           412], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           413], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           414], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           415], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           416], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           417], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           418], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           419], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           420], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           421], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           422], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           423], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           424], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           425], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           426], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           427], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           428], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           429], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           430], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           431], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           432], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           433], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           434], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           435], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           436], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           437], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           438], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           439], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           440], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           441], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           442], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           443], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           444], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           445], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           446], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           447], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           448], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           449], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           450], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           451], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           452], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           453], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           454], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           455], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           456], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           457], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           458], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           459], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           460], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           461], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           462], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           463], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           464], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           465], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           466], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           467], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           468], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           469], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           470], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           471], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           472], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           473], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           474], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           475], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           476], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           477], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           478], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           479], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           480], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           481], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           482], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           483], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           484], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           485], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           486], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           487], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           488], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           489], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           490], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           491], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           492], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           493], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           494], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           495], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           496], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           497], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           498], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           499], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           500], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           501], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           502], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           503], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           504], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           505], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           506], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           507], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           508], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           509], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           510], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           511], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           512], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           513], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           514], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           515], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           516], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           517], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           518], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           519], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           520], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           521], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           522], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           523], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           524], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           525], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           526], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           527], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           528], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           529], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           530], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           531], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           532], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           533], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           534], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           535], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           536], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           537], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           538], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           539], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           540], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           541], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           542], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           543], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           544], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           545], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           546], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           547], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           548], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           549], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           550], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           551], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           552], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           553], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           554], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           555], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           556], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           557], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           558], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           559], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           560], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           561], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           562], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           563], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           564], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           565], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           566], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           567], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           568], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           569], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           570], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           571], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           572], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           573], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           574], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           575], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           576], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           577], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           578], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           579], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           580], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           581], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           582], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           583], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           584], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           585], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           586], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           587], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           588], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           589], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           590], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           591], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           592], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           593], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           594], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           595], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           596], 
          InsetBox[
           StyleBox["\"\"", StripOnInput -> False, ShowContents -> False], 
           597]}, {}}}], {}}}, AspectRatio -> 0.9, Axes -> {True, True}, 
    AxesLabel -> {None, None}, AxesOrigin -> {5.5, -0.05}, 
    FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
    GridLines -> {None, None}, ImageSize -> 250, PlotLabel -> 
    FormBox["\"mxPH Histogram\"", TraditionalForm], 
    PlotRange -> {{5.5, Automatic}, {-0.05, Automatic}}, PlotRangePadding -> {{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.1]}}, Ticks -> {Automatic, Automatic}],GraphicsBox[{{}, {{{
        Hue[0.9060679774997897, 0.6, 0.6], 
        Opacity[0], 
        Dashing[Small], 
        LineBox[{{-6.402853672618526, 5.6}, {5.200508742528997, 5.6}}]}, {
        Hue[0.9060679774997897, 0.6, 0.6], 
        Opacity[0], 
        Dashing[Small], 
        LineBox[{{9.905007597970673, 9.7}, {28.86184099219466, 9.7}}]}, {}, {
        Hue[0.9060679774997897, 0.6, 0.6], 
        Opacity[0], 
        LineBox[{{5.200508742528997, 5.6}, {9.905007597970673, 9.7}}]}}, {{}, {
        RGBColor[0.24720000000000014`, 0.24, 0.6], 
        PointBox[CompressedData["
1:eJxN1gs01PkeAHCsRJcVxV3M/B8jh2RvNjpbzWq/3Wi47SZKZCUVEtLQY0Qy
Etles3vRpSuKKHnM9SjsHo/YKI/iEjdELCka2+aZosv4bd/9nTNnzuecmd/8
vo/fd/7s3kOOXkoKCgo1s6+5d+eebdlRSXrgLV+6oFpYpkO56kND/dzShaf1
oto19/ThcuLc0oMFyk26BtoGoCBf+qC9gWs8tMWAfF8ffIOalDMj0GqiRfxj
OejgogAwa0GfH9ui9W7cACzkywC2rk0ez9PlkP05IGsX9fZZcMBNUjlm4saB
Jdu1BYr2HJBTwgH1fd+HuvpwoGqOlRzQfN8Q9oWYQ87PAffCB0o/XULnxzr0
crM5sFy+IRfyHncFh1dwyO9zwYzz1PVdM/rMK7d/Zj5Hh5QeOZc8ia4wMq4Z
UuOSeLjw7xPtnlf1uSRfXBiX+l94YIq+eiW1JmgduvazUH6GHdr4g88Lfxc0
c8Gn6aE3On/AkG0+gjaIaxSIT3FJ/LPnaV60tFPCJfFyQSsis2YoiUvyScGX
F75dXpiJ/nnfpti1d9AaCdYK4kq0eTlf99xDdKbz3ZXu7VwSPwXu94093/dz
wbYnZGmugALXhpiLPr//kQ8KxPtebkt/j+7qTDS5vZD66PMtw9sva6NFg75v
d3DRdoKD2jJj9Maio6Huq9CN59TfZH9FQaDVorY0IQUSO9fP2jdREDp7mp4Q
CqJ3HRcNbKVIPigojD8b0eqKzngSG3vTE70iduWEewD6CyftvikROkLiFxEW
QYE83B4KCkKNBgbOUjA+l/4xCgL6F9L8OIrki4axtxVGwVcokB9nKQ23+luH
UjIooKOGHIopGpykp3cUSCnSjzQ8O3oaCoopkl8afEfvh1y9iw6aNG4IrUUr
2EyM2zSjzSyuSD90oF34ujcy+9DPAoXR1jL01X6r141j6Eu3Z8T2M+hXSZGP
KlToj7a6ZnfQSBNdEfboedhfaXAspmYjoqF8R39VLY12sJg4oz4b1/z9pWGz
1DF/ozlN+peG9G98yoRr0HSl6rI4QHslJTvn2qL9wj1ry7eiu7ckDN53QZ8/
mWVY64FeVC3sqvJBfx4giLgjRH/nay1MDUZ3+u3UiBHTcF0411A0lOqFFO+P
IfEW0CCNK3+04Qca5OEVz8bld1aqm0CTejNgwqblP09Bj3rvXJV/A+1vmBp9
XIoO97ZUsSpCK+1NV5kuQ78Ij+wsqUbb5gg7Dj9Ef/qav2NFK9rRbSr52VO0
IIxeGNePVrSJ77aRoePim4PHR9Enj07wMt6jDyvILpkqMfP50WPANS52VFGF
If3LwAaTdY5P1NBjB7Pa/qPBzOfPkIHBXaXZMVoM6RcGLKPd3nrooLV8/9W/
Vg99biozcQkXnWOutn6YQS/+b8C7B8vQFT79Uxkm6AJRi1eUGfrImLq3lzl6
RrfVSGCJXnd06pHpGjST8Fiy+Cu0ysieHye/Rru5CxR/3cjMz4NvGHhsMKje
KEBXB4X0lm9mSP8zED2inJdvz5B5xUByYOTNm9vQ0nvDb685owMOOLQlf4e2
Uew4nLIb/eHF6CfX96Ej2p1Ls/ejr9fw2kr8GHg1W42o2fc9SiPf1x1iyHxk
QLNpWrP3MEPmIwPqkhXp0yJmvt5iBpzCLM9QJxiY+7TVWQZaDpSPWYtJ/RMZ
0HE5tSrwNHq9q1dEWgz6ZcMNk87z6L7VqoEGP6J/+W04fU88WvUvSTrSRDQl
cdFSTkZbRmfJPFLRoWaxStUZ6PDcyiyLrD/tL+uzvSVFqzX1WZkWortv80cK
itElWZtaBaWkvgUMTK9O2/n8LqlnPQMdvnFjkmr0iEegiU0d2mCGK1JpRFO7
JQdbWtA9/F0p0ifo9qd7biZ0oX8/7vv5D7+iX30y1XnpBbq+lxHmyJj5+dnJ
gPa3/lktb9CLo17v1pgk9X3NQHBBoL/LNKmnAgsBZdKyO0rsR9usa9++XBU9
emzV13ka6IWVvdfsl6CjrJcULdBDd5/Y1NRCoTl2au5ly9A5ncovq0zRreOR
9IA5Wm+vuGX5l+z885smC2Y+jgsuWrFkvrDQUsZ261izZJ6wkNG1/l7VP1jy
/8hCh2W8y2UHltxHFpb1BomTXNBs5psjDbvR9kkH6sz3o/ueOEXVBqBLGoW8
lGMsua8seA+W3Ck4yZL7NHue+NgFn55BTzzwTyuUoIX5k7Q0AZ18uZivkoru
KC0y+yXrT3afmRi9jY7aUjmQUYHONgXToTqSj0QW/ibam9Xahr41c8Umso8F
+eNELgvr+UMirTcsyK93KQvq6v+T3VLgkf5hYTgn3CN6MY/knwcT9b/dl7Ho
lbJrdbareSTfPDh5qMx75WYeyQ8PTGMSnC56ovMyynaNn0Jb/30ocn8mOveh
oGu064/9DUFlzbT2XStDEp8h/B/TpceG
         "]]}, {}, {}}}, {}}, AspectRatio -> 0.9, Axes -> {False, False}, 
    AxesLabel -> {None, None}, AxesOrigin -> {6.5, 5.6000000000000005`}, 
    Epilog -> {{}, 
      StyleBox[
       LineBox[{{-6.402853672618526, -4.512402481951168}, {28.86184099219466, 
        26.220998156140777`}}], 
       Directive[
        Dashing[{}], 
        RGBColor[1, 0, 0]], StripOnInput -> False]}, Frame -> True, 
    FrameLabel -> {None, None}, GridLines -> Automatic, ImageSize -> 250, 
    Method -> {"ScalingFunctions" -> None}, PlotLabel -> 
    FormBox["\"mxPH Quantile Plot\"", TraditionalForm], 
    PlotRange -> {{6.402853672618526, 9.620613664064887}, {5.6, 9.7}}, 
    PlotRangeClipping -> True, PlotRangePadding -> {{
       Scaled[0.02], 
       Scaled[0.02]}, {
       Scaled[0.02], 
       Scaled[0.02]}}, Ticks -> {Automatic, Automatic}]},
  "RowWithSeparator"]], "Output",
 CellChangeTimes->{
  3.585493206128911*^9, {3.585493551638611*^9, 3.585493555718646*^9}, 
   3.5859971042457047`*^9}]
}, {2}]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Box & Whisker etc.", "Title",
 CellChangeTimes->{{3.585417299136742*^9, 3.585417302023638*^9}, {
  3.585486190840365*^9, 3.585486194479013*^9}, {3.585493092664253*^9, 
  3.585493093144408*^9}, {3.585500789157826*^9, 3.585500792412249*^9}, {
  3.585997658535183*^9, 3.585997659191278*^9}}],

Cell["\<\
A box and whisker chart can also assist in visualizing distributions:\
\>", "Text",
 CellChangeTimes->{{3.585997636455536*^9, 3.585997674982914*^9}, {
  3.5860213332997007`*^9, 3.586021334307088*^9}, {3.5860214358183603`*^9, 
  3.586021451896106*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BoxWhiskerChart", "[", 
  RowBox[{
   RowBox[{"med", "[", "oPO4", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"\"\<Outliers\>\"", ",", 
     RowBox[{"{", 
      RowBox[{"\"\<MedianMarker\>\"", ",", "White"}], "}"}]}], "}"}], ",", 
   RowBox[{"GridLines", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"None", ",", 
      RowBox[{"{", 
       RowBox[{"Mean", "@", 
        RowBox[{"med", "[", "oPO4", "]"}]}], "}"}]}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"GridLinesStyle", "\[Rule]", 
    RowBox[{"Directive", "[", "Dashed", "]"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"None", ",", "\"\<Orthophosphate (oPO4)\>\""}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Epilog", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Blue", ",", 
      RowBox[{"Line", "[", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{".4", ",", "#"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.45", ",", "#"}], "}"}]}], "}"}], "&"}], "/@", 
         RowBox[{"med", "[", "oPO4", "]"}]}], ")"}], "]"}]}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.574177978775443*^9, 3.574177989700743*^9}, {
  3.5741782572000475`*^9, 3.574178379775648*^9}, {3.5741784775884333`*^9, 
  3.5741786253386745`*^9}, {3.5741788981545076`*^9, 3.5741789064491835`*^9}, {
  3.5741790498097973`*^9, 3.574179211188321*^9}, {3.5741792987014394`*^9, 
  3.5741793082036233`*^9}, {3.585500826613817*^9, 3.5855008280331583`*^9}}],

Cell[BoxData[
 GraphicsBox[{
   {Opacity[0], 
    PointBox[{{0.4163731656936597, -27.179999}, {1.5836268343063402`, 
     592.7799789999999}}]}, 
   {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], {}, 
    {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
     {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
      TagBox[
       TooltipBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          GraphicsGroupBox[{Antialiasing -> False, 
            
            PolygonBox[{{0.8039430656936596, 100.}, {1.1960569343063403`, 
             100.}, {1.1960569343063403`, 15.6}, {0.8039430656936596, 
             15.6}}], {}, {{
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox["\"\[FilledSmallCircle]\"", 10, 
                  GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
               1., 246.}], 
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox["\"\[FilledSmallCircle]\"", 10, 
                  GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
               1., 264.89999}], 
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox["\"\[FilledSmallCircle]\"", 10, 
                  GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
               1., 276.85001}], 
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox["\"\[FilledSmallCircle]\"", 10, 
                  GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
               1., 282.16699}], 
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox["\"\[FilledSmallCircle]\"", 10, 
                  GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
               1., 267.75}], 
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox["\"\[FilledSmallCircle]\"", 10, 
                  GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
               1., 261.60001}], 
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox["\"\[FilledSmallCircle]\"", 10, 
                  GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
               1., 238.2}], 
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox["\"\[FilledSmallCircle]\"", 10, 
                  GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
               1., 234.5}], 
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox["\"\[FilledSmallCircle]\"", 10, 
                  GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
               1., 236.39999}], 
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox["\"\[FilledSmallCircle]\"", 10, 
                  GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
               1., 346.16699}]}, {
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox["\"\[FilledSmallCircle]\"", 10, 
                  GrayLevel[0.5], StripOnInput -> False], TraditionalForm]], {
               1., 428.75}], 
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox["\"\[FilledSmallCircle]\"", 10, 
                  GrayLevel[0.5], StripOnInput -> False], TraditionalForm]], {
               1., 564.59998}], 
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox["\"\[FilledSmallCircle]\"", 10, 
                  GrayLevel[0.5], StripOnInput -> False], TraditionalForm]], {
               1., 467.5}], 
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox["\"\[FilledSmallCircle]\"", 10, 
                  GrayLevel[0.5], StripOnInput -> False], TraditionalForm]], {
               1., 412.33301}]}}, {}, {
             GrayLevel[0], 
             GrayLevel[1], 
             
             LineBox[{{1.1960569343063403`, 39.}, {0.8039430656936597, 
              39.}}]}, {}, {
             GrayLevel[0], 
             GrayLevel[0.5], 
             
             LineBox[{{{1., 15.6}, {1., 1.}}, {{1., 100.}, {1., 
              221.89999}}}]}, {
             GrayLevel[0], 
             GrayLevel[0.5], 
             
             LineBox[{{{1.0980284671531702`, 1.}, {0.9019715328468298, 
              1.}}, {{1.0980284671531702`, 221.89999}, {0.9019715328468298, 
              221.89999}}}]}, {}}]},
         ImageSizeCache->{{143.5857864376269, 
          251.4142135623731}, {-96.71473879172414, 85.41421356237309}}],
        StyleBox[
         TagBox[
          GridBox[{{
             StyleBox["\"max\"", Bold, StripOnInput -> False], "564.59998`"}, {
             StyleBox["\"75%\"", Bold, StripOnInput -> False], "100.`"}, {
             StyleBox["\"median\"", Bold, StripOnInput -> False], "39.`"}, {
             StyleBox["\"25%\"", Bold, StripOnInput -> False], "15.6`"}, {
             StyleBox["\"min\"", Bold, StripOnInput -> False], "1.`"}}, 
           GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
           AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}, "Rows" -> {
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}}, 
           GridBoxFrame -> {
            "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, BaseStyle -> 
           Directive[
             AbsoluteThickness[1], 
             Dashing[{}]]], "Grid"], {
          GrayLevel[0]}, StripOnInput -> False]],
       Annotation[#, 
        Style[
         Grid[{{
            Style["max", Bold], 564.59998}, {
            Style["75%", Bold], 100.}, {
            Style["median", Bold], 39.}, {
            Style["25%", Bold], 15.6}, {
            Style["min", Bold], 1.}}, Dividers -> {{
             Directive[
              GrayLevel[0.3]], {
              Directive[
               GrayLevel[0.3]]}, 
             Directive[
              GrayLevel[0.3]]}, {
             Directive[
              GrayLevel[0.3]], {
              Directive[
               GrayLevel[0.3]]}, 
             Directive[
              GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, Frame -> 
          GrayLevel[0], BaseStyle -> Directive[
            AbsoluteThickness[1], 
            Dashing[{}]]], {
          GrayLevel[0]}], 
        "Tooltip"]& ]}}, {}, {}}, {{{{{{}, {}}, {}}, {}}, {}}, {}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  Epilog->{
    RGBColor[0, 0, 1], 
    LineBox[CompressedData["
1:eJy9mG1MlWUYx58ha2SMaUoxp8lrGo4k0SCOeQ7CeH85vJwmLyNAOREJHly6
bOWO64NrOaI1ltpKZgwTW2OOVSPWmEtqDRs1mTNq+kGs3Fw0odBw6z7ncN13
///Gy/nS2Zj7+9t1P9dz39fb/cQ07CtrXGZZ1rD6C5n7O3nC97tqt3w/R5Xj
0ojv97PWwEdeRa608J73v47ua35ec9HCP/zjzHDBe8WaixYeN373cPPaIs1F
o39byL8tyLuKkXeZ9QtT38yoc2VrLlq42/d7fKfmovH5Nnq+Dbn3CeRKC9/8
S/wDR1wJmosGe2sj2iuNPJl4MvFE4onEVxJfqfnx1offGOo1+ysa7beS/Vbk
Q1nIlRYett95YaT7iOaiwT7tdbRXWniK/7dZc9HB7U8Y8bAgeSzxWOIriK8I
kqcTTw8yPsqIl9H5tNL5tFL85lP85i/5/AP/rtNcNNh7itDeQ/lt3bPj+vfs
yEPp+aHavtvz7PIr7zZpLlq4Uh95Lrk1Fy384/Qb7i/+qtdctPCp+5df+f0z
479o4acfulXtbvdoLlp47VRk94miNs1F4/vF0/vFE6f6Y9mCjP/VxFcHuf4i
9WWB+hfI13WUvxQf1npaf32Q+TdJ8TNp/3+5Rf5ZQfo3v33WW3t//efscs1F
B/f8+fPn6CNXv/+7fFr7Jxrtp8j/Kc0D/z+ruWiwP/4SPl9p4TPX8g/utTVr
LhrsbzSgvdIYf9kUf9nEC4gXII+qRx5VT/tXSftXibzOhVxp6K+Jz2B/VRrX
30nr0/zRR7zP8MC/pn+IRv8yyb9Msk8g+wT0v9eG/vdyfXCQ/w7ko9XIlRY+
+Num3JQUs/+iMb4KHRhfhZqPpxSEVFw8pLlo4Qkj/ffPnTb1V7TuH7PdP50Z
+E//mNPg/6AH/R/0IJ95AbnSwKNrkSstvGZZdcKuSBPfosF+cjfaK437n0r7
n6r5O7dfs2+LMPO9aOFVe2zXSly7NBcN61/Pw/WVFt7kW9Bl11w0zufbaT7f
rvlAXnjIpm9M/xAN/rfnof/tebS/dH+JpvuLk+LfmUnxnUbxnUb7S/XDovrh
pfW9Zv3+bw9+darZ3E9E43xWSvNZKd0f4uj+EEf+rSH/1mg+e/bPH4saYjQX
LTz0uYik87dNfRGN70f1x2u4vx21Pa25aIiPsWSMjzEzn9S8fWF6Y024if85
DfNTpck/0XB/G27B+5vSuD/UPyyTX59+eag388oezUVj/Lopfs38+FTYJ2ur
Xjb7Ixrju5jim87fWULxWbLk/uXP185KzN9O6k8zdD+YMfeDi9F9+5tKMzQX
jffnXLo/55L/ueQ/8QXqU2A/G2l/Gyk/yP8hut/UUf2to/rrJf+85J+D+peD
+pdF3xcsOr/rTqqPTuQddciVxv5m8kO08B9ix+8eTjT9WTS+H9UPbynGh6uc
6ns57W8O7W8OnX8OnX8O5t9NB+bfTd4/2n+L95/mA0c1vd/89TVwnzD1RzQ+
n+ZDi+dDuv94eb5JI3vTH/z9etrEr2jMjxbKjxY8//ACPP9wk9+BfmTu36Lx
/HbQ+e2g96P51Wvqg3/euWXqo2h4v043vl+nm/Y/hvbf9JdAv0qi/pVE86fJ
H9HCA98Ljf+i4fmrXPj8VWb+znr08ucjg+b+IRrqd/+LWL+VBvtjLWh/zJxf
YJ48QPPlAZpfKmh+qdDcl04TUeb9RUP+jrkwf8dceD4Tu/F8Jng+XOT7wAL3
91pfwzr3mOm/c1p40vkP1Ik8qLloqA/uCKwPSqN/i30fiyIehfNF5DacL5TG
/kLf17rM/ShfteOjT5r5UTT435OF/vdk4fodNB935GF83snG+Lxj6s8+lc7f
tRl70VgfM3B9h+nPG3wBO5CiuWjhge/phote6ny9mL3fn1H6fjhqvh/6591e
479onF+oP3VSf7Kovyr9L24sTiY=
     "]]},
  Frame->True,
  FrameLabel->{{
     FormBox["\"Orthophosphate (oPO4)\"", TraditionalForm], None}, {
    None, None}},
  FrameTicks->{{Automatic, Automatic}, {{{0.8039430656936596, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0, 0}}, {1.1960569343063403`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0, 0}}, {1., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.008, 0}}}, {{0.8039430656936596, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0, 0}}, {1.1960569343063403`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0, 0}}, {1., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.008, 0}}}}},
  GridLines->{None, {73.59059595959597}},
  GridLinesStyle->Directive[
    Dashing[{Small, Small}]],
  PlotRangePadding->Scaled[0.02],
  Ticks->{None, Automatic}]], "Output",
 CellChangeTimes->{3.585500813239958*^9, 
  3.585997123026032*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, {2}]],

Cell[TextData[{
 "Similarly for ",
 StyleBox["DistributionChart", "Input"],
 ":"
}], "Text",
 CellChangeTimes->{{3.586021439937417*^9, 3.5860214570963783`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DistributionChart", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"med", "[", "#", "]"}], "&"}], "/@", "responseColumns"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", "Automatic"}], ",", "\[IndentingNewLine]", 
   RowBox[{"ChartLabels", "\[Rule]", "responseColumns"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ChartElementFunction", "\[Rule]", "\"\<HistogramDensity\>\""}], 
   ",", "\[IndentingNewLine]", 
   RowBox[{"ChartStyle", "\[Rule]", "\"\<SouthwestColors\>\""}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.585997732418373*^9, 3.585997924453127*^9}, {
  3.5859981506651278`*^9, 3.5859981744538383`*^9}}],

Cell[BoxData[
 GraphicsBox[{
   {Opacity[0], 
    PointBox[{{0.5368626627285948, -4.49}, {7.463137337271405, 
     94.28999999999999}}]}, 
   {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
    EdgeForm[Opacity[0.7]], {}, 
    {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
     EdgeForm[Opacity[0.7]], 
     {RGBColor[0.396811, 0.31014, 0.204105], EdgeForm[Opacity[0.7]], 
      TagBox[
       TooltipBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          TagBox[
           GraphicsGroupBox[{Antialiasing -> False, {
              TagBox[
               TooltipBox[
                
                RectangleBox[{0.6897046006743153, 0}, {
                 1.3102953993256847`, 10}, "RoundingRadius" -> 0], "108.`"], 
               Annotation[#, 108., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{0.8583179497418572, 10}, {
                 1.1416820502581428`, 20}, "RoundingRadius" -> 0], "36.`"], 
               Annotation[#, 36., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{0.9145223994310377, 20}, {
                 1.0854776005689621`, 30}, "RoundingRadius" -> 0], "12.`"], 
               Annotation[#, 12., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{0.9145223994310377, 30}, {
                 1.0854776005689621`, 40}, "RoundingRadius" -> 0], "12.`"], 
               Annotation[#, 12., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{0.9192061035718029, 40}, {
                 1.0807938964281971`, 50}, "RoundingRadius" -> 0], "10.`"], 
               Annotation[#, 10., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{0.9192061035718029, 50}, {
                 1.0807938964281971`, 60}, "RoundingRadius" -> 0], "10.`"], 
               Annotation[#, 10., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{0.9285735118533329, 60}, {
                 1.071426488146667, 70}, "RoundingRadius" -> 0], "6.`"], 
               Annotation[#, 6., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{0.9379409201348631, 70}, {
                 1.062059079865137, 80}, "RoundingRadius" -> 0], "2.`"], 
               Annotation[#, 2., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{0.9332572159940979, 80}, {
                 1.066742784005902, 90}, "RoundingRadius" -> 0], "4.`"], 
               Annotation[#, 4., "Tooltip"]& ]}}], 
           Annotation[#, {{0.6897046006743153, 1.3102953993256847`}, {0, 90}},
             "BoundingBox"]& ]},
         ImageSizeCache->{{50.105639549997875`, 
          78.7181373040204}, {-101.31147126764388`, 86.67390491804203}}],
        StyleBox[
         TagBox[
          GridBox[{{
             StyleBox["\"max\"", Bold, StripOnInput -> False], "89.8`"}, {
             StyleBox["\"75%\"", Bold, StripOnInput -> False], "24.8`"}, {
             StyleBox["\"median\"", Bold, StripOnInput -> False], "6.9`"}, {
             StyleBox["\"25%\"", Bold, StripOnInput -> False], "1.5`"}, {
             StyleBox["\"min\"", Bold, StripOnInput -> False], "0.`"}}, 
           GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
           AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}, "Rows" -> {
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}}, 
           GridBoxFrame -> {
            "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, BaseStyle -> 
           Directive[
             AbsoluteThickness[1], 
             Dashing[{}]]], "Grid"], {
          GrayLevel[0]}, StripOnInput -> False]],
       Annotation[#, 
        Style[
         Grid[{{
            Style["max", Bold], 89.8}, {
            Style["75%", Bold], 24.8}, {
            Style["median", Bold], 6.9}, {
            Style["25%", Bold], 1.5}, {
            Style["min", Bold], 0.}}, Dividers -> {{
             Directive[
              GrayLevel[0.3]], {
              Directive[
               GrayLevel[0.3]]}, 
             Directive[
              GrayLevel[0.3]]}, {
             Directive[
              GrayLevel[0.3]], {
              Directive[
               GrayLevel[0.3]]}, 
             Directive[
              GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, Frame -> 
          GrayLevel[0], BaseStyle -> Directive[
            AbsoluteThickness[1], 
            Dashing[{}]]], {
          GrayLevel[0]}], "Tooltip"]& ]}, 
     {RGBColor[0.6427400000000001, 0.330577, 0.15407549999999998`], EdgeForm[
      Opacity[0.7]], 
      TagBox[
       TooltipBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          TagBox[
           GraphicsGroupBox[{Antialiasing -> False, {
              TagBox[
               TooltipBox[
                
                RectangleBox[{1.6897046006743155`, 0}, {
                 2.3102953993256845`, 10}, "RoundingRadius" -> 0], "146.`"], 
               Annotation[#, 146., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{1.886933457232011, 10}, {2.113066542767989, 20},
                  "RoundingRadius" -> 0], "30.`"], 
               Annotation[#, 30., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{1.9141374374468654`, 20}, {
                 2.085862562553135, 30}, "RoundingRadius" -> 0], "14.`"], 
               Annotation[#, 14., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{1.929439676317721, 30}, {2.070560323682279, 40},
                  "RoundingRadius" -> 0], "5.`"], 
               Annotation[#, 5., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{1.932840173844578, 40}, {2.067159826155422, 50},
                  "RoundingRadius" -> 0], "3.`"], 
               Annotation[#, 3., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{1.9362406713714346`, 50}, {
                 2.0637593286285654`, 60}, "RoundingRadius" -> 0], "1.`"], 
               Annotation[#, 1., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{1.9875, 60}, {2.0125, 70}, "RoundingRadius" -> 
                 0], "0.`"], Annotation[#, 0., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{1.9362406713714346`, 70}, {
                 2.0637593286285654`, 80}, "RoundingRadius" -> 0], "1.`"], 
               Annotation[#, 1., "Tooltip"]& ]}}], 
           Annotation[#, {{1.6897046006743153`, 2.3102953993256845`}, {0, 
             80}}, "BoundingBox"]& ]},
         ImageSizeCache->{{94.59952797700703, 
          123.21202573102954`}, {-80.53531835812323, 86.67390491804203}}],
        StyleBox[
         TagBox[
          GridBox[{{
             StyleBox["\"max\"", Bold, StripOnInput -> False], "72.6`"}, {
             StyleBox["\"75%\"", Bold, StripOnInput -> False], "11.3`"}, {
             StyleBox["\"median\"", Bold, StripOnInput -> False], "2.9`"}, {
             StyleBox["\"25%\"", Bold, StripOnInput -> False], "0.`"}, {
             StyleBox["\"min\"", Bold, StripOnInput -> False], "0.`"}}, 
           GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
           AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}, "Rows" -> {
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}}, 
           GridBoxFrame -> {
            "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, BaseStyle -> 
           Directive[
             AbsoluteThickness[1], 
             Dashing[{}]]], "Grid"], {
          GrayLevel[0]}, StripOnInput -> False]],
       Annotation[#, 
        Style[
         Grid[{{
            Style["max", Bold], 72.6}, {
            Style["75%", Bold], 11.3}, {
            Style["median", Bold], 2.9}, {
            Style["25%", Bold], 0.}, {
            Style["min", Bold], 0.}}, Dividers -> {{
             Directive[
              GrayLevel[0.3]], {
              Directive[
               GrayLevel[0.3]]}, 
             Directive[
              GrayLevel[0.3]]}, {
             Directive[
              GrayLevel[0.3]], {
              Directive[
               GrayLevel[0.3]]}, 
             Directive[
              GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, Frame -> 
          GrayLevel[0], BaseStyle -> Directive[
            AbsoluteThickness[1], 
            Dashing[{}]]], {
          GrayLevel[0]}], "Tooltip"]& ]}, 
     {RGBColor[0.726732, 0.538136, 0.31593], EdgeForm[Opacity[0.7]], 
      TagBox[
       TooltipBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          TagBox[
           GraphicsGroupBox[{Antialiasing -> False, {
              TagBox[
               TooltipBox[
                
                RectangleBox[{2.6897046006743155`, 0}, {
                 3.3102953993256845`, 5}, "RoundingRadius" -> 0], "150.`"], 
               Annotation[#, 150., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{2.9031878354103866`, 5}, {
                 3.0968121645896134`, 10}, "RoundingRadius" -> 0], "21.`"], 
               Annotation[#, 21., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{2.9180820145780193`, 10}, {
                 3.0819179854219807`, 15}, "RoundingRadius" -> 0], "12.`"], 
               Annotation[#, 12., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{2.9280114673564412`, 15}, {
                 3.0719885326435588`, 20}, "RoundingRadius" -> 0], "6.`"], 
               Annotation[#, 6., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{2.9263565585600375`, 20}, {
                 3.0736434414399625`, 25}, "RoundingRadius" -> 0], "7.`"], 
               Annotation[#, 7., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{2.9346311025420557`, 25}, {
                 3.0653688974579443`, 30}, "RoundingRadius" -> 0], "2.`"], 
               Annotation[#, 2., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{2.9875, 30}, {3.0125, 35}, "RoundingRadius" -> 
                 0], "0.`"], Annotation[#, 0., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{2.9362860113384595`, 35}, {
                 3.0637139886615405`, 40}, "RoundingRadius" -> 0], "1.`"], 
               Annotation[#, 1., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{2.9362860113384595`, 40}, {
                 3.0637139886615405`, 45}, "RoundingRadius" -> 0], "1.`"], 
               Annotation[#, 1., "Tooltip"]& ]}}], 
           Annotation[#, {{2.6897046006743155`, 3.3102953993256845`}, {0, 
             45}}, "BoundingBox"]& ]},
         ImageSizeCache->{{139.09341640401615`, 
          167.70591415803867`}, {-7.818783174800927, 86.67390491804203}}],
        StyleBox[
         TagBox[
          GridBox[{{
             StyleBox["\"max\"", Bold, StripOnInput -> False], "42.8`"}, {
             StyleBox["\"75%\"", Bold, StripOnInput -> False], "4.9`"}, {
             StyleBox["\"median\"", Bold, StripOnInput -> False], "1.5`"}, {
             StyleBox["\"25%\"", Bold, StripOnInput -> False], "0.`"}, {
             StyleBox["\"min\"", Bold, StripOnInput -> False], "0.`"}}, 
           GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
           AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}, "Rows" -> {
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}}, 
           GridBoxFrame -> {
            "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, BaseStyle -> 
           Directive[
             AbsoluteThickness[1], 
             Dashing[{}]]], "Grid"], {
          GrayLevel[0]}, StripOnInput -> False]],
       Annotation[#, 
        Style[
         Grid[{{
            Style["max", Bold], 42.8}, {
            Style["75%", Bold], 4.9}, {
            Style["median", Bold], 1.5}, {
            Style["25%", Bold], 0.}, {
            Style["min", Bold], 0.}}, Dividers -> {{
             Directive[
              GrayLevel[0.3]], {
              Directive[
               GrayLevel[0.3]]}, 
             Directive[
              GrayLevel[0.3]]}, {
             Directive[
              GrayLevel[0.3]], {
              Directive[
               GrayLevel[0.3]]}, 
             Directive[
              GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, Frame -> 
          GrayLevel[0], BaseStyle -> Directive[
            AbsoluteThickness[1], 
            Dashing[{}]]], {
          GrayLevel[0]}], "Tooltip"]& ]}, 
     {RGBColor[0.817882, 0.7260905, 0.426991], EdgeForm[Opacity[0.7]], 
      TagBox[
       TooltipBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          TagBox[
           GraphicsGroupBox[{Antialiasing -> False, {
              TagBox[
               TooltipBox[
                
                RectangleBox[{3.6897046006743155`, 0}, {
                 4.3102953993256845`, 5}, "RoundingRadius" -> 0], "179.`"], 
               Annotation[#, 179., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{3.9185257890038705`, 5}, {
                 4.081474210996129, 10}, "RoundingRadius" -> 0], "14.`"], 
               Annotation[#, 14., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{3.931006944730937, 10}, {4.068993055269063, 15},
                  "RoundingRadius" -> 0], "5.`"], 
               Annotation[#, 5., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{3.9875, 15}, {4.0125, 20}, "RoundingRadius" -> 
                 0], "0.`"], Annotation[#, 0., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{3.9875, 20}, {4.0125, 25}, "RoundingRadius" -> 
                 0], "0.`"], Annotation[#, 0., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{3.936554125054078, 25}, {4.063445874945922, 30},
                  "RoundingRadius" -> 0], "1.`"], 
               Annotation[#, 1., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{3.9875, 30}, {4.0125, 35}, "RoundingRadius" -> 
                 0], "0.`"], Annotation[#, 0., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{3.9875, 35}, {4.0125, 40}, "RoundingRadius" -> 
                 0], "0.`"], Annotation[#, 0., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{3.936554125054078, 40}, {4.063445874945922, 45},
                  "RoundingRadius" -> 0], "1.`"], 
               Annotation[#, 1., "Tooltip"]& ]}}], 
           Annotation[#, {{3.6897046006743155`, 4.3102953993256845`}, {0, 
             45}}, "BoundingBox"]& ]},
         ImageSizeCache->{{183.5873048310253, 
          212.19980258504782`}, {-7.818783174800927, 86.67390491804203}}],
        StyleBox[
         TagBox[
          GridBox[{{
             StyleBox["\"max\"", Bold, StripOnInput -> False], "44.6`"}, {
             StyleBox["\"75%\"", Bold, StripOnInput -> False], "2.4`"}, {
             StyleBox["\"median\"", Bold, StripOnInput -> False], "0.`"}, {
             StyleBox["\"25%\"", Bold, StripOnInput -> False], "0.`"}, {
             StyleBox["\"min\"", Bold, StripOnInput -> False], "0.`"}}, 
           GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
           AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}, "Rows" -> {
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}}, 
           GridBoxFrame -> {
            "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, BaseStyle -> 
           Directive[
             AbsoluteThickness[1], 
             Dashing[{}]]], "Grid"], {
          GrayLevel[0]}, StripOnInput -> False]],
       Annotation[#, 
        Style[
         Grid[{{
            Style["max", Bold], 44.6}, {
            Style["75%", Bold], 2.4}, {
            Style["median", Bold], 0.}, {
            Style["25%", Bold], 0.}, {
            Style["min", Bold], 0.}}, Dividers -> {{
             Directive[
              GrayLevel[0.3]], {
              Directive[
               GrayLevel[0.3]]}, 
             Directive[
              GrayLevel[0.3]]}, {
             Directive[
              GrayLevel[0.3]], {
              Directive[
               GrayLevel[0.3]]}, 
             Directive[
              GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, Frame -> 
          GrayLevel[0], BaseStyle -> Directive[
            AbsoluteThickness[1], 
            Dashing[{}]]], {
          GrayLevel[0]}], "Tooltip"]& ]}, 
     {RGBColor[0.831964, 0.810543, 0.372854], EdgeForm[Opacity[0.7]], 
      TagBox[
       TooltipBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          TagBox[
           GraphicsGroupBox[{Antialiasing -> False, {
              TagBox[
               TooltipBox[
                
                RectangleBox[{4.6897046006743155`, 0}, {
                 5.3102953993256845`, 5}, "RoundingRadius" -> 0], "128.`"], 
               Annotation[#, 128., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{4.859756252588234, 5}, {5.140243747411766, 10}, 
                 "RoundingRadius" -> 0], "41.`"], 
               Annotation[#, 41., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{4.918394753248206, 10}, {5.081605246751794, 15},
                  "RoundingRadius" -> 0], "11.`"], 
               Annotation[#, 11., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{4.922303986625537, 15}, {5.077696013374463, 20},
                  "RoundingRadius" -> 0], "9.`"], 
               Annotation[#, 9., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{4.9301224533802, 20}, {5.0698775466198, 25}, 
                 "RoundingRadius" -> 0], "5.`"], 
               Annotation[#, 5., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{4.935986303446198, 25}, {5.064013696553802, 30},
                  "RoundingRadius" -> 0], "2.`"], 
               Annotation[#, 2., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{4.935986303446198, 30}, {5.064013696553802, 35},
                  "RoundingRadius" -> 0], "2.`"], 
               Annotation[#, 2., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{4.937940920134863, 35}, {5.062059079865137, 40},
                  "RoundingRadius" -> 0], "1.`"], 
               Annotation[#, 1., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{4.937940920134863, 40}, {5.062059079865137, 45},
                  "RoundingRadius" -> 0], "1.`"], 
               Annotation[#, 1., "Tooltip"]& ]}}], 
           Annotation[#, {{4.6897046006743155`, 5.3102953993256845`}, {0, 
             45}}, "BoundingBox"]& ]},
         ImageSizeCache->{{228.08119325803446`, 
          256.69369101205695`}, {-7.818783174800927, 86.67390491804203}}],
        StyleBox[
         TagBox[
          GridBox[{{
             StyleBox["\"max\"", Bold, StripOnInput -> False], "44.4`"}, {
             StyleBox["\"75%\"", Bold, StripOnInput -> False], "7.5`"}, {
             StyleBox["\"median\"", Bold, StripOnInput -> False], "1.9`"}, {
             StyleBox["\"25%\"", Bold, StripOnInput -> False], "0.`"}, {
             StyleBox["\"min\"", Bold, StripOnInput -> False], "0.`"}}, 
           GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
           AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}, "Rows" -> {
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}}, 
           GridBoxFrame -> {
            "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, BaseStyle -> 
           Directive[
             AbsoluteThickness[1], 
             Dashing[{}]]], "Grid"], {
          GrayLevel[0]}, StripOnInput -> False]],
       Annotation[#, 
        Style[
         Grid[{{
            Style["max", Bold], 44.4}, {
            Style["75%", Bold], 7.5}, {
            Style["median", Bold], 1.9}, {
            Style["25%", Bold], 0.}, {
            Style["min", Bold], 0.}}, Dividers -> {{
             Directive[
              GrayLevel[0.3]], {
              Directive[
               GrayLevel[0.3]]}, 
             Directive[
              GrayLevel[0.3]]}, {
             Directive[
              GrayLevel[0.3]], {
              Directive[
               GrayLevel[0.3]]}, 
             Directive[
              GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, Frame -> 
          GrayLevel[0], BaseStyle -> Directive[
            AbsoluteThickness[1], 
            Dashing[{}]]], {
          GrayLevel[0]}], "Tooltip"]& ]}, 
     {RGBColor[0.6419975, 0.7183185000000001, 0.3669065], EdgeForm[Opacity[
      0.7]], 
      TagBox[
       TooltipBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          TagBox[
           GraphicsGroupBox[{Antialiasing -> False, {
              TagBox[
               TooltipBox[
                
                RectangleBox[{5.6897046006743155`, 0}, {
                 6.3102953993256845`, 10}, "RoundingRadius" -> 0], "162.`"], 
               Annotation[#, 162., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{5.905562269770444, 10}, {6.094437730229556, 20},
                  "RoundingRadius" -> 0], "22.`"], 
               Annotation[#, 22., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{5.931773558160688, 20}, {6.068226441839312, 30},
                  "RoundingRadius" -> 0], "5.`"], 
               Annotation[#, 5., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{5.933315398654232, 30}, {6.066684601345768, 40},
                  "RoundingRadius" -> 0], "4.`"], 
               Annotation[#, 4., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{5.933315398654232, 40}, {6.066684601345768, 50},
                  "RoundingRadius" -> 0], "4.`"], 
               Annotation[#, 4., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{5.937940920134863, 50}, {6.062059079865137, 60},
                  "RoundingRadius" -> 0], "1.`"], 
               Annotation[#, 1., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{5.937940920134863, 60}, {6.062059079865137, 70},
                  "RoundingRadius" -> 0], "1.`"], 
               Annotation[#, 1., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{5.937940920134863, 70}, {6.062059079865137, 80},
                  "RoundingRadius" -> 0], "1.`"], 
               Annotation[#, 1., "Tooltip"]& ]}}], 
           Annotation[#, {{5.6897046006743155`, 6.3102953993256845`}, {0, 
             80}}, "BoundingBox"]& ]},
         ImageSizeCache->{{272.5750816850436, 
          301.1875794390661}, {-80.53531835812323, 86.67390491804203}}],
        StyleBox[
         TagBox[
          GridBox[{{
             StyleBox["\"max\"", Bold, StripOnInput -> False], "77.6`"}, {
             StyleBox["\"75%\"", Bold, StripOnInput -> False], "6.9`"}, {
             StyleBox["\"median\"", Bold, StripOnInput -> False], "0.`"}, {
             StyleBox["\"25%\"", Bold, StripOnInput -> False], "0.`"}, {
             StyleBox["\"min\"", Bold, StripOnInput -> False], "0.`"}}, 
           GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
           AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}, "Rows" -> {
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}}, 
           GridBoxFrame -> {
            "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, BaseStyle -> 
           Directive[
             AbsoluteThickness[1], 
             Dashing[{}]]], "Grid"], {
          GrayLevel[0]}, StripOnInput -> False]],
       Annotation[#, 
        Style[
         Grid[{{
            Style["max", Bold], 77.6}, {
            Style["75%", Bold], 6.9}, {
            Style["median", Bold], 0.}, {
            Style["25%", Bold], 0.}, {
            Style["min", Bold], 0.}}, Dividers -> {{
             Directive[
              GrayLevel[0.3]], {
              Directive[
               GrayLevel[0.3]]}, 
             Directive[
              GrayLevel[0.3]]}, {
             Directive[
              GrayLevel[0.3]], {
              Directive[
               GrayLevel[0.3]]}, 
             Directive[
              GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, Frame -> 
          GrayLevel[0], BaseStyle -> Directive[
            AbsoluteThickness[1], 
            Dashing[{}]]], {
          GrayLevel[0]}], "Tooltip"]& ]}, 
     {RGBColor[0.35082, 0.595178, 0.853742], EdgeForm[Opacity[0.7]], 
      TagBox[
       TooltipBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          TagBox[
           GraphicsGroupBox[{Antialiasing -> False, {
              TagBox[
               TooltipBox[
                
                RectangleBox[{6.6897046006743155`, 0}, {
                 7.3102953993256845`, 5}, "RoundingRadius" -> 0], "173.`"], 
               Annotation[#, 173., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{6.917735638318307, 5}, {7.082264361681693, 10}, 
                 "RoundingRadius" -> 0], "15.`"], 
               Annotation[#, 15., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{6.933611216888458, 10}, {7.066388783111542, 15},
                  "RoundingRadius" -> 0], "4.`"], 
               Annotation[#, 4., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{6.935054451303927, 15}, {7.064945548696073, 20},
                  "RoundingRadius" -> 0], "3.`"], 
               Annotation[#, 3., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{6.937940920134863, 20}, {7.062059079865137, 25},
                  "RoundingRadius" -> 0], "1.`"], 
               Annotation[#, 1., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{6.937940920134863, 25}, {7.062059079865137, 30},
                  "RoundingRadius" -> 0], "1.`"], 
               Annotation[#, 1., "Tooltip"]& ], 
              TagBox[
               TooltipBox[
                
                RectangleBox[{6.935054451303927, 30}, {7.064945548696073, 35},
                  "RoundingRadius" -> 0], "3.`"], 
               Annotation[#, 3., "Tooltip"]& ]}}], 
           Annotation[#, {{6.6897046006743155`, 7.3102953993256845`}, {0, 
             35}}, "BoundingBox"]& ]},
         ImageSizeCache->{{317.06897011205274`, 345.68146786607525`}, {
          12.95736973471972, 86.67390491804203}}],
        StyleBox[
         TagBox[
          GridBox[{{
             StyleBox["\"max\"", Bold, StripOnInput -> False], "31.6`"}, {
             StyleBox["\"75%\"", Bold, StripOnInput -> False], "2.4`"}, {
             StyleBox["\"median\"", Bold, StripOnInput -> False], "1.`"}, {
             StyleBox["\"25%\"", Bold, StripOnInput -> False], "0.`"}, {
             StyleBox["\"min\"", Bold, StripOnInput -> False], "0.`"}}, 
           GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
           AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}, "Rows" -> {
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}}, 
           GridBoxFrame -> {
            "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, BaseStyle -> 
           Directive[
             AbsoluteThickness[1], 
             Dashing[{}]]], "Grid"], {
          GrayLevel[0]}, StripOnInput -> False]],
       Annotation[#, 
        Style[
         Grid[{{
            Style["max", Bold], 31.6}, {
            Style["75%", Bold], 2.4}, {
            Style["median", Bold], 1.}, {
            Style["25%", Bold], 0.}, {
            Style["min", Bold], 0.}}, Dividers -> {{
             Directive[
              GrayLevel[0.3]], {
              Directive[
               GrayLevel[0.3]]}, 
             Directive[
              GrayLevel[0.3]]}, {
             Directive[
              GrayLevel[0.3]], {
              Directive[
               GrayLevel[0.3]]}, 
             Directive[
              GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, Frame -> 
          GrayLevel[0], BaseStyle -> Directive[
            AbsoluteThickness[1], 
            Dashing[{}]]], {
          GrayLevel[0]}], 
        "Tooltip"]& ]}}, {}, {}}, {{{{{{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, \
{}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}}, \
{}}, {}}, {}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  Frame->True,
  FrameTicks->{{Automatic, Automatic}, {{{0.6897046006743153, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0, 0}}, {7.3102953993256845`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0, 0}}, {1., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.008, 0}}, {1., 
       FormBox["a1", TraditionalForm], 0}, {2., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.008, 0}}, {2., 
       FormBox["a2", TraditionalForm], 0}, {3., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.008, 0}}, {3., 
       FormBox["a3", TraditionalForm], 0}, {4., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.008, 0}}, {4., 
       FormBox["a4", TraditionalForm], 0}, {5., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.008, 0}}, {5., 
       FormBox["a5", TraditionalForm], 0}, {6., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.008, 0}}, {6., 
       FormBox["a6", TraditionalForm], 0}, {7., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.008, 0}}, {7., 
       FormBox["a7", TraditionalForm], 0}}, {{0.6897046006743153, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0, 0}}, {7.3102953993256845`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0, 0}}, {1., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.008, 0}}, {2., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.008, 0}}, {3., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.008, 0}}, {4., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.008, 0}}, {5., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.008, 0}}, {6., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.008, 0}}, {7., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.008, 0}}}}},
  PlotRange->Automatic,
  PlotRangePadding->Scaled[0.02],
  Ticks->{None, Automatic}]], "Output",
 CellChangeTimes->{{3.58599774379212*^9, 3.585997846486525*^9}, {
   3.5859978836499033`*^9, 3.585997925288548*^9}, 3.58599817508011*^9}]
}, {2}]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"BoxWhiskerChart", "[", 
    RowBox[{
     RowBox[{"med", "[", "col", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<Outliers\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"\"\<MedianMarker\>\"", ",", "White"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"GridLines", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"None", ",", 
        RowBox[{"{", 
         RowBox[{"Mean", "@", 
          RowBox[{"med", "[", "col", "]"}]}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"GridLinesStyle", "\[Rule]", 
      RowBox[{"Directive", "[", "Dashed", "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"None", ",", "\"\<Orthophosphate (oPO4)\>\""}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{".4", ",", "#"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"0.45", ",", "#"}], "}"}]}], "}"}], "&"}], "/@", 
           RowBox[{"med", "[", "col", "]"}]}], ")"}], "]"}]}], "}"}]}]}], 
    "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"col", ",", 
       RowBox[{"columns", "[", 
        RowBox[{"[", "4", "]"}], "]"}], ",", "\"\<Column\>\""}], "}"}], ",", 
     RowBox[{"columns", "[", 
      RowBox[{"[", 
       RowBox[{"4", ";;"}], "]"}], "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{{3.574177978775443*^9, 3.574177989700743*^9}, {
  3.5741782572000475`*^9, 3.574178379775648*^9}, {3.5741784775884333`*^9, 
  3.5741786253386745`*^9}, {3.5741788981545076`*^9, 3.5741789064491835`*^9}, {
  3.5741790498097973`*^9, 3.574179211188321*^9}, {3.5741792987014394`*^9, 
  3.5741793082036233`*^9}, {3.585500826613817*^9, 3.5855008951808357`*^9}, {
  3.586098987775023*^9, 3.586098994745599*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`col$$ = $CellContext`mxPH, Typeset`show$$ = 
    True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`col$$], $CellContext`mxPH, 
       "Column"}, {$CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}}}, 
    Typeset`size$$ = {360., {104., 109.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`col$41986$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`col$$ = $CellContext`mxPH},
       "ControllerVariables" :> {
        Hold[$CellContext`col$$, $CellContext`col$41986$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> BoxWhiskerChart[
        $CellContext`med[$CellContext`col$$], {
        "Outliers", {"MedianMarker", White}}, GridLines -> {None, {
           Mean[
            $CellContext`med[$CellContext`col$$]]}}, GridLinesStyle -> 
        Directive[Dashed], FrameLabel -> {None, "Orthophosphate (oPO4)"}, 
        Epilog -> {Blue, 
          Line[
           Map[{{0.4, #}, {0.45, #}}& , 
            $CellContext`med[$CellContext`col$$]]]}], 
      "Specifications" :> {{{$CellContext`col$$, $CellContext`mxPH, 
          "Column"}, {$CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}}}, 
      "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{405., {148., 153.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`med = $CellContext`sym$23716, 
       Attributes[$CellContext`sym$23716] = {
        Temporary}, $CellContext`sym$23716[$CellContext`a1] = CompressedData["
1:eJx1lM1OVEEQhS+RqJGfjDFK+AlmjBIQgZnBhJlE7FKcjDCYXAmYuDXRrQtW
7HgAXgAegBU7VuxcusAH4AXYGxKiITGGOV819sWpTaWquqpOna7u8qeva597
siz7nl3Jl46cB+k79uP4Um6b7Ec235FZ9A10jXjDVKVqe7uXUlF+v8n/rSn/
cECvSG+9x27RL0ivLlv2X5mj74LO7axx7ik4SoofLlLnJfWr8p8Z+X3gHI19
5J8mfp/8muLbOfneLyO/pwtO57MkXKfMs71I/Ta8vJK9+YH567Ge5luCp3X8
bXDVpQ/Wyaswf4t68LnTUv5RTnye88+o85w55sDTxn7M/eWWzvMnaI4G5ybQ
d83jsn8H56ejG3ncn6T/8Qj5T4ifBekp6s2Y72OK42ZX3ovidYt+9X8Ajn5L
z5XANcS9Veg3Jv/Hd+Aq4/e9n0SX2cOF9D69z70c/lvE6+QNsK++d29knzTV
b38j8ux4/d06786X4jPoi1DkMZVfQfhK6Tv6h7f03T+Me+L5/k8I/wt4zczx
UUXnrUleb9wf2ezDyRJ5hp6McxeR+575u/b9SN6TWZe5fa6L4PenvLFYL+3z
M/ZP55oq1O8t8H5+DXdS1+fdf03eiuyJt9jLzLXK3lTju/d9KeIrzpfiHqfu
rfiPyT/If+X/us9Vu8af78NfkcrlTA==
        "], $CellContext`sym$23716[$CellContext`a2] = CompressedData["
1:eJyVVMtKA0EQXEFREDTGGI1oMD7WF9FosoIS2MHkJJ5y8yro1YM/kN9IfsOf
8BB/w7MgiCKIZqpqQrKbbOxLMbPV3dXd01u4fWjcTXie9+z17N5a3rx0unZl
7GWzbsrWpolF4nvYbnXti7hkvLHsLQRmxuQnG/QUIvFQz08Yn79krO7cCf02
WNcm7m/q7MNevE5TA681RVx2PBvmUf4zBjpSRvmRZzYSF3HW4/ONMMRP/9sP
OhZY93eYxIe+RfLnB/xSPKsP6ucWz6o7uT7p6u9bsoF/RH6W/fcYJ+vmAey9
P/v5NaTekvPTnHQe3ZfAaA+AZeY95DnHc41xPiP9xvcP3hcTePtG7xt4Sp0F
6t4dqtfyri/pXyKaoXyZ5g0+9615AX+/4f4TfXk6k4x/HImveoG+m7fqA6tK
lM5zN89Ykc3A9QX5t8nTHlc5D5/7X+G5Av1PAetg3r948d1YYZ5i5H3g/sDl
1X4C5/r/n7lgwE/7kte988Mxw3yr7p1pLtpLfE+7/MC1If1PD/T7zEi/+iF/
xNUcxd8xv1HjQEM=
        "], $CellContext`sym$23716[$CellContext`a3] = CompressedData["
1:eJyNVEtOAkEQbUQj/iIRJH5REEMMmqgI6mrKhTtXHsFEtl7BA3gBvYaXcKHX
YI0xMRiNUea9atI1mUBtKtVV8+q9qumu3Nxd32accy9uaM3YCtKJ7TeKXfdY
kC3z/DN6ehzYjLjAJk08tLfXgTkB/hz9Fv13FNblBH4nFc8acD6itDz4Ntnv
QLQe/sTr1XrEs+zfS+Ain/d54OwavuUEf/CYklF8x9UV1i0m+o1npcQ+oO+S
eDn6foS96J79XETnhfyZQOcR64qeF/BPma/TL5s8+3dbtk/CQj4634rng/iL
+1ll3bxYHOSz/jzGfbgI+983GTfo634+2kf/I/BaMro2Td9txsN5Auc9odf+
B5jPOXR22xKcd9YYb5i51ExdnvvW816k9zvmf0X8zoTPQ1de9D4jv2J0ORs7
xUXU5rwy/j0Bj/XEdyEe79lza8T92U/D8Qb+P+b7fjTqHoV8p1mX/u5BZ4F6
9X04lDC/wHnuUVeDcTUVF3PQ/1HfIef3EtT93yedF/jXzPz0v6tIqKvI/ZQk
xMmK8kZdVf4APmw1ew==
        "], $CellContext`sym$23716[$CellContext`a4] = CompressedData["
1:eJy1VMtKQ0EMnWqlllbsU4qFqpuWdutWmKxcueonFHTr9+gXubj+y5WKIIqo
9yRzmUzTB+LZhGRyc85kknuxuJ/fVpxzT67EXYEv7zbgssAxrY7Xkvh29ZYe
tkuwbXrOfnBzzf6QoG8v1H98+MUR+00V7+6sY1ugfoWEH/o+fKE3OzF5kV/f
oKvK9+yQ8MgJePaN7yfoV3bFdmbxmPzgffOaF/ER+4dsx4m+WLe8S+7FQn+D
z8ckvnwXq8nVHPZCHu5XpbgfOr+EvA9430Me/HbSD5k3mUtEm2EuoeOU/T5J
3yxenE8THg3cy36fXSH7LP2y9hvxFsX5qQ7069zUh+9euX7LyOtxPGeeQciD
P+L5eAl9X99f+W8sud5n8FFnSDFvCj3Hq3msvSt1qDDf40DtidWX/4fM49+q
6H0+o2+/5PSb
        "], $CellContext`sym$23716[$CellContext`a5] = CompressedData["
1:eJzNVEtKw1AUTTGiYkGhbWqEhibVVAQ/taUThdxOXIBLEHTqFtxG3YabcKDb
cFwpdCKINefcV96LITjzQnjc37nf3Pj24eau5nney/J7mi4pnMjb6w/ti0e6
z2mRgYsgfxzLMKc27QJjrwT9PHN54H1RvlvwQ/yIedSdPPYMn+c7vTS8jZ+I
jecV4sD/VDQP+KVi11tNwFl38krZnzW8z0PWs0n5BuUXhbygPxStB3itgt1/
IeR3zL71BdIe3z7riE3dsNO5BwL/Bnndu8j0T/fB3puE8ibtm+QnJh74kXnt
/ehSfsX3SNy6YN+hfkD/FvOIjT30CeUHhf1BfaHYuPPS/YL9lulfVf+B16Xd
SHT/8+d9gP6GY9YRQ55OpCwPyM+J16XdtWjfwX9mwDthvIDybdr5Dr7+Z3XO
+8PEtfdhRtye2P/VzLkbSjpH3aM24+7Qb1jRP79CXyTksbqPSjpn3T/wHcdu
dSf1TvyOU/vzHdK5aP3oi2/6CHnDzAX6M3Hr0Ttl39tZpv5l8b8B/+9H3A==

        "], $CellContext`sym$23716[$CellContext`a6] = CompressedData["
1:eJyVVMtKA0EQ3KCCSEAJGo0J6pIYTS66vm4yfRFEPIievAp69eAP+BvxN/wJ
D/obngVBVhDRbNWsTI+T7BYsS/d0V9X0zmx8dXt+XYmi6On3eRgMsSZRADcZ
5mQ3Q4/vpiAfB/vKAnwfBu+wH+h383X4/zTId/K85dP9qN9y+y+PgnrlkJAn
NW5c59zaVsfTy3w0EpVPPf9FAb1348azni7yE16+GP86z8E+3/PkaQnmvCqj
v0OTdRXM5zFh/Qx5Ynl5HmKJ8+tzvZ/7xXo710e8ifo7CdTtybhzDz/Houfo
+hfqVT0e5CeD/P/zNcB3eqB810bz3B+KvQe2Hvvs0d8y4xbnvJ3z6fvgYgV9
3bN8PYtfrb/U2P+B7oSeumeDBbWvL3U+dzwed/5vBjxT2FdVuK8L1TdmXiUA
nwn1Qv8J6skJz0vC77HIWPdtBP1hP9+F773VQV9N9LlDPK1iQ39/5wCoe75Q
1/HyFj8ErQ+2
        "], $CellContext`sym$23716[$CellContext`a7] = CompressedData["
1:eJylVNFKQkEQXVOJTNAwUisIqR6EkCgIemnnG/wEQV/7nvqNfqKH/JcrgihC
iJ6ZjZl1Na7nZZk7s2fOzNzZzuC9Pyw4577dH8Y/azgabXDL58zDm/nnDY7J
JQD/kuNbHDf3mreevI+4a/r8WKNg8qeBuN8oTvLCKkV5pR6c03Bf82URL/x3
pG3RvdirNwXcP2E9NRI7L5+Fno/onvl9fYa/Rbov3aBL+mf7KHOEFfcR/vsw
Z8zrAXW3X7gPnvvwyt/f8P3rkf1F0nxlsnm255f/+YZ268y8nstZxA//xEt/
rA7UVY/05gV4riIeO8ftc5U5ynkZdEk89D+ZeUveYoiXvsE+TdaV2gv9n3u+
b/dofuA+lUMdyNdLviuiB/4KyX3Mr8rnOZl3kOxeaT67bxXStu3vNHe94Dui
3VEXXFczxP0vb2b2usF1N2kFQ/IeOA==
        "], $CellContext`sym$23716[
        All] = {{
         "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170., 
          50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
         "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
          558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
         "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
          125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
         "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
          61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
         "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222, 
          97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
         "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
          56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
         "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
          111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
         "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
          44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
         "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
          71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
         "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
          0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
         "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
          20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
         "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
          19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
         "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
          41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
         "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5, 
          31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
         "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 0.3,
           52.2, 5., 7.8, 0., 4., 0., 0.}, {
         "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 98.25,
           1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
         "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50., 
          1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
         "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 57.833,
           0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
         "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
          0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
         "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
          564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
         "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
          586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
         "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 0.5,
           15.5, 0., 0., 2.3, 0., 0., 0.}, {
         "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
          7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
         "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
          27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
         "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
          1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
         "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
          44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
         "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
          0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
         "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
          Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
         "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
          17.1, 0., 19.6, 0., 0., 0., 2.5}, {
         "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5, 
          33.9, 1., 14.6, 0., 0., 0., 0.}, {
         "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 4.9,
           3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
         "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
          2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
         "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
          130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
         "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47., 
          2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
         "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23., 
          0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
         "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 58.875,
           84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
         "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
          0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
          Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0., 
          0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
          196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
         "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
          182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
         "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001, 
          296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
         "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
          59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
         "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
          344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
         "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 276.85001,
           326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
         "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
          40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
         "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
          3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
         "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 0.8,
           54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
          Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
          0., 0.}, {
         "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
          2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
         "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
          20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
         "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
          49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
         "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
          22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
         "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
          11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
         "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818, 
          0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
         "winter", "small", "high", 6.6, 10.8, 
          Missing[], 3.245, 10., 1., 6.5, 
          Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
         "spring", "small", "medium", 5.6, 11.8, 
          Missing[], 2.22, 5., 1., 1., 
          Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
         "autumn", "small", "medium", 5.7, 10.8, 
          Missing[], 2.55, 10., 1., 4., 
          Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
         "spring", "small", "high", 6.6, 9.5, 
          Missing[], 1.32, 20., 1., 6., 
          Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
         "summer", "small", "high", 6.6, 10.8, 
          Missing[], 2.64, 10., 2., 11., 
          Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
         "autumn", "small", "medium", 6.6, 11.3, 
          Missing[], 4.17, 10., 1., 6., 
          Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
         "spring", "small", "medium", 6.5, 10.4, 
          Missing[], 5.97, 10., 2., 14., 
          Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
         "summer", "small", "medium", 6.4, 
          Missing[], 
          Missing[], 
          Missing[], 
          Missing[], 
          Missing[], 14., 
          Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
         "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
          6.667, 
          Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
         "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75, 
          1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
         "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2, 
          0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
         "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
          0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
         "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 10.75,
           2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
         "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
          0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
         "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75, 
          351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
         "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
          209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
         "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
          151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
         "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
          152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
         "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
          58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
         "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
          249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
         "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 100.,
           233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
         "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
          215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
         "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 25.167,
           102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
         "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
          105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
         "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
          111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
         "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
          1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
         "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
          56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
         "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
          4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
         "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
          104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
         "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
          69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
         "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
          214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
         "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
          254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
         "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
          57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
         "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
          412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
         "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
          282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
         "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
          197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
         "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
          267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
         "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 191.75,
           265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
         "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
          232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
         "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 144.66701,
           244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
         "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
          218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
         "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
          138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
         "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222, 
          239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
         "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
          235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
         "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75, 
          205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
         "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 31.333,
           211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
         "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625, 
          186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
         "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
          12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
         "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
          51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
         "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
          292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
         "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
          285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
         "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
          201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
         "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
          275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
         "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
          124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
         "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
          60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
         "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71., 
          132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
         "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
          17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
         "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
          0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
         "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
          8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
         "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
          37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
         "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
          86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
         "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
          10.111, 
          Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
         "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 16.833,
           18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
         "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545, 
          13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
         "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
          261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
         "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
          320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
         "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
          144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
         "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
          166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
         "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
          222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
         "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
          36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
         "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556, 
          127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
         "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
          89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
         "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 55.,
           284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
         "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
          102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
         "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 75.875,
           177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
         "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
          72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
         "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 48.667,
           82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
         "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 48.625,
           66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
         "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
          23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
         "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
          317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
         "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 84.,
           4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
         "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
          2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
         "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
          88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
         "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115., 
          11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
         "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
          98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
         "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
          143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
         "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
          197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
         "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 1.,
           19., 0., 22., 5., 1.1, 5.4, 0.}, {
         "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 10.583,
           23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
         "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
          200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
         "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
          77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
         "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5, 
          276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
         "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
          123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
         "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
          75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
         "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
          116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
         "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
          188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
         "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
          72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
         "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
          16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
         "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
          34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
         "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
          27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
         "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
          58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
         "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
          175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
         "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
          22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
         "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
          26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
         "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
          54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
         "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333, 
          34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
         "spring", "large", "low", 9., 5.8, 
          Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
          0., 0.}, {
         "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 151.33299,
           252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
         "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
          269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
         "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
          46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
         "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 85.,
           2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
         "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 66.4,
           171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
         "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 102.364,
           232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
         "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 84.3,
           146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
         "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
          246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
         "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
          205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
         "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
          236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
         "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 1081.66003,
           346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 5.9, 1.7}, {
         "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
          82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
         "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 64.389,
           137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
         "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
          87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
         "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
          159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
         "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
          21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
         "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
          0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
         "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
          14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
         "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222, 
          7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
         "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
          0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
         "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 7.654,
           4., 56.8, 5., 0., 0., 0., 0., 0.}, {
         "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
          2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
         "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
          56.091, 
          Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
         "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
          52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
         "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
          104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
         "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
          85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
         "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
          87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
         "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
          101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
         "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 50.889,
           127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
         "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
          81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
         "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
          19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
         "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111, 
          120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
         "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 51.111,
           91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
         "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 19.111,
           61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
         "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625, 
          79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
         "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333, 
          75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
         "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333, 
          140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
         "winter", "large", "medium", 8., 7.6, 
          Missing[], 
          Missing[], 
          Missing[], 
          Missing[], 
          Missing[], 
          Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
         "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
          140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 
          5.8}}, $CellContext`sym$23716[$CellContext`Chla] = CompressedData["
1:eJxdVHtIU2EUn2stFTNba/konWZOBr63pc26J1CGGZk2VCgkhCJIsqIorGAR
0R89ZEj0EI3eRCBiYhISlhIUFYFSSFSKVFhZiT0MKdrd+X0f3Pv9czjPe36/
e85JrW+s2hZhMBj6DOKV0bOn6vuhFIRfDm0Pv18K+1dAL6aLF9QXBZlELfGm
6tgsG/QJRUiuM875gRLiOqOwDyFuSidHZD7HW5CXK/O5j2TiOrOIm4GMlHFc
Zy5p6wn7IuAxo84S6Ebw8EVhGYP8x7Lva7tXR7+6mkklJxs+zk6kwj8f+U7+
fsBDHb6xJmuHA/UXwB+t42lK0faRCX8KafGP6nj5LvvR8GwwyXiW6aSNdwKf
Fd9zUMrxz5W9b12Ic7Jel08Cv5bXSDknGBzUWQi/G/5I2OdJv5gbobNMQp6Y
jxjYl0FXINMgE2lDfVxt0bCLvO8qTp9LriLFXXevrLuWRD9hOj+4oa/R4c3T
4umv0uJq2EiCJ7YXQWbreBzCfAj803L+xN4IvOd3WY71fyqUeN+km4+eHVgu
+2n/dvNR+d0E6k0OEV9oY1xfRb8RbI+rpgP3LyXmtG3mPpeWwZ+hxS3nS/Rr
g7TIOBYmxDuknfEsRn6CxKutXyD54u/bYRc8r9T9P2L9jgd6LsedWkeCv7A5
4KV/wwcnMoLF0D3wr0I/mM+ta7nenEp68ORyac/OGrrROmjvdNbQwM/MLc31
fh0fsfT+RdrrP9nl4NcNexb17QtdrpfxdMI28vx3i4uulPZM//VbKXTMutoa
bTSzafx662AaBScPK+52L/pxkdhbsXdiL8VeaPc0jtQr4Bszy77C/igfqVez
60ge+MgiNarJn0/71YN6ppAOhQ02an4YAlZhJ/Xc3NpjxXx7KDT1Mcbb8bwP
3UboFurcuyM42adw3fX59B+9vOsY
        "], $CellContext`sym$23716[$CellContext`Cl] = CompressedData["
1:eJx1VAlIlFEQXqU7EVu0NVHbzGPLLvGqbPs/212PbU1X3Uy7VLJMzCStJKKM
sAOxELujMtOig4gIk4ropsNuIcwiJSKkO7PToPf+mTUI+uFnmPfmzXzvm2/e
iNylqXkuGo3movgXqt8MaOTXbsPVbsOcra5m7P9w5Mb0jDTcbRbfiem0X5xC
NiUVawsulNZsSkK4/LoiaV2j77UdqzxPxueMYN+T4sKHsT+A8jZr2ff9j+V6
mpnYs1t+ncpXAe/KcmCHqbLw9fkQrh+EF8lVO4u0ozg+iG0A2wn/+KPZTkZ+
9bvVilcE+YhlnEa03vuW9rJiKpr8K97Ymz4rtP5NUeNqI/BR0BOdGMXn0ijO
m3nSJKLn6KdHSVonb3aylxyUv8Z5LyeecbwfBrUdwcB9Ub4hJgbzziW6uR73
xoIYcUOdF+osjV2/0z2IP5sWr3/JQkPgMWvSmZsr+jP+QbC6uYZuHDqQfVDe
G0bI2/hbQPU8TGj7sabgQp9YxpFDdkw22XZeLzfS+YUxpI8rkzk+uNdSPwPZ
D8WuIu36S1YD+wrnsUKivDh8GmzRm2OzHQmo8e4z073KyvnnU1xTHlIlobsz
IMMPHLPyeTvp6nIyTu8TAp1to3Mb/upXtWWZkLdvXeMg/0Eybok0PhvTkSWJ
dKTg/Wolct7oJN5PwPPAfuu2v4yn/X3x3A8z4fQyQ7YhtD+wXALeouN7+SEk
bMAJ36zhhKPRCpHFVPnWhocBktlmJVdtzHdFvY9dh8N7r+lPHUuFWddytrkw
G0tkA+vicF1/alm+3YIvv1vKOqMSIKq+elAXgs5gWcCpZwPNpU4h3Tqm0Lp+
KgQIgTwI7mMFMyGBxOtY7s+sfOalDMZBTw4VO7i/5SYINjtWtcRy/6b1rtNc
JUCV1ZZEnj89zGLsfi0OhEBb/e5aGvOZjjsHhTD7sq5rzbTv6+SP+SyPh+jC
+OfbzL16kHCMPnGUp3s+6TMyk/czyILnR8yVSuPEcPadOozjeAveiuMVlRZe
n0C4M6NID43phKchGULE3YYeC34K+ZeWmFAiCX2Sgfqe+qdHfuZCbWtEFkbK
Nj6z0zwOLoDoSkBb3iJI2jzHOd8vN55DL+jUh0PDfLnwfj/SbYc71fUNwOXb
grASf+KtivtQ6nxPokn/9ijW2yiae8/xWCkJnGvgd8CP+vQ4muvyvGWHob5Y
dnoM4V6bQ++BuP8fKhHjmw==
        "], $CellContext`sym$23716[$CellContext`mnO2] = CompressedData["
1:eJx1VCtMBEEMXeQdJOSA+//2O3t7Fn25cWgwmFMkYBCg8RgMBgMWj0YjUKDR
eCwJAgG37XubmYNJNk237Zv2tdPo6OzgeC0Iguff7+52eRIblCe0ry/LY+xu
ebb1f6z61Ip/qnqmcl3jEntSnlRlrvZE4ypdcHOVE4s8BCdVvaY4mcqY90tc
pP4x/UQP9R5DXJFG4wri4D/yl7gxcUQCN9L4TGVL7x2ofaR4yGvK+wR3orIg
Dx/7j6PLU0PeJH6sccgXdWfkEbrYE89uyCP6ALvbl5T8ID/B+5pL/Pcc9Yk9
ZJ7QRfbZB5fvtvrXvf4lzAO8vt2fz+qHxqurY+tLwxX439A45Lvaf8wF+gS+
XL2p+pbidDU+ZD/F3lN7k32V/+BtyDmDRN7/zZ+bT4f1oO5ZWTD6k/N+8et5
9SLP2HsnCXXgCH6f+aP/mFuXH+SD+c/ZP7dveK+ow1DHXLrvpeLb5Tcknjvv
2D/grbHC3/XT52SxibxrjMO8YE+JP/hsq73lvdeCeSxKYPDXYD+lzoj8iN5h
3fIf+3LI+8Wv6/UpszsPe+8XN1U//uYt5R5y90T1njG/4Ev0Efc58ODnzufY
25u4d+Dh9OwPK8Mlwg==
        "], $CellContext`sym$23716[$CellContext`mxPH] = CompressedData["
1:eJxtVC1QQkEQflaLhWFG5P6gYCYzs00DRTLJGS0GsWKxUCxkrJgpFopFgwWz
xULWYMHse3f73c3t88rO3u3tz7ffrju/Hl3sFUXxVuBY6lfniWXf0uNksP/R
tWRmX2drbcmb3Vl635RnaOlhUZ5DS5f+OFrrytCE941mqei3N56/7DRtp43V
yVaHfwvDcTT7N3RThltONPtTdFx96xkaecfw2w55FIZuK3dTTd5sbMirDcN6
m/0fEerD/xBfxTqDhH9LVRaDe8txHdvb6Ac6/mf+h+kdEn6ln1Cn5jpV1PM4
Jsrw3mLZZL9NcZ9k8NPi/4cRx1PfCE2vu6oxbZaKPGxz4AupowROQXfMFxNx
CHGBS6eGTy616IOKOiTsgEtubwReLvIQcYO9i/bAMcu/zDPg6AQvE4+lLvNC
XLyjz76tn+BRmhPglOeBvGDX5XtX4xH+53hbUbcSPE31hjgdwUcn7FWNf7KP
iIc68/imNl/SD/DDe5j/NCde/0l1++dnJ/qian2T/ED9/88h8OhGvvg1snI1
XgI/PycHjveWi/sx7CPem0tD3+Xt7Er2GfadGl+RH+wkT+T+yOfOCR5iP7va
fEgehf2T7CROeR4pnz+AYBOX
        "], $CellContext`sym$23716[$CellContext`NH4] = CompressedData["
1:eJxdVH1MzHEY/yHmbS15y4bOdE0Srjel6BGpxMnVcV3dWy/nnLsyqawZh8RW
Ee0WEpmwYrTJDcPORszLzNtME5nN+/u7UfPrnk+3ue8/n32e7/N93p/vhOwC
RV4fQRDaBByfTeRCSQlJb7Z2HWsuots/054frlCRsedEWvm+s5TRlklZ/TKl
qtMrmLdkUJjrjKYxXku9Q3ZF0Ms/TZ/vWkPp09G2lBnJMawnSGjvHvGMSYSd
EGq9VnzxwOQ5ZNr5fl2cMg7yJAqZ3d95M+ASc686RkqHnQRq/NvYfnSwGTwI
94vAY4HhHqgFyv9HZxJj8THIzzI+rgcPBgYw7rZQTeW+LbMURq6PQ0vSicsN
O2LLoJdG37rur33tSIb9eOQVCZz7vz1hHuRzGH1MqEcsMJSuSFpWm+6Qx7sR
Hjzcg3tiKPz09iMXONWN3MfpzJvs1NQop1MJDSTTaW0XPjSwXGJhpEzGhnzG
b6sgJ+oW0w8cZCHZwONj1a166MEfZTB2FoDrSZ0b83TxAy3X07iU5UO3MlZX
0q+qk7PC7pWST5G/Ld3soAlvZgtNd0/SkbrLkpbBOtZLhV1JDssnq9iuXQW5
gfoGbx316IeZOgIGbLTnqFmuz2GMyuH5V2POG7RU4LvZef2zmT7EF9a3yUpY
7kBcCwuppz0R3uhnp5Xe75H2aR5fRcON7d3K+nKWP1nHetsxD0I0Lf9yK3LG
nRUkRjG3olED/yvd/XL1/UE0ybN9VNFrgnjfilBHYRmNk+w+lFhbRGJ2VbVT
F5IY5cEEXz0N7UlQk4f8UhFXAu/zjXzUJQ35oV42K+oP7reM6qLOPl0yEvvg
RN42E/xjjwh7LOi4rpFZ6NcG+M3DPeZ6G+J3VnI+dhOVbXz55JDfAbyDvt6K
OJUc13fMgz4FcYDbHrKdkUbmpvVs78RO5lm18If5isAc0GLIDfxeme3On/+n
BezfnEHnXwUnhdXkk2JeufL8JAPzQsy/Xxk9etvhP23vZtjdxf5fVNP+j+LH
N1rHdppTuS8XTOhLCtX4iR+lpnefgyguQnsu+d0Cmu/42nU/KtA9B4xSYK8+
/gtxz6rlmt9TZuZyf4egLmK/XWtUnk7nkkXPV2XIN4O2vF1yZrwmleN4Hs96
gQr3vrj0PqVzPZQ6OpH4rHSEt5wqLOKPPiyG/gGlrJwB
        "], $CellContext`sym$23716[$CellContext`NO3] = CompressedData["
1:eJw9lAtIE1AUhufSqcs93MOGmTW1MqJEohcR54SZ9pBIIUJEQjJC7P1AKoqo
EJGIiN4vyqKMiIgICQkzUxItS02lJKSm1jStOTddSvfec9YFd+fdvff85zv/
uc6C3dmFIRqNpl78vWq8nf7c48D3vpxv966NQHZV/Gn3Jjt+SPg8dqxIi3fE
rxNtSehqkQsJeLbWm5x31g+j4rPWa8W5qRGP4nIHYKW+o2LPylFY8XXjmUu7
/HC9btaTfTvG4I2cznlAXCpu9kH+i7VR2vk+mKkWvKDCVY3COrFaGuMDuXvw
aADGjxVVHzivw+YmMTZYcbbuxIW08u8wfL9+/dKycNyrAgZgnpSR7Ad5uuud
CUcm2kp+zBnj9e+gprw+oP3NcHeP/KJH0mtE2hfB9+vw6hU5KiF3m8xkKpLu
PhiQk/sHzFA/TMUC85blzzLN+Lfy98esAgfutpysabxtRCHaERrjROI4E9W0
zIJHbI8zeg5bUcVPtGBQTzA+cY3AdqE+NcLC/MdBwBQ3/2Feg8w9El/L7bUh
uF2NUAzypDkMZTTbYzPKz4yeabhfYgUv0OyBlO4kkbGPefQz10GQFH05Hlgj
y14yCEvLVm11tQxz/QKg6tEU5JaAbw+9vBWbYkRV1lI9Ghc8vTF034YK36UR
CPI7KLBsNrqAOOhZVyTxqbKiX9qvzo6Ub5BnNApziasMKKul7zBwnmbiWBGH
rVmyEkaunx4vy+ONFtZj4/UpzMvK59tB3p7+vJV99wF29gVEJU3ktyYH74tE
Wg/FSWmr1HBsWC+JOHndznG0pP+Uk7g8sCD5LgwVjvoY1uEHjRqTHD8A5J9O
mK4K0g0X08qL+wJdzOkL91MvLFLDxHzMmCkBNsQh+dHG/olFJSsrBBOlfaon
QaXXFYIbpOxCG3MNR+oXA+v0gmrjbR6O7yX/G2LJRwsdXO9Y9q2V+8KGpO8n
+8cFKt3yxP/xqL7jnIcWVVifk+7dlYjk53iu5yjrGGPfabife4B8puU+0qLC
0bqG9YTxeTvnZ+V9Bnwo8Zo7mec49/EE+3gAZLc9invBfVADSqbFDYpvhpX9
bOd83SBMLFYCVL8lZlRlLTYgvVtR/B6YULVXmgmPF6kXgd6FT9HMXY8U9xeo
dlw8DOTzIbg5JEG62A8ueCCxrupnv7iB+v0nqGP5vfR/b9CvRuah++9f4j3B
/a5lf/hBHBbWHQaVzlAUyu6b9SQUV8vyVxr5HQz6P5zfGR3+A5Qp1OE=
        "], $CellContext`sym$23716[$CellContext`oPO4] = CompressedData["
1:eJx9VGtIk2EU/jIJM5FuloSV1/KCaS0vabXjJt4v87LQKTaXLvM6pSSjYtIP
icKKkLSoxIamRohIhUmIpEXMsFCkJPSHdhEkIy0rhbad5xu0H70/vofzvec9
t+ec46GpSC9cJQjCkIBDKrKg8Qy13nru3lV8lO58bRtKvJFCXhO/zhe7JfM9
7WNsTqGksItRamUMac1nlwz3kYx6Pwr64L2mVunDsuALDAb6AzdQY/nGC/0d
sCvsZ+yPJocqxYDRUMty+DmSWE6QjR0HG/QErrfBCJs40uGnHPEmWP3fbDKf
7SzrkLfwW8poTwbdIcfx60Vk+t7TDWvpfsS09smPfFpYGT395VEytaybzdHW
6yhvwcXQlFyJ997ASJv4N9v8R11M9eN8EYew0ya/een/USBbOfpS6ac/7Y70
77091W159/pnxiL0FqTDRvNZZrmxhJYmE6pLI4tZf1qD+GKAiYyu+bCXzahW
Mq/+B/BfxtglQ33Bh1oO2Qd9INaBGEdyqO9zQJxEkk8cVxJNSBLtMgdryMfY
s9LZUkmGZcP7tt4i1u/TMS4dZ3TPo9zVOT5ZLoh7/hjsh9G1ubPSEGcVqQoi
J1OVWfx/Kp6KzBdKKcvNB6k33sku4IUf69fHwy7mRSFH3OGwi3ro5dTzsvrZ
3eIUlvvTMA9e0NtGy+3f3iZrPMj+iHNg9xzqo5eRhabKUI5jLJhyrwws+uY6
cT9l63jehspgR0MPn9Z0yMcLEK+W9jo8cFOdlCFu+FekWvmy5NsAnpbSadC9
q6ooLQrzHAf9OGud2G4h8sDcqFFfPfQIfAnwN6VgvKoGb8H0xtO0SPyxD/Rp
qHsG7MbCfyzn91G0J9rPsdaV5yIU92Ifin0TznwvIl5FGft3SgRP4n45jHfZ
3D+zGn7XoIV9D/AViP5UYB9m8/0mJUVvHX1s7CvhevecYPlyGfryFPolk8xp
zbgqON8xJfuZEfsQe8A073lmwjp3UGD3bZOntVwHrTP0xD3myn3hEgJeIijB
RHPdHhXrt0aj7vEc5/cYqjCl/aoSfUtRtNsccK8Ee11i7WtRtuiNJHD/dkSh
X8CToKC/kqeRLA==
        "], $CellContext`sym$23716[$CellContext`PO4] = CompressedData["
1:eJxdVHtIk2sY/zKxYSJGdMFWeTp5KbuYWt4If6ZZXjKdTqazuU03pza3b6aM
k+ewOohJRIsSMorKFl3/qDCT6LKiO+tCGZUjKqLoSlJZCRbt63nssPP+8+P3
fs/3vM/7e3/P84feojCMEgThisALBvzC5nWwHu8KuqergVFapTq0vi3qnWZQ
IT+pPUOrzKe4ATVO7Ppw4Iq6mLi7CDc9vpW/jHkioZDAuIBxHsV5Cog7Vbyf
g+5rzed2v+H87gLIbIUXPfINxAvXc1w8YxahI415NC5HHLOZxmUj4deK5e/Z
/nW4dcwbCVVajuO6hSQsDn6wzzpVyVzmjwctmFWx+eLgKwv/Z0P6oS+v7c8M
0Hye4Opsb8KwJTKtx7yG9eI63Us5PpPzTSaEBlPLq9Oe3E6k+x9eTrq/XIQd
ndKKhi/Liztd0fxfOONAOmGYfz4h6n98zm/UnM4JCTgy8v8Ufge5f7wjknkg
3WeoibCzEapGhzZUFOEadvUfCK5CilTwyhUUH8N6xJkJB+ogXWtlRxlyQwJi
2xrKaf+hmvOr/f0ksB+Ecrzz2a11bRHrVoczr2KXJ9yzIGD39GxZhAHjjf0/
lEPrsX2Sdvrj1n/hTcgLKBm0UXyLnXCbleoM53ocDax3PWEh++CpGRWj1ZGq
Jo47U8u8juNqCLOqaH/QSDzXhrOpVx2rvSKka7xIrkWgs/9STrxIuoZU0vmn
deSPLVqYtrxvSVeO9EEqej5977MfikPQuo7Mja4yxLZNfHTrvBLZ0ofkmfRe
efHkB+Nsigtdi66xb9TGoDWss4iCmCz33norfvTZX0dd5/s5NJCOW3irkrip
lPUUSS+lSDzRSD5LUeBP79A/dTtLaP9YIWEvz4U73C8C98Ue1idiJG8Fnd/O
/fxNB1nEyfatLhP7OANS28S0JEF2VF5ePaaW9PlLz+8ikl/ua0inmwrWcRXp
3lFD95/z3z7Vk0H/TSimPprPfnQ2sw5mmgeNlZS3KY/PUfC5/L5OCyI93d+P
9Fvx8e4KfVgyzwMooQ9TpXSbDMia1HfKIzdDJRm/QE913W+AZO+Jf9fD2/oy
ddNokfIssVP8cDX7Q0c+zjQRP1jP83Ih3yOK6js50q9y7s/JCCwNnXti1zTe
j8Ptr8XP94/lvrHmEt+4mnQu4/e5pqS5vaqM36cSF27sXdpTVQJpvC1OzeG6
NLjuGzvhV0vJd73chwPF8E2dGd4hBaTw4DYd6e/U4SeBO9yW
        "], $CellContext`sym$23716[$CellContext`season] = {
        "winter", "spring", "autumn", "spring", "autumn", "winter", "summer", 
         "autumn", "winter", "winter", "spring", "summer", "winter", "summer",
          "winter", "autumn", "winter", "spring", "summer", "spring", 
         "winter", "spring", "autumn", "winter", "spring", "summer", "winter",
          "autumn", "winter", "spring", "autumn", "winter", "summer", 
         "autumn", "winter", "summer", "winter", "spring", "winter", "spring",
          "winter", "summer", "winter", "spring", "winter", "spring", 
         "autumn", "winter", "spring", "autumn", "winter", "summer", "winter",
          "spring", "winter", "spring", "autumn", "spring", "summer", 
         "autumn", "spring", "summer", "autumn", "spring", "summer", "winter",
          "spring", "summer", "winter", "spring", "summer", "autumn", 
         "summer", "winter", "spring", "spring", "autumn", "winter", "spring",
          "winter", "spring", "autumn", "winter", "summer", "autumn", 
         "winter", "summer", "winter", "summer", "winter", "spring", "summer",
          "winter", "spring", "summer", "autumn", "winter", "spring", 
         "winter", "summer", "winter", "spring", "winter", "summer", "autumn",
          "winter", "summer", "autumn", "winter", "summer", "winter", 
         "spring", "summer", "spring", "summer", "winter", "summer", "autumn",
          "spring", "summer", "winter", "spring", "summer", "winter", 
         "spring", "summer", "winter", "spring", "summer", "winter", "spring",
          "summer", "winter", "spring", "autumn", "spring", "autumn", 
         "winter", "summer", "winter", "summer", "spring", "autumn", "winter",
          "spring", "autumn", "winter", "autumn", "winter", "spring", 
         "autumn", "summer", "autumn", "spring", "autumn", "spring", "summer",
          "spring", "autumn", "winter", "spring", "spring", "summer", 
         "autumn", "winter", "autumn", "spring", "autumn", "winter", "autumn",
          "winter", "summer", "winter", "spring", "spring", "winter", 
         "autumn", "spring", "summer", "spring", "summer", "winter", "summer",
          "winter", "summer", "winter", "winter", "summer", "autumn", 
         "spring", "autumn", "winter", "spring", "autumn", "summer", "autumn",
          "spring", "autumn", "winter", 
         "summer"}, $CellContext`sym$23716[$CellContext`size] = {
        "small", "small", "small", "small", "small", "small", "small", 
         "small", "small", "small", "small", "small", "small", "small", 
         "small", "small", "small", "small", "small", "small", "small", 
         "small", "small", "small", "small", "small", "small", "small", 
         "small", "small", "small", "small", "small", "small", "small", 
         "small", "small", "small", "small", "small", "small", "small", 
         "small", "small", "small", "small", "small", "small", "small", 
         "small", "small", "small", "small", "small", "small", "small", 
         "small", "small", "small", "small", "small", "small", "small", 
         "small", "small", "small", "small", "small", "small", "small", 
         "small", "medium", "medium", "medium", "medium", "medium", "medium", 
         "medium", "medium", "medium", "medium", "medium", "medium", "medium",
          "medium", "medium", "medium", "medium", "medium", "medium", 
         "medium", "medium", "medium", "medium", "medium", "medium", "medium",
          "medium", "medium", "medium", "medium", "medium", "medium", 
         "medium", "medium", "medium", "medium", "medium", "medium", "medium",
          "medium", "medium", "medium", "medium", "medium", "medium", 
         "medium", "medium", "medium", "medium", "medium", "medium", "medium",
          "medium", "medium", "medium", "medium", "medium", "medium", 
         "medium", "medium", "medium", "medium", "medium", "medium", "medium",
          "medium", "medium", "medium", "medium", "medium", "medium", 
         "medium", "medium", "medium", "medium", "medium", "medium", "medium",
          "medium", "medium", "medium", "medium", "medium", "medium", "large",
          "large", "large", "large", "large", "large", "large", "large", 
         "large", "large", "large", "large", "large", "large", "large", 
         "large", "large", "large", "large", "large", "large", "large", 
         "large", "large", "large", "large", "large", "large", "large", 
         "large", "large", "large", "large", "large", "large", "large", 
         "large", "large", "large", "large", "large", "large", "large", 
         "large", "large"}, $CellContext`sym$23716[$CellContext`speed] = {
        "medium", "medium", "medium", "medium", "medium", "high", "high", 
         "high", "medium", "high", "high", "high", "high", "high", "high", 
         "high", "high", "high", "high", "medium", "medium", "high", "high", 
         "high", "high", "high", "high", "high", "high", "high", "high", 
         "high", "high", "medium", "medium", "medium", "high", "high", 
         "medium", "medium", "medium", "medium", "high", "high", "high", 
         "high", "high", "low", "medium", "medium", "medium", "medium", 
         "high", "high", "high", "medium", "medium", "high", "high", "medium",
          "medium", "medium", "high", "high", "high", "high", "high", "high", 
         "medium", "medium", "medium", "medium", "medium", "medium", "medium",
          "high", "medium", "medium", "medium", "high", "high", "high", 
         "high", "high", "medium", "medium", "medium", "medium", "medium", 
         "medium", "medium", "medium", "high", "high", "high", "low", "low", 
         "low", "high", "high", "medium", "medium", "low", "low", "low", 
         "low", "low", "high", "high", "high", "high", "high", "high", 
         "medium", "medium", "high", "high", "medium", "low", "low", "medium",
          "medium", "medium", "high", "high", "high", "medium", "medium", 
         "medium", "high", "high", "high", "medium", "medium", "medium", 
         "medium", "medium", "low", "low", "medium", "medium", "high", "high",
          "low", "low", "low", "high", "high", "high", "high", "high", "high",
          "high", "medium", "medium", "low", "low", "low", "low", "low", 
         "low", "low", "low", "low", "high", "high", "low", "low", "low", 
         "low", "medium", "medium", "medium", "medium", "medium", "medium", 
         "high", "high", "high", "medium", "medium", "medium", "medium", 
         "high", "high", "low", "low", "low", "low", "medium", "medium", 
         "medium", "medium", "medium", "medium", "medium", "medium", "medium",
          "medium", "medium"}, $CellContext`sym$23716[$CellContext`a1, 
         "factorized"] = 
       False, $CellContext`sym$23716[$CellContext`a1, 
         "missing"] = {}, $CellContext`sym$23716[$CellContext`a1, 
         "raw"] = CompressedData["
1:eJx1lM1OVEEQhS+RqJGfjDFK+AlmjBIQgZnBhJlE7FKcjDCYXAmYuDXRrQtW
7HgAXgAegBU7VuxcusAH4AXYGxKiITGGOV819sWpTaWquqpOna7u8qeva597
siz7nl3Jl46cB+k79uP4Um6b7Ec235FZ9A10jXjDVKVqe7uXUlF+v8n/rSn/
cECvSG+9x27RL0ivLlv2X5mj74LO7axx7ik4SoofLlLnJfWr8p8Z+X3gHI19
5J8mfp/8muLbOfneLyO/pwtO57MkXKfMs71I/Ta8vJK9+YH567Ge5luCp3X8
bXDVpQ/Wyaswf4t68LnTUv5RTnye88+o85w55sDTxn7M/eWWzvMnaI4G5ybQ
d83jsn8H56ejG3ncn6T/8Qj5T4ifBekp6s2Y72OK42ZX3ovidYt+9X8Ajn5L
z5XANcS9Veg3Jv/Hd+Aq4/e9n0SX2cOF9D69z70c/lvE6+QNsK++d29knzTV
b38j8ux4/d06786X4jPoi1DkMZVfQfhK6Tv6h7f03T+Me+L5/k8I/wt4zczx
UUXnrUleb9wf2ezDyRJ5hp6McxeR+575u/b9SN6TWZe5fa6L4PenvLFYL+3z
M/ZP55oq1O8t8H5+DXdS1+fdf03eiuyJt9jLzLXK3lTju/d9KeIrzpfiHqfu
rfiPyT/If+X/us9Vu8af78NfkcrlTA==
        "], $CellContext`sym$23716[$CellContext`a2, "factorized"] = 
       False, $CellContext`sym$23716[$CellContext`a2, 
         "missing"] = {}, $CellContext`sym$23716[$CellContext`a2, 
         "raw"] = CompressedData["
1:eJyVVMtKA0EQXEFREDTGGI1oMD7WF9FosoIS2MHkJJ5y8yro1YM/kN9IfsOf
8BB/w7MgiCKIZqpqQrKbbOxLMbPV3dXd01u4fWjcTXie9+z17N5a3rx0unZl
7GWzbsrWpolF4nvYbnXti7hkvLHsLQRmxuQnG/QUIvFQz08Yn79krO7cCf02
WNcm7m/q7MNevE5TA681RVx2PBvmUf4zBjpSRvmRZzYSF3HW4/ONMMRP/9sP
OhZY93eYxIe+RfLnB/xSPKsP6ucWz6o7uT7p6u9bsoF/RH6W/fcYJ+vmAey9
P/v5NaTekvPTnHQe3ZfAaA+AZeY95DnHc41xPiP9xvcP3hcTePtG7xt4Sp0F
6t4dqtfyri/pXyKaoXyZ5g0+9615AX+/4f4TfXk6k4x/HImveoG+m7fqA6tK
lM5zN89Ykc3A9QX5t8nTHlc5D5/7X+G5Av1PAetg3r948d1YYZ5i5H3g/sDl
1X4C5/r/n7lgwE/7kte988Mxw3yr7p1pLtpLfE+7/MC1If1PD/T7zEi/+iF/
xNUcxd8xv1HjQEM=
        "], $CellContext`sym$23716[$CellContext`a3, "factorized"] = 
       False, $CellContext`sym$23716[$CellContext`a3, 
         "missing"] = {}, $CellContext`sym$23716[$CellContext`a3, 
         "raw"] = CompressedData["
1:eJyNVEtOAkEQbUQj/iIRJH5REEMMmqgI6mrKhTtXHsFEtl7BA3gBvYaXcKHX
YI0xMRiNUea9atI1mUBtKtVV8+q9qumu3Nxd32accy9uaM3YCtKJ7TeKXfdY
kC3z/DN6ehzYjLjAJk08tLfXgTkB/hz9Fv13FNblBH4nFc8acD6itDz4Ntnv
QLQe/sTr1XrEs+zfS+Ain/d54OwavuUEf/CYklF8x9UV1i0m+o1npcQ+oO+S
eDn6foS96J79XETnhfyZQOcR64qeF/BPma/TL5s8+3dbtk/CQj4634rng/iL
+1ll3bxYHOSz/jzGfbgI+983GTfo634+2kf/I/BaMro2Td9txsN5Auc9odf+
B5jPOXR22xKcd9YYb5i51ExdnvvW816k9zvmf0X8zoTPQ1de9D4jv2J0ORs7
xUXU5rwy/j0Bj/XEdyEe79lza8T92U/D8Qb+P+b7fjTqHoV8p1mX/u5BZ4F6
9X04lDC/wHnuUVeDcTUVF3PQ/1HfIef3EtT93yedF/jXzPz0v6tIqKvI/ZQk
xMmK8kZdVf4APmw1ew==
        "], $CellContext`sym$23716[$CellContext`a4, "factorized"] = 
       False, $CellContext`sym$23716[$CellContext`a4, 
         "missing"] = {}, $CellContext`sym$23716[$CellContext`a4, 
         "raw"] = CompressedData["
1:eJy1VMtKQ0EMnWqlllbsU4qFqpuWdutWmKxcueonFHTr9+gXubj+y5WKIIqo
9yRzmUzTB+LZhGRyc85kknuxuJ/fVpxzT67EXYEv7zbgssAxrY7Xkvh29ZYe
tkuwbXrOfnBzzf6QoG8v1H98+MUR+00V7+6sY1ugfoWEH/o+fKE3OzF5kV/f
oKvK9+yQ8MgJePaN7yfoV3bFdmbxmPzgffOaF/ER+4dsx4m+WLe8S+7FQn+D
z8ckvnwXq8nVHPZCHu5XpbgfOr+EvA9430Me/HbSD5k3mUtEm2EuoeOU/T5J
3yxenE8THg3cy36fXSH7LP2y9hvxFsX5qQ7069zUh+9euX7LyOtxPGeeQciD
P+L5eAl9X99f+W8sud5n8FFnSDFvCj3Hq3msvSt1qDDf40DtidWX/4fM49+q
6H0+o2+/5PSb
        "], $CellContext`sym$23716[$CellContext`a5, "factorized"] = 
       False, $CellContext`sym$23716[$CellContext`a5, 
         "missing"] = {}, $CellContext`sym$23716[$CellContext`a5, 
         "raw"] = CompressedData["
1:eJzNVEtKw1AUTTGiYkGhbWqEhibVVAQ/taUThdxOXIBLEHTqFtxG3YabcKDb
cFwpdCKINefcV96LITjzQnjc37nf3Pj24eau5nney/J7mi4pnMjb6w/ti0e6
z2mRgYsgfxzLMKc27QJjrwT9PHN54H1RvlvwQ/yIedSdPPYMn+c7vTS8jZ+I
jecV4sD/VDQP+KVi11tNwFl38krZnzW8z0PWs0n5BuUXhbygPxStB3itgt1/
IeR3zL71BdIe3z7riE3dsNO5BwL/Bnndu8j0T/fB3puE8ibtm+QnJh74kXnt
/ehSfsX3SNy6YN+hfkD/FvOIjT30CeUHhf1BfaHYuPPS/YL9lulfVf+B16Xd
SHT/8+d9gP6GY9YRQ55OpCwPyM+J16XdtWjfwX9mwDthvIDybdr5Dr7+Z3XO
+8PEtfdhRtye2P/VzLkbSjpH3aM24+7Qb1jRP79CXyTksbqPSjpn3T/wHcdu
dSf1TvyOU/vzHdK5aP3oi2/6CHnDzAX6M3Hr0Ttl39tZpv5l8b8B/+9H3A==

        "], $CellContext`sym$23716[$CellContext`a6, "factorized"] = 
       False, $CellContext`sym$23716[$CellContext`a6, 
         "missing"] = {}, $CellContext`sym$23716[$CellContext`a6, 
         "raw"] = CompressedData["
1:eJyVVMtKA0EQ3KCCSEAJGo0J6pIYTS66vm4yfRFEPIievAp69eAP+BvxN/wJ
D/obngVBVhDRbNWsTI+T7BYsS/d0V9X0zmx8dXt+XYmi6On3eRgMsSZRADcZ
5mQ3Q4/vpiAfB/vKAnwfBu+wH+h383X4/zTId/K85dP9qN9y+y+PgnrlkJAn
NW5c59zaVsfTy3w0EpVPPf9FAb1348azni7yE16+GP86z8E+3/PkaQnmvCqj
v0OTdRXM5zFh/Qx5Ynl5HmKJ8+tzvZ/7xXo710e8ifo7CdTtybhzDz/Houfo
+hfqVT0e5CeD/P/zNcB3eqB810bz3B+KvQe2Hvvs0d8y4xbnvJ3z6fvgYgV9
3bN8PYtfrb/U2P+B7oSeumeDBbWvL3U+dzwed/5vBjxT2FdVuK8L1TdmXiUA
nwn1Qv8J6skJz0vC77HIWPdtBP1hP9+F773VQV9N9LlDPK1iQ39/5wCoe75Q
1/HyFj8ErQ+2
        "], $CellContext`sym$23716[$CellContext`a7, "factorized"] = 
       False, $CellContext`sym$23716[$CellContext`a7, 
         "missing"] = {}, $CellContext`sym$23716[$CellContext`a7, 
         "raw"] = CompressedData["
1:eJylVNFKQkEQXVOJTNAwUisIqR6EkCgIemnnG/wEQV/7nvqNfqKH/JcrgihC
iJ6ZjZl1Na7nZZk7s2fOzNzZzuC9Pyw4577dH8Y/azgabXDL58zDm/nnDY7J
JQD/kuNbHDf3mreevI+4a/r8WKNg8qeBuN8oTvLCKkV5pR6c03Bf82URL/x3
pG3RvdirNwXcP2E9NRI7L5+Fno/onvl9fYa/Rbov3aBL+mf7KHOEFfcR/vsw
Z8zrAXW3X7gPnvvwyt/f8P3rkf1F0nxlsnm255f/+YZ268y8nstZxA//xEt/
rA7UVY/05gV4riIeO8ftc5U5ynkZdEk89D+ZeUveYoiXvsE+TdaV2gv9n3u+
b/dofuA+lUMdyNdLviuiB/4KyX3Mr8rnOZl3kOxeaT67bxXStu3vNHe94Dui
3VEXXFczxP0vb2b2usF1N2kFQ/IeOA==
        "], $CellContext`sym$23716[
        All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$23716[
        All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed}, $CellContext`sym$23716[$CellContext`Chla, "factorized"] = 
       False, $CellContext`sym$23716[$CellContext`Chla, "missing"] = {{55}, {
        56}, {57}, {58}, {59}, {60}, {61}, {62}, {63}, {116}, {184}, {
        199}}, $CellContext`sym$23716[$CellContext`Chla, "raw"] = {
        50., 1.3, 15.6, 1.4, 10.5, 28.4, 3.2, 6.9, 5.544, 0.8, 0.8, 0.6, 41., 
         0.5, 0.3, 1.1, 1.1, 0.4, 0.8, 4.5, 16., 0.5, 7.6, 1.7, 1.5, 3., 0.5, 
         2.7, 0.8, 0.5, 4.9, 2.8, 5.8, 2.3, 0.9, 3.6, 0.2, 0.3, 12.32, 8.957, 
         3.7, 13.2, 22.5, 11.84, 3.9, 3.3, 0.8, 1.1, 2.8, 12.1, 7.9, 4.5, 0.5,
          0.8, 
         Missing[], 
         Missing[], 
         Missing[], 
         Missing[], 
         Missing[], 
         Missing[], 
         Missing[], 
         Missing[], 
         Missing[], 1., 0.3, 0.6, 2.5, 0.5, 10., 1., 13.1, 5.2, 11.6, 20.87, 
         13., 18.37, 3.6, 3., 3., 1.3, 2., 4.3, 21., 3.1, 2.9, 4.3, 3.2, 4.3, 
         6.8, 40., 3.5, 7.3, 31., 9., 6.5, 20.829, 72.478, 98.817, 2., 21.9, 
         30., 5.2, 17.2, 3., 75., 3., 65.7, 13.1, 25., 15., 1., 0.3, 2.1, 1.2,
          3., 
         Missing[], 1.4, 3.2, 24.917, 6.8, 9.882, 17.2, 6.429, 5.555, 5.233, 
         2.15, 88.255, 110.456, 50.225, 11.1, 2., 3.3, 15.3, 5.5, 4.5, 2., 
         2.5, 11.7, 2., 5.45, 6.4, 1., 2., 19.4, 3., 8.1, 30.4, 23.8, 7.3, 
         32., 22.7, 16., 53.1, 2.1, 27.5, 28.567, 22.5, 26.8, 20.6, 34.75, 
         68.05, 93.683, 92.667, 81.54, 2., 3.8, 54.367, 21.22, 14.7, 6.209, 
         20.578, 5.083, 5.609, 9.384, 27.618, 20.8, 1.1, 0.6, 0.8, 1.3, 0.8, 
         4., 2.86, 
         Missing[], 2., 46.075, 17.491, 14.775, 18.33, 24.556, 5.62, 8.155, 
         5.111, 22.9, 6.167, 2.338, 4.667, 31.738, 
         Missing[], 18.3}, $CellContext`sym$23716[$CellContext`Cl, 
         "factorized"] = 
       False, $CellContext`sym$23716[$CellContext`Cl, "missing"] = {{55}, {
        56}, {57}, {58}, {59}, {60}, {61}, {62}, {161}, {
        199}}, $CellContext`sym$23716[$CellContext`Cl, "raw"] = {
        60.8, 57.75, 40.02, 77.364, 55.35, 65.75, 73.25, 59.067, 21.95, 8., 
         8., 8.69, 5., 6.3, 3., 4.7, 7., 7., 7., 64., 88., 0.8, 32.92, 11.867,
          10.975, 12.536, 10.5, 9., 16., 9., 13., 26., 20.083, 34.5, 29.2, 
         30.523, 1.17, 1.45, 20.625, 22.286, 77., 54.19, 50., 54.143, 69.75, 
         87., 66.3, 9., 15., 17.75, 32.3, 27.233, 6.167, 5.273, 
         Missing[], 
         Missing[], 
         Missing[], 
         Missing[], 
         Missing[], 
         Missing[], 
         Missing[], 
         Missing[], 4.083, 4.575, 4.326, 2.933, 3.275, 3.136, 32.4, 29.775, 
         32.54, 38.125, 34.037, 136., 129.375, 35.75, 29.5, 27.4, 26.76, 11., 
         11., 10.4, 13.5, 12.146, 31., 53., 36.248, 48.667, 53.102, 125.6, 
         173.75, 94.405, 53.333, 70., 63.51, 56.717, 61.05, 57.75, 101.875, 
         85.982, 63.625, 82.111, 65.333, 58.331, 49.625, 47.778, 47.229, 41.5,
          40.167, 32.056, 5.889, 7.25, 7.838, 53.425, 57.848, 0.222, 1.549, 
         5.83, 74.667, 131.39999, 45.273, 42.636, 48.429, 11.818, 10.556, 12.,
          31.091, 28.333, 30.125, 10.936, 10.078, 11.088, 194.75, 391.5, 
         130.67, 39., 35.66, 37.6, 39., 49.9, 51.113, 8.3, 10.207, 79.077, 
         81.333, 64.093, 41.25, 40.226, 46.167, 47., 41.163, 53., 44.205, 
         127.833, 100.83, 94., 69., 50., 19.22, 26., 
         Missing[], 44., 43., 43.09, 16., 22.35, 82.857, 63.292, 43.97, 
         38.902, 95.367, 151.83299, 104.818, 71.444, 208.364, 187.183, 4.545, 
         3.5, 5.326, 2.111, 2.2, 2.75, 3.86, 9.055, 7.613, 39.109, 22.455, 
         23.25, 22.32, 12.778, 15.541, 12.182, 7.333, 23.825, 12.444, 17.375, 
         14.32, 139.989, 
         Missing[], 82.852}, $CellContext`sym$23716[$CellContext`mnO2, 
         "factorized"] = 
       False, $CellContext`sym$23716[$CellContext`mnO2, "missing"] = {{38}, {
        62}}, $CellContext`sym$23716[$CellContext`mnO2, "raw"] = {
        9.8, 8., 11.4, 4.8, 9., 13.1, 10.3, 10.6, 3.4, 9.9, 10.2, 11.7, 9.6, 
         11.8, 9.6, 11.5, 12., 9.8, 10.4, 3.2, 10.7, 9.2, 10.3, 8.5, 9.4, 
         10.7, 8.4, 11.1, 9.8, 11.3, 12.5, 10.3, 11.3, 9.9, 7.8, 8.4, 10.9, 
         Missing[], 8.9, 10.5, 5.5, 7.1, 7.7, 8.8, 13.4, 12.5, 12.1, 12.6, 
         9.6, 11.21, 10.2, 7.9, 11., 9., 10.8, 11.8, 10.8, 9.5, 10.8, 11.3, 
         10.4, 
         Missing[], 11.7, 10.8, 11.7, 10.1, 9.8, 12.1, 1.5, 1.8, 7.1, 8.1, 
         10.2, 8.1, 6.8, 9.4, 9.8, 5.9, 3.3, 9.2, 9.8, 11.7, 8.9, 11.17, 10.8,
          6., 10.77, 3.6, 9.7, 8.6, 9.4, 10.7, 8.5, 10.5, 11.8, 10.5, 5.4, 
         4.5, 6.3, 8.2, 7.1, 6.5, 5.3, 8.8, 10., 7.4, 11.1, 11.1, 6., 11.1, 
         9.8, 11.3, 11.8, 6., 9.7, 10.8, 11.62, 11.6, 5.3, 6.6, 9.4, 7.1, 9., 
         10.7, 9.7, 10.7, 11.6, 6.9, 10., 10.1, 7.7, 10.5, 9.8, 8.3, 11.9, 
         9.2, 11.7, 9.9, 6.2, 11.2, 6.2, 9.5, 10.5, 4.5, 6.3, 6.5, 8.1, 9.9, 
         9., 4.9, 11., 4.4, 11.8, 6., 10.53, 3.2, 4.9, 3.6, 10.6, 11.5, 5.8, 
         5.7, 8.8, 12.9, 9.9, 10.68, 4.3, 11.1, 8.7, 8.3, 6.1, 6.2, 9.3, 7.3, 
         10.6, 6.35, 10.7, 10.7, 10.29, 10.1, 9.5, 10.5, 10., 10.9, 10.2, 
         10.8, 11.7, 8.2, 11., 7.6, 11.4, 10.5, 8.2, 11.1, 7.9, 8.4, 10.6, 7.,
          7.6, 6.7}, $CellContext`sym$23716[$CellContext`mxPH, "factorized"] = 
       False, $CellContext`sym$23716[$CellContext`mxPH, "missing"] = {{
        48}}, $CellContext`sym$23716[$CellContext`mxPH, "raw"] = {
        8., 8.35, 8.1, 8.07, 8.06, 8.25, 8.15, 8.05, 8.7, 7.93, 7.7, 7.45, 
         7.74, 7.72, 7.9, 7.55, 7.78, 7.61, 7.35, 7.79, 7.83, 7.2, 7.75, 7.62,
          7.84, 7.77, 7.09, 6.8, 8., 7.2, 7.4, 8.1, 7.8, 8.4, 8.27, 8.66, 8.3,
          8., 8.3, 8.1, 8., 8.15, 8.3, 8.3, 8.4, 8.3, 8., 
         Missing[], 7.6, 7.29, 7.6, 8., 7.9, 7.9, 6.6, 5.6, 5.7, 6.6, 6.6, 
         6.6, 6.5, 6.4, 7.83, 7.57, 7.19, 7.44, 7.14, 7., 7.5, 7.5, 7.8, 8.5, 
         7.925, 8.1, 8.2, 9.1, 8.1, 8., 8., 7.5, 7.4, 7.3, 7.4, 7.4, 7.5, 7.6,
          7.4, 7.8, 7.6, 8.5, 8.7, 8.1, 8.8, 7.8, 7.9, 8.5, 9.1, 8.9, 7.9, 
         7.8, 7.7, 7.8, 7.7, 7.5, 7.6, 8.7, 7.7, 8.3, 8.43, 8.16, 8.7, 8.2, 
         8.5, 7.8, 8., 9.7, 8.6, 8.3, 8.4, 8.2, 8.2, 8.1, 8.1, 7.4, 8.3, 8.6, 
         9.1, 9., 8.3, 8.5, 8.3, 7.3, 7.9, 7.9, 8., 8., 8.1, 8.43, 8.1, 7.9, 
         8.1, 7.8, 7.9, 8., 7.6, 7.8, 8.22, 8.3, 8.47, 8.4, 8.87, 7.7, 7.3, 
         7.9, 7.8, 7.8, 7.6, 8.6, 8.4, 8.3, 9., 9.5, 8.8, 8.84, 7.3, 7.4, 9.1,
          8.53, 8.56, 8.06, 8.24, 7.91, 8.21, 8.5, 8.6, 9.06, 8.7, 8.1, 8.4, 
         8.6, 8.2, 8.5, 8.3, 8., 8.1, 8.7, 8.7, 8.4, 8.55, 8.5, 8.7, 8.4, 8.2,
          8.58, 8.5, 8.4, 8.3, 8.2, 8., 
         8.5}, $CellContext`sym$23716[$CellContext`NH4, "factorized"] = 
       False, $CellContext`sym$23716[$CellContext`NH4, "missing"] = {{62}, {
        199}}, $CellContext`sym$23716[$CellContext`NH4, "raw"] = {
        578., 370., 346.66699, 98.182, 233.7, 430., 110., 205.66701, 102.75, 
         5.8, 21.571, 18.429, 27.286, 8., 46.2, 14.75, 34.333, 31.333, 49., 
         8777.59961, 1729., 81., 42., 208.33299, 12.5, 58.5, 28., 20., 20., 
         120., 60., 60., 49.5, 3515., 6400., 1911., 13.5, 10., 228.75, 
         178.57001, 122.85, 647.57001, 76., 51.429, 37.5, 22.5, 39., 10., 40.,
          35., 192.5, 28.333, 18.333, 33.636, 10., 5., 10., 20., 10., 10., 
         10., 
         Missing[], 18., 27.5, 160., 15., 15., 16.2, 1386.25, 2082.8501, 
         2167.37012, 225., 109., 245., 271.25, 32.5, 224.286, 133.636, 165., 
         101., 255., 130., 123.333, 89.6, 737.5, 914., 429.20001, 5738.33008, 
         4073.33008, 124.167, 101.25, 153., 96.667, 98.333, 137., 215.714, 
         105.556, 155., 153.75, 421.66699, 122.5, 215.556, 371.11099, 758.75, 
         308.75, 38.111, 239., 931.83301, 723.66699, 461.875, 51.111, 25., 
         206.53799, 118.571, 217.75, 10., 25.833, 12.727, 131.66701, 92., 
         345.45499, 56.364, 128.571, 170.909, 65.556, 43.75, 246.364, 76.667, 
         102.5, 236., 103.333, 92.375, 3466.65991, 380., 196., 120., 46.5, 
         124., 112.857, 505., 175., 34., 132.25, 920., 196.66701, 1990.16003, 
         172.5, 235., 84.667, 91.833, 54.75, 90., 24064., 176.66701, 486.5, 
         1131.66003, 1495., 134., 96.833, 62.5, 142., 146.66701, 103.333, 
         52.2, 101.667, 244.60001, 137.27299, 227.60001, 643., 627.27301, 
         1168., 1081.66003, 124.364, 66.667, 197.909, 54.778, 32.727, 12.5, 
         53.846, 11.111, 10., 10.5, 32., 40., 32.5, 161.81799, 88.182, 43.75, 
         82.1, 17.778, 103., 65.455, 37.778, 72.6, 96.667, 83.75, 125.333, 
         60.11, 
         Missing[], 27.069}, $CellContext`sym$23716[$CellContext`NO3, 
         "factorized"] = 
       False, $CellContext`sym$23716[$CellContext`NO3, "missing"] = {{62}, {
        199}}, $CellContext`sym$23716[$CellContext`NO3, "raw"] = {
        6.238, 1.288, 5.33, 2.302, 10.416, 9.248, 1.535, 4.99, 0.886, 1.39, 
         1.527, 1.588, 1.223, 1.47, 1.448, 1.32, 1.42, 1.443, 1.718, 2.822, 
         4.825, 0.642, 2.942, 1.715, 1.51, 3.976, 1.572, 0.63, 0.73, 0.23, 
         3.33, 3.78, 3.02, 2.818, 0.05, 3.444, 0.735, 0.81, 3.414, 4.071, 
         6.096, 3.829, 8.543, 7.83, 4.555, 4.87, 4.535, 0.23, 3.02, 3.07, 
         4.508, 1.651, 1.172, 0.91, 3.245, 2.22, 2.55, 1.32, 2.64, 4.17, 5.97, 
         Missing[], 1.328, 1.203, 1.474, 0.77, 0.923, 1.208, 0.921, 1.051, 
         1.72, 3.85, 9.08, 3.773, 3.316, 5.164, 1.287, 0.735, 0.658, 3.31, 
         3.235, 4.93, 5.442, 6.188, 4.408, 3.734, 3.73, 4.03, 7.16, 3.778, 
         3.318, 4.698, 5.132, 2.443, 4.94, 0.33, 0.308, 0.267, 3.978, 6.2, 
         3.14, 2.603, 2.899, 8.688, 5.456, 2.316, 8.759, 4.665, 2.67, 5.694, 
         1.534, 1.875, 1.732, 0.381, 0.461, 0.406, 0.445, 0.701, 3.9, 4.188, 
         7.195, 5.078, 6.64, 2.163, 1.921, 2.231, 5.099, 2.954, 3.726, 1.335, 
         1.212, 1.374, 6.513, 6.045, 6.54, 4.86, 5.13, 0.826, 0.673, 9.773, 
         5.099, 1.67, 2.304, 8.984, 9.715, 7.74, 1.415, 1.587, 2.102, 0.536, 
         2.273, 2.31, 45.65, 2.68, 5.41, 4.908, 3.685, 0.376, 1.655, 1.87, 
         0.9, 0.102, 0.13, 0.846, 4.82, 5.414, 0.86, 1.726, 4.053, 3.678, 
         3.561, 3.923, 3.908, 2.512, 4.459, 3.351, 0.941, 1.013, 0.996, 0.663,
          0.672, 0.758, 0.866, 0.825, 0.699, 6.225, 3.765, 2.805, 3.14, 1.873,
          2.323, 1.519, 1.003, 3.617, 2.586, 3.833, 3.2, 2.978, 
         Missing[], 2.8}, $CellContext`sym$23716[$CellContext`oPO4, 
         "factorized"] = 
       False, $CellContext`sym$23716[$CellContext`oPO4, "missing"] = {{62}, {
        199}}, $CellContext`sym$23716[$CellContext`oPO4, "raw"] = {
        105., 428.75, 125.667, 61.182, 58.222, 18.25, 61.25, 44.667, 36.3, 
         27.25, 12.75, 10.667, 12., 16., 13., 4.25, 18.667, 20., 41.5, 
         564.59998, 467.5, 15.6, 16., 3., 3., 9., 4., 4., 26., 12., 72., 246.,
          53., 20., 7.4, 58.875, 1.625, 2.5, 196.62, 182.42, 143.71001, 
         59.429, 264.89999, 276.85001, 10., 27., 16., 5., 27., 13., 12.75, 
         7.3, 7.75, 9., 1., 1., 1., 1., 2., 1., 2., 
         Missing[], 3.333, 2., 2.5, 1.333, 1.25, 1.8, 220.75, 209.85699, 
         151.125, 45., 55., 136.75, 100., 85.5, 25.167, 36., 37.375, 26.6, 
         38.75, 10.8, 27.667, 32., 111.25, 137.60001, 57.6, 412.33301, 
         282.16699, 197.83299, 267.75, 191.75, 120.5, 144.66701, 159.5, 23., 
         104.222, 97.333, 51.75, 31.333, 28.625, 12.889, 51.111, 104.5, 
         38.625, 24.667, 54., 39., 60.833, 71., 9.667, 6.5, 8.692, 37.857, 
         37., 22.444, 16.833, 3.545, 261.60001, 238.2, 144., 166.72701, 181., 
         36.909, 61.556, 62.625, 55., 102.333, 75.875, 34.636, 48.667, 48.625,
          23., 173., 75., 187., 49., 32.5, 60., 67.5, 132.5, 16.8, 10.583, 
         70., 77.333, 47.5, 46.667, 33.8, 48., 109., 39., 22.2, 44., 27.5, 
         24., 175.66701, 234.5, 54.1, 20.667, 30.75, 102., 151.33299, 
         180.66701, 8.6, 14.667, 66.4, 102.364, 84.3, 221.89999, 205.636, 
         236.39999, 346.16699, 82.222, 64.389, 87.333, 159.16701, 16., 12.75, 
         7.667, 3.222, 3.8, 4., 6., 21.083, 26.625, 104.727, 41.3, 51.125, 
         45.9, 50.889, 34.5, 19.727, 19.111, 51.111, 19.111, 53.625, 35.333, 
         78.333, 
         Missing[], 64.}, $CellContext`sym$23716[$CellContext`PO4, 
         "factorized"] = 
       False, $CellContext`sym$23716[$CellContext`PO4, "missing"] = {{28}, {
        199}}, $CellContext`sym$23716[$CellContext`PO4, "raw"] = {
        170., 558.75, 187.05701, 138.7, 97.58, 56.667, 111.75, 77.434, 71., 
         46.6, 20.75, 19., 17., 15., 61.6, 98.25, 50., 57.833, 61.5, 
         771.59998, 586., 18., 40., 27.5, 11.5, 44.136, 13.6, 
         Missing[], 45., 19., 142., 304., 130.75, 47., 23., 84.46, 3., 3., 
         253.25, 255.28, 296., 175.04601, 344.60001, 326.85699, 40.667, 43.5, 
         39., 6., 121., 20.812, 49.333, 22.9, 11.8, 11.818, 6.5, 1., 4., 6., 
         11., 6., 14., 14., 6.667, 6.75, 7.2, 6., 10.75, 2.5, 351.60001, 
         313.60001, 279.06601, 152.33299, 58.623, 249.25, 233.5, 215.5, 
         102.333, 105.727, 111.375, 108., 56.667, 60., 104., 69.93, 214., 
         254.60001, 169.00101, 607.16699, 624.73297, 303.33301, 391.75, 
         265.25, 232.83299, 244., 218., 138.5, 239., 235.66701, 205.875, 
         211.66701, 186.5, 154.125, 183.66701, 292.625, 285.71399, 201.778, 
         275.14301, 124.2, 141.83299, 132.54601, 17.333, 26., 16.662, 102.571,
          86.997, 10.111, 18.293, 13.2, 432.909, 320.39999, 287., 262.72699, 
         222.286, 122., 127.222, 89.625, 284., 277.33301, 177.625, 72.9, 
         82.444, 66.75, 173.75, 317., 84., 213., 88.5, 115., 98.143, 143.75, 
         197.14301, 35.2, 23.485, 200.231, 147.83299, 276., 123.333, 75.207, 
         116.2, 188.66701, 72.696, 116.2, 34., 76.333, 58.374, 361., 236., 
         125.8, 54.916, 75.333, 186., 252.5, 269.66699, 46.438, 85., 171.272, 
         232.89999, 146.452, 246.66701, 219.909, 272.22198, 388.16699, 
         167.89999, 137.778, 194.10001, 221.278, 21.3, 11., 14.354, 7., 6.2, 
         7.654, 16., 56.091, 52.875, 228.364, 85.4, 87.125, 101.455, 127., 
         81.558, 50.455, 120.889, 91.111, 61.444, 79.75, 75.904, 140.22, 
         Missing[], 140.517}, $CellContext`sym$23716[$CellContext`season, 
         "factorized"] = 
       True, $CellContext`sym$23716[$CellContext`season, "factors"] = {
        "spring", "summer", "autumn", 
         "winter"}, $CellContext`sym$23716[$CellContext`season, 
         "missing"] = {}, $CellContext`sym$23716[$CellContext`season, 
         "raw"] = {
        "winter", "spring", "autumn", "spring", "autumn", "winter", "summer", 
         "autumn", "winter", "winter", "spring", "summer", "winter", "summer",
          "winter", "autumn", "winter", "spring", "summer", "spring", 
         "winter", "spring", "autumn", "winter", "spring", "summer", "winter",
          "autumn", "winter", "spring", "autumn", "winter", "summer", 
         "autumn", "winter", "summer", "winter", "spring", "winter", "spring",
          "winter", "summer", "winter", "spring", "winter", "spring", 
         "autumn", "winter", "spring", "autumn", "winter", "summer", "winter",
          "spring", "winter", "spring", "autumn", "spring", "summer", 
         "autumn", "spring", "summer", "autumn", "spring", "summer", "winter",
          "spring", "summer", "winter", "spring", "summer", "autumn", 
         "summer", "winter", "spring", "spring", "autumn", "winter", "spring",
          "winter", "spring", "autumn", "winter", "summer", "autumn", 
         "winter", "summer", "winter", "summer", "winter", "spring", "summer",
          "winter", "spring", "summer", "autumn", "winter", "spring", 
         "winter", "summer", "winter", "spring", "winter", "summer", "autumn",
          "winter", "summer", "autumn", "winter", "summer", "winter", 
         "spring", "summer", "spring", "summer", "winter", "summer", "autumn",
          "spring", "summer", "winter", "spring", "summer", "winter", 
         "spring", "summer", "winter", "spring", "summer", "winter", "spring",
          "summer", "winter", "spring", "autumn", "spring", "autumn", 
         "winter", "summer", "winter", "summer", "spring", "autumn", "winter",
          "spring", "autumn", "winter", "autumn", "winter", "spring", 
         "autumn", "summer", "autumn", "spring", "autumn", "spring", "summer",
          "spring", "autumn", "winter", "spring", "spring", "summer", 
         "autumn", "winter", "autumn", "spring", "autumn", "winter", "autumn",
          "winter", "summer", "winter", "spring", "spring", "winter", 
         "autumn", "spring", "summer", "spring", "summer", "winter", "summer",
          "winter", "summer", "winter", "winter", "summer", "autumn", 
         "spring", "autumn", "winter", "spring", "autumn", "summer", "autumn",
          "spring", "autumn", "winter", 
         "summer"}, $CellContext`sym$23716[$CellContext`size, "factorized"] = 
       True, $CellContext`sym$23716[$CellContext`size, "factors"] = {
        "small", "medium", "large"}, $CellContext`sym$23716[$CellContext`size,
          "missing"] = {}, $CellContext`sym$23716[$CellContext`size, 
         "raw"] = {
        "small", "small", "small", "small", "small", "small", "small", 
         "small", "small", "small", "small", "small", "small", "small", 
         "small", "small", "small", "small", "small", "small", "small", 
         "small", "small", "small", "small", "small", "small", "small", 
         "small", "small", "small", "small", "small", "small", "small", 
         "small", "small", "small", "small", "small", "small", "small", 
         "small", "small", "small", "small", "small", "small", "small", 
         "small", "small", "small", "small", "small", "small", "small", 
         "small", "small", "small", "small", "small", "small", "small", 
         "small", "small", "small", "small", "small", "small", "small", 
         "small", "medium", "medium", "medium", "medium", "medium", "medium", 
         "medium", "medium", "medium", "medium", "medium", "medium", "medium",
          "medium", "medium", "medium", "medium", "medium", "medium", 
         "medium", "medium", "medium", "medium", "medium", "medium", "medium",
          "medium", "medium", "medium", "medium", "medium", "medium", 
         "medium", "medium", "medium", "medium", "medium", "medium", "medium",
          "medium", "medium", "medium", "medium", "medium", "medium", 
         "medium", "medium", "medium", "medium", "medium", "medium", "medium",
          "medium", "medium", "medium", "medium", "medium", "medium", 
         "medium", "medium", "medium", "medium", "medium", "medium", "medium",
          "medium", "medium", "medium", "medium", "medium", "medium", 
         "medium", "medium", "medium", "medium", "medium", "medium", "medium",
          "medium", "medium", "medium", "medium", "medium", "medium", "large",
          "large", "large", "large", "large", "large", "large", "large", 
         "large", "large", "large", "large", "large", "large", "large", 
         "large", "large", "large", "large", "large", "large", "large", 
         "large", "large", "large", "large", "large", "large", "large", 
         "large", "large", "large", "large", "large", "large", "large", 
         "large", "large", "large", "large", "large", "large", "large", 
         "large", "large"}, $CellContext`sym$23716[$CellContext`speed, 
         "factorized"] = 
       True, $CellContext`sym$23716[$CellContext`speed, "factors"] = {
        "low", "medium", "high"}, $CellContext`sym$23716[$CellContext`speed, 
         "missing"] = {}, $CellContext`sym$23716[$CellContext`speed, 
         "raw"] = {
        "medium", "medium", "medium", "medium", "medium", "high", "high", 
         "high", "medium", "high", "high", "high", "high", "high", "high", 
         "high", "high", "high", "high", "medium", "medium", "high", "high", 
         "high", "high", "high", "high", "high", "high", "high", "high", 
         "high", "high", "medium", "medium", "medium", "high", "high", 
         "medium", "medium", "medium", "medium", "high", "high", "high", 
         "high", "high", "low", "medium", "medium", "medium", "medium", 
         "high", "high", "high", "medium", "medium", "high", "high", "medium",
          "medium", "medium", "high", "high", "high", "high", "high", "high", 
         "medium", "medium", "medium", "medium", "medium", "medium", "medium",
          "high", "medium", "medium", "medium", "high", "high", "high", 
         "high", "high", "medium", "medium", "medium", "medium", "medium", 
         "medium", "medium", "medium", "high", "high", "high", "low", "low", 
         "low", "high", "high", "medium", "medium", "low", "low", "low", 
         "low", "low", "high", "high", "high", "high", "high", "high", 
         "medium", "medium", "high", "high", "medium", "low", "low", "medium",
          "medium", "medium", "high", "high", "high", "medium", "medium", 
         "medium", "high", "high", "high", "medium", "medium", "medium", 
         "medium", "medium", "low", "low", "medium", "medium", "high", "high",
          "low", "low", "low", "high", "high", "high", "high", "high", "high",
          "high", "medium", "medium", "low", "low", "low", "low", "low", 
         "low", "low", "low", "low", "high", "high", "low", "low", "low", 
         "low", "medium", "medium", "medium", "medium", "medium", "medium", 
         "high", "high", "high", "medium", "medium", "medium", "medium", 
         "high", "high", "low", "low", "low", "low", "medium", "medium", 
         "medium", "medium", "medium", "medium", "medium", "medium", "medium",
          "medium", "medium"}}; Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.585500890157349*^9, 3.585500895743271*^9}, {
  3.586098978626936*^9, 3.586098995245166*^9}}]
}, {2}]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Outlier Selector", "Title",
 CellChangeTimes->{{3.585417299136742*^9, 3.585417302023638*^9}, {
  3.585486190840365*^9, 3.585486194479013*^9}, {3.585493092664253*^9, 
  3.585493093144408*^9}, {3.585500789157826*^9, 3.585500792412249*^9}, {
  3.585500956960967*^9, 3.585500959536669*^9}}],

Cell["\<\
If we decided we wanted to hand craft a dataset with certain outliers \
removed, we could implement interactive selection of plot points like this:\t\
\>", "Text",
 CellChangeTimes->{{3.585998245216113*^9, 3.5859982903308077`*^9}, {
  3.585998382905151*^9, 3.58599838327969*^9}, {3.585998434582018*^9, 
  3.585998447420947*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DynamicModule", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"col", "=", "NH4"}], ",", "clickHash", ",", 
     RowBox[{"clicks", "=", 
      RowBox[{"{", "}"}]}], ",", "toggle", ",", "plotYMax"}], "}"}], ",", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"toggle", "[", "pt_", "]"}], ":=", 
     RowBox[{"(", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Head", "[", 
           RowBox[{"clickHash", "[", "pt", "]"}], "]"}], "===", "Integer"}], 
         ",", 
         RowBox[{
          RowBox[{"clickHash", "[", "pt", "]"}], "=", 
          RowBox[{"Xor", "[", 
           RowBox[{
            RowBox[{"clickHash", "[", "pt", "]"}], ",", "1"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"clickHash", "[", "pt", "]"}], "=", "1"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"clicks", "=", 
        RowBox[{"With", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"uv", "=", 
             RowBox[{"ReleaseHold", "/@", 
              RowBox[{
               RowBox[{"DownValues", "[", "clickHash", "]"}], "[", 
               RowBox[{"[", 
                RowBox[{"All", ",", "1", ",", "All", ",", "1"}], "]"}], 
               "]"}]}]}], ",", 
            RowBox[{"dv", "=", 
             RowBox[{
              RowBox[{"DownValues", "[", "clickHash", "]"}], "[", 
              RowBox[{"[", 
               RowBox[{"All", ",", "2"}], "]"}], "]"}]}]}], "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"Pick", "[", 
           RowBox[{"uv", ",", "dv", ",", "1"}], "]"}]}], 
         "\[IndentingNewLine]", "]"}]}]}], ")"}]}], ";", "\n", 
    "\[IndentingNewLine]", 
    RowBox[{"plotYMax", "=", 
     RowBox[{"Max", "[", 
      RowBox[{"med", "[", "col", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"Row", "[", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"LocatorPane", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Dynamic", "[", "clicks", "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"ListPlot", "[", 
          RowBox[{
           RowBox[{"MapIndexed", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Button", "[", 
               RowBox[{
                RowBox[{"Tooltip", "[", "#1", "]"}], ",", 
                RowBox[{"toggle", "[", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"First", "@", "#2"}], ",", "#1"}], "}"}], "]"}]}], 
               "]"}], "&"}], ",", 
             RowBox[{"med", "[", 
              RowBox[{"col", ",", "\"\<raw\>\""}], "]"}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"PlotRange", "\[Rule]", "Full"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"PlotMarkers", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Automatic", ",", "Medium"}], "}"}]}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"FrameLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"None", ",", "col"}], "}"}]}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Frame", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
           RowBox[{"ImageSize", "\[Rule]", "300"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Epilog", "\[Rule]", 
            RowBox[{"Dynamic", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Text", "[", 
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{
                   RowBox[{"First", "@", "#"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"Red", ",", "9"}], "}"}]}], "]"}], ",", 
                 RowBox[{"#", "+", 
                  RowBox[{"{", 
                   RowBox[{"0", ",", 
                    RowBox[{"plotYMax", "/", "12"}]}], "}"}]}]}], "]"}], 
               "&"}], "/@", "clicks"}], "]"}]}]}], "\[IndentingNewLine]", 
          "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"Appearance", "\[Rule]", 
          RowBox[{"Graphics", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"Red", ",", 
              RowBox[{"Circle", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"0", ",", "0"}], "}"}], ",", "1"}], "]"}]}], "}"}], 
            ",", 
            RowBox[{"ImageSize", "\[Rule]", "15"}]}], "]"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Enabled", "\[Rule]", "False"}], ",", "\[IndentingNewLine]", 
         RowBox[{"LocatorAutoCreate", "\[Rule]", "True"}]}], 
        "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Dynamic", "@", 
        RowBox[{"ListPlot", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Tooltip", "[", 
             RowBox[{"#", ",", "#"}], "]"}], "&"}], "/@", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"selected", "=", 
              RowBox[{"columnize", "[", 
               RowBox[{"Delete", "[", 
                RowBox[{
                 RowBox[{"med", "[", "All", "]"}], ",", 
                 RowBox[{"List", "/@", 
                  RowBox[{"clicks", "[", 
                   RowBox[{"[", 
                    RowBox[{"All", ",", "1"}], "]"}], "]"}]}]}], "]"}], 
               "]"}]}], ")"}], "[", "col", "]"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"PlotRange", "\[Rule]", "Full"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"PlotMarkers", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Automatic", ",", "Medium"}], "}"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"FrameLabel", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"None", ",", "col"}], "}"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{"Frame", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
          RowBox[{"ImageSize", "\[Rule]", "300"}], ",", "\[IndentingNewLine]", 
          RowBox[{"PlotStyle", "\[Rule]", "Magenta"}]}], 
         "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", "}"}], 
     "]"}]}], "\[IndentingNewLine]", ",", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{{3.5741870983528337`*^9, 3.574187103506787*^9}, {
   3.5741872315324116`*^9, 3.5741872355114565`*^9}, {3.574187282814009*^9, 
   3.574187501951175*^9}, {3.574187629541683*^9, 3.574187671823063*^9}, {
   3.5741877596031075`*^9, 3.5741879121913824`*^9}, {3.574188251835252*^9, 
   3.574188271543255*^9}, {3.5741885864692817`*^9, 3.574188587679209*^9}, {
   3.5741886677227182`*^9, 3.574188714496129*^9}, {3.585501014758038*^9, 
   3.58550109867064*^9}, {3.5855011513783197`*^9, 3.585501167654454*^9}, {
   3.585501210905669*^9, 3.585501250444046*^9}, {3.585501290215548*^9, 
   3.5855012953323936`*^9}, {3.585501328634472*^9, 3.585501345494871*^9}, {
   3.585501471173225*^9, 3.585501477941948*^9}, {3.58550151023269*^9, 
   3.585501643682033*^9}, {3.5855017527320433`*^9, 3.5855017621555634`*^9}, {
   3.58550180088277*^9, 3.5855018047180758`*^9}, {3.585997198422304*^9, 
   3.585997250804903*^9}, {3.5859972823175373`*^9, 3.585997284555352*^9}, {
   3.5859985269905977`*^9, 3.585998534712661*^9}, 3.5859985852467213`*^9, {
   3.5860895576229153`*^9, 3.586089562781684*^9}}],

Cell[BoxData[
 DynamicModuleBox[{$CellContext`col$$ = $CellContext`NH4, \
$CellContext`clickHash$$, $CellContext`clicks$$ = {{20, 8777.59961}, {
   153, 24064.}}, $CellContext`toggle$$, $CellContext`plotYMax$$ = 24064.}, 
  TemplateBox[{LocatorPaneBox[
     Dynamic[$CellContext`clicks$$], 
     GraphicsBox[{{}, 
       GraphicsComplexBox[CompressedData["
1:eJztl/lvVFUUxx+IBpGQiiAlQXho2yBLtZSWsvYILVCWQlumdJt2mM4GgjUi
aAjRh2wmgBaapiwiY6iSggESsREC5pkoGsUYEGIgAmNIREUQFLcoxGnv55B0
Ev+Deb+cfN+5555zz3rvUH9DabC7ZVmbullWBzXfjfxOkvKK8MNQ+wVwT0k/
efj2/n3LwSny1Z9ll9/eWAHuJ6GOL3cpONXQ2ErwIEOdarAtNfdUp1e8vwj8
qKGHKsFpkt35DQBnyMAe5X1Gbc0BD5Mr/7TdPL10NHi43Nh7YtbYogngkXf1
GJopO7bHv4HTwU9izyhwlhz+bMWHu4c/BR4tkS3XVuV78sHZrJ8BHiOjJt/r
nkz7CIxdPXaCcw2V+eCx0EJonrT+23p+b6/F4HHQx6HjkZ8D1nNNTKBjoJMS
8GRoLVTPUQyVrtgBu3o+/LBiP3z1yxHoFEO/3QUfbI2AToWmwQdvW8L/Amna
9Ma6SaUh+AUmf9rV3kJJfyy88PWJa+Gr38qg0+TW7TMv/theBH8a9qsdxNkh
Do5itUvPqfYpLoDqvpzbAadE4M8kP4iDo1jzcZZ8Yh96LnIKvzqzuuqzZkP7
wZ+dwNe4E09nTgK/uCt2EvFcsNozj//kkYCtAP8VZxrqJmCrhHqkbqTE0LZm
5EukrbVY3iuMIl8iWXW1zvHrYKvUUJv4C1joBw44+gzy4FvPIk/cBX9KmdyJ
hz/jfvZzyiSr57uDqg77kGd9lPNZ1KHQX7QuYw3IK1/l50tVYMKluWc1Hz0m
P0PlrPMY2nsD8uDGTch75K/NBydlf639r1xSlg9x5i9uR75chv402Wo7fRD5
cnln58f2oV51yKNnnvbDBYba9cgvMOuH03+dBcbeZrCr6xciXyHdR2x4+Nwf
9BupkAtp961urq9CHjkf+7vgPLBVafp/1cqufoziH6dSGvqucT+/yf5upVyf
smzXiSydH+hpx18Cnr0M+SrpKJ+cPtSnCz+m86Rarm1P77Zv8Gbkq+Wh0Pk7
nl3rkSePLq5Cvtrs9xp1a9VA6bNSI+Ffv8wde4r549RI3BtTN7Z6kWd93tPI
8V/rS7ym3s+yn+OVYn9Kxbjn6d+u18y35eTT3T5MXKRWHrG37Znewjx1aiUe
vc0tmfQBt1bi3nyrsK/K10nvjgB6g8jXET+ta/ImRp9068x8/oJ6snzkC3Vh
s29U6wHs4G+fj/yH78BPxf6oT3bmHblU0p/54GrdEO+Y7qf9UvMQP2heCn1Z
lM85fAtNvuYSBwd+48voB8fwh6vy9OsY+FX1n5911KftN/Fpxj7xy9rVVy7u
Sd2NftY3sr8D9uGfqB9/Uveu3/jrd+o2puu171NHDnytY+cb9Ncbe/ozD7UO
Iy+xrt7Yd2AL+uHXtKBf65bzxuqNPTl6P6MPCnPBBqvfJGD0e9TuQEL8A9yf
ZqI/YM6/GL4bkGM/jJiR3US+xQJSWrDec2yYxiVo+Mvo1zZ+TWW+S1DOXb0w
5Ikda9Cveb4V/UFz/u8b0R+UN3+JX/gGaL8MGnv2UQ/xvOisl+OafyHqhXjY
IWlKjV8ovTpP8Lvev3whyc+pPVr0M+d1QjKt/bfbZ/Iy0K/r6Qeu4nT0K9Z7
VhjK/cIG351nYWks9v49cjxx8YVN/T5Avjis1/qOhs08Ws/ccsNytCh+4k+z
WMd6V+dHRNZdLflgsBf/2BHjj8tT0B8x+2Uwd32RhPmCH2+gLxox+eFR/0fk
wPTvVvbro/eQRbJxSfyG/qDeW5Pvi+T7wkq+L5LvC0OT74vk+6LjS74vkEu+
Lzpp8n2B/uT7Ivm+6PiS7wuj5//fF/8Bi2yW+w==
        "], {{{
           RGBColor[0.24720000000000014`, 0.24, 0.6], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             198], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             199], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             200], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             201], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             202], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             203], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             204], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             205], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             206], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             207], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             208], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             209], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             210], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             211], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             212], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             213], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             214], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             215], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             216], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             217], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             218], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             219], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             220], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             221], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             222], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             223], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             224], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             225], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             226], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             227], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             228], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             229], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             230], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             231], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             232], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             233], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             234], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             235], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             236], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             237], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             238], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             239], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             240], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             241], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             242], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             243], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             244], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             245], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             246], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             247], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             248], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             249], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             250], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             251], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             252], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             253], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             254], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             255], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             256], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             257], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             258], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             259], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             260], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             261], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             262], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             263], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             264], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             265], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             266], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             267], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             268], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             269], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             270], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             271], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             272], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             273], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             274], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             275], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             276], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             277], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             278], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             279], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             280], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             281], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             282], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             283], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             284], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             285], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             286], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             287], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             288], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             289], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             290], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             291], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             292], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             293], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             294], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             295], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             296], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             297], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             298], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             299], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             300], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             301], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             302], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             303], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             304], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             305], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             306], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             307], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             308], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             309], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             310], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             311], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             312], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             313], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             314], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             315], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             316], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             317], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             318], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             319], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             320], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             321], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             322], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             323], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             324], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             325], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             326], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             327], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             328], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             329], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             330], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             331], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             332], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             333], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             334], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             335], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             336], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             337], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             338], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             339], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             340], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             341], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             342], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             343], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             344], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             345], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             346], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             347], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             348], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             349], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             350], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             351], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             352], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             353], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             354], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             355], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             356], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             357], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             358], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             359], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             360], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             361], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             362], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             363], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             364], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             365], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             366], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             367], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             368], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             369], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             370], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             371], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             372], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             373], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             374], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             375], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             376], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             377], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             378], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             379], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             380], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             381], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             382], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             383], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             384], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             385], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             386], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             387], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             388], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             389], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             390], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             391], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             392], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             393], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             394], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             395], 
           InsetBox[
            StyleBox[
            "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> Medium],
             396]}, {}}, {
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[198]}, 
             RowBox[{"{", 
               RowBox[{"200.`", ",", "27.069`"}], "}"}]], 
            Annotation[#, {200., 27.069}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{200}], 27.069}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[199]}, 
             RowBox[{"{", 
               RowBox[{"1.`", ",", "578.`"}], "}"}]], 
            Annotation[#, {1., 578.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{1}], 578.}], PassEventsDown -> Automatic, PassEventsUp -> 
             True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[200]}, 
             RowBox[{"{", 
               RowBox[{"2.`", ",", "370.`"}], "}"}]], 
            Annotation[#, {2., 370.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{2}], 370.}], PassEventsDown -> Automatic, PassEventsUp -> 
             True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[201]}, 
             RowBox[{"{", 
               RowBox[{"3.`", ",", "346.66699`"}], "}"}]], 
            Annotation[#, {3., 346.66699}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{3}], 346.66699}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[202]}, 
             RowBox[{"{", 
               RowBox[{"4.`", ",", "98.182`"}], "}"}]], 
            Annotation[#, {4., 98.182}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{4}], 98.182}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[203]}, 
             RowBox[{"{", 
               RowBox[{"5.`", ",", "233.7`"}], "}"}]], 
            Annotation[#, {5., 233.7}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{5}], 233.7}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[204]}, 
             RowBox[{"{", 
               RowBox[{"6.`", ",", "430.`"}], "}"}]], 
            Annotation[#, {6., 430.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{6}], 430.}], PassEventsDown -> Automatic, PassEventsUp -> 
             True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[205]}, 
             RowBox[{"{", 
               RowBox[{"7.`", ",", "110.`"}], "}"}]], 
            Annotation[#, {7., 110.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{7}], 110.}], PassEventsDown -> Automatic, PassEventsUp -> 
             True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[206]}, 
             RowBox[{"{", 
               RowBox[{"8.`", ",", "205.66701`"}], "}"}]], 
            Annotation[#, {8., 205.66701}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{8}], 205.66701}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[207]}, 
             RowBox[{"{", 
               RowBox[{"9.`", ",", "102.75`"}], "}"}]], 
            Annotation[#, {9., 102.75}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{9}], 102.75}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[208]}, 
             RowBox[{"{", 
               RowBox[{"10.`", ",", "5.8`"}], "}"}]], 
            Annotation[#, {10., 5.8}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{10}], 5.8}], PassEventsDown -> Automatic, PassEventsUp -> 
             True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[209]}, 
             RowBox[{"{", 
               RowBox[{"11.`", ",", "21.571`"}], "}"}]], 
            Annotation[#, {11., 21.571}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{11}], 21.571}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[210]}, 
             RowBox[{"{", 
               RowBox[{"12.`", ",", "18.429`"}], "}"}]], 
            Annotation[#, {12., 18.429}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{12}], 18.429}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[211]}, 
             RowBox[{"{", 
               RowBox[{"13.`", ",", "27.286`"}], "}"}]], 
            Annotation[#, {13., 27.286}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{13}], 27.286}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[212]}, 
             RowBox[{"{", 
               RowBox[{"14.`", ",", "8.`"}], "}"}]], 
            Annotation[#, {14., 8.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{14}], 8.}], PassEventsDown -> Automatic, PassEventsUp -> 
             True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[213]}, 
             RowBox[{"{", 
               RowBox[{"15.`", ",", "46.2`"}], "}"}]], 
            Annotation[#, {15., 46.2}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{15}], 46.2}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[214]}, 
             RowBox[{"{", 
               RowBox[{"16.`", ",", "14.75`"}], "}"}]], 
            Annotation[#, {16., 14.75}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{16}], 14.75}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[215]}, 
             RowBox[{"{", 
               RowBox[{"17.`", ",", "34.333`"}], "}"}]], 
            Annotation[#, {17., 34.333}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{17}], 34.333}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[216]}, 
             RowBox[{"{", 
               RowBox[{"18.`", ",", "31.333`"}], "}"}]], 
            Annotation[#, {18., 31.333}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{18}], 31.333}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[217]}, 
             RowBox[{"{", 
               RowBox[{"19.`", ",", "49.`"}], "}"}]], 
            Annotation[#, {19., 49.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{19}], 49.}], PassEventsDown -> Automatic, PassEventsUp -> 
             True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[218]}, 
             RowBox[{"{", 
               RowBox[{"20.`", ",", "8777.59961`"}], "}"}]], 
            Annotation[#, {20., 8777.59961}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{20}], 8777.59961}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[219]}, 
             RowBox[{"{", 
               RowBox[{"21.`", ",", "1729.`"}], "}"}]], 
            Annotation[#, {21., 1729.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{21}], 1729.}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[220]}, 
             RowBox[{"{", 
               RowBox[{"22.`", ",", "81.`"}], "}"}]], 
            Annotation[#, {22., 81.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{22}], 81.}], PassEventsDown -> Automatic, PassEventsUp -> 
             True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[221]}, 
             RowBox[{"{", 
               RowBox[{"23.`", ",", "42.`"}], "}"}]], 
            Annotation[#, {23., 42.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{23}], 42.}], PassEventsDown -> Automatic, PassEventsUp -> 
             True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[222]}, 
             RowBox[{"{", 
               RowBox[{"24.`", ",", "208.33299`"}], "}"}]], 
            Annotation[#, {24., 208.33299}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{24}], 208.33299}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[223]}, 
             RowBox[{"{", 
               RowBox[{"25.`", ",", "12.5`"}], "}"}]], 
            Annotation[#, {25., 12.5}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{25}], 12.5}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[224]}, 
             RowBox[{"{", 
               RowBox[{"26.`", ",", "58.5`"}], "}"}]], 
            Annotation[#, {26., 58.5}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{26}], 58.5}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[225]}, 
             RowBox[{"{", 
               RowBox[{"27.`", ",", "28.`"}], "}"}]], 
            Annotation[#, {27., 28.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{27}], 28.}], PassEventsDown -> Automatic, PassEventsUp -> 
             True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[226]}, 
             RowBox[{"{", 
               RowBox[{"28.`", ",", "20.`"}], "}"}]], 
            Annotation[#, {28., 20.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{28}], 20.}], PassEventsDown -> Automatic, PassEventsUp -> 
             True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[227]}, 
             RowBox[{"{", 
               RowBox[{"29.`", ",", "20.`"}], "}"}]], 
            Annotation[#, {29., 20.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{29}], 20.}], PassEventsDown -> Automatic, PassEventsUp -> 
             True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[228]}, 
             RowBox[{"{", 
               RowBox[{"30.`", ",", "120.`"}], "}"}]], 
            Annotation[#, {30., 120.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{30}], 120.}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[229]}, 
             RowBox[{"{", 
               RowBox[{"31.`", ",", "60.`"}], "}"}]], 
            Annotation[#, {31., 60.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{31}], 60.}], PassEventsDown -> Automatic, PassEventsUp -> 
             True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[230]}, 
             RowBox[{"{", 
               RowBox[{"32.`", ",", "60.`"}], "}"}]], 
            Annotation[#, {32., 60.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{32}], 60.}], PassEventsDown -> Automatic, PassEventsUp -> 
             True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[231]}, 
             RowBox[{"{", 
               RowBox[{"33.`", ",", "49.5`"}], "}"}]], 
            Annotation[#, {33., 49.5}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{33}], 49.5}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[232]}, 
             RowBox[{"{", 
               RowBox[{"34.`", ",", "3515.`"}], "}"}]], 
            Annotation[#, {34., 3515.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{34}], 3515.}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[233]}, 
             RowBox[{"{", 
               RowBox[{"35.`", ",", "6400.`"}], "}"}]], 
            Annotation[#, {35., 6400.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{35}], 6400.}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[234]}, 
             RowBox[{"{", 
               RowBox[{"36.`", ",", "1911.`"}], "}"}]], 
            Annotation[#, {36., 1911.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{36}], 1911.}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[235]}, 
             RowBox[{"{", 
               RowBox[{"37.`", ",", "13.5`"}], "}"}]], 
            Annotation[#, {37., 13.5}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{37}], 13.5}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[236]}, 
             RowBox[{"{", 
               RowBox[{"38.`", ",", "10.`"}], "}"}]], 
            Annotation[#, {38., 10.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{38}], 10.}], PassEventsDown -> Automatic, PassEventsUp -> 
             True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[237]}, 
             RowBox[{"{", 
               RowBox[{"39.`", ",", "228.75`"}], "}"}]], 
            Annotation[#, {39., 228.75}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{39}], 228.75}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[238]}, 
             RowBox[{"{", 
               RowBox[{"40.`", ",", "178.57001`"}], "}"}]], 
            Annotation[#, {40., 178.57001}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{40}], 178.57001}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[239]}, 
             RowBox[{"{", 
               RowBox[{"41.`", ",", "122.85`"}], "}"}]], 
            Annotation[#, {41., 122.85}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{41}], 122.85}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[240]}, 
             RowBox[{"{", 
               RowBox[{"42.`", ",", "647.57001`"}], "}"}]], 
            Annotation[#, {42., 647.57001}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{42}], 647.57001}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[241]}, 
             RowBox[{"{", 
               RowBox[{"43.`", ",", "76.`"}], "}"}]], 
            Annotation[#, {43., 76.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{43}], 76.}], PassEventsDown -> Automatic, PassEventsUp -> 
             True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[242]}, 
             RowBox[{"{", 
               RowBox[{"44.`", ",", "51.429`"}], "}"}]], 
            Annotation[#, {44., 51.429}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{44}], 51.429}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[243]}, 
             RowBox[{"{", 
               RowBox[{"45.`", ",", "37.5`"}], "}"}]], 
            Annotation[#, {45., 37.5}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{45}], 37.5}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[244]}, 
             RowBox[{"{", 
               RowBox[{"46.`", ",", "22.5`"}], "}"}]], 
            Annotation[#, {46., 22.5}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{46}], 22.5}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[245]}, 
             RowBox[{"{", 
               RowBox[{"47.`", ",", "39.`"}], "}"}]], 
            Annotation[#, {47., 39.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{47}], 39.}], PassEventsDown -> Automatic, PassEventsUp -> 
             True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[246]}, 
             RowBox[{"{", 
               RowBox[{"48.`", ",", "10.`"}], "}"}]], 
            Annotation[#, {48., 10.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{48}], 10.}], PassEventsDown -> Automatic, PassEventsUp -> 
             True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[247]}, 
             RowBox[{"{", 
               RowBox[{"49.`", ",", "40.`"}], "}"}]], 
            Annotation[#, {49., 40.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{49}], 40.}], PassEventsDown -> Automatic, PassEventsUp -> 
             True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[248]}, 
             RowBox[{"{", 
               RowBox[{"50.`", ",", "35.`"}], "}"}]], 
            Annotation[#, {50., 35.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{50}], 35.}], PassEventsDown -> Automatic, PassEventsUp -> 
             True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[249]}, 
             RowBox[{"{", 
               RowBox[{"51.`", ",", "192.5`"}], "}"}]], 
            Annotation[#, {51., 192.5}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{51}], 192.5}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[250]}, 
             RowBox[{"{", 
               RowBox[{"52.`", ",", "28.333`"}], "}"}]], 
            Annotation[#, {52., 28.333}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{52}], 28.333}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[251]}, 
             RowBox[{"{", 
               RowBox[{"53.`", ",", "18.333`"}], "}"}]], 
            Annotation[#, {53., 18.333}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{53}], 18.333}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[252]}, 
             RowBox[{"{", 
               RowBox[{"54.`", ",", "33.636`"}], "}"}]], 
            Annotation[#, {54., 33.636}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{54}], 33.636}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[253]}, 
             RowBox[{"{", 
               RowBox[{"55.`", ",", "10.`"}], "}"}]], 
            Annotation[#, {55., 10.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{55}], 10.}], PassEventsDown -> Automatic, PassEventsUp -> 
             True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[254]}, 
             RowBox[{"{", 
               RowBox[{"56.`", ",", "5.`"}], "}"}]], 
            Annotation[#, {56., 5.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{56}], 5.}], PassEventsDown -> Automatic, PassEventsUp -> 
             True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[255]}, 
             RowBox[{"{", 
               RowBox[{"57.`", ",", "10.`"}], "}"}]], 
            Annotation[#, {57., 10.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{57}], 10.}], PassEventsDown -> Automatic, PassEventsUp -> 
             True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[256]}, 
             RowBox[{"{", 
               RowBox[{"58.`", ",", "20.`"}], "}"}]], 
            Annotation[#, {58., 20.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{58}], 20.}], PassEventsDown -> Automatic, PassEventsUp -> 
             True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[257]}, 
             RowBox[{"{", 
               RowBox[{"59.`", ",", "10.`"}], "}"}]], 
            Annotation[#, {59., 10.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{59}], 10.}], PassEventsDown -> Automatic, PassEventsUp -> 
             True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[258]}, 
             RowBox[{"{", 
               RowBox[{"60.`", ",", "10.`"}], "}"}]], 
            Annotation[#, {60., 10.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{60}], 10.}], PassEventsDown -> Automatic, PassEventsUp -> 
             True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[259]}, 
             RowBox[{"{", 
               RowBox[{"61.`", ",", "10.`"}], "}"}]], 
            Annotation[#, {61., 10.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{61}], 10.}], PassEventsDown -> Automatic, PassEventsUp -> 
             True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[260]}, 
             RowBox[{"{", 
               RowBox[{"63.`", ",", "18.`"}], "}"}]], 
            Annotation[#, {63., 18.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{63}], 18.}], PassEventsDown -> Automatic, PassEventsUp -> 
             True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[261]}, 
             RowBox[{"{", 
               RowBox[{"64.`", ",", "27.5`"}], "}"}]], 
            Annotation[#, {64., 27.5}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{64}], 27.5}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[262]}, 
             RowBox[{"{", 
               RowBox[{"65.`", ",", "160.`"}], "}"}]], 
            Annotation[#, {65., 160.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{65}], 160.}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[263]}, 
             RowBox[{"{", 
               RowBox[{"66.`", ",", "15.`"}], "}"}]], 
            Annotation[#, {66., 15.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{66}], 15.}], PassEventsDown -> Automatic, PassEventsUp -> 
             True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[264]}, 
             RowBox[{"{", 
               RowBox[{"67.`", ",", "15.`"}], "}"}]], 
            Annotation[#, {67., 15.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{67}], 15.}], PassEventsDown -> Automatic, PassEventsUp -> 
             True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[265]}, 
             RowBox[{"{", 
               RowBox[{"68.`", ",", "16.2`"}], "}"}]], 
            Annotation[#, {68., 16.2}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{68}], 16.2}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[266]}, 
             RowBox[{"{", 
               RowBox[{"69.`", ",", "1386.25`"}], "}"}]], 
            Annotation[#, {69., 1386.25}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{69}], 1386.25}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[267]}, 
             RowBox[{"{", 
               RowBox[{"70.`", ",", "2082.8501`"}], "}"}]], 
            Annotation[#, {70., 2082.8501}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{70}], 2082.8501}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[268]}, 
             RowBox[{"{", 
               RowBox[{"71.`", ",", "2167.37012`"}], "}"}]], 
            Annotation[#, {71., 2167.37012}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{71}], 2167.37012}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[269]}, 
             RowBox[{"{", 
               RowBox[{"72.`", ",", "225.`"}], "}"}]], 
            Annotation[#, {72., 225.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{72}], 225.}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[270]}, 
             RowBox[{"{", 
               RowBox[{"73.`", ",", "109.`"}], "}"}]], 
            Annotation[#, {73., 109.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{73}], 109.}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[271]}, 
             RowBox[{"{", 
               RowBox[{"74.`", ",", "245.`"}], "}"}]], 
            Annotation[#, {74., 245.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{74}], 245.}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[272]}, 
             RowBox[{"{", 
               RowBox[{"75.`", ",", "271.25`"}], "}"}]], 
            Annotation[#, {75., 271.25}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{75}], 271.25}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[273]}, 
             RowBox[{"{", 
               RowBox[{"76.`", ",", "32.5`"}], "}"}]], 
            Annotation[#, {76., 32.5}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{76}], 32.5}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[274]}, 
             RowBox[{"{", 
               RowBox[{"77.`", ",", "224.286`"}], "}"}]], 
            Annotation[#, {77., 224.286}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{77}], 224.286}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[275]}, 
             RowBox[{"{", 
               RowBox[{"78.`", ",", "133.636`"}], "}"}]], 
            Annotation[#, {78., 133.636}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{78}], 133.636}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[276]}, 
             RowBox[{"{", 
               RowBox[{"79.`", ",", "165.`"}], "}"}]], 
            Annotation[#, {79., 165.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{79}], 165.}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[277]}, 
             RowBox[{"{", 
               RowBox[{"80.`", ",", "101.`"}], "}"}]], 
            Annotation[#, {80., 101.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{80}], 101.}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[278]}, 
             RowBox[{"{", 
               RowBox[{"81.`", ",", "255.`"}], "}"}]], 
            Annotation[#, {81., 255.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{81}], 255.}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[279]}, 
             RowBox[{"{", 
               RowBox[{"82.`", ",", "130.`"}], "}"}]], 
            Annotation[#, {82., 130.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{82}], 130.}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[280]}, 
             RowBox[{"{", 
               RowBox[{"83.`", ",", "123.333`"}], "}"}]], 
            Annotation[#, {83., 123.333}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{83}], 123.333}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[281]}, 
             RowBox[{"{", 
               RowBox[{"84.`", ",", "89.6`"}], "}"}]], 
            Annotation[#, {84., 89.6}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{84}], 89.6}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[282]}, 
             RowBox[{"{", 
               RowBox[{"85.`", ",", "737.5`"}], "}"}]], 
            Annotation[#, {85., 737.5}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{85}], 737.5}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[283]}, 
             RowBox[{"{", 
               RowBox[{"86.`", ",", "914.`"}], "}"}]], 
            Annotation[#, {86., 914.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{86}], 914.}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[284]}, 
             RowBox[{"{", 
               RowBox[{"87.`", ",", "429.20001`"}], "}"}]], 
            Annotation[#, {87., 429.20001}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{87}], 429.20001}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[285]}, 
             RowBox[{"{", 
               RowBox[{"88.`", ",", "5738.33008`"}], "}"}]], 
            Annotation[#, {88., 5738.33008}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{88}], 5738.33008}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[286]}, 
             RowBox[{"{", 
               RowBox[{"89.`", ",", "4073.33008`"}], "}"}]], 
            Annotation[#, {89., 4073.33008}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{89}], 4073.33008}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[287]}, 
             RowBox[{"{", 
               RowBox[{"90.`", ",", "124.167`"}], "}"}]], 
            Annotation[#, {90., 124.167}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{90}], 124.167}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[288]}, 
             RowBox[{"{", 
               RowBox[{"91.`", ",", "101.25`"}], "}"}]], 
            Annotation[#, {91., 101.25}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{91}], 101.25}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[289]}, 
             RowBox[{"{", 
               RowBox[{"92.`", ",", "153.`"}], "}"}]], 
            Annotation[#, {92., 153.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{92}], 153.}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[290]}, 
             RowBox[{"{", 
               RowBox[{"93.`", ",", "96.667`"}], "}"}]], 
            Annotation[#, {93., 96.667}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{93}], 96.667}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[291]}, 
             RowBox[{"{", 
               RowBox[{"94.`", ",", "98.333`"}], "}"}]], 
            Annotation[#, {94., 98.333}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{94}], 98.333}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[292]}, 
             RowBox[{"{", 
               RowBox[{"95.`", ",", "137.`"}], "}"}]], 
            Annotation[#, {95., 137.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{95}], 137.}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[293]}, 
             RowBox[{"{", 
               RowBox[{"96.`", ",", "215.714`"}], "}"}]], 
            Annotation[#, {96., 215.714}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{96}], 215.714}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[294]}, 
             RowBox[{"{", 
               RowBox[{"97.`", ",", "105.556`"}], "}"}]], 
            Annotation[#, {97., 105.556}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{97}], 105.556}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[295]}, 
             RowBox[{"{", 
               RowBox[{"98.`", ",", "155.`"}], "}"}]], 
            Annotation[#, {98., 155.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{98}], 155.}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[296]}, 
             RowBox[{"{", 
               RowBox[{"99.`", ",", "153.75`"}], "}"}]], 
            Annotation[#, {99., 153.75}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{99}], 153.75}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[297]}, 
             RowBox[{"{", 
               RowBox[{"100.`", ",", "421.66699`"}], "}"}]], 
            Annotation[#, {100., 421.66699}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{100}], 421.66699}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[298]}, 
             RowBox[{"{", 
               RowBox[{"101.`", ",", "122.5`"}], "}"}]], 
            Annotation[#, {101., 122.5}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{101}], 122.5}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[299]}, 
             RowBox[{"{", 
               RowBox[{"102.`", ",", "215.556`"}], "}"}]], 
            Annotation[#, {102., 215.556}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{102}], 215.556}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[300]}, 
             RowBox[{"{", 
               RowBox[{"103.`", ",", "371.11099`"}], "}"}]], 
            Annotation[#, {103., 371.11099}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{103}], 371.11099}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[301]}, 
             RowBox[{"{", 
               RowBox[{"104.`", ",", "758.75`"}], "}"}]], 
            Annotation[#, {104., 758.75}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{104}], 758.75}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[302]}, 
             RowBox[{"{", 
               RowBox[{"105.`", ",", "308.75`"}], "}"}]], 
            Annotation[#, {105., 308.75}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{105}], 308.75}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[303]}, 
             RowBox[{"{", 
               RowBox[{"106.`", ",", "38.111`"}], "}"}]], 
            Annotation[#, {106., 38.111}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{106}], 38.111}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[304]}, 
             RowBox[{"{", 
               RowBox[{"107.`", ",", "239.`"}], "}"}]], 
            Annotation[#, {107., 239.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{107}], 239.}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[305]}, 
             RowBox[{"{", 
               RowBox[{"108.`", ",", "931.83301`"}], "}"}]], 
            Annotation[#, {108., 931.83301}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{108}], 931.83301}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[306]}, 
             RowBox[{"{", 
               RowBox[{"109.`", ",", "723.66699`"}], "}"}]], 
            Annotation[#, {109., 723.66699}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{109}], 723.66699}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[307]}, 
             RowBox[{"{", 
               RowBox[{"110.`", ",", "461.875`"}], "}"}]], 
            Annotation[#, {110., 461.875}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{110}], 461.875}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[308]}, 
             RowBox[{"{", 
               RowBox[{"111.`", ",", "51.111`"}], "}"}]], 
            Annotation[#, {111., 51.111}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{111}], 51.111}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[309]}, 
             RowBox[{"{", 
               RowBox[{"112.`", ",", "25.`"}], "}"}]], 
            Annotation[#, {112., 25.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{112}], 25.}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[310]}, 
             RowBox[{"{", 
               RowBox[{"113.`", ",", "206.53799`"}], "}"}]], 
            Annotation[#, {113., 206.53799}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{113}], 206.53799}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[311]}, 
             RowBox[{"{", 
               RowBox[{"114.`", ",", "118.571`"}], "}"}]], 
            Annotation[#, {114., 118.571}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{114}], 118.571}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[312]}, 
             RowBox[{"{", 
               RowBox[{"115.`", ",", "217.75`"}], "}"}]], 
            Annotation[#, {115., 217.75}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{115}], 217.75}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[313]}, 
             RowBox[{"{", 
               RowBox[{"116.`", ",", "10.`"}], "}"}]], 
            Annotation[#, {116., 10.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{116}], 10.}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[314]}, 
             RowBox[{"{", 
               RowBox[{"117.`", ",", "25.833`"}], "}"}]], 
            Annotation[#, {117., 25.833}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{117}], 25.833}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[315]}, 
             RowBox[{"{", 
               RowBox[{"118.`", ",", "12.727`"}], "}"}]], 
            Annotation[#, {118., 12.727}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{118}], 12.727}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[316]}, 
             RowBox[{"{", 
               RowBox[{"119.`", ",", "131.66701`"}], "}"}]], 
            Annotation[#, {119., 131.66701}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{119}], 131.66701}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[317]}, 
             RowBox[{"{", 
               RowBox[{"120.`", ",", "92.`"}], "}"}]], 
            Annotation[#, {120., 92.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{120}], 92.}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[318]}, 
             RowBox[{"{", 
               RowBox[{"121.`", ",", "345.45499`"}], "}"}]], 
            Annotation[#, {121., 345.45499}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{121}], 345.45499}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[319]}, 
             RowBox[{"{", 
               RowBox[{"122.`", ",", "56.364`"}], "}"}]], 
            Annotation[#, {122., 56.364}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{122}], 56.364}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[320]}, 
             RowBox[{"{", 
               RowBox[{"123.`", ",", "128.571`"}], "}"}]], 
            Annotation[#, {123., 128.571}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{123}], 128.571}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[321]}, 
             RowBox[{"{", 
               RowBox[{"124.`", ",", "170.909`"}], "}"}]], 
            Annotation[#, {124., 170.909}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{124}], 170.909}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[322]}, 
             RowBox[{"{", 
               RowBox[{"125.`", ",", "65.556`"}], "}"}]], 
            Annotation[#, {125., 65.556}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{125}], 65.556}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[323]}, 
             RowBox[{"{", 
               RowBox[{"126.`", ",", "43.75`"}], "}"}]], 
            Annotation[#, {126., 43.75}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{126}], 43.75}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[324]}, 
             RowBox[{"{", 
               RowBox[{"127.`", ",", "246.364`"}], "}"}]], 
            Annotation[#, {127., 246.364}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{127}], 246.364}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[325]}, 
             RowBox[{"{", 
               RowBox[{"128.`", ",", "76.667`"}], "}"}]], 
            Annotation[#, {128., 76.667}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{128}], 76.667}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[326]}, 
             RowBox[{"{", 
               RowBox[{"129.`", ",", "102.5`"}], "}"}]], 
            Annotation[#, {129., 102.5}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{129}], 102.5}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[327]}, 
             RowBox[{"{", 
               RowBox[{"130.`", ",", "236.`"}], "}"}]], 
            Annotation[#, {130., 236.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{130}], 236.}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[328]}, 
             RowBox[{"{", 
               RowBox[{"131.`", ",", "103.333`"}], "}"}]], 
            Annotation[#, {131., 103.333}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{131}], 103.333}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[329]}, 
             RowBox[{"{", 
               RowBox[{"132.`", ",", "92.375`"}], "}"}]], 
            Annotation[#, {132., 92.375}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{132}], 92.375}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[330]}, 
             RowBox[{"{", 
               RowBox[{"133.`", ",", "3466.65991`"}], "}"}]], 
            Annotation[#, {133., 3466.65991}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{133}], 3466.65991}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[331]}, 
             RowBox[{"{", 
               RowBox[{"134.`", ",", "380.`"}], "}"}]], 
            Annotation[#, {134., 380.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{134}], 380.}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[332]}, 
             RowBox[{"{", 
               RowBox[{"135.`", ",", "196.`"}], "}"}]], 
            Annotation[#, {135., 196.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{135}], 196.}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[333]}, 
             RowBox[{"{", 
               RowBox[{"136.`", ",", "120.`"}], "}"}]], 
            Annotation[#, {136., 120.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{136}], 120.}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[334]}, 
             RowBox[{"{", 
               RowBox[{"137.`", ",", "46.5`"}], "}"}]], 
            Annotation[#, {137., 46.5}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{137}], 46.5}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[335]}, 
             RowBox[{"{", 
               RowBox[{"138.`", ",", "124.`"}], "}"}]], 
            Annotation[#, {138., 124.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{138}], 124.}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[336]}, 
             RowBox[{"{", 
               RowBox[{"139.`", ",", "112.857`"}], "}"}]], 
            Annotation[#, {139., 112.857}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{139}], 112.857}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[337]}, 
             RowBox[{"{", 
               RowBox[{"140.`", ",", "505.`"}], "}"}]], 
            Annotation[#, {140., 505.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{140}], 505.}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[338]}, 
             RowBox[{"{", 
               RowBox[{"141.`", ",", "175.`"}], "}"}]], 
            Annotation[#, {141., 175.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{141}], 175.}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[339]}, 
             RowBox[{"{", 
               RowBox[{"142.`", ",", "34.`"}], "}"}]], 
            Annotation[#, {142., 34.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{142}], 34.}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[340]}, 
             RowBox[{"{", 
               RowBox[{"143.`", ",", "132.25`"}], "}"}]], 
            Annotation[#, {143., 132.25}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{143}], 132.25}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[341]}, 
             RowBox[{"{", 
               RowBox[{"144.`", ",", "920.`"}], "}"}]], 
            Annotation[#, {144., 920.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{144}], 920.}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[342]}, 
             RowBox[{"{", 
               RowBox[{"145.`", ",", "196.66701`"}], "}"}]], 
            Annotation[#, {145., 196.66701}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{145}], 196.66701}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[343]}, 
             RowBox[{"{", 
               RowBox[{"146.`", ",", "1990.16003`"}], "}"}]], 
            Annotation[#, {146., 1990.16003}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{146}], 1990.16003}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[344]}, 
             RowBox[{"{", 
               RowBox[{"147.`", ",", "172.5`"}], "}"}]], 
            Annotation[#, {147., 172.5}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{147}], 172.5}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[345]}, 
             RowBox[{"{", 
               RowBox[{"148.`", ",", "235.`"}], "}"}]], 
            Annotation[#, {148., 235.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{148}], 235.}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[346]}, 
             RowBox[{"{", 
               RowBox[{"149.`", ",", "84.667`"}], "}"}]], 
            Annotation[#, {149., 84.667}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{149}], 84.667}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[347]}, 
             RowBox[{"{", 
               RowBox[{"150.`", ",", "91.833`"}], "}"}]], 
            Annotation[#, {150., 91.833}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{150}], 91.833}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[348]}, 
             RowBox[{"{", 
               RowBox[{"151.`", ",", "54.75`"}], "}"}]], 
            Annotation[#, {151., 54.75}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{151}], 54.75}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[349]}, 
             RowBox[{"{", 
               RowBox[{"152.`", ",", "90.`"}], "}"}]], 
            Annotation[#, {152., 90.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{152}], 90.}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[350]}, 
             RowBox[{"{", 
               RowBox[{"153.`", ",", "24064.`"}], "}"}]], 
            Annotation[#, {153., 24064.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{153}], 24064.}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[351]}, 
             RowBox[{"{", 
               RowBox[{"154.`", ",", "176.66701`"}], "}"}]], 
            Annotation[#, {154., 176.66701}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{154}], 176.66701}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[352]}, 
             RowBox[{"{", 
               RowBox[{"155.`", ",", "486.5`"}], "}"}]], 
            Annotation[#, {155., 486.5}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{155}], 486.5}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[353]}, 
             RowBox[{"{", 
               RowBox[{"156.`", ",", "1131.66003`"}], "}"}]], 
            Annotation[#, {156., 1131.66003}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{156}], 1131.66003}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[354]}, 
             RowBox[{"{", 
               RowBox[{"157.`", ",", "1495.`"}], "}"}]], 
            Annotation[#, {157., 1495.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{157}], 1495.}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[355]}, 
             RowBox[{"{", 
               RowBox[{"158.`", ",", "134.`"}], "}"}]], 
            Annotation[#, {158., 134.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{158}], 134.}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[356]}, 
             RowBox[{"{", 
               RowBox[{"159.`", ",", "96.833`"}], "}"}]], 
            Annotation[#, {159., 96.833}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{159}], 96.833}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[357]}, 
             RowBox[{"{", 
               RowBox[{"160.`", ",", "62.5`"}], "}"}]], 
            Annotation[#, {160., 62.5}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{160}], 62.5}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[358]}, 
             RowBox[{"{", 
               RowBox[{"161.`", ",", "142.`"}], "}"}]], 
            Annotation[#, {161., 142.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{161}], 142.}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[359]}, 
             RowBox[{"{", 
               RowBox[{"162.`", ",", "146.66701`"}], "}"}]], 
            Annotation[#, {162., 146.66701}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{162}], 146.66701}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[360]}, 
             RowBox[{"{", 
               RowBox[{"163.`", ",", "103.333`"}], "}"}]], 
            Annotation[#, {163., 103.333}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{163}], 103.333}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[361]}, 
             RowBox[{"{", 
               RowBox[{"164.`", ",", "52.2`"}], "}"}]], 
            Annotation[#, {164., 52.2}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{164}], 52.2}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[362]}, 
             RowBox[{"{", 
               RowBox[{"165.`", ",", "101.667`"}], "}"}]], 
            Annotation[#, {165., 101.667}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{165}], 101.667}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[363]}, 
             RowBox[{"{", 
               RowBox[{"166.`", ",", "244.60001`"}], "}"}]], 
            Annotation[#, {166., 244.60001}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{166}], 244.60001}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[364]}, 
             RowBox[{"{", 
               RowBox[{"167.`", ",", "137.27299`"}], "}"}]], 
            Annotation[#, {167., 137.27299}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{167}], 137.27299}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[365]}, 
             RowBox[{"{", 
               RowBox[{"168.`", ",", "227.60001`"}], "}"}]], 
            Annotation[#, {168., 227.60001}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{168}], 227.60001}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[366]}, 
             RowBox[{"{", 
               RowBox[{"169.`", ",", "643.`"}], "}"}]], 
            Annotation[#, {169., 643.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{169}], 643.}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[367]}, 
             RowBox[{"{", 
               RowBox[{"170.`", ",", "627.27301`"}], "}"}]], 
            Annotation[#, {170., 627.27301}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{170}], 627.27301}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[368]}, 
             RowBox[{"{", 
               RowBox[{"171.`", ",", "1168.`"}], "}"}]], 
            Annotation[#, {171., 1168.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{171}], 1168.}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[369]}, 
             RowBox[{"{", 
               RowBox[{"172.`", ",", "1081.66003`"}], "}"}]], 
            Annotation[#, {172., 1081.66003}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{172}], 1081.66003}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[370]}, 
             RowBox[{"{", 
               RowBox[{"173.`", ",", "124.364`"}], "}"}]], 
            Annotation[#, {173., 124.364}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{173}], 124.364}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[371]}, 
             RowBox[{"{", 
               RowBox[{"174.`", ",", "66.667`"}], "}"}]], 
            Annotation[#, {174., 66.667}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{174}], 66.667}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[372]}, 
             RowBox[{"{", 
               RowBox[{"175.`", ",", "197.909`"}], "}"}]], 
            Annotation[#, {175., 197.909}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{175}], 197.909}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[373]}, 
             RowBox[{"{", 
               RowBox[{"176.`", ",", "54.778`"}], "}"}]], 
            Annotation[#, {176., 54.778}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{176}], 54.778}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[374]}, 
             RowBox[{"{", 
               RowBox[{"177.`", ",", "32.727`"}], "}"}]], 
            Annotation[#, {177., 32.727}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{177}], 32.727}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[375]}, 
             RowBox[{"{", 
               RowBox[{"178.`", ",", "12.5`"}], "}"}]], 
            Annotation[#, {178., 12.5}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{178}], 12.5}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[376]}, 
             RowBox[{"{", 
               RowBox[{"179.`", ",", "53.846`"}], "}"}]], 
            Annotation[#, {179., 53.846}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{179}], 53.846}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[377]}, 
             RowBox[{"{", 
               RowBox[{"180.`", ",", "11.111`"}], "}"}]], 
            Annotation[#, {180., 11.111}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{180}], 11.111}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[378]}, 
             RowBox[{"{", 
               RowBox[{"181.`", ",", "10.`"}], "}"}]], 
            Annotation[#, {181., 10.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{181}], 10.}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[379]}, 
             RowBox[{"{", 
               RowBox[{"182.`", ",", "10.5`"}], "}"}]], 
            Annotation[#, {182., 10.5}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{182}], 10.5}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[380]}, 
             RowBox[{"{", 
               RowBox[{"183.`", ",", "32.`"}], "}"}]], 
            Annotation[#, {183., 32.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{183}], 32.}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[381]}, 
             RowBox[{"{", 
               RowBox[{"184.`", ",", "40.`"}], "}"}]], 
            Annotation[#, {184., 40.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{184}], 40.}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[382]}, 
             RowBox[{"{", 
               RowBox[{"185.`", ",", "32.5`"}], "}"}]], 
            Annotation[#, {185., 32.5}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{185}], 32.5}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[383]}, 
             RowBox[{"{", 
               RowBox[{"186.`", ",", "161.81799`"}], "}"}]], 
            Annotation[#, {186., 161.81799}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{186}], 161.81799}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[384]}, 
             RowBox[{"{", 
               RowBox[{"187.`", ",", "88.182`"}], "}"}]], 
            Annotation[#, {187., 88.182}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{187}], 88.182}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[385]}, 
             RowBox[{"{", 
               RowBox[{"188.`", ",", "43.75`"}], "}"}]], 
            Annotation[#, {188., 43.75}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{188}], 43.75}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[386]}, 
             RowBox[{"{", 
               RowBox[{"189.`", ",", "82.1`"}], "}"}]], 
            Annotation[#, {189., 82.1}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{189}], 82.1}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[387]}, 
             RowBox[{"{", 
               RowBox[{"190.`", ",", "17.778`"}], "}"}]], 
            Annotation[#, {190., 17.778}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{190}], 17.778}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[388]}, 
             RowBox[{"{", 
               RowBox[{"191.`", ",", "103.`"}], "}"}]], 
            Annotation[#, {191., 103.}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{191}], 103.}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[389]}, 
             RowBox[{"{", 
               RowBox[{"192.`", ",", "65.455`"}], "}"}]], 
            Annotation[#, {192., 65.455}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{192}], 65.455}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[390]}, 
             RowBox[{"{", 
               RowBox[{"193.`", ",", "37.778`"}], "}"}]], 
            Annotation[#, {193., 37.778}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{193}], 37.778}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[391]}, 
             RowBox[{"{", 
               RowBox[{"194.`", ",", "72.6`"}], "}"}]], 
            Annotation[#, {194., 72.6}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{194}], 72.6}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[392]}, 
             RowBox[{"{", 
               RowBox[{"195.`", ",", "96.667`"}], "}"}]], 
            Annotation[#, {195., 96.667}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{195}], 96.667}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[393]}, 
             RowBox[{"{", 
               RowBox[{"196.`", ",", "83.75`"}], "}"}]], 
            Annotation[#, {196., 83.75}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{196}], 83.75}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[394]}, 
             RowBox[{"{", 
               RowBox[{"197.`", ",", "125.333`"}], "}"}]], 
            Annotation[#, {197., 125.333}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{197}], 125.333}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[395]}, 
             RowBox[{"{", 
               RowBox[{"198.`", ",", "60.11`"}], "}"}]], 
            Annotation[#, {198., 60.11}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{198}], 60.11}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]], 
          TagBox[
           TagBox[
            TooltipBox[{
              Opacity[0.], 
              PointBox[396]}, 
             RowBox[{"{", 
               RowBox[{"200.`", ",", "27.069`"}], "}"}]], 
            Annotation[#, {200., 27.069}, "Tooltip"]& ], 
           EventHandlerTag[{"MouseClicked" :> $CellContext`toggle$$[{
                First[{200}], 27.069}], PassEventsDown -> Automatic, 
             PassEventsUp -> True}]]}}], {}}, AspectRatio -> 
      NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> True, 
      AxesOrigin -> {0, 0}, Epilog -> DynamicBox[
        Typeset`ToBoxes[
         Map[Text[
           Style[
            First[#], {Red, 9}], # + {
            0, $CellContext`plotYMax$$/12}]& , $CellContext`clicks$$], 
         StandardForm, Graphics]], Frame -> True, FrameLabel -> {{
         FormBox["NH4", TraditionalForm], None}, {None, None}}, ImageSize -> 
      300, Method -> {}, PlotRange -> {{1., 200.}, {0, 24064.}}, 
      PlotRangeClipping -> True, PlotRangePadding -> {
        Scaled[0.02], 
        Scaled[0.02]}], Appearance -> GraphicsBox[{
        RGBColor[1, 0, 0], 
        CircleBox[{0, 0}, 1]}, ImageSize -> 15], Enabled -> False, 
     LocatorAutoCreate -> True],DynamicBox[
     ToBoxes[
      ListPlot[
       Map[Tooltip[#, #]& , 
        ($CellContext`selected = $CellContext`columnize[
          Delete[
           $CellContext`med[All], 
           Map[List, 
            Part[$CellContext`clicks$$, All, 1]]]])[$CellContext`col$$]], 
       PlotRange -> Full, PlotMarkers -> {Automatic, Medium}, 
       FrameLabel -> {None, $CellContext`col$$}, Frame -> True, ImageSize -> 
       300, PlotStyle -> Magenta], StandardForm], 
     ImageSizeCache -> {300., {83., 87.}}]},
   "RowDefault"],
  DynamicModuleValues:>{{DownValues[$CellContext`clickHash$$] = {HoldPattern[
         $CellContext`clickHash$$[{20, 8777.59961}]] :> 1, HoldPattern[
         $CellContext`clickHash$$[{35, 6400.}]] :> False, HoldPattern[
         $CellContext`clickHash$$[{88, 5738.33008}]] :> False, HoldPattern[
         $CellContext`clickHash$$[{153, 24064.}]] :> 1}}, {
    DownValues[$CellContext`toggle$$] = {HoldPattern[
         $CellContext`toggle$$[
          Pattern[$CellContext`pt$, 
           Blank[]]]] :> (If[Head[
            $CellContext`clickHash$$[$CellContext`pt$]] === 
          Integer, $CellContext`clickHash$$[$CellContext`pt$] = Xor[
            $CellContext`clickHash$$[$CellContext`pt$], 
            1], $CellContext`clickHash$$[$CellContext`pt$] = 
          1]; $CellContext`clicks$$ = With[{$CellContext`uv = Map[ReleaseHold, 
              Part[
               DownValues[$CellContext`clickHash$$], All, 1, All, 
               1]], $CellContext`dv = Part[
              DownValues[$CellContext`clickHash$$], All, 2]}, 
           Pick[$CellContext`uv, $CellContext`dv, 1]])}}},
  Initialization:>{$CellContext`selected = $CellContext`sym$238599, 
    Attributes[$CellContext`sym$236862] = {
     Temporary}, $CellContext`sym$236862[$CellContext`a1] = Part[
      $CellContext`sym$236862[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$236862[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$236862[$CellContext`a2] = Part[
      $CellContext`sym$236862[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$236862[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$236862[$CellContext`a3] = Part[
      $CellContext`sym$236862[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$236862[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$236862[$CellContext`a4] = Part[
      $CellContext`sym$236862[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$236862[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$236862[$CellContext`a5] = Part[
      $CellContext`sym$236862[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$236862[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$236862[$CellContext`a6] = Part[
      $CellContext`sym$236862[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$236862[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$236862[$CellContext`a7] = Part[
      $CellContext`sym$236862[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$236862[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$236862[
     All] = {{"winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 
       170., 50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
      "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
       558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
      "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 125.667,
        187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
      "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 61.182, 
       138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
      "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222, 
       97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
      "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
       56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
      "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
       111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
      "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 44.667, 
       77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
      "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 71., 
       5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 0.8, 
       17., 0., 0., 2.9, 0., 0., 1.7}, {
      "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 20.75, 
       0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
      "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 19.,
        0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
      "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 41., 
       43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
      "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5, 
       31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
      "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 0.3, 
       52.2, 5., 7.8, 0., 4., 0., 0.}, {
      "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 98.25, 
       1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50., 
       1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
      "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 57.833, 
       0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
      "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 0.8, 
       50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
      "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
       564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
      "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 586.,
        16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
      "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 0.5, 
       15.5, 0., 0., 2.3, 0., 0., 0.}, {
      "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 7.6,
        23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
      "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
       27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
      "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 1.5,
        13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
      "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 44.136, 
       3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
      "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 0.5, 
       29.7, 0., 0., 4.9, 0., 0., 0.}, {
      "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
       Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
      "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 17.1,
        0., 19.6, 0., 0., 0., 2.5}, {
      "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5, 
       33.9, 1., 14.6, 0., 0., 0., 0.}, {
      "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 4.9, 
       3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
      "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 2.8, 
       6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
      "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 130.75, 
       5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
      "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47., 
       2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
      "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23., 
       0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
      "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 58.875, 
       84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
      "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 0.2,
        66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
       Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0., 
       0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
       196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
      "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
       182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
      "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001, 
       296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
      "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 59.429,
        175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
      "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
       344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
      "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 276.85001, 
       326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
      "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 40.667, 
       3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
      "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 3.3, 
       29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
      "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 0.8, 
       54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
       Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 0., 
       0.}, {"spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121.,
        2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 20.812,
        12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
      "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
       49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
      "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 22.9, 
       4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
      "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 11.8, 
       0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818, 
       0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
      "winter", "small", "high", 6.6, 10.8, 
       Missing[], 3.245, 10., 1., 6.5, 
       Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "medium", 5.6, 11.8, 
       Missing[], 2.22, 5., 1., 1., 
       Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 5.7, 10.8, 
       Missing[], 2.55, 10., 1., 4., 
       Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
      "spring", "small", "high", 6.6, 9.5, 
       Missing[], 1.32, 20., 1., 6., 
       Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
      "summer", "small", "high", 6.6, 10.8, 
       Missing[], 2.64, 10., 2., 11., 
       Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
      "autumn", "small", "medium", 6.6, 11.3, 
       Missing[], 4.17, 10., 1., 6., 
       Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
      "spring", "small", "medium", 6.5, 10.4, 
       Missing[], 5.97, 10., 2., 14., 
       Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
      "summer", "small", "medium", 6.4, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 14., 
       Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
      "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 6.667, 
       Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75, 1.,
        20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
      "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2, 
       0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
      "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 0.6,
        55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
      "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 10.75, 
       2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
      "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 0.5, 
       64.2, 0., 3., 0., 0., 0., 0.}, {
      "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75, 
       351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
      "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
       209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
      "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 151.125,
        279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
      "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
       152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
      "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
       58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
      "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
       249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
      "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 100., 
       233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
      "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 215.5, 
       18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
      "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 25.167, 
       102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
      "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
       105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
      "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
       111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
      "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 1.3, 
       6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
      "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 56.667, 
       2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
      "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 4.3,
        1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
      "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
       104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
      "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 69.93,
        3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
      "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
       214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
      "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
       254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
      "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 57.6,
        169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
      "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
       412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
      "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
       282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
      "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
       197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
      "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 267.75, 
       391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
      "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 191.75, 
       265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
      "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
       232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
      "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 144.66701, 
       244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
      "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 218., 
       6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
      "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 138.5,
        20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
      "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222, 
       239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
      "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
       235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
      "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75, 
       205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
      "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 31.333, 
       211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
      "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625, 
       186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
      "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 12.889, 
       154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
      "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 51.111, 
       183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
      "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
       292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
      "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
       285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
      "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
       201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
      "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
       275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
      "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
       124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
      "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 60.833, 
       141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
      "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71., 
       132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
      "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
       17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
      "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 0.3, 
       46.6, 0., 2.5, 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 8.692, 
       16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
      "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 37.857, 
       102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
      "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
       86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
      "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
       10.111, 
       Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 16.833, 
       18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
      "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545, 
       13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
      "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 261.60001, 
       432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
      "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
       320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
      "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 144., 
       287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
      "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
       166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
      "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
       222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
      "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 36.909, 
       122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
      "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556, 
       127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
      "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
       89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
      "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 55., 
       284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
      "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 102.333, 
       277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
      "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 75.875, 
       177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
      "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
       72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
      "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 48.667, 
       82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
      "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 48.625, 
       66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
      "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 23., 
       173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
      "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 317., 
       5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
      "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 84., 
       4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
      "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 2., 
       10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
      "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 88.5, 
       2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
      "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115., 
       11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
      "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 98.143, 
       2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
      "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
       143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
      "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
       197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
      "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 1., 
       19., 0., 22., 5., 1.1, 5.4, 0.}, {
      "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 10.583, 
       23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
      "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 200.231, 
       19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
      "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 77.333, 
       147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
      "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5, 
       276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
      "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
       123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
      "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 75.207,
        23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
      "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 116.2,
        7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
      "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
       188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
      "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
       72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
      "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 16., 
       0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
      "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 34., 
       53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
      "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 27.5, 
       76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
      "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
       58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
      "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 175.66701, 
       361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
      "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
       22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
      "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 26.8,
        0., 28., 0., 0., 0., 0., 15.1}, {
      "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
       54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
      "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333, 
       34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
      "spring", "large", "low", 9., 5.8, 
       Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 0., 
       0.}, {"spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
       151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
      "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
       269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
      "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 46.438, 
       81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
      "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 85., 
       2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
      "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 66.4, 
       171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
      "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 102.364, 
       232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
      "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 84.3, 
       146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
      "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
       246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
      "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 205.636, 
       219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
      "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 236.39999,
        272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
      "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 1081.66003, 
       346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 5.9, 1.7}, {
      "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 82.222,
        167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
      "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 64.389, 
       137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
      "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 87.333,
        194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
      "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
       159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
      "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 21.3, 
       1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
      "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 0.6,
        37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
      "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
       14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
      "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222, 7.,
        1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 0.8, 
       50.4, 3.8, 0., 0., 0., 0., 0.}, {
      "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 7.654, 
       4., 56.8, 5., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 2.86, 
       17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
      "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 56.091, 
       Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
      "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
       52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
      "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 104.727, 
       228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
      "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 85.4, 
       17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
      "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 87.125,
        14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
      "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 101.455, 
       18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
      "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 50.889, 
       127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
      "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
       81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
      "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 19.727, 
       50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
      "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111, 
       120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
      "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 51.111, 
       91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
      "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 19.111, 
       61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
      "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625, 
       79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
      "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333, 
       75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
      "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333, 
       140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
      "winter", "large", "medium", 8., 7.6, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
      "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
       140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 
       5.8}}, $CellContext`sym$236862[$CellContext`Chla] = Part[
      $CellContext`sym$236862[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$236862[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$236862[$CellContext`Cl] = Part[
      $CellContext`sym$236862[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$236862[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$236862[$CellContext`mnO2] = Part[
      $CellContext`sym$236862[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$236862[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$236862[$CellContext`mxPH] = Part[
      $CellContext`sym$236862[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$236862[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$236862[$CellContext`NH4] = Part[
      $CellContext`sym$236862[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$236862[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$236862[$CellContext`NO3] = Part[
      $CellContext`sym$236862[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$236862[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$236862[$CellContext`oPO4] = Part[
      $CellContext`sym$236862[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$236862[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$236862[$CellContext`PO4] = Part[
      $CellContext`sym$236862[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$236862[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$236862[$CellContext`season] = Part[
      $CellContext`sym$236862[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$236862[$CellContext`season, 
         "missing"]]]], $CellContext`sym$236862[$CellContext`size] = Part[
      $CellContext`sym$236862[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$236862[$CellContext`size, 
         "missing"]]]], $CellContext`sym$236862[$CellContext`speed] = Part[
      $CellContext`sym$236862[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$236862[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$236862[$CellContext`a1, 
      "factorized"] = 
    False, $CellContext`sym$236862[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$236862[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$236862[All], 
      All, $CellContext`i$236874], $CellContext`sym$236862[$CellContext`a2, 
      "factorized"] = 
    False, $CellContext`sym$236862[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$236862[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$236862[All], 
      All, $CellContext`i$236875], $CellContext`sym$236862[$CellContext`a3, 
      "factorized"] = 
    False, $CellContext`sym$236862[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$236862[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$236862[All], 
      All, $CellContext`i$236876], $CellContext`sym$236862[$CellContext`a4, 
      "factorized"] = 
    False, $CellContext`sym$236862[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$236862[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$236862[All], 
      All, $CellContext`i$236877], $CellContext`sym$236862[$CellContext`a5, 
      "factorized"] = 
    False, $CellContext`sym$236862[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$236862[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$236862[All], 
      All, $CellContext`i$236878], $CellContext`sym$236862[$CellContext`a6, 
      "factorized"] = 
    False, $CellContext`sym$236862[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$236862[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$236862[All], 
      All, $CellContext`i$236879], $CellContext`sym$236862[$CellContext`a7, 
      "factorized"] = 
    False, $CellContext`sym$236862[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$236862[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$236862[All], 
      All, $CellContext`i$236880], $CellContext`sym$236862[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$236862[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed}, $CellContext`sym$236862[$CellContext`Chla, "factorized"] = 
    False, $CellContext`sym$236862[$CellContext`Chla, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {63}, {116}, {184}, {
     199}}, $CellContext`sym$236862[$CellContext`Chla, "raw"] = Part[
      $CellContext`sym$236862[All], 
      All, $CellContext`i$236873], $CellContext`sym$236862[$CellContext`Cl, 
      "factorized"] = 
    False, $CellContext`sym$236862[$CellContext`Cl, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {161}, {
     199}}, $CellContext`sym$236862[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$236862[All], 
      All, $CellContext`i$236868], $CellContext`sym$236862[$CellContext`mnO2, 
      "factorized"] = 
    False, $CellContext`sym$236862[$CellContext`mnO2, "missing"] = {{38}, {
     62}}, $CellContext`sym$236862[$CellContext`mnO2, "raw"] = Part[
      $CellContext`sym$236862[All], 
      All, $CellContext`i$236867], $CellContext`sym$236862[$CellContext`mxPH, 
      "factorized"] = 
    False, $CellContext`sym$236862[$CellContext`mxPH, "missing"] = {{
     48}}, $CellContext`sym$236862[$CellContext`mxPH, "raw"] = Part[
      $CellContext`sym$236862[All], 
      All, $CellContext`i$236866], $CellContext`sym$236862[$CellContext`NH4, 
      "factorized"] = 
    False, $CellContext`sym$236862[$CellContext`NH4, "missing"] = {{62}, {
     199}}, $CellContext`sym$236862[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$236862[All], 
      All, $CellContext`i$236870], $CellContext`sym$236862[$CellContext`NO3, 
      "factorized"] = 
    False, $CellContext`sym$236862[$CellContext`NO3, "missing"] = {{62}, {
     199}}, $CellContext`sym$236862[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$236862[All], 
      All, $CellContext`i$236869], $CellContext`sym$236862[$CellContext`oPO4, 
      "factorized"] = 
    False, $CellContext`sym$236862[$CellContext`oPO4, "missing"] = {{62}, {
     199}}, $CellContext`sym$236862[$CellContext`oPO4, "raw"] = Part[
      $CellContext`sym$236862[All], 
      All, $CellContext`i$236871], $CellContext`sym$236862[$CellContext`PO4, 
      "factorized"] = 
    False, $CellContext`sym$236862[$CellContext`PO4, "missing"] = {{28}, {
     199}}, $CellContext`sym$236862[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$236862[All], 
      All, $CellContext`i$236872], \
$CellContext`sym$236862[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$236862[$CellContext`season, "factors"] = 
    Part[{"autumn", "spring", "summer", "winter"}, 
      $CellContext`fordering[$CellContext`sym$236862, $CellContext`season]], \
$CellContext`sym$236862[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$236862[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$236862[All], 
      All, $CellContext`i$236863], $CellContext`sym$236862[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$236862[$CellContext`size, "factors"] = 
    Part[{"large", "medium", "small"}, 
      $CellContext`fordering[$CellContext`sym$236862, $CellContext`size]], \
$CellContext`sym$236862[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$236862[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$236862[All], 
      All, $CellContext`i$236864], $CellContext`sym$236862[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$236862[$CellContext`speed, "factors"] = 
    Part[{"high", "low", "medium"}, 
      $CellContext`fordering[$CellContext`sym$236862, $CellContext`speed]], \
$CellContext`sym$236862[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$236862[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$236862[All], 
      All, $CellContext`i$236865], \
$CellContext`fordering[$CellContext`sym$101871, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$101871, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$101871, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$101871, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$101871, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$101871, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$101871, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$101871, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$101871, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$101871, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$101871, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$101871, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$101871, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$101871, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$101871, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$101871, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$101871, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$101871, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$10211, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$10211, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$10211, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$10211, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$10211, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$10211, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$10211, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$10211, $CellContext`Chla] = {
     1}, $CellContext`fordering[$CellContext`sym$10211, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$10211, $CellContext`mnO2] = {
     1}, $CellContext`fordering[$CellContext`sym$10211, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$10211, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$10211, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$10211, $CellContext`oPO4] = {
     1}, $CellContext`fordering[$CellContext`sym$10211, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$10211, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$10211, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$10211, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$10239, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$10239, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$10239, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$10239, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$10239, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$10239, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$10239, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$10239, $CellContext`Chla] = {
     1}, $CellContext`fordering[$CellContext`sym$10239, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$10239, $CellContext`mnO2] = {
     1}, $CellContext`fordering[$CellContext`sym$10239, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$10239, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$10239, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$10239, $CellContext`oPO4] = {
     1}, $CellContext`fordering[$CellContext`sym$10239, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$10239, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$10239, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$10239, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$104104, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$104104, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$104104, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$104104, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$104104, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$104104, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$104104, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$104104, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$104104, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$104104, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$104104, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$104104, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$104104, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$104104, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$104104, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$104104, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$104104, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$104104, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$106337, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$106337, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$106337, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$106337, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$106337, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$106337, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$106337, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$106337, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$106337, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$106337, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$106337, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$106337, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$106337, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$106337, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$106337, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$106337, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$106337, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$106337, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$108570, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$108570, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$108570, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$108570, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$108570, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$108570, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$108570, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$108570, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$108570, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$108570, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$108570, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$108570, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$108570, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$108570, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$108570, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$108570, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$108570, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$108570, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$110803, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$110803, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$110803, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$110803, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$110803, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$110803, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$110803, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$110803, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$110803, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$110803, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$110803, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$110803, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$110803, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$110803, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$110803, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$110803, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$110803, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$110803, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$113036, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$113036, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$113036, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$113036, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$113036, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$113036, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$113036, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$113036, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$113036, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$113036, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$113036, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$113036, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$113036, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$113036, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$113036, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$113036, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$113036, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$113036, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$115269, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$115269, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$115269, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$115269, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$115269, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$115269, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$115269, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$115269, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$115269, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$115269, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$115269, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$115269, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$115269, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$115269, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$115269, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$115269, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$115269, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$115269, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$117502, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$117502, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$117502, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$117502, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$117502, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$117502, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$117502, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$117502, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$117502, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$117502, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$117502, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$117502, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$117502, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$117502, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$117502, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$117502, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$117502, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$117502, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$119735, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$119735, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$119735, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$119735, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$119735, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$119735, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$119735, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$119735, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$119735, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$119735, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$119735, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$119735, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$119735, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$119735, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$119735, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$119735, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$119735, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$119735, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$121968, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$121968, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$121968, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$121968, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$121968, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$121968, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$121968, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$121968, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$121968, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$121968, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$121968, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$121968, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$121968, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$121968, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$121968, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$121968, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$121968, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$121968, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$124201, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$124201, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$124201, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$124201, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$124201, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$124201, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$124201, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$124201, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$124201, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$124201, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$124201, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$124201, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$124201, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$124201, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$124201, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$124201, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$124201, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$124201, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$12472, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$12472, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$12472, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$12472, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$12472, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$12472, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$12472, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$12472, $CellContext`Chla] = {
     1}, $CellContext`fordering[$CellContext`sym$12472, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$12472, $CellContext`mnO2] = {
     1}, $CellContext`fordering[$CellContext`sym$12472, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$12472, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$12472, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$12472, $CellContext`oPO4] = {
     1}, $CellContext`fordering[$CellContext`sym$12472, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$12472, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$12472, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$12472, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$126434, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$126434, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$126434, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$126434, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$126434, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$126434, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$126434, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$126434, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$126434, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$126434, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$126434, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$126434, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$126434, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$126434, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$126434, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$126434, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$126434, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$126434, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$128667, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$128667, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$128667, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$128667, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$128667, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$128667, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$128667, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$128667, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$128667, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$128667, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$128667, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$128667, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$128667, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$128667, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$128667, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$128667, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$128667, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$128667, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$130900, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$130900, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$130900, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$130900, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$130900, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$130900, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$130900, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$130900, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$130900, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$130900, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$130900, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$130900, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$130900, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$130900, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$130900, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$130900, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$130900, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$130900, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$133133, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$133133, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$133133, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$133133, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$133133, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$133133, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$133133, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$133133, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$133133, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$133133, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$133133, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$133133, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$133133, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$133133, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$133133, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$133133, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$133133, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$133133, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$135366, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$135366, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$135366, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$135366, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$135366, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$135366, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$135366, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$135366, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$135366, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$135366, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$135366, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$135366, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$135366, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$135366, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$135366, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$135366, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$135366, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$135366, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$137599, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$137599, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$137599, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$137599, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$137599, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$137599, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$137599, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$137599, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$137599, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$137599, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$137599, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$137599, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$137599, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$137599, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$137599, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$137599, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$137599, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$137599, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$139832, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$139832, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$139832, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$139832, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$139832, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$139832, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$139832, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$139832, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$139832, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$139832, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$139832, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$139832, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$139832, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$139832, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$139832, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$139832, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$139832, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$139832, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$142065, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$142065, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$142065, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$142065, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$142065, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$142065, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$142065, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$142065, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$142065, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$142065, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$142065, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$142065, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$142065, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$142065, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$142065, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$142065, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$142065, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$142065, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$144298, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$144298, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$144298, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$144298, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$144298, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$144298, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$144298, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$144298, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$144298, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$144298, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$144298, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$144298, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$144298, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$144298, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$144298, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$144298, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$144298, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$144298, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$146531, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$146531, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$146531, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$146531, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$146531, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$146531, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$146531, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$146531, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$146531, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$146531, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$146531, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$146531, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$146531, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$146531, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$146531, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$146531, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$146531, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$146531, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$14705, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$14705, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$14705, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$14705, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$14705, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$14705, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$14705, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$14705, $CellContext`Chla] = {
     1}, $CellContext`fordering[$CellContext`sym$14705, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$14705, $CellContext`mnO2] = {
     1}, $CellContext`fordering[$CellContext`sym$14705, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$14705, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$14705, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$14705, $CellContext`oPO4] = {
     1}, $CellContext`fordering[$CellContext`sym$14705, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$14705, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$14705, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$14705, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$148764, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$148764, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$148764, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$148764, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$148764, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$148764, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$148764, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$148764, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$148764, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$148764, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$148764, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$148764, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$148764, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$148764, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$148764, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$148764, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$148764, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$148764, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$150997, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$150997, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$150997, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$150997, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$150997, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$150997, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$150997, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$150997, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$150997, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$150997, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$150997, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$150997, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$150997, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$150997, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$150997, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$150997, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$150997, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$150997, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$153230, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$153230, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$153230, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$153230, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$153230, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$153230, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$153230, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$153230, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$153230, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$153230, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$153230, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$153230, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$153230, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$153230, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$153230, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$153230, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$153230, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$153230, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$155463, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$155463, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$155463, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$155463, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$155463, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$155463, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$155463, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$155463, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$155463, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$155463, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$155463, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$155463, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$155463, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$155463, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$155463, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$155463, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$155463, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$155463, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$157696, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$157696, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$157696, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$157696, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$157696, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$157696, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$157696, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$157696, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$157696, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$157696, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$157696, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$157696, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$157696, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$157696, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$157696, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$157696, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$157696, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$157696, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$159929, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$159929, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$159929, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$159929, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$159929, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$159929, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$159929, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$159929, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$159929, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$159929, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$159929, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$159929, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$159929, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$159929, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$159929, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$159929, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$159929, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$159929, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$162162, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$162162, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$162162, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$162162, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$162162, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$162162, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$162162, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$162162, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$162162, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$162162, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$162162, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$162162, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$162162, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$162162, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$162162, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$162162, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$162162, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$162162, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$164395, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$164395, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$164395, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$164395, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$164395, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$164395, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$164395, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$164395, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$164395, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$164395, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$164395, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$164395, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$164395, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$164395, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$164395, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$164395, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$164395, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$164395, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$166628, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$166628, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$166628, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$166628, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$166628, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$166628, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$166628, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$166628, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$166628, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$166628, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$166628, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$166628, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$166628, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$166628, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$166628, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$166628, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$166628, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$166628, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$168861, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$168861, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$168861, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$168861, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$168861, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$168861, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$168861, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$168861, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$168861, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$168861, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$168861, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$168861, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$168861, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$168861, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$168861, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$168861, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$168861, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$168861, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$16938, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$16938, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$16938, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$16938, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$16938, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$16938, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$16938, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$16938, $CellContext`Chla] = {
     1}, $CellContext`fordering[$CellContext`sym$16938, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$16938, $CellContext`mnO2] = {
     1}, $CellContext`fordering[$CellContext`sym$16938, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$16938, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$16938, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$16938, $CellContext`oPO4] = {
     1}, $CellContext`fordering[$CellContext`sym$16938, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$16938, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$16938, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$16938, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$171094, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$171094, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$171094, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$171094, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$171094, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$171094, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$171094, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$171094, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$171094, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$171094, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$171094, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$171094, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$171094, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$171094, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$171094, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$171094, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$171094, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$171094, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$173327, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$173327, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$173327, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$173327, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$173327, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$173327, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$173327, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$173327, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$173327, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$173327, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$173327, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$173327, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$173327, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$173327, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$173327, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$173327, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$173327, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$173327, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$175560, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$175560, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$175560, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$175560, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$175560, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$175560, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$175560, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$175560, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$175560, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$175560, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$175560, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$175560, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$175560, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$175560, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$175560, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$175560, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$175560, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$175560, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$177793, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$177793, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$177793, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$177793, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$177793, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$177793, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$177793, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$177793, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$177793, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$177793, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$177793, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$177793, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$177793, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$177793, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$177793, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$177793, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$177793, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$177793, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$180026, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$180026, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$180026, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$180026, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$180026, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$180026, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$180026, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$180026, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$180026, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$180026, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$180026, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$180026, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$180026, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$180026, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$180026, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$180026, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$180026, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$180026, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$182259, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$182259, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$182259, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$182259, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$182259, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$182259, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$182259, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$182259, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$182259, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$182259, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$182259, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$182259, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$182259, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$182259, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$182259, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$182259, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$182259, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$182259, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$184492, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$184492, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$184492, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$184492, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$184492, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$184492, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$184492, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$184492, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$184492, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$184492, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$184492, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$184492, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$184492, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$184492, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$184492, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$184492, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$184492, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$184492, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$186725, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$186725, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$186725, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$186725, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$186725, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$186725, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$186725, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$186725, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$186725, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$186725, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$186725, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$186725, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$186725, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$186725, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$186725, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$186725, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$186725, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$186725, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$188958, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$188958, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$188958, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$188958, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$188958, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$188958, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$188958, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$188958, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$188958, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$188958, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$188958, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$188958, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$188958, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$188958, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$188958, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$188958, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$188958, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$188958, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$191191, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$191191, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$191191, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$191191, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$191191, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$191191, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$191191, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$191191, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$191191, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$191191, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$191191, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$191191, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$191191, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$191191, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$191191, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$191191, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$191191, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$191191, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$19171, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$19171, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$19171, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$19171, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$19171, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$19171, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$19171, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$19171, $CellContext`Chla] = {
     1}, $CellContext`fordering[$CellContext`sym$19171, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$19171, $CellContext`mnO2] = {
     1}, $CellContext`fordering[$CellContext`sym$19171, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$19171, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$19171, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$19171, $CellContext`oPO4] = {
     1}, $CellContext`fordering[$CellContext`sym$19171, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$19171, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$19171, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$19171, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$193424, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$193424, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$193424, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$193424, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$193424, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$193424, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$193424, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$193424, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$193424, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$193424, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$193424, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$193424, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$193424, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$193424, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$193424, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$193424, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$193424, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$193424, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$195657, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$195657, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$195657, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$195657, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$195657, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$195657, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$195657, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$195657, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$195657, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$195657, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$195657, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$195657, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$195657, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$195657, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$195657, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$195657, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$195657, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$195657, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$197890, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$197890, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$197890, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$197890, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$197890, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$197890, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$197890, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$197890, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$197890, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$197890, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$197890, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$197890, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$197890, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$197890, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$197890, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$197890, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$197890, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$197890, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$200123, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$200123, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$200123, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$200123, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$200123, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$200123, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$200123, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$200123, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$200123, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$200123, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$200123, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$200123, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$200123, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$200123, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$200123, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$200123, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$200123, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$200123, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$202356, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$202356, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$202356, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$202356, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$202356, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$202356, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$202356, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$202356, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$202356, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$202356, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$202356, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$202356, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$202356, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$202356, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$202356, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$202356, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$202356, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$202356, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$204589, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$204589, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$204589, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$204589, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$204589, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$204589, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$204589, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$204589, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$204589, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$204589, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$204589, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$204589, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$204589, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$204589, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$204589, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$204589, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$204589, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$204589, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$206822, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$206822, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$206822, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$206822, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$206822, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$206822, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$206822, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$206822, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$206822, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$206822, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$206822, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$206822, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$206822, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$206822, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$206822, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$206822, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$206822, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$206822, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$209055, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$209055, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$209055, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$209055, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$209055, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$209055, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$209055, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$209055, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$209055, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$209055, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$209055, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$209055, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$209055, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$209055, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$209055, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$209055, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$209055, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$209055, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$211288, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$211288, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$211288, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$211288, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$211288, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$211288, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$211288, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$211288, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$211288, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$211288, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$211288, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$211288, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$211288, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$211288, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$211288, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$211288, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$211288, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$211288, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$213521, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$213521, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$213521, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$213521, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$213521, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$213521, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$213521, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$213521, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$213521, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$213521, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$213521, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$213521, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$213521, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$213521, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$213521, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$213521, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$213521, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$213521, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$21404, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$21404, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$21404, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$21404, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$21404, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$21404, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$21404, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$21404, $CellContext`Chla] = {
     1}, $CellContext`fordering[$CellContext`sym$21404, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$21404, $CellContext`mnO2] = {
     1}, $CellContext`fordering[$CellContext`sym$21404, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$21404, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$21404, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$21404, $CellContext`oPO4] = {
     1}, $CellContext`fordering[$CellContext`sym$21404, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$21404, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$21404, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$21404, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$215754, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$215754, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$215754, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$215754, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$215754, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$215754, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$215754, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$215754, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$215754, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$215754, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$215754, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$215754, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$215754, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$215754, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$215754, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$215754, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$215754, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$215754, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$217987, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$217987, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$217987, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$217987, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$217987, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$217987, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$217987, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$217987, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$217987, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$217987, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$217987, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$217987, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$217987, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$217987, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$217987, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$217987, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$217987, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$217987, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$220220, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$220220, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$220220, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$220220, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$220220, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$220220, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$220220, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$220220, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$220220, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$220220, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$220220, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$220220, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$220220, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$220220, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$220220, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$220220, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$220220, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$220220, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$222453, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$222453, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$222453, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$222453, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$222453, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$222453, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$222453, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$222453, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$222453, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$222453, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$222453, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$222453, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$222453, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$222453, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$222453, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$222453, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$222453, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$222453, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$224686, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$224686, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$224686, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$224686, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$224686, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$224686, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$224686, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$224686, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$224686, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$224686, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$224686, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$224686, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$224686, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$224686, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$224686, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$224686, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$224686, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$224686, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$226925, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$226925, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$226925, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$226925, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$226925, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$226925, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$226925, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$226925, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$226925, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$226925, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$226925, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$226925, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$226925, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$226925, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$226925, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$226925, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$226925, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$226925, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$226954, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$226954, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$226954, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$226954, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$226954, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$226954, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$226954, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$226954, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$226954, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$226954, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$226954, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$226954, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$226954, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$226954, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$226954, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$226954, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$226954, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$226954, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$227039, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$227039, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$227039, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$227039, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$227039, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$227039, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$227039, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$227039, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$227039, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$227039, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$227039, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$227039, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$227039, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$227039, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$227039, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$227039, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$227039, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$227039, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$227110, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$227110, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$227110, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$227110, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$227110, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$227110, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$227110, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$227110, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$227110, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$227110, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$227110, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$227110, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$227110, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$227110, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$227110, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$227110, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$227110, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$227110, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$227178, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$227178, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$227178, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$227178, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$227178, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$227178, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$227178, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$227178, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$227178, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$227178, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$227178, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$227178, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$227178, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$227178, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$227178, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$227178, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$227178, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$227178, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$227254, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$227254, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$227254, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$227254, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$227254, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$227254, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$227254, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$227254, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$227254, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$227254, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$227254, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$227254, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$227254, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$227254, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$227254, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$227254, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$227254, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$227254, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$227310, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$227310, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$227310, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$227310, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$227310, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$227310, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$227310, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$227310, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$227310, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$227310, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$227310, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$227310, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$227310, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$227310, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$227310, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$227310, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$227310, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$227310, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$227342, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$227342, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$227342, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$227342, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$227342, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$227342, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$227342, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$227342, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$227342, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$227342, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$227342, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$227342, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$227342, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$227342, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$227342, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$227342, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$227342, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$227342, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$227370, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$227370, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$227370, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$227370, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$227370, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$227370, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$227370, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$227370, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$227370, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$227370, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$227370, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$227370, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$227370, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$227370, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$227370, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$227370, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$227370, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$227370, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$227398, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$227398, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$227398, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$227398, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$227398, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$227398, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$227398, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$227398, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$227398, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$227398, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$227398, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$227398, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$227398, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$227398, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$227398, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$227398, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$227398, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$227398, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$227445, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$227445, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$227445, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$227445, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$227445, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$227445, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$227445, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$227445, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$227445, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$227445, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$227445, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$227445, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$227445, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$227445, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$227445, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$227445, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$227445, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$227445, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$227522, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$227522, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$227522, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$227522, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$227522, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$227522, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$227522, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$227522, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$227522, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$227522, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$227522, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$227522, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$227522, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$227522, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$227522, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$227522, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$227522, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$227522, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$227589, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$227589, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$227589, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$227589, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$227589, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$227589, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$227589, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$227589, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$227589, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$227589, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$227589, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$227589, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$227589, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$227589, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$227589, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$227589, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$227589, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$227589, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$227634, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$227634, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$227634, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$227634, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$227634, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$227634, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$227634, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$227634, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$227634, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$227634, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$227634, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$227634, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$227634, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$227634, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$227634, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$227634, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$227634, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$227634, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$227670, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$227670, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$227670, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$227670, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$227670, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$227670, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$227670, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$227670, $CellContext`Chla] = \
{1}, $CellContext`fordering[$CellContext`sym$227670, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$227670, $CellContext`mnO2] = \
{1}, $CellContext`fordering[$CellContext`sym$227670, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$227670, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$227670, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$227670, $CellContext`oPO4] = \
{1}, $CellContext`fordering[$CellContext`sym$227670, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$227670, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$227670, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$227670, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$227704, $CellContext`season] = {
     2, 3, 1, 4}, $CellContext`fordering[$CellContext`sym$227704, \
$CellContext`size] = {3, 2, 
     1}, $CellContext`fordering[$CellContext`sym$227704, $CellContext`speed] = \
{2, 3, 1}, $CellContext`fordering[$CellContext`sym$227724, \
$CellContext`season] = {1, 2, 3, 
     4}, $CellContext`fordering[$CellContext`sym$227724, $CellContext`size] = \
{1, 2, 3}, $CellContext`fordering[$CellContext`sym$227724, \
$CellContext`speed] = {1, 2, 
     3}, $CellContext`fordering[$CellContext`sym$228168, $CellContext`season] = \
{2, 3, 1, 
     4}, $CellContext`fordering[$CellContext`sym$228168, $CellContext`size] = \
{3, 2, 1}, $CellContext`fordering[$CellContext`sym$228168, \
$CellContext`speed] = {2, 3, 
     1}, $CellContext`fordering[$CellContext`sym$228188, $CellContext`season] = \
{2, 3, 1, 
     4}, $CellContext`fordering[$CellContext`sym$228188, $CellContext`size] = \
{3, 2, 1}, $CellContext`fordering[$CellContext`sym$228188, \
$CellContext`speed] = {2, 3, 
     1}, $CellContext`fordering[$CellContext`sym$228209, $CellContext`season] = \
{1, 2, 3, 
     4}, $CellContext`fordering[$CellContext`sym$228209, $CellContext`size] = \
{1, 2, 3}, $CellContext`fordering[$CellContext`sym$228209, \
$CellContext`speed] = {1, 2, 
     3}, $CellContext`fordering[$CellContext`sym$228643, $CellContext`season] = \
{1, 2, 3, 
     4}, $CellContext`fordering[$CellContext`sym$228643, $CellContext`size] = \
{1, 2, 3}, $CellContext`fordering[$CellContext`sym$228643, \
$CellContext`speed] = {1, 2, 
     3}, $CellContext`fordering[$CellContext`sym$229076, $CellContext`season] = \
{1, 2, 3, 
     4}, $CellContext`fordering[$CellContext`sym$229076, $CellContext`size] = \
{1, 2, 3}, $CellContext`fordering[$CellContext`sym$229076, \
$CellContext`speed] = {1, 2, 
     3}, $CellContext`fordering[$CellContext`sym$229509, $CellContext`season] = \
{1, 2, 3, 
     4}, $CellContext`fordering[$CellContext`sym$229509, $CellContext`size] = \
{1, 2, 3}, $CellContext`fordering[$CellContext`sym$229509, \
$CellContext`speed] = {1, 2, 
     3}, $CellContext`fordering[$CellContext`sym$229942, $CellContext`season] = \
{1, 2, 3, 
     4}, $CellContext`fordering[$CellContext`sym$229942, $CellContext`size] = \
{1, 2, 3}, $CellContext`fordering[$CellContext`sym$229942, \
$CellContext`speed] = {1, 2, 
     3}, $CellContext`fordering[$CellContext`sym$230375, $CellContext`season] = \
{1, 2, 3, 
     4}, $CellContext`fordering[$CellContext`sym$230375, $CellContext`size] = \
{1, 2, 3}, $CellContext`fordering[$CellContext`sym$230375, \
$CellContext`speed] = {1, 2, 
     3}, $CellContext`fordering[$CellContext`sym$230808, $CellContext`season] = \
{1, 2, 3, 
     4}, $CellContext`fordering[$CellContext`sym$230808, $CellContext`size] = \
{1, 2, 3}, $CellContext`fordering[$CellContext`sym$230808, \
$CellContext`speed] = {1, 2, 
     3}, $CellContext`fordering[$CellContext`sym$231241, $CellContext`season] = \
{1, 2, 3, 
     4}, $CellContext`fordering[$CellContext`sym$231241, $CellContext`size] = \
{1, 2, 3}, $CellContext`fordering[$CellContext`sym$231241, \
$CellContext`speed] = {1, 2, 
     3}, $CellContext`fordering[$CellContext`sym$231674, $CellContext`season] = \
{1, 2, 3, 
     4}, $CellContext`fordering[$CellContext`sym$231674, $CellContext`size] = \
{1, 2, 3}, $CellContext`fordering[$CellContext`sym$231674, \
$CellContext`speed] = {1, 2, 
     3}, $CellContext`fordering[$CellContext`sym$232107, $CellContext`season] = \
{1, 2, 3, 
     4}, $CellContext`fordering[$CellContext`sym$232107, $CellContext`size] = \
{1, 2, 3}, $CellContext`fordering[$CellContext`sym$232107, \
$CellContext`speed] = {1, 2, 
     3}, $CellContext`fordering[$CellContext`sym$232540, $CellContext`season] = \
{1, 2, 3, 
     4}, $CellContext`fordering[$CellContext`sym$232540, $CellContext`size] = \
{1, 2, 3}, $CellContext`fordering[$CellContext`sym$232540, \
$CellContext`speed] = {1, 2, 
     3}, $CellContext`fordering[$CellContext`sym$232973, $CellContext`season] = \
{1, 2, 3, 
     4}, $CellContext`fordering[$CellContext`sym$232973, $CellContext`size] = \
{1, 2, 3}, $CellContext`fordering[$CellContext`sym$232973, \
$CellContext`speed] = {1, 2, 
     3}, $CellContext`fordering[$CellContext`sym$233406, $CellContext`season] = \
{1, 2, 3, 
     4}, $CellContext`fordering[$CellContext`sym$233406, $CellContext`size] = \
{1, 2, 3}, $CellContext`fordering[$CellContext`sym$233406, \
$CellContext`speed] = {1, 2, 
     3}, $CellContext`fordering[$CellContext`sym$233839, $CellContext`season] = \
{1, 2, 3, 
     4}, $CellContext`fordering[$CellContext`sym$233839, $CellContext`size] = \
{1, 2, 3}, $CellContext`fordering[$CellContext`sym$233839, \
$CellContext`speed] = {1, 2, 
     3}, $CellContext`fordering[$CellContext`sym$234272, $CellContext`season] = \
{1, 2, 3, 
     4}, $CellContext`fordering[$CellContext`sym$234272, $CellContext`size] = \
{1, 2, 3}, $CellContext`fordering[$CellContext`sym$234272, \
$CellContext`speed] = {1, 2, 
     3}, $CellContext`fordering[$CellContext`sym$234705, $CellContext`season] = \
{1, 2, 3, 
     4}, $CellContext`fordering[$CellContext`sym$234705, $CellContext`size] = \
{1, 2, 3}, $CellContext`fordering[$CellContext`sym$234705, \
$CellContext`speed] = {1, 2, 
     3}, $CellContext`fordering[$CellContext`sym$235138, $CellContext`season] = \
{1, 2, 3, 
     4}, $CellContext`fordering[$CellContext`sym$235138, $CellContext`size] = \
{1, 2, 3}, $CellContext`fordering[$CellContext`sym$235138, \
$CellContext`speed] = {1, 2, 
     3}, $CellContext`fordering[$CellContext`sym$235571, $CellContext`season] = \
{1, 2, 3, 
     4}, $CellContext`fordering[$CellContext`sym$235571, $CellContext`size] = \
{1, 2, 3}, $CellContext`fordering[$CellContext`sym$235571, \
$CellContext`speed] = {1, 2, 
     3}, $CellContext`fordering[$CellContext`sym$236130, $CellContext`season] = \
{1, 2, 3, 
     4}, $CellContext`fordering[$CellContext`sym$236130, $CellContext`size] = \
{1, 2, 3}, $CellContext`fordering[$CellContext`sym$236130, \
$CellContext`speed] = {1, 2, 
     3}, $CellContext`fordering[$CellContext`sym$23637, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$23637, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$23637, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$23637, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$23637, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$23637, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$23637, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$23637, $CellContext`Chla] = {
     1}, $CellContext`fordering[$CellContext`sym$23637, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$23637, $CellContext`mnO2] = {
     1}, $CellContext`fordering[$CellContext`sym$23637, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$23637, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$23637, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$23637, $CellContext`oPO4] = {
     1}, $CellContext`fordering[$CellContext`sym$23637, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$23637, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$23637, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$23637, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$236862, $CellContext`season] = {
     1, 2, 3, 4}, $CellContext`fordering[$CellContext`sym$236862, \
$CellContext`size] = {1, 2, 
     3}, $CellContext`fordering[$CellContext`sym$236862, $CellContext`speed] = \
{1, 2, 3}, $CellContext`fordering[$CellContext`sym$237297, \
$CellContext`season] = {1, 2, 3, 
     4}, $CellContext`fordering[$CellContext`sym$237297, $CellContext`size] = \
{1, 2, 3}, $CellContext`fordering[$CellContext`sym$237297, \
$CellContext`speed] = {1, 2, 
     3}, $CellContext`fordering[$CellContext`sym$237731, $CellContext`season] = \
{1, 2, 3, 
     4}, $CellContext`fordering[$CellContext`sym$237731, $CellContext`size] = \
{1, 2, 3}, $CellContext`fordering[$CellContext`sym$237731, \
$CellContext`speed] = {1, 2, 
     3}, $CellContext`fordering[$CellContext`sym$238165, $CellContext`season] = \
{1, 2, 3, 
     4}, $CellContext`fordering[$CellContext`sym$238165, $CellContext`size] = \
{1, 2, 3}, $CellContext`fordering[$CellContext`sym$238165, \
$CellContext`speed] = {1, 2, 
     3}, $CellContext`fordering[$CellContext`sym$238599, $CellContext`season] = \
{1, 2, 3, 
     4}, $CellContext`fordering[$CellContext`sym$238599, $CellContext`size] = \
{1, 2, 3}, $CellContext`fordering[$CellContext`sym$238599, \
$CellContext`speed] = {1, 2, 
     3}, $CellContext`fordering[$CellContext`sym$25870, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$25870, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$25870, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$25870, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$25870, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$25870, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$25870, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$25870, $CellContext`Chla] = {
     1}, $CellContext`fordering[$CellContext`sym$25870, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$25870, $CellContext`mnO2] = {
     1}, $CellContext`fordering[$CellContext`sym$25870, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$25870, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$25870, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$25870, $CellContext`oPO4] = {
     1}, $CellContext`fordering[$CellContext`sym$25870, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$25870, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$25870, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$25870, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$28103, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$28103, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$28103, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$28103, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$28103, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$28103, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$28103, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$28103, $CellContext`Chla] = {
     1}, $CellContext`fordering[$CellContext`sym$28103, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$28103, $CellContext`mnO2] = {
     1}, $CellContext`fordering[$CellContext`sym$28103, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$28103, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$28103, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$28103, $CellContext`oPO4] = {
     1}, $CellContext`fordering[$CellContext`sym$28103, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$28103, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$28103, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$28103, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$30337, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$30337, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$30337, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$30337, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$30337, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$30337, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$30337, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$30337, $CellContext`Chla] = {
     1}, $CellContext`fordering[$CellContext`sym$30337, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$30337, $CellContext`mnO2] = {
     1}, $CellContext`fordering[$CellContext`sym$30337, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$30337, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$30337, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$30337, $CellContext`oPO4] = {
     1}, $CellContext`fordering[$CellContext`sym$30337, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$30337, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$30337, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$30337, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$32570, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$32570, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$32570, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$32570, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$32570, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$32570, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$32570, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$32570, $CellContext`Chla] = {
     1}, $CellContext`fordering[$CellContext`sym$32570, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$32570, $CellContext`mnO2] = {
     1}, $CellContext`fordering[$CellContext`sym$32570, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$32570, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$32570, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$32570, $CellContext`oPO4] = {
     1}, $CellContext`fordering[$CellContext`sym$32570, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$32570, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$32570, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$32570, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$34803, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$34803, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$34803, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$34803, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$34803, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$34803, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$34803, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$34803, $CellContext`Chla] = {
     1}, $CellContext`fordering[$CellContext`sym$34803, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$34803, $CellContext`mnO2] = {
     1}, $CellContext`fordering[$CellContext`sym$34803, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$34803, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$34803, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$34803, $CellContext`oPO4] = {
     1}, $CellContext`fordering[$CellContext`sym$34803, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$34803, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$34803, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$34803, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$3488, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$3488, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$3488, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$3488, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$3488, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$3488, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$3488, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$3488, $CellContext`Chla] = {
     1}, $CellContext`fordering[$CellContext`sym$3488, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$3488, $CellContext`mnO2] = {
     1}, $CellContext`fordering[$CellContext`sym$3488, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$3488, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$3488, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$3488, $CellContext`oPO4] = {
     1}, $CellContext`fordering[$CellContext`sym$3488, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$3488, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$3488, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$3488, $CellContext`speed] = {
     1}, $CellContext`fordering[$CellContext`sym$37036, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$37036, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$37036, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$37036, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$37036, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$37036, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$37036, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$37036, $CellContext`Chla] = {
     1}, $CellContext`fordering[$CellContext`sym$37036, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$37036, $CellContext`mnO2] = {
     1}, $CellContext`fordering[$CellContext`sym$37036, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$37036, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$37036, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$37036, $CellContext`oPO4] = {
     1}, $CellContext`fordering[$CellContext`sym$37036, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$37036, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$37036, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$37036, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$39269, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$39269, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$39269, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$39269, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$39269, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$39269, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$39269, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$39269, $CellContext`Chla] = {
     1}, $CellContext`fordering[$CellContext`sym$39269, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$39269, $CellContext`mnO2] = {
     1}, $CellContext`fordering[$CellContext`sym$39269, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$39269, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$39269, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$39269, $CellContext`oPO4] = {
     1}, $CellContext`fordering[$CellContext`sym$39269, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$39269, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$39269, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$39269, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$41502, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$41502, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$41502, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$41502, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$41502, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$41502, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$41502, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$41502, $CellContext`Chla] = {
     1}, $CellContext`fordering[$CellContext`sym$41502, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$41502, $CellContext`mnO2] = {
     1}, $CellContext`fordering[$CellContext`sym$41502, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$41502, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$41502, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$41502, $CellContext`oPO4] = {
     1}, $CellContext`fordering[$CellContext`sym$41502, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$41502, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$41502, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$41502, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$43735, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$43735, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$43735, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$43735, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$43735, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$43735, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$43735, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$43735, $CellContext`Chla] = {
     1}, $CellContext`fordering[$CellContext`sym$43735, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$43735, $CellContext`mnO2] = {
     1}, $CellContext`fordering[$CellContext`sym$43735, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$43735, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$43735, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$43735, $CellContext`oPO4] = {
     1}, $CellContext`fordering[$CellContext`sym$43735, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$43735, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$43735, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$43735, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$45968, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$45968, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$45968, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$45968, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$45968, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$45968, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$45968, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$45968, $CellContext`Chla] = {
     1}, $CellContext`fordering[$CellContext`sym$45968, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$45968, $CellContext`mnO2] = {
     1}, $CellContext`fordering[$CellContext`sym$45968, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$45968, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$45968, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$45968, $CellContext`oPO4] = {
     1}, $CellContext`fordering[$CellContext`sym$45968, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$45968, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$45968, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$45968, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$48201, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$48201, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$48201, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$48201, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$48201, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$48201, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$48201, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$48201, $CellContext`Chla] = {
     1}, $CellContext`fordering[$CellContext`sym$48201, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$48201, $CellContext`mnO2] = {
     1}, $CellContext`fordering[$CellContext`sym$48201, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$48201, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$48201, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$48201, $CellContext`oPO4] = {
     1}, $CellContext`fordering[$CellContext`sym$48201, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$48201, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$48201, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$48201, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$50434, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$50434, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$50434, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$50434, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$50434, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$50434, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$50434, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$50434, $CellContext`Chla] = {
     1}, $CellContext`fordering[$CellContext`sym$50434, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$50434, $CellContext`mnO2] = {
     1}, $CellContext`fordering[$CellContext`sym$50434, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$50434, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$50434, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$50434, $CellContext`oPO4] = {
     1}, $CellContext`fordering[$CellContext`sym$50434, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$50434, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$50434, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$50434, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$52667, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$52667, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$52667, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$52667, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$52667, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$52667, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$52667, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$52667, $CellContext`Chla] = {
     1}, $CellContext`fordering[$CellContext`sym$52667, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$52667, $CellContext`mnO2] = {
     1}, $CellContext`fordering[$CellContext`sym$52667, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$52667, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$52667, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$52667, $CellContext`oPO4] = {
     1}, $CellContext`fordering[$CellContext`sym$52667, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$52667, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$52667, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$52667, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$54900, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$54900, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$54900, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$54900, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$54900, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$54900, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$54900, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$54900, $CellContext`Chla] = {
     1}, $CellContext`fordering[$CellContext`sym$54900, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$54900, $CellContext`mnO2] = {
     1}, $CellContext`fordering[$CellContext`sym$54900, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$54900, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$54900, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$54900, $CellContext`oPO4] = {
     1}, $CellContext`fordering[$CellContext`sym$54900, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$54900, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$54900, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$54900, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$57133, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$57133, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$57133, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$57133, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$57133, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$57133, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$57133, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$57133, $CellContext`Chla] = {
     1}, $CellContext`fordering[$CellContext`sym$57133, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$57133, $CellContext`mnO2] = {
     1}, $CellContext`fordering[$CellContext`sym$57133, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$57133, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$57133, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$57133, $CellContext`oPO4] = {
     1}, $CellContext`fordering[$CellContext`sym$57133, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$57133, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$57133, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$57133, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$5743, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$5743, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$5743, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$5743, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$5743, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$5743, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$5743, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$5743, $CellContext`Chla] = {
     1}, $CellContext`fordering[$CellContext`sym$5743, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$5743, $CellContext`mnO2] = {
     1}, $CellContext`fordering[$CellContext`sym$5743, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$5743, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$5743, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$5743, $CellContext`oPO4] = {
     1}, $CellContext`fordering[$CellContext`sym$5743, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$5743, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$5743, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$5743, $CellContext`speed] = {
     1}, $CellContext`fordering[$CellContext`sym$59366, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$59366, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$59366, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$59366, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$59366, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$59366, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$59366, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$59366, $CellContext`Chla] = {
     1}, $CellContext`fordering[$CellContext`sym$59366, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$59366, $CellContext`mnO2] = {
     1}, $CellContext`fordering[$CellContext`sym$59366, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$59366, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$59366, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$59366, $CellContext`oPO4] = {
     1}, $CellContext`fordering[$CellContext`sym$59366, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$59366, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$59366, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$59366, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$61599, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$61599, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$61599, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$61599, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$61599, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$61599, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$61599, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$61599, $CellContext`Chla] = {
     1}, $CellContext`fordering[$CellContext`sym$61599, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$61599, $CellContext`mnO2] = {
     1}, $CellContext`fordering[$CellContext`sym$61599, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$61599, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$61599, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$61599, $CellContext`oPO4] = {
     1}, $CellContext`fordering[$CellContext`sym$61599, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$61599, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$61599, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$61599, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$63832, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$63832, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$63832, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$63832, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$63832, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$63832, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$63832, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$63832, $CellContext`Chla] = {
     1}, $CellContext`fordering[$CellContext`sym$63832, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$63832, $CellContext`mnO2] = {
     1}, $CellContext`fordering[$CellContext`sym$63832, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$63832, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$63832, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$63832, $CellContext`oPO4] = {
     1}, $CellContext`fordering[$CellContext`sym$63832, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$63832, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$63832, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$63832, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$66065, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$66065, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$66065, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$66065, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$66065, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$66065, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$66065, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$66065, $CellContext`Chla] = {
     1}, $CellContext`fordering[$CellContext`sym$66065, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$66065, $CellContext`mnO2] = {
     1}, $CellContext`fordering[$CellContext`sym$66065, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$66065, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$66065, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$66065, $CellContext`oPO4] = {
     1}, $CellContext`fordering[$CellContext`sym$66065, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$66065, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$66065, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$66065, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$68298, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$68298, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$68298, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$68298, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$68298, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$68298, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$68298, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$68298, $CellContext`Chla] = {
     1}, $CellContext`fordering[$CellContext`sym$68298, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$68298, $CellContext`mnO2] = {
     1}, $CellContext`fordering[$CellContext`sym$68298, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$68298, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$68298, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$68298, $CellContext`oPO4] = {
     1}, $CellContext`fordering[$CellContext`sym$68298, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$68298, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$68298, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$68298, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$70548, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$70548, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$70548, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$70548, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$70548, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$70548, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$70548, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$70548, $CellContext`Chla] = {
     1}, $CellContext`fordering[$CellContext`sym$70548, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$70548, $CellContext`mnO2] = {
     1}, $CellContext`fordering[$CellContext`sym$70548, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$70548, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$70548, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$70548, $CellContext`oPO4] = {
     1}, $CellContext`fordering[$CellContext`sym$70548, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$70548, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$70548, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$70548, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$70989, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$70989, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$70989, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$70989, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$70989, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$70989, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$70989, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$70989, $CellContext`Chla] = {
     1}, $CellContext`fordering[$CellContext`sym$70989, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$70989, $CellContext`mnO2] = {
     1}, $CellContext`fordering[$CellContext`sym$70989, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$70989, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$70989, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$70989, $CellContext`oPO4] = {
     1}, $CellContext`fordering[$CellContext`sym$70989, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$70989, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$70989, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$70989, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$72812, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$72812, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$72812, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$72812, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$72812, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$72812, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$72812, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$72812, $CellContext`Chla] = {
     1}, $CellContext`fordering[$CellContext`sym$72812, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$72812, $CellContext`mnO2] = {
     1}, $CellContext`fordering[$CellContext`sym$72812, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$72812, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$72812, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$72812, $CellContext`oPO4] = {
     1}, $CellContext`fordering[$CellContext`sym$72812, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$72812, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$72812, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$72812, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$75045, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$75045, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$75045, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$75045, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$75045, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$75045, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$75045, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$75045, $CellContext`Chla] = {
     1}, $CellContext`fordering[$CellContext`sym$75045, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$75045, $CellContext`mnO2] = {
     1}, $CellContext`fordering[$CellContext`sym$75045, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$75045, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$75045, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$75045, $CellContext`oPO4] = {
     1}, $CellContext`fordering[$CellContext`sym$75045, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$75045, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$75045, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$75045, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$77278, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$77278, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$77278, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$77278, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$77278, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$77278, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$77278, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$77278, $CellContext`Chla] = {
     1}, $CellContext`fordering[$CellContext`sym$77278, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$77278, $CellContext`mnO2] = {
     1}, $CellContext`fordering[$CellContext`sym$77278, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$77278, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$77278, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$77278, $CellContext`oPO4] = {
     1}, $CellContext`fordering[$CellContext`sym$77278, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$77278, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$77278, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$77278, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$79513, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$79513, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$79513, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$79513, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$79513, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$79513, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$79513, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$79513, $CellContext`Chla] = {
     1}, $CellContext`fordering[$CellContext`sym$79513, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$79513, $CellContext`mnO2] = {
     1}, $CellContext`fordering[$CellContext`sym$79513, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$79513, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$79513, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$79513, $CellContext`oPO4] = {
     1}, $CellContext`fordering[$CellContext`sym$79513, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$79513, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$79513, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$79513, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$79541, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$79541, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$79541, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$79541, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$79541, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$79541, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$79541, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$79541, $CellContext`Chla] = {
     1}, $CellContext`fordering[$CellContext`sym$79541, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$79541, $CellContext`mnO2] = {
     1}, $CellContext`fordering[$CellContext`sym$79541, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$79541, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$79541, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$79541, $CellContext`oPO4] = {
     1}, $CellContext`fordering[$CellContext`sym$79541, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$79541, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$79541, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$79541, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$7976, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$7976, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$7976, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$7976, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$7976, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$7976, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$7976, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$7976, $CellContext`Chla] = {
     1}, $CellContext`fordering[$CellContext`sym$7976, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$7976, $CellContext`mnO2] = {
     1}, $CellContext`fordering[$CellContext`sym$7976, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$7976, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$7976, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$7976, $CellContext`oPO4] = {
     1}, $CellContext`fordering[$CellContext`sym$7976, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$7976, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$7976, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$7976, $CellContext`speed] = {
     1}, $CellContext`fordering[$CellContext`sym$81774, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$81774, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$81774, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$81774, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$81774, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$81774, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$81774, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$81774, $CellContext`Chla] = {
     1}, $CellContext`fordering[$CellContext`sym$81774, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$81774, $CellContext`mnO2] = {
     1}, $CellContext`fordering[$CellContext`sym$81774, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$81774, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$81774, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$81774, $CellContext`oPO4] = {
     1}, $CellContext`fordering[$CellContext`sym$81774, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$81774, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$81774, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$81774, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$84007, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$84007, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$84007, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$84007, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$84007, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$84007, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$84007, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$84007, $CellContext`Chla] = {
     1}, $CellContext`fordering[$CellContext`sym$84007, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$84007, $CellContext`mnO2] = {
     1}, $CellContext`fordering[$CellContext`sym$84007, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$84007, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$84007, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$84007, $CellContext`oPO4] = {
     1}, $CellContext`fordering[$CellContext`sym$84007, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$84007, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$84007, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$84007, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$86240, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$86240, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$86240, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$86240, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$86240, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$86240, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$86240, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$86240, $CellContext`Chla] = {
     1}, $CellContext`fordering[$CellContext`sym$86240, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$86240, $CellContext`mnO2] = {
     1}, $CellContext`fordering[$CellContext`sym$86240, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$86240, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$86240, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$86240, $CellContext`oPO4] = {
     1}, $CellContext`fordering[$CellContext`sym$86240, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$86240, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$86240, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$86240, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$88473, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$88473, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$88473, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$88473, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$88473, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$88473, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$88473, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$88473, $CellContext`Chla] = {
     1}, $CellContext`fordering[$CellContext`sym$88473, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$88473, $CellContext`mnO2] = {
     1}, $CellContext`fordering[$CellContext`sym$88473, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$88473, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$88473, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$88473, $CellContext`oPO4] = {
     1}, $CellContext`fordering[$CellContext`sym$88473, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$88473, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$88473, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$88473, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$90706, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$90706, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$90706, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$90706, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$90706, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$90706, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$90706, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$90706, $CellContext`Chla] = {
     1}, $CellContext`fordering[$CellContext`sym$90706, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$90706, $CellContext`mnO2] = {
     1}, $CellContext`fordering[$CellContext`sym$90706, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$90706, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$90706, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$90706, $CellContext`oPO4] = {
     1}, $CellContext`fordering[$CellContext`sym$90706, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$90706, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$90706, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$90706, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$92939, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$92939, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$92939, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$92939, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$92939, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$92939, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$92939, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$92939, $CellContext`Chla] = {
     1}, $CellContext`fordering[$CellContext`sym$92939, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$92939, $CellContext`mnO2] = {
     1}, $CellContext`fordering[$CellContext`sym$92939, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$92939, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$92939, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$92939, $CellContext`oPO4] = {
     1}, $CellContext`fordering[$CellContext`sym$92939, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$92939, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$92939, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$92939, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$95172, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$95172, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$95172, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$95172, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$95172, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$95172, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$95172, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$95172, $CellContext`Chla] = {
     1}, $CellContext`fordering[$CellContext`sym$95172, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$95172, $CellContext`mnO2] = {
     1}, $CellContext`fordering[$CellContext`sym$95172, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$95172, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$95172, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$95172, $CellContext`oPO4] = {
     1}, $CellContext`fordering[$CellContext`sym$95172, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$95172, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$95172, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$95172, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$97405, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$97405, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$97405, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$97405, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$97405, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$97405, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$97405, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$97405, $CellContext`Chla] = {
     1}, $CellContext`fordering[$CellContext`sym$97405, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$97405, $CellContext`mnO2] = {
     1}, $CellContext`fordering[$CellContext`sym$97405, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$97405, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$97405, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$97405, $CellContext`oPO4] = {
     1}, $CellContext`fordering[$CellContext`sym$97405, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$97405, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$97405, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$97405, $CellContext`speed] = \
{1}, $CellContext`fordering[$CellContext`sym$99638, $CellContext`a1] = {
     1}, $CellContext`fordering[$CellContext`sym$99638, $CellContext`a2] = {
     1}, $CellContext`fordering[$CellContext`sym$99638, $CellContext`a3] = {
     1}, $CellContext`fordering[$CellContext`sym$99638, $CellContext`a4] = {
     1}, $CellContext`fordering[$CellContext`sym$99638, $CellContext`a5] = {
     1}, $CellContext`fordering[$CellContext`sym$99638, $CellContext`a6] = {
     1}, $CellContext`fordering[$CellContext`sym$99638, $CellContext`a7] = {
     1}, $CellContext`fordering[$CellContext`sym$99638, $CellContext`Chla] = {
     1}, $CellContext`fordering[$CellContext`sym$99638, $CellContext`Cl] = {
     1}, $CellContext`fordering[$CellContext`sym$99638, $CellContext`mnO2] = {
     1}, $CellContext`fordering[$CellContext`sym$99638, $CellContext`mxPH] = {
     1}, $CellContext`fordering[$CellContext`sym$99638, $CellContext`NH4] = {
     1}, $CellContext`fordering[$CellContext`sym$99638, $CellContext`NO3] = {
     1}, $CellContext`fordering[$CellContext`sym$99638, $CellContext`oPO4] = {
     1}, $CellContext`fordering[$CellContext`sym$99638, $CellContext`PO4] = {
     1}, $CellContext`fordering[$CellContext`sym$99638, $CellContext`season] = \
{1}, $CellContext`fordering[$CellContext`sym$99638, $CellContext`size] = {
     1}, $CellContext`fordering[$CellContext`sym$99638, $CellContext`speed] = \
{1}, Attributes[$CellContext`sym$86240] = {
     Temporary}, $CellContext`sym$86240[$CellContext`a1] = Part[
      $CellContext`sym$86240[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$86240[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$86240[$CellContext`a2] = Part[
      $CellContext`sym$86240[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$86240[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$86240[$CellContext`a3] = Part[
      $CellContext`sym$86240[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$86240[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$86240[$CellContext`a4] = Part[
      $CellContext`sym$86240[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$86240[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$86240[$CellContext`a5] = Part[
      $CellContext`sym$86240[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$86240[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$86240[$CellContext`a6] = Part[
      $CellContext`sym$86240[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$86240[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$86240[$CellContext`a7] = Part[
      $CellContext`sym$86240[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$86240[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$86240[All] = $CellContext`med[
     All], $CellContext`sym$86240[$CellContext`Chla] = Part[
      $CellContext`sym$86240[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$86240[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$86240[$CellContext`Cl] = Part[
      $CellContext`sym$86240[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$86240[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$86240[$CellContext`mnO2] = Part[
      $CellContext`sym$86240[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$86240[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$86240[$CellContext`mxPH] = Part[
      $CellContext`sym$86240[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$86240[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$86240[$CellContext`NH4] = Part[
      $CellContext`sym$86240[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$86240[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$86240[$CellContext`NO3] = Part[
      $CellContext`sym$86240[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$86240[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$86240[$CellContext`oPO4] = Part[
      $CellContext`sym$86240[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$86240[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$86240[$CellContext`PO4] = Part[
      $CellContext`sym$86240[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$86240[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$86240[$CellContext`season] = Part[
      $CellContext`sym$86240[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$86240[$CellContext`season, 
         "missing"]]]], $CellContext`sym$86240[$CellContext`size] = Part[
      $CellContext`sym$86240[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$86240[$CellContext`size, 
         "missing"]]]], $CellContext`sym$86240[$CellContext`speed] = Part[
      $CellContext`sym$86240[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$86240[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$86240[$CellContext`a1, "factorized"] = 
    True, $CellContext`sym$86240[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$86240, $CellContext`a1]], \
$CellContext`sym$86240[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$86240[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$86240[All], 
      All, $CellContext`i$87799], $CellContext`sym$86240[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$86240[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$86240, $CellContext`a2]], \
$CellContext`sym$86240[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$86240[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$86240[All], 
      All, $CellContext`i$87800], $CellContext`sym$86240[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$86240[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$86240, $CellContext`a3]], \
$CellContext`sym$86240[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$86240[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$86240[All], 
      All, $CellContext`i$87801], $CellContext`sym$86240[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$86240[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$86240, $CellContext`a4]], \
$CellContext`sym$86240[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$86240[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$86240[All], 
      All, $CellContext`i$87802], $CellContext`sym$86240[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$86240[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$86240, $CellContext`a5]], \
$CellContext`sym$86240[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$86240[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$86240[All], 
      All, $CellContext`i$87803], $CellContext`sym$86240[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$86240[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$86240, $CellContext`a6]], \
$CellContext`sym$86240[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$86240[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$86240[All], 
      All, $CellContext`i$87804], $CellContext`sym$86240[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$86240[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$86240, $CellContext`a7]], \
$CellContext`sym$86240[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$86240[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$86240[All], 
      All, $CellContext`i$87805], $CellContext`sym$86240[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$86240[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$86240[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$86240[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$86240, $CellContext`Chla]], \
$CellContext`sym$86240[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$86240[$CellContext`Chla, "raw"] = Part[
      $CellContext`sym$86240[All], 
      All, $CellContext`i$87798], $CellContext`sym$86240[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$86240[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$86240, $CellContext`Cl]], \
$CellContext`sym$86240[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$86240[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$86240[All], 
      All, $CellContext`i$87793], $CellContext`sym$86240[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$86240[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$86240, $CellContext`mnO2]], \
$CellContext`sym$86240[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$86240[$CellContext`mnO2, "raw"] = Part[
      $CellContext`sym$86240[All], 
      All, $CellContext`i$87792], $CellContext`sym$86240[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$86240[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$86240, $CellContext`mxPH]], \
$CellContext`sym$86240[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$86240[$CellContext`mxPH, "raw"] = Part[
      $CellContext`sym$86240[All], 
      All, $CellContext`i$87791], $CellContext`sym$86240[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$86240[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$86240, $CellContext`NH4]], \
$CellContext`sym$86240[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$86240[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$86240[All], 
      All, $CellContext`i$87795], $CellContext`sym$86240[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$86240[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$86240, $CellContext`NO3]], \
$CellContext`sym$86240[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$86240[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$86240[All], 
      All, $CellContext`i$87794], $CellContext`sym$86240[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$86240[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$86240, $CellContext`oPO4]], \
$CellContext`sym$86240[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$86240[$CellContext`oPO4, "raw"] = Part[
      $CellContext`sym$86240[All], 
      All, $CellContext`i$87796], $CellContext`sym$86240[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$86240[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$86240, $CellContext`PO4]], \
$CellContext`sym$86240[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$86240[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$86240[All], 
      All, $CellContext`i$87797], $CellContext`sym$86240[$CellContext`season, 
      "factorized"] = 
    True, $CellContext`sym$86240[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$86240, $CellContext`season]], \
$CellContext`sym$86240[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$86240[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$86240[All], 
      All, $CellContext`i$86241], $CellContext`sym$86240[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$86240[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$86240, $CellContext`size]], \
$CellContext`sym$86240[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$86240[$CellContext`size, "raw"] = Part[
      $CellContext`sym$86240[All], 
      All, $CellContext`i$87789], $CellContext`sym$86240[$CellContext`speed, 
      "factorized"] = 
    True, $CellContext`sym$86240[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$86240, $CellContext`speed]], \
$CellContext`sym$86240[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$86240[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$86240[All], All, $CellContext`i$87790], 
    Attributes[$CellContext`i$87802] = {Temporary}, $CellContext`i$87802 = 15,
     Attributes[$CellContext`i$87789] = {Temporary}, $CellContext`i$87789 = 
    2, $CellContext`med = $CellContext`sym$227704, 
    Attributes[$CellContext`sym$227704] = {
     Temporary}, $CellContext`sym$227704[$CellContext`a1] = Part[
      $CellContext`sym$227704[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$227704[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$227704[$CellContext`a2] = Part[
      $CellContext`sym$227704[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$227704[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$227704[$CellContext`a3] = Part[
      $CellContext`sym$227704[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$227704[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$227704[$CellContext`a4] = Part[
      $CellContext`sym$227704[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$227704[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$227704[$CellContext`a5] = Part[
      $CellContext`sym$227704[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$227704[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$227704[$CellContext`a6] = Part[
      $CellContext`sym$227704[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$227704[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$227704[$CellContext`a7] = Part[
      $CellContext`sym$227704[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$227704[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$227704[
     All] = {{"winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 
       170., 50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
      "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
       558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
      "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 125.667,
        187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
      "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 61.182, 
       138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
      "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222, 
       97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
      "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
       56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
      "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
       111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
      "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 44.667, 
       77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
      "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 71., 
       5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 0.8, 
       17., 0., 0., 2.9, 0., 0., 1.7}, {
      "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 20.75, 
       0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
      "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 19.,
        0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
      "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 41., 
       43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
      "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5, 
       31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
      "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 0.3, 
       52.2, 5., 7.8, 0., 4., 0., 0.}, {
      "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 98.25, 
       1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50., 
       1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
      "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 57.833, 
       0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
      "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 0.8, 
       50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
      "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
       564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
      "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 586.,
        16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
      "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 0.5, 
       15.5, 0., 0., 2.3, 0., 0., 0.}, {
      "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 7.6,
        23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
      "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
       27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
      "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 1.5,
        13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
      "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 44.136, 
       3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
      "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 0.5, 
       29.7, 0., 0., 4.9, 0., 0., 0.}, {
      "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
       Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
      "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 17.1,
        0., 19.6, 0., 0., 0., 2.5}, {
      "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5, 
       33.9, 1., 14.6, 0., 0., 0., 0.}, {
      "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 4.9, 
       3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
      "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 2.8, 
       6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
      "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 130.75, 
       5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
      "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47., 
       2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
      "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23., 
       0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
      "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 58.875, 
       84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
      "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 0.2,
        66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
       Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0., 
       0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
       196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
      "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
       182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
      "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001, 
       296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
      "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 59.429,
        175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
      "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
       344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
      "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 276.85001, 
       326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
      "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 40.667, 
       3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
      "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 3.3, 
       29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
      "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 0.8, 
       54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
       Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 0., 
       0.}, {"spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121.,
        2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 20.812,
        12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
      "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
       49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
      "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 22.9, 
       4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
      "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 11.8, 
       0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818, 
       0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
      "winter", "small", "high", 6.6, 10.8, 
       Missing[], 3.245, 10., 1., 6.5, 
       Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "medium", 5.6, 11.8, 
       Missing[], 2.22, 5., 1., 1., 
       Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 5.7, 10.8, 
       Missing[], 2.55, 10., 1., 4., 
       Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
      "spring", "small", "high", 6.6, 9.5, 
       Missing[], 1.32, 20., 1., 6., 
       Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
      "summer", "small", "high", 6.6, 10.8, 
       Missing[], 2.64, 10., 2., 11., 
       Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
      "autumn", "small", "medium", 6.6, 11.3, 
       Missing[], 4.17, 10., 1., 6., 
       Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
      "spring", "small", "medium", 6.5, 10.4, 
       Missing[], 5.97, 10., 2., 14., 
       Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
      "summer", "small", "medium", 6.4, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 14., 
       Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
      "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 6.667, 
       Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75, 1.,
        20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
      "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2, 
       0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
      "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 0.6,
        55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
      "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 10.75, 
       2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
      "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 0.5, 
       64.2, 0., 3., 0., 0., 0., 0.}, {
      "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75, 
       351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
      "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
       209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
      "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 151.125,
        279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
      "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
       152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
      "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
       58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
      "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
       249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
      "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 100., 
       233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
      "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 215.5, 
       18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
      "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 25.167, 
       102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
      "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
       105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
      "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
       111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
      "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 1.3, 
       6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
      "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 56.667, 
       2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
      "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 4.3,
        1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
      "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
       104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
      "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 69.93,
        3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
      "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
       214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
      "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
       254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
      "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 57.6,
        169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
      "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
       412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
      "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
       282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
      "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
       197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
      "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 267.75, 
       391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
      "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 191.75, 
       265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
      "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
       232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
      "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 144.66701, 
       244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
      "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 218., 
       6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
      "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 138.5,
        20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
      "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222, 
       239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
      "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
       235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
      "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75, 
       205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
      "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 31.333, 
       211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
      "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625, 
       186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
      "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 12.889, 
       154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
      "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 51.111, 
       183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
      "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
       292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
      "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
       285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
      "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
       201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
      "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
       275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
      "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
       124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
      "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 60.833, 
       141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
      "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71., 
       132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
      "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
       17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
      "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 0.3, 
       46.6, 0., 2.5, 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 8.692, 
       16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
      "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 37.857, 
       102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
      "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
       86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
      "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
       10.111, 
       Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 16.833, 
       18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
      "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545, 
       13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
      "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 261.60001, 
       432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
      "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
       320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
      "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 144., 
       287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
      "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
       166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
      "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
       222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
      "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 36.909, 
       122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
      "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556, 
       127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
      "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
       89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
      "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 55., 
       284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
      "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 102.333, 
       277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
      "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 75.875, 
       177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
      "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
       72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
      "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 48.667, 
       82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
      "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 48.625, 
       66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
      "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 23., 
       173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
      "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 317., 
       5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
      "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 84., 
       4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
      "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 2., 
       10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
      "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 88.5, 
       2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
      "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115., 
       11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
      "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 98.143, 
       2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
      "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
       143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
      "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
       197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
      "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 1., 
       19., 0., 22., 5., 1.1, 5.4, 0.}, {
      "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 10.583, 
       23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
      "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 200.231, 
       19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
      "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 77.333, 
       147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
      "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5, 
       276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
      "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
       123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
      "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 75.207,
        23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
      "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 116.2,
        7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
      "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
       188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
      "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
       72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
      "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 16., 
       0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
      "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 34., 
       53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
      "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 27.5, 
       76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
      "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
       58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
      "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 175.66701, 
       361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
      "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
       22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
      "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 26.8,
        0., 28., 0., 0., 0., 0., 15.1}, {
      "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
       54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
      "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333, 
       34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
      "spring", "large", "low", 9., 5.8, 
       Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 0., 
       0.}, {"spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
       151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
      "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
       269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
      "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 46.438, 
       81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
      "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 85., 
       2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
      "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 66.4, 
       171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
      "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 102.364, 
       232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
      "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 84.3, 
       146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
      "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
       246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
      "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 205.636, 
       219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
      "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 236.39999,
        272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
      "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 1081.66003, 
       346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 5.9, 1.7}, {
      "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 82.222,
        167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
      "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 64.389, 
       137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
      "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 87.333,
        194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
      "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
       159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
      "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 21.3, 
       1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
      "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 0.6,
        37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
      "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
       14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
      "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222, 7.,
        1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 0.8, 
       50.4, 3.8, 0., 0., 0., 0., 0.}, {
      "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 7.654, 
       4., 56.8, 5., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 2.86, 
       17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
      "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 56.091, 
       Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
      "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
       52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
      "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 104.727, 
       228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
      "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 85.4, 
       17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
      "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 87.125,
        14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
      "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 101.455, 
       18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
      "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 50.889, 
       127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
      "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
       81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
      "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 19.727, 
       50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
      "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111, 
       120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
      "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 51.111, 
       91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
      "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 19.111, 
       61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
      "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625, 
       79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
      "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333, 
       75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
      "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333, 
       140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
      "winter", "large", "medium", 8., 7.6, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
      "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
       140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 
       5.8}}, $CellContext`sym$227704[$CellContext`Chla] = Part[
      $CellContext`sym$227704[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$227704[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$227704[$CellContext`Cl] = Part[
      $CellContext`sym$227704[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$227704[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$227704[$CellContext`mnO2] = Part[
      $CellContext`sym$227704[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$227704[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$227704[$CellContext`mxPH] = Part[
      $CellContext`sym$227704[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$227704[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$227704[$CellContext`NH4] = Part[
      $CellContext`sym$227704[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$227704[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$227704[$CellContext`NO3] = Part[
      $CellContext`sym$227704[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$227704[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$227704[$CellContext`oPO4] = Part[
      $CellContext`sym$227704[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$227704[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$227704[$CellContext`PO4] = Part[
      $CellContext`sym$227704[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$227704[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$227704[$CellContext`season] = Part[
      $CellContext`sym$227704[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$227704[$CellContext`season, 
         "missing"]]]], $CellContext`sym$227704[$CellContext`size] = Part[
      $CellContext`sym$227704[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$227704[$CellContext`size, 
         "missing"]]]], $CellContext`sym$227704[$CellContext`speed] = Part[
      $CellContext`sym$227704[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$227704[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$227704[$CellContext`a1, 
      "factorized"] = 
    False, $CellContext`sym$227704[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$227704[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$227704[All], 
      All, $CellContext`i$227716], $CellContext`sym$227704[$CellContext`a2, 
      "factorized"] = 
    False, $CellContext`sym$227704[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$227704[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$227704[All], 
      All, $CellContext`i$227717], $CellContext`sym$227704[$CellContext`a3, 
      "factorized"] = 
    False, $CellContext`sym$227704[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$227704[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$227704[All], 
      All, $CellContext`i$227718], $CellContext`sym$227704[$CellContext`a4, 
      "factorized"] = 
    False, $CellContext`sym$227704[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$227704[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$227704[All], 
      All, $CellContext`i$227719], $CellContext`sym$227704[$CellContext`a5, 
      "factorized"] = 
    False, $CellContext`sym$227704[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$227704[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$227704[All], 
      All, $CellContext`i$227720], $CellContext`sym$227704[$CellContext`a6, 
      "factorized"] = 
    False, $CellContext`sym$227704[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$227704[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$227704[All], 
      All, $CellContext`i$227721], $CellContext`sym$227704[$CellContext`a7, 
      "factorized"] = 
    False, $CellContext`sym$227704[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$227704[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$227704[All], 
      All, $CellContext`i$227722], $CellContext`sym$227704[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$227704[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed}, $CellContext`sym$227704[$CellContext`Chla, "factorized"] = 
    False, $CellContext`sym$227704[$CellContext`Chla, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {63}, {116}, {184}, {
     199}}, $CellContext`sym$227704[$CellContext`Chla, "raw"] = Part[
      $CellContext`sym$227704[All], 
      All, $CellContext`i$227715], $CellContext`sym$227704[$CellContext`Cl, 
      "factorized"] = 
    False, $CellContext`sym$227704[$CellContext`Cl, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {161}, {
     199}}, $CellContext`sym$227704[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$227704[All], 
      All, $CellContext`i$227710], $CellContext`sym$227704[$CellContext`mnO2, 
      "factorized"] = 
    False, $CellContext`sym$227704[$CellContext`mnO2, "missing"] = {{38}, {
     62}}, $CellContext`sym$227704[$CellContext`mnO2, "raw"] = Part[
      $CellContext`sym$227704[All], 
      All, $CellContext`i$227709], $CellContext`sym$227704[$CellContext`mxPH, 
      "factorized"] = 
    False, $CellContext`sym$227704[$CellContext`mxPH, "missing"] = {{
     48}}, $CellContext`sym$227704[$CellContext`mxPH, "raw"] = Part[
      $CellContext`sym$227704[All], 
      All, $CellContext`i$227708], $CellContext`sym$227704[$CellContext`NH4, 
      "factorized"] = 
    False, $CellContext`sym$227704[$CellContext`NH4, "missing"] = {{62}, {
     199}}, $CellContext`sym$227704[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$227704[All], 
      All, $CellContext`i$227712], $CellContext`sym$227704[$CellContext`NO3, 
      "factorized"] = 
    False, $CellContext`sym$227704[$CellContext`NO3, "missing"] = {{62}, {
     199}}, $CellContext`sym$227704[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$227704[All], 
      All, $CellContext`i$227711], $CellContext`sym$227704[$CellContext`oPO4, 
      "factorized"] = 
    False, $CellContext`sym$227704[$CellContext`oPO4, "missing"] = {{62}, {
     199}}, $CellContext`sym$227704[$CellContext`oPO4, "raw"] = Part[
      $CellContext`sym$227704[All], 
      All, $CellContext`i$227713], $CellContext`sym$227704[$CellContext`PO4, 
      "factorized"] = 
    False, $CellContext`sym$227704[$CellContext`PO4, "missing"] = {{28}, {
     199}}, $CellContext`sym$227704[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$227704[All], 
      All, $CellContext`i$227714], \
$CellContext`sym$227704[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$227704[$CellContext`season, "factors"] = 
    Part[{"autumn", "spring", "summer", "winter"}, 
      $CellContext`fordering[$CellContext`sym$227704, $CellContext`season]], \
$CellContext`sym$227704[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$227704[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$227704[All], 
      All, $CellContext`i$227705], $CellContext`sym$227704[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$227704[$CellContext`size, "factors"] = 
    Part[{"large", "medium", "small"}, 
      $CellContext`fordering[$CellContext`sym$227704, $CellContext`size]], \
$CellContext`sym$227704[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$227704[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$227704[All], 
      All, $CellContext`i$227706], $CellContext`sym$227704[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$227704[$CellContext`speed, "factors"] = 
    Part[{"high", "low", "medium"}, 
      $CellContext`fordering[$CellContext`sym$227704, $CellContext`speed]], \
$CellContext`sym$227704[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$227704[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$227704[All], All, $CellContext`i$227707], 
    Attributes[$CellContext`i$227705] = {Temporary}, $CellContext`i$227705 = 
    1, Attributes[$CellContext`i$227710] = {Temporary}, $CellContext`i$227710 = 
    6, Attributes[$CellContext`i$227714] = {Temporary}, $CellContext`i$227714 = 
    10, Attributes[$CellContext`i$227718] = {
     Temporary}, $CellContext`i$227718 = 14, 
    Attributes[$CellContext`i$227720] = {Temporary}, $CellContext`i$227720 = 
    16, Attributes[$CellContext`i$227709] = {
     Temporary}, $CellContext`i$227709 = 5, 
    Attributes[$CellContext`i$227706] = {Temporary}, $CellContext`i$227706 = 
    2, Attributes[$CellContext`i$227713] = {Temporary}, $CellContext`i$227713 = 
    9, Attributes[$CellContext`i$227707] = {Temporary}, $CellContext`i$227707 = 
    3, Attributes[$CellContext`i$227711] = {Temporary}, $CellContext`i$227711 = 
    7, Attributes[$CellContext`i$227708] = {Temporary}, $CellContext`i$227708 = 
    4, Attributes[$CellContext`i$227717] = {Temporary}, $CellContext`i$227717 = 
    13, Attributes[$CellContext`i$227712] = {
     Temporary}, $CellContext`i$227712 = 8, 
    Attributes[$CellContext`i$227719] = {Temporary}, $CellContext`i$227719 = 
    15, Attributes[$CellContext`i$227722] = {
     Temporary}, $CellContext`i$227722 = 18, 
    Attributes[$CellContext`i$227716] = {Temporary}, $CellContext`i$227716 = 
    12, Attributes[$CellContext`i$227721] = {
     Temporary}, $CellContext`i$227721 = 17, 
    Attributes[$CellContext`i$227715] = {Temporary}, $CellContext`i$227715 = 
    11, Attributes[$CellContext`i$87793] = {Temporary}, $CellContext`i$87793 = 
    6, Attributes[$CellContext`i$87790] = {Temporary}, $CellContext`i$87790 = 
    3, Attributes[$CellContext`i$87798] = {Temporary}, $CellContext`i$87798 = 
    11, Attributes[$CellContext`i$87799] = {Temporary}, $CellContext`i$87799 = 
    12, Attributes[$CellContext`i$87795] = {Temporary}, $CellContext`i$87795 = 
    8, Attributes[$CellContext`i$87792] = {Temporary}, $CellContext`i$87792 = 
    5, Attributes[$CellContext`i$86241] = {Temporary}, $CellContext`i$86241 = 
    1, Attributes[$CellContext`i$87800] = {Temporary}, $CellContext`i$87800 = 
    13, Attributes[$CellContext`i$87797] = {Temporary}, $CellContext`i$87797 = 
    10, Attributes[$CellContext`i$87804] = {Temporary}, $CellContext`i$87804 = 
    17, Attributes[$CellContext`i$87796] = {Temporary}, $CellContext`i$87796 = 
    9, Attributes[$CellContext`i$87791] = {Temporary}, $CellContext`i$87791 = 
    4, Attributes[$CellContext`i$87805] = {Temporary}, $CellContext`i$87805 = 
    18, Attributes[$CellContext`i$87801] = {Temporary}, $CellContext`i$87801 = 
    14, Attributes[$CellContext`i$87803] = {Temporary}, $CellContext`i$87803 = 
    16, Attributes[$CellContext`i$87794] = {Temporary}, $CellContext`i$87794 = 
    7, Attributes[$CellContext`sym$137599] = {
     Temporary}, $CellContext`sym$137599[$CellContext`a1] = Part[
      $CellContext`sym$137599[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$137599[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$137599[$CellContext`a2] = Part[
      $CellContext`sym$137599[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$137599[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$137599[$CellContext`a3] = Part[
      $CellContext`sym$137599[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$137599[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$137599[$CellContext`a4] = Part[
      $CellContext`sym$137599[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$137599[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$137599[$CellContext`a5] = Part[
      $CellContext`sym$137599[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$137599[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$137599[$CellContext`a6] = Part[
      $CellContext`sym$137599[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$137599[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$137599[$CellContext`a7] = Part[
      $CellContext`sym$137599[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$137599[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$137599[All] = $CellContext`med[
     All], $CellContext`sym$137599[$CellContext`Chla] = Part[
      $CellContext`sym$137599[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$137599[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$137599[$CellContext`Cl] = Part[
      $CellContext`sym$137599[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$137599[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$137599[$CellContext`mnO2] = Part[
      $CellContext`sym$137599[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$137599[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$137599[$CellContext`mxPH] = Part[
      $CellContext`sym$137599[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$137599[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$137599[$CellContext`NH4] = Part[
      $CellContext`sym$137599[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$137599[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$137599[$CellContext`NO3] = Part[
      $CellContext`sym$137599[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$137599[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$137599[$CellContext`oPO4] = Part[
      $CellContext`sym$137599[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$137599[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$137599[$CellContext`PO4] = Part[
      $CellContext`sym$137599[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$137599[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$137599[$CellContext`season] = Part[
      $CellContext`sym$137599[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$137599[$CellContext`season, 
         "missing"]]]], $CellContext`sym$137599[$CellContext`size] = Part[
      $CellContext`sym$137599[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$137599[$CellContext`size, 
         "missing"]]]], $CellContext`sym$137599[$CellContext`speed] = Part[
      $CellContext`sym$137599[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$137599[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$137599[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$137599[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$137599, $CellContext`a1]], \
$CellContext`sym$137599[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$137599[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$137599[All], 
      All, $CellContext`i$139158], $CellContext`sym$137599[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$137599[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$137599, $CellContext`a2]], \
$CellContext`sym$137599[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$137599[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$137599[All], 
      All, $CellContext`i$139159], $CellContext`sym$137599[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$137599[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$137599, $CellContext`a3]], \
$CellContext`sym$137599[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$137599[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$137599[All], 
      All, $CellContext`i$139160], $CellContext`sym$137599[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$137599[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$137599, $CellContext`a4]], \
$CellContext`sym$137599[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$137599[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$137599[All], 
      All, $CellContext`i$139161], $CellContext`sym$137599[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$137599[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$137599, $CellContext`a5]], \
$CellContext`sym$137599[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$137599[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$137599[All], 
      All, $CellContext`i$139162], $CellContext`sym$137599[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$137599[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$137599, $CellContext`a6]], \
$CellContext`sym$137599[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$137599[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$137599[All], 
      All, $CellContext`i$139163], $CellContext`sym$137599[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$137599[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$137599, $CellContext`a7]], \
$CellContext`sym$137599[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$137599[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$137599[All], 
      All, $CellContext`i$139164], $CellContext`sym$137599[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$137599[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$137599[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$137599[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$137599, $CellContext`Chla]], \
$CellContext`sym$137599[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$137599[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$137599[All], 
      All, $CellContext`i$139157], $CellContext`sym$137599[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$137599[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$137599, $CellContext`Cl]], \
$CellContext`sym$137599[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$137599[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$137599[All], 
      All, $CellContext`i$139152], $CellContext`sym$137599[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$137599[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$137599, $CellContext`mnO2]], \
$CellContext`sym$137599[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$137599[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$137599[All], 
      All, $CellContext`i$139151], $CellContext`sym$137599[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$137599[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$137599, $CellContext`mxPH]], \
$CellContext`sym$137599[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$137599[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$137599[All], 
      All, $CellContext`i$139150], $CellContext`sym$137599[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$137599[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$137599, $CellContext`NH4]], \
$CellContext`sym$137599[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$137599[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$137599[All], 
      All, $CellContext`i$139154], $CellContext`sym$137599[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$137599[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$137599, $CellContext`NO3]], \
$CellContext`sym$137599[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$137599[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$137599[All], 
      All, $CellContext`i$139153], $CellContext`sym$137599[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$137599[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$137599, $CellContext`oPO4]], \
$CellContext`sym$137599[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$137599[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$137599[All], 
      All, $CellContext`i$139155], $CellContext`sym$137599[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$137599[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$137599, $CellContext`PO4]], \
$CellContext`sym$137599[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$137599[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$137599[All], 
      All, $CellContext`i$139156], \
$CellContext`sym$137599[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$137599[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$137599, $CellContext`season]], \
$CellContext`sym$137599[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$137599[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$137599[All], 
      All, $CellContext`i$137600], $CellContext`sym$137599[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$137599[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$137599, $CellContext`size]], \
$CellContext`sym$137599[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$137599[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$137599[All], 
      All, $CellContext`i$139148], $CellContext`sym$137599[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$137599[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$137599, $CellContext`speed]], \
$CellContext`sym$137599[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$137599[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$137599[All], All, $CellContext`i$139149], 
    Attributes[$CellContext`i$139163] = {Temporary}, $CellContext`i$139163 = 
    17, Attributes[$CellContext`i$139162] = {
     Temporary}, $CellContext`i$139162 = 16, 
    Attributes[$CellContext`i$139148] = {Temporary}, $CellContext`i$139148 = 
    2, Attributes[$CellContext`i$139158] = {Temporary}, $CellContext`i$139158 = 
    12, Attributes[$CellContext`i$139159] = {
     Temporary}, $CellContext`i$139159 = 13, 
    Attributes[$CellContext`i$139153] = {Temporary}, $CellContext`i$139153 = 
    7, Attributes[$CellContext`i$139164] = {Temporary}, $CellContext`i$139164 = 
    18, Attributes[$CellContext`i$137600] = {
     Temporary}, $CellContext`i$137600 = 1, 
    Attributes[$CellContext`i$139154] = {Temporary}, $CellContext`i$139154 = 
    8, Attributes[$CellContext`i$139157] = {Temporary}, $CellContext`i$139157 = 
    11, Attributes[$CellContext`i$139155] = {
     Temporary}, $CellContext`i$139155 = 9, 
    Attributes[$CellContext`i$139151] = {Temporary}, $CellContext`i$139151 = 
    5, Attributes[$CellContext`i$139160] = {Temporary}, $CellContext`i$139160 = 
    14, Attributes[$CellContext`i$139152] = {
     Temporary}, $CellContext`i$139152 = 6, 
    Attributes[$CellContext`i$139161] = {Temporary}, $CellContext`i$139161 = 
    15, Attributes[$CellContext`i$139149] = {
     Temporary}, $CellContext`i$139149 = 3, 
    Attributes[$CellContext`i$139150] = {Temporary}, $CellContext`i$139150 = 
    4, Attributes[$CellContext`i$139156] = {Temporary}, $CellContext`i$139156 = 
    10, Attributes[$CellContext`sym$227398] = {
     Temporary}, $CellContext`sym$227398[$CellContext`a1] = Part[
      $CellContext`sym$227398[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227398[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$227398[$CellContext`a2] = Part[
      $CellContext`sym$227398[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227398[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$227398[$CellContext`a3] = Part[
      $CellContext`sym$227398[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227398[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$227398[$CellContext`a4] = Part[
      $CellContext`sym$227398[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227398[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$227398[$CellContext`a5] = Part[
      $CellContext`sym$227398[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227398[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$227398[$CellContext`a6] = Part[
      $CellContext`sym$227398[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227398[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$227398[$CellContext`a7] = Part[
      $CellContext`sym$227398[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227398[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$227398[All] = $CellContext`med[
     All], $CellContext`sym$227398[$CellContext`Chla] = Part[
      $CellContext`sym$227398[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227398[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$227398[$CellContext`Cl] = Part[
      $CellContext`sym$227398[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227398[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$227398[$CellContext`mnO2] = Part[
      $CellContext`sym$227398[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227398[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$227398[$CellContext`mxPH] = Part[
      $CellContext`sym$227398[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227398[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$227398[$CellContext`NH4] = Part[
      $CellContext`sym$227398[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227398[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$227398[$CellContext`NO3] = Part[
      $CellContext`sym$227398[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227398[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$227398[$CellContext`oPO4] = Part[
      $CellContext`sym$227398[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227398[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$227398[$CellContext`PO4] = Part[
      $CellContext`sym$227398[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227398[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$227398[$CellContext`season] = Part[
      $CellContext`sym$227398[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227398[$CellContext`season, 
         "missing"]]]], $CellContext`sym$227398[$CellContext`size] = Part[
      $CellContext`sym$227398[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227398[$CellContext`size, 
         "missing"]]]], $CellContext`sym$227398[$CellContext`speed] = Part[
      $CellContext`sym$227398[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227398[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$227398[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$227398[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227398, $CellContext`a1]], \
$CellContext`sym$227398[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$227398[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$227398[All], 
      All, $CellContext`i$227410], $CellContext`sym$227398[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$227398[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227398, $CellContext`a2]], \
$CellContext`sym$227398[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$227398[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$227398[All], 
      All, $CellContext`i$227411], $CellContext`sym$227398[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$227398[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227398, $CellContext`a3]], \
$CellContext`sym$227398[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$227398[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$227398[All], 
      All, $CellContext`i$227412], $CellContext`sym$227398[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$227398[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227398, $CellContext`a4]], \
$CellContext`sym$227398[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$227398[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$227398[All], 
      All, $CellContext`i$227413], $CellContext`sym$227398[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$227398[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227398, $CellContext`a5]], \
$CellContext`sym$227398[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$227398[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$227398[All], 
      All, $CellContext`i$227414], $CellContext`sym$227398[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$227398[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227398, $CellContext`a6]], \
$CellContext`sym$227398[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$227398[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$227398[All], 
      All, $CellContext`i$227415], $CellContext`sym$227398[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$227398[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227398, $CellContext`a7]], \
$CellContext`sym$227398[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$227398[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$227398[All], 
      All, $CellContext`i$227416], $CellContext`sym$227398[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$227398[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$227398[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$227398[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227398, $CellContext`Chla]], \
$CellContext`sym$227398[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$227398[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$227398[All], 
      All, $CellContext`i$227409], $CellContext`sym$227398[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$227398[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227398, $CellContext`Cl]], \
$CellContext`sym$227398[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$227398[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$227398[All], 
      All, $CellContext`i$227404], $CellContext`sym$227398[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$227398[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227398, $CellContext`mnO2]], \
$CellContext`sym$227398[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$227398[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$227398[All], 
      All, $CellContext`i$227403], $CellContext`sym$227398[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$227398[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227398, $CellContext`mxPH]], \
$CellContext`sym$227398[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$227398[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$227398[All], 
      All, $CellContext`i$227402], $CellContext`sym$227398[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$227398[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227398, $CellContext`NH4]], \
$CellContext`sym$227398[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$227398[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$227398[All], 
      All, $CellContext`i$227406], $CellContext`sym$227398[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$227398[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227398, $CellContext`NO3]], \
$CellContext`sym$227398[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$227398[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$227398[All], 
      All, $CellContext`i$227405], $CellContext`sym$227398[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$227398[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227398, $CellContext`oPO4]], \
$CellContext`sym$227398[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$227398[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$227398[All], 
      All, $CellContext`i$227407], $CellContext`sym$227398[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$227398[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227398, $CellContext`PO4]], \
$CellContext`sym$227398[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$227398[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$227398[All], 
      All, $CellContext`i$227408], \
$CellContext`sym$227398[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$227398[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227398, $CellContext`season]], \
$CellContext`sym$227398[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$227398[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$227398[All], 
      All, $CellContext`i$227399], $CellContext`sym$227398[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$227398[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227398, $CellContext`size]], \
$CellContext`sym$227398[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$227398[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$227398[All], 
      All, $CellContext`i$227400], $CellContext`sym$227398[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$227398[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227398, $CellContext`speed]], \
$CellContext`sym$227398[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$227398[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$227398[All], All, $CellContext`i$227401], 
    Attributes[$CellContext`i$227404] = {Temporary}, $CellContext`i$227404 = 
    6, Attributes[$CellContext`i$227406] = {Temporary}, $CellContext`i$227406 = 
    8, Attributes[$CellContext`i$227409] = {Temporary}, $CellContext`i$227409 = 
    11, Attributes[$CellContext`i$227412] = {
     Temporary}, $CellContext`i$227412 = 14, 
    Attributes[$CellContext`i$227416] = {Temporary}, $CellContext`i$227416 = 
    18, Attributes[$CellContext`i$227411] = {
     Temporary}, $CellContext`i$227411 = 13, 
    Attributes[$CellContext`i$227407] = {Temporary}, $CellContext`i$227407 = 
    9, Attributes[$CellContext`i$227413] = {Temporary}, $CellContext`i$227413 = 
    15, Attributes[$CellContext`i$227402] = {
     Temporary}, $CellContext`i$227402 = 4, 
    Attributes[$CellContext`i$227401] = {Temporary}, $CellContext`i$227401 = 
    3, Attributes[$CellContext`i$227399] = {Temporary}, $CellContext`i$227399 = 
    1, Attributes[$CellContext`i$227410] = {Temporary}, $CellContext`i$227410 = 
    12, Attributes[$CellContext`i$227405] = {
     Temporary}, $CellContext`i$227405 = 7, 
    Attributes[$CellContext`i$227403] = {Temporary}, $CellContext`i$227403 = 
    5, Attributes[$CellContext`i$227408] = {Temporary}, $CellContext`i$227408 = 
    10, Attributes[$CellContext`i$227414] = {
     Temporary}, $CellContext`i$227414 = 16, 
    Attributes[$CellContext`i$227400] = {Temporary}, $CellContext`i$227400 = 
    2, Attributes[$CellContext`i$227415] = {Temporary}, $CellContext`i$227415 = 
    17, Attributes[$CellContext`sym$182259] = {
     Temporary}, $CellContext`sym$182259[$CellContext`a1] = Part[
      $CellContext`sym$182259[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$182259[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$182259[$CellContext`a2] = Part[
      $CellContext`sym$182259[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$182259[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$182259[$CellContext`a3] = Part[
      $CellContext`sym$182259[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$182259[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$182259[$CellContext`a4] = Part[
      $CellContext`sym$182259[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$182259[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$182259[$CellContext`a5] = Part[
      $CellContext`sym$182259[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$182259[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$182259[$CellContext`a6] = Part[
      $CellContext`sym$182259[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$182259[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$182259[$CellContext`a7] = Part[
      $CellContext`sym$182259[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$182259[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$182259[All] = $CellContext`med[
     All], $CellContext`sym$182259[$CellContext`Chla] = Part[
      $CellContext`sym$182259[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$182259[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$182259[$CellContext`Cl] = Part[
      $CellContext`sym$182259[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$182259[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$182259[$CellContext`mnO2] = Part[
      $CellContext`sym$182259[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$182259[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$182259[$CellContext`mxPH] = Part[
      $CellContext`sym$182259[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$182259[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$182259[$CellContext`NH4] = Part[
      $CellContext`sym$182259[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$182259[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$182259[$CellContext`NO3] = Part[
      $CellContext`sym$182259[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$182259[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$182259[$CellContext`oPO4] = Part[
      $CellContext`sym$182259[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$182259[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$182259[$CellContext`PO4] = Part[
      $CellContext`sym$182259[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$182259[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$182259[$CellContext`season] = Part[
      $CellContext`sym$182259[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$182259[$CellContext`season, 
         "missing"]]]], $CellContext`sym$182259[$CellContext`size] = Part[
      $CellContext`sym$182259[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$182259[$CellContext`size, 
         "missing"]]]], $CellContext`sym$182259[$CellContext`speed] = Part[
      $CellContext`sym$182259[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$182259[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$182259[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$182259[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$182259, $CellContext`a1]], \
$CellContext`sym$182259[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$182259[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$182259[All], 
      All, $CellContext`i$183818], $CellContext`sym$182259[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$182259[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$182259, $CellContext`a2]], \
$CellContext`sym$182259[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$182259[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$182259[All], 
      All, $CellContext`i$183819], $CellContext`sym$182259[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$182259[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$182259, $CellContext`a3]], \
$CellContext`sym$182259[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$182259[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$182259[All], 
      All, $CellContext`i$183820], $CellContext`sym$182259[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$182259[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$182259, $CellContext`a4]], \
$CellContext`sym$182259[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$182259[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$182259[All], 
      All, $CellContext`i$183821], $CellContext`sym$182259[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$182259[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$182259, $CellContext`a5]], \
$CellContext`sym$182259[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$182259[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$182259[All], 
      All, $CellContext`i$183822], $CellContext`sym$182259[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$182259[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$182259, $CellContext`a6]], \
$CellContext`sym$182259[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$182259[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$182259[All], 
      All, $CellContext`i$183823], $CellContext`sym$182259[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$182259[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$182259, $CellContext`a7]], \
$CellContext`sym$182259[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$182259[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$182259[All], 
      All, $CellContext`i$183824], $CellContext`sym$182259[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$182259[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$182259[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$182259[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$182259, $CellContext`Chla]], \
$CellContext`sym$182259[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$182259[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$182259[All], 
      All, $CellContext`i$183817], $CellContext`sym$182259[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$182259[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$182259, $CellContext`Cl]], \
$CellContext`sym$182259[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$182259[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$182259[All], 
      All, $CellContext`i$183812], $CellContext`sym$182259[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$182259[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$182259, $CellContext`mnO2]], \
$CellContext`sym$182259[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$182259[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$182259[All], 
      All, $CellContext`i$183811], $CellContext`sym$182259[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$182259[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$182259, $CellContext`mxPH]], \
$CellContext`sym$182259[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$182259[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$182259[All], 
      All, $CellContext`i$183810], $CellContext`sym$182259[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$182259[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$182259, $CellContext`NH4]], \
$CellContext`sym$182259[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$182259[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$182259[All], 
      All, $CellContext`i$183814], $CellContext`sym$182259[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$182259[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$182259, $CellContext`NO3]], \
$CellContext`sym$182259[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$182259[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$182259[All], 
      All, $CellContext`i$183813], $CellContext`sym$182259[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$182259[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$182259, $CellContext`oPO4]], \
$CellContext`sym$182259[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$182259[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$182259[All], 
      All, $CellContext`i$183815], $CellContext`sym$182259[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$182259[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$182259, $CellContext`PO4]], \
$CellContext`sym$182259[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$182259[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$182259[All], 
      All, $CellContext`i$183816], \
$CellContext`sym$182259[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$182259[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$182259, $CellContext`season]], \
$CellContext`sym$182259[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$182259[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$182259[All], 
      All, $CellContext`i$182260], $CellContext`sym$182259[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$182259[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$182259, $CellContext`size]], \
$CellContext`sym$182259[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$182259[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$182259[All], 
      All, $CellContext`i$183808], $CellContext`sym$182259[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$182259[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$182259, $CellContext`speed]], \
$CellContext`sym$182259[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$182259[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$182259[All], All, $CellContext`i$183809], 
    Attributes[$CellContext`i$183815] = {Temporary}, $CellContext`i$183815 = 
    9, Attributes[$CellContext`i$183820] = {Temporary}, $CellContext`i$183820 = 
    14, Attributes[$CellContext`i$183810] = {
     Temporary}, $CellContext`i$183810 = 4, 
    Attributes[$CellContext`i$183822] = {Temporary}, $CellContext`i$183822 = 
    16, Attributes[$CellContext`i$183809] = {
     Temporary}, $CellContext`i$183809 = 3, 
    Attributes[$CellContext`i$182260] = {Temporary}, $CellContext`i$182260 = 
    1, Attributes[$CellContext`i$183817] = {Temporary}, $CellContext`i$183817 = 
    11, Attributes[$CellContext`i$183814] = {
     Temporary}, $CellContext`i$183814 = 8, 
    Attributes[$CellContext`i$183808] = {Temporary}, $CellContext`i$183808 = 
    2, Attributes[$CellContext`i$183816] = {Temporary}, $CellContext`i$183816 = 
    10, Attributes[$CellContext`i$183818] = {
     Temporary}, $CellContext`i$183818 = 12, 
    Attributes[$CellContext`i$183812] = {Temporary}, $CellContext`i$183812 = 
    6, Attributes[$CellContext`i$183813] = {Temporary}, $CellContext`i$183813 = 
    7, Attributes[$CellContext`i$183821] = {Temporary}, $CellContext`i$183821 = 
    15, Attributes[$CellContext`i$183824] = {
     Temporary}, $CellContext`i$183824 = 18, 
    Attributes[$CellContext`i$183823] = {Temporary}, $CellContext`i$183823 = 
    17, Attributes[$CellContext`i$183811] = {
     Temporary}, $CellContext`i$183811 = 5, 
    Attributes[$CellContext`i$183819] = {Temporary}, $CellContext`i$183819 = 
    13, Attributes[$CellContext`sym$206822] = {
     Temporary}, $CellContext`sym$206822[$CellContext`a1] = Part[
      $CellContext`sym$206822[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$206822[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$206822[$CellContext`a2] = Part[
      $CellContext`sym$206822[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$206822[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$206822[$CellContext`a3] = Part[
      $CellContext`sym$206822[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$206822[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$206822[$CellContext`a4] = Part[
      $CellContext`sym$206822[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$206822[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$206822[$CellContext`a5] = Part[
      $CellContext`sym$206822[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$206822[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$206822[$CellContext`a6] = Part[
      $CellContext`sym$206822[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$206822[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$206822[$CellContext`a7] = Part[
      $CellContext`sym$206822[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$206822[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$206822[All] = $CellContext`med[
     All], $CellContext`sym$206822[$CellContext`Chla] = Part[
      $CellContext`sym$206822[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$206822[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$206822[$CellContext`Cl] = Part[
      $CellContext`sym$206822[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$206822[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$206822[$CellContext`mnO2] = Part[
      $CellContext`sym$206822[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$206822[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$206822[$CellContext`mxPH] = Part[
      $CellContext`sym$206822[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$206822[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$206822[$CellContext`NH4] = Part[
      $CellContext`sym$206822[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$206822[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$206822[$CellContext`NO3] = Part[
      $CellContext`sym$206822[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$206822[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$206822[$CellContext`oPO4] = Part[
      $CellContext`sym$206822[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$206822[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$206822[$CellContext`PO4] = Part[
      $CellContext`sym$206822[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$206822[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$206822[$CellContext`season] = Part[
      $CellContext`sym$206822[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$206822[$CellContext`season, 
         "missing"]]]], $CellContext`sym$206822[$CellContext`size] = Part[
      $CellContext`sym$206822[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$206822[$CellContext`size, 
         "missing"]]]], $CellContext`sym$206822[$CellContext`speed] = Part[
      $CellContext`sym$206822[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$206822[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$206822[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$206822[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$206822, $CellContext`a1]], \
$CellContext`sym$206822[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$206822[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$206822[All], 
      All, $CellContext`i$208381], $CellContext`sym$206822[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$206822[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$206822, $CellContext`a2]], \
$CellContext`sym$206822[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$206822[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$206822[All], 
      All, $CellContext`i$208382], $CellContext`sym$206822[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$206822[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$206822, $CellContext`a3]], \
$CellContext`sym$206822[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$206822[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$206822[All], 
      All, $CellContext`i$208383], $CellContext`sym$206822[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$206822[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$206822, $CellContext`a4]], \
$CellContext`sym$206822[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$206822[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$206822[All], 
      All, $CellContext`i$208384], $CellContext`sym$206822[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$206822[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$206822, $CellContext`a5]], \
$CellContext`sym$206822[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$206822[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$206822[All], 
      All, $CellContext`i$208385], $CellContext`sym$206822[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$206822[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$206822, $CellContext`a6]], \
$CellContext`sym$206822[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$206822[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$206822[All], 
      All, $CellContext`i$208386], $CellContext`sym$206822[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$206822[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$206822, $CellContext`a7]], \
$CellContext`sym$206822[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$206822[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$206822[All], 
      All, $CellContext`i$208387], $CellContext`sym$206822[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$206822[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$206822[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$206822[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$206822, $CellContext`Chla]], \
$CellContext`sym$206822[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$206822[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$206822[All], 
      All, $CellContext`i$208380], $CellContext`sym$206822[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$206822[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$206822, $CellContext`Cl]], \
$CellContext`sym$206822[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$206822[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$206822[All], 
      All, $CellContext`i$208375], $CellContext`sym$206822[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$206822[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$206822, $CellContext`mnO2]], \
$CellContext`sym$206822[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$206822[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$206822[All], 
      All, $CellContext`i$208374], $CellContext`sym$206822[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$206822[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$206822, $CellContext`mxPH]], \
$CellContext`sym$206822[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$206822[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$206822[All], 
      All, $CellContext`i$208373], $CellContext`sym$206822[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$206822[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$206822, $CellContext`NH4]], \
$CellContext`sym$206822[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$206822[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$206822[All], 
      All, $CellContext`i$208377], $CellContext`sym$206822[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$206822[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$206822, $CellContext`NO3]], \
$CellContext`sym$206822[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$206822[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$206822[All], 
      All, $CellContext`i$208376], $CellContext`sym$206822[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$206822[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$206822, $CellContext`oPO4]], \
$CellContext`sym$206822[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$206822[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$206822[All], 
      All, $CellContext`i$208378], $CellContext`sym$206822[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$206822[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$206822, $CellContext`PO4]], \
$CellContext`sym$206822[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$206822[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$206822[All], 
      All, $CellContext`i$208379], \
$CellContext`sym$206822[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$206822[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$206822, $CellContext`season]], \
$CellContext`sym$206822[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$206822[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$206822[All], 
      All, $CellContext`i$206823], $CellContext`sym$206822[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$206822[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$206822, $CellContext`size]], \
$CellContext`sym$206822[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$206822[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$206822[All], 
      All, $CellContext`i$208371], $CellContext`sym$206822[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$206822[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$206822, $CellContext`speed]], \
$CellContext`sym$206822[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$206822[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$206822[All], All, $CellContext`i$208372], 
    Attributes[$CellContext`i$208386] = {Temporary}, $CellContext`i$208386 = 
    17, Attributes[$CellContext`i$208373] = {
     Temporary}, $CellContext`i$208373 = 4, 
    Attributes[$CellContext`i$208382] = {Temporary}, $CellContext`i$208382 = 
    13, Attributes[$CellContext`i$208376] = {
     Temporary}, $CellContext`i$208376 = 7, 
    Attributes[$CellContext`i$208375] = {Temporary}, $CellContext`i$208375 = 
    6, Attributes[$CellContext`i$208372] = {Temporary}, $CellContext`i$208372 = 
    3, Attributes[$CellContext`i$206823] = {Temporary}, $CellContext`i$206823 = 
    1, Attributes[$CellContext`i$208381] = {Temporary}, $CellContext`i$208381 = 
    12, Attributes[$CellContext`i$208384] = {
     Temporary}, $CellContext`i$208384 = 15, 
    Attributes[$CellContext`i$208387] = {Temporary}, $CellContext`i$208387 = 
    18, Attributes[$CellContext`i$208383] = {
     Temporary}, $CellContext`i$208383 = 14, 
    Attributes[$CellContext`i$208377] = {Temporary}, $CellContext`i$208377 = 
    8, Attributes[$CellContext`i$208371] = {Temporary}, $CellContext`i$208371 = 
    2, Attributes[$CellContext`i$208374] = {Temporary}, $CellContext`i$208374 = 
    5, Attributes[$CellContext`i$208385] = {Temporary}, $CellContext`i$208385 = 
    16, Attributes[$CellContext`i$208380] = {
     Temporary}, $CellContext`i$208380 = 11, 
    Attributes[$CellContext`i$208378] = {Temporary}, $CellContext`i$208378 = 
    9, Attributes[$CellContext`i$208379] = {Temporary}, $CellContext`i$208379 = 
    10, Attributes[$CellContext`sym$124201] = {
     Temporary}, $CellContext`sym$124201[$CellContext`a1] = Part[
      $CellContext`sym$124201[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$124201[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$124201[$CellContext`a2] = Part[
      $CellContext`sym$124201[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$124201[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$124201[$CellContext`a3] = Part[
      $CellContext`sym$124201[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$124201[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$124201[$CellContext`a4] = Part[
      $CellContext`sym$124201[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$124201[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$124201[$CellContext`a5] = Part[
      $CellContext`sym$124201[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$124201[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$124201[$CellContext`a6] = Part[
      $CellContext`sym$124201[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$124201[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$124201[$CellContext`a7] = Part[
      $CellContext`sym$124201[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$124201[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$124201[All] = $CellContext`med[
     All], $CellContext`sym$124201[$CellContext`Chla] = Part[
      $CellContext`sym$124201[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$124201[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$124201[$CellContext`Cl] = Part[
      $CellContext`sym$124201[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$124201[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$124201[$CellContext`mnO2] = Part[
      $CellContext`sym$124201[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$124201[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$124201[$CellContext`mxPH] = Part[
      $CellContext`sym$124201[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$124201[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$124201[$CellContext`NH4] = Part[
      $CellContext`sym$124201[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$124201[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$124201[$CellContext`NO3] = Part[
      $CellContext`sym$124201[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$124201[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$124201[$CellContext`oPO4] = Part[
      $CellContext`sym$124201[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$124201[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$124201[$CellContext`PO4] = Part[
      $CellContext`sym$124201[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$124201[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$124201[$CellContext`season] = Part[
      $CellContext`sym$124201[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$124201[$CellContext`season, 
         "missing"]]]], $CellContext`sym$124201[$CellContext`size] = Part[
      $CellContext`sym$124201[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$124201[$CellContext`size, 
         "missing"]]]], $CellContext`sym$124201[$CellContext`speed] = Part[
      $CellContext`sym$124201[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$124201[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$124201[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$124201[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$124201, $CellContext`a1]], \
$CellContext`sym$124201[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$124201[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$124201[All], 
      All, $CellContext`i$125760], $CellContext`sym$124201[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$124201[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$124201, $CellContext`a2]], \
$CellContext`sym$124201[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$124201[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$124201[All], 
      All, $CellContext`i$125761], $CellContext`sym$124201[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$124201[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$124201, $CellContext`a3]], \
$CellContext`sym$124201[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$124201[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$124201[All], 
      All, $CellContext`i$125762], $CellContext`sym$124201[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$124201[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$124201, $CellContext`a4]], \
$CellContext`sym$124201[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$124201[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$124201[All], 
      All, $CellContext`i$125763], $CellContext`sym$124201[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$124201[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$124201, $CellContext`a5]], \
$CellContext`sym$124201[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$124201[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$124201[All], 
      All, $CellContext`i$125764], $CellContext`sym$124201[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$124201[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$124201, $CellContext`a6]], \
$CellContext`sym$124201[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$124201[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$124201[All], 
      All, $CellContext`i$125765], $CellContext`sym$124201[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$124201[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$124201, $CellContext`a7]], \
$CellContext`sym$124201[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$124201[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$124201[All], 
      All, $CellContext`i$125766], $CellContext`sym$124201[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$124201[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$124201[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$124201[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$124201, $CellContext`Chla]], \
$CellContext`sym$124201[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$124201[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$124201[All], 
      All, $CellContext`i$125759], $CellContext`sym$124201[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$124201[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$124201, $CellContext`Cl]], \
$CellContext`sym$124201[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$124201[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$124201[All], 
      All, $CellContext`i$125754], $CellContext`sym$124201[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$124201[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$124201, $CellContext`mnO2]], \
$CellContext`sym$124201[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$124201[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$124201[All], 
      All, $CellContext`i$125753], $CellContext`sym$124201[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$124201[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$124201, $CellContext`mxPH]], \
$CellContext`sym$124201[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$124201[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$124201[All], 
      All, $CellContext`i$125752], $CellContext`sym$124201[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$124201[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$124201, $CellContext`NH4]], \
$CellContext`sym$124201[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$124201[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$124201[All], 
      All, $CellContext`i$125756], $CellContext`sym$124201[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$124201[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$124201, $CellContext`NO3]], \
$CellContext`sym$124201[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$124201[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$124201[All], 
      All, $CellContext`i$125755], $CellContext`sym$124201[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$124201[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$124201, $CellContext`oPO4]], \
$CellContext`sym$124201[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$124201[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$124201[All], 
      All, $CellContext`i$125757], $CellContext`sym$124201[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$124201[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$124201, $CellContext`PO4]], \
$CellContext`sym$124201[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$124201[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$124201[All], 
      All, $CellContext`i$125758], \
$CellContext`sym$124201[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$124201[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$124201, $CellContext`season]], \
$CellContext`sym$124201[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$124201[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$124201[All], 
      All, $CellContext`i$124202], $CellContext`sym$124201[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$124201[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$124201, $CellContext`size]], \
$CellContext`sym$124201[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$124201[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$124201[All], 
      All, $CellContext`i$125750], $CellContext`sym$124201[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$124201[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$124201, $CellContext`speed]], \
$CellContext`sym$124201[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$124201[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$124201[All], All, $CellContext`i$125751], 
    Attributes[$CellContext`i$125755] = {Temporary}, $CellContext`i$125755 = 
    7, Attributes[$CellContext`i$125765] = {Temporary}, $CellContext`i$125765 = 
    17, Attributes[$CellContext`i$125756] = {
     Temporary}, $CellContext`i$125756 = 8, 
    Attributes[$CellContext`i$125762] = {Temporary}, $CellContext`i$125762 = 
    14, Attributes[$CellContext`i$125753] = {
     Temporary}, $CellContext`i$125753 = 5, 
    Attributes[$CellContext`i$125766] = {Temporary}, $CellContext`i$125766 = 
    18, Attributes[$CellContext`i$125758] = {
     Temporary}, $CellContext`i$125758 = 10, 
    Attributes[$CellContext`i$125763] = {Temporary}, $CellContext`i$125763 = 
    15, Attributes[$CellContext`i$125752] = {
     Temporary}, $CellContext`i$125752 = 4, 
    Attributes[$CellContext`i$125751] = {Temporary}, $CellContext`i$125751 = 
    3, Attributes[$CellContext`i$125754] = {Temporary}, $CellContext`i$125754 = 
    6, Attributes[$CellContext`i$125757] = {Temporary}, $CellContext`i$125757 = 
    9, Attributes[$CellContext`i$124202] = {Temporary}, $CellContext`i$124202 = 
    1, Attributes[$CellContext`i$125759] = {Temporary}, $CellContext`i$125759 = 
    11, Attributes[$CellContext`i$125764] = {
     Temporary}, $CellContext`i$125764 = 16, 
    Attributes[$CellContext`i$125761] = {Temporary}, $CellContext`i$125761 = 
    13, Attributes[$CellContext`i$125760] = {
     Temporary}, $CellContext`i$125760 = 12, 
    Attributes[$CellContext`i$125750] = {Temporary}, $CellContext`i$125750 = 
    2, Attributes[$CellContext`sym$79513] = {
     Temporary}, $CellContext`sym$79513[$CellContext`a1] = Part[
      $CellContext`sym$79513[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$79513[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$79513[$CellContext`a2] = Part[
      $CellContext`sym$79513[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$79513[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$79513[$CellContext`a3] = Part[
      $CellContext`sym$79513[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$79513[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$79513[$CellContext`a4] = Part[
      $CellContext`sym$79513[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$79513[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$79513[$CellContext`a5] = Part[
      $CellContext`sym$79513[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$79513[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$79513[$CellContext`a6] = Part[
      $CellContext`sym$79513[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$79513[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$79513[$CellContext`a7] = Part[
      $CellContext`sym$79513[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$79513[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$79513[All] = $CellContext`med[
     All], $CellContext`sym$79513[$CellContext`Chla] = Part[
      $CellContext`sym$79513[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$79513[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$79513[$CellContext`Cl] = Part[
      $CellContext`sym$79513[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$79513[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$79513[$CellContext`mnO2] = Part[
      $CellContext`sym$79513[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$79513[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$79513[$CellContext`mxPH] = Part[
      $CellContext`sym$79513[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$79513[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$79513[$CellContext`NH4] = Part[
      $CellContext`sym$79513[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$79513[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$79513[$CellContext`NO3] = Part[
      $CellContext`sym$79513[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$79513[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$79513[$CellContext`oPO4] = Part[
      $CellContext`sym$79513[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$79513[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$79513[$CellContext`PO4] = Part[
      $CellContext`sym$79513[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$79513[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$79513[$CellContext`season] = Part[
      $CellContext`sym$79513[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$79513[$CellContext`season, 
         "missing"]]]], $CellContext`sym$79513[$CellContext`size] = Part[
      $CellContext`sym$79513[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$79513[$CellContext`size, 
         "missing"]]]], $CellContext`sym$79513[$CellContext`speed] = Part[
      $CellContext`sym$79513[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$79513[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$79513[$CellContext`a1, "factorized"] = 
    True, $CellContext`sym$79513[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$79513, $CellContext`a1]], \
$CellContext`sym$79513[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$79513[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$79513[All], 
      All, $CellContext`i$79525], $CellContext`sym$79513[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$79513[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$79513, $CellContext`a2]], \
$CellContext`sym$79513[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$79513[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$79513[All], 
      All, $CellContext`i$79526], $CellContext`sym$79513[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$79513[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$79513, $CellContext`a3]], \
$CellContext`sym$79513[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$79513[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$79513[All], 
      All, $CellContext`i$79527], $CellContext`sym$79513[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$79513[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$79513, $CellContext`a4]], \
$CellContext`sym$79513[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$79513[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$79513[All], 
      All, $CellContext`i$79528], $CellContext`sym$79513[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$79513[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$79513, $CellContext`a5]], \
$CellContext`sym$79513[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$79513[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$79513[All], 
      All, $CellContext`i$79529], $CellContext`sym$79513[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$79513[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$79513, $CellContext`a6]], \
$CellContext`sym$79513[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$79513[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$79513[All], 
      All, $CellContext`i$79530], $CellContext`sym$79513[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$79513[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$79513, $CellContext`a7]], \
$CellContext`sym$79513[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$79513[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$79513[All], 
      All, $CellContext`i$79531], $CellContext`sym$79513[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$79513[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$79513[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$79513[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$79513, $CellContext`Chla]], \
$CellContext`sym$79513[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$79513[$CellContext`Chla, "raw"] = Part[
      $CellContext`sym$79513[All], 
      All, $CellContext`i$79524], $CellContext`sym$79513[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$79513[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$79513, $CellContext`Cl]], \
$CellContext`sym$79513[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$79513[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$79513[All], 
      All, $CellContext`i$79519], $CellContext`sym$79513[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$79513[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$79513, $CellContext`mnO2]], \
$CellContext`sym$79513[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$79513[$CellContext`mnO2, "raw"] = Part[
      $CellContext`sym$79513[All], 
      All, $CellContext`i$79518], $CellContext`sym$79513[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$79513[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$79513, $CellContext`mxPH]], \
$CellContext`sym$79513[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$79513[$CellContext`mxPH, "raw"] = Part[
      $CellContext`sym$79513[All], 
      All, $CellContext`i$79517], $CellContext`sym$79513[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$79513[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$79513, $CellContext`NH4]], \
$CellContext`sym$79513[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$79513[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$79513[All], 
      All, $CellContext`i$79521], $CellContext`sym$79513[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$79513[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$79513, $CellContext`NO3]], \
$CellContext`sym$79513[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$79513[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$79513[All], 
      All, $CellContext`i$79520], $CellContext`sym$79513[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$79513[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$79513, $CellContext`oPO4]], \
$CellContext`sym$79513[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$79513[$CellContext`oPO4, "raw"] = Part[
      $CellContext`sym$79513[All], 
      All, $CellContext`i$79522], $CellContext`sym$79513[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$79513[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$79513, $CellContext`PO4]], \
$CellContext`sym$79513[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$79513[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$79513[All], 
      All, $CellContext`i$79523], $CellContext`sym$79513[$CellContext`season, 
      "factorized"] = 
    True, $CellContext`sym$79513[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$79513, $CellContext`season]], \
$CellContext`sym$79513[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$79513[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$79513[All], 
      All, $CellContext`i$79514], $CellContext`sym$79513[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$79513[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$79513, $CellContext`size]], \
$CellContext`sym$79513[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$79513[$CellContext`size, "raw"] = Part[
      $CellContext`sym$79513[All], 
      All, $CellContext`i$79515], $CellContext`sym$79513[$CellContext`speed, 
      "factorized"] = 
    True, $CellContext`sym$79513[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$79513, $CellContext`speed]], \
$CellContext`sym$79513[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$79513[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$79513[All], All, $CellContext`i$79516], 
    Attributes[$CellContext`i$79522] = {Temporary}, $CellContext`i$79522 = 9, 
    Attributes[$CellContext`i$79519] = {Temporary}, $CellContext`i$79519 = 6, 
    Attributes[$CellContext`i$79529] = {Temporary}, $CellContext`i$79529 = 16,
     Attributes[$CellContext`i$79520] = {Temporary}, $CellContext`i$79520 = 7,
     Attributes[$CellContext`i$79530] = {Temporary}, $CellContext`i$79530 = 
    17, Attributes[$CellContext`i$79518] = {Temporary}, $CellContext`i$79518 = 
    5, Attributes[$CellContext`i$79514] = {Temporary}, $CellContext`i$79514 = 
    1, Attributes[$CellContext`i$79525] = {Temporary}, $CellContext`i$79525 = 
    12, Attributes[$CellContext`i$79527] = {Temporary}, $CellContext`i$79527 = 
    14, Attributes[$CellContext`i$79524] = {Temporary}, $CellContext`i$79524 = 
    11, Attributes[$CellContext`i$79515] = {Temporary}, $CellContext`i$79515 = 
    2, Attributes[$CellContext`i$79526] = {Temporary}, $CellContext`i$79526 = 
    13, Attributes[$CellContext`i$79531] = {Temporary}, $CellContext`i$79531 = 
    18, Attributes[$CellContext`i$79516] = {Temporary}, $CellContext`i$79516 = 
    3, Attributes[$CellContext`i$79517] = {Temporary}, $CellContext`i$79517 = 
    4, Attributes[$CellContext`i$79521] = {Temporary}, $CellContext`i$79521 = 
    8, Attributes[$CellContext`i$79528] = {Temporary}, $CellContext`i$79528 = 
    15, Attributes[$CellContext`i$79523] = {Temporary}, $CellContext`i$79523 = 
    10, Attributes[$CellContext`sym$135366] = {
     Temporary}, $CellContext`sym$135366[$CellContext`a1] = Part[
      $CellContext`sym$135366[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$135366[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$135366[$CellContext`a2] = Part[
      $CellContext`sym$135366[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$135366[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$135366[$CellContext`a3] = Part[
      $CellContext`sym$135366[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$135366[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$135366[$CellContext`a4] = Part[
      $CellContext`sym$135366[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$135366[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$135366[$CellContext`a5] = Part[
      $CellContext`sym$135366[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$135366[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$135366[$CellContext`a6] = Part[
      $CellContext`sym$135366[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$135366[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$135366[$CellContext`a7] = Part[
      $CellContext`sym$135366[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$135366[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$135366[All] = $CellContext`med[
     All], $CellContext`sym$135366[$CellContext`Chla] = Part[
      $CellContext`sym$135366[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$135366[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$135366[$CellContext`Cl] = Part[
      $CellContext`sym$135366[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$135366[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$135366[$CellContext`mnO2] = Part[
      $CellContext`sym$135366[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$135366[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$135366[$CellContext`mxPH] = Part[
      $CellContext`sym$135366[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$135366[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$135366[$CellContext`NH4] = Part[
      $CellContext`sym$135366[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$135366[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$135366[$CellContext`NO3] = Part[
      $CellContext`sym$135366[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$135366[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$135366[$CellContext`oPO4] = Part[
      $CellContext`sym$135366[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$135366[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$135366[$CellContext`PO4] = Part[
      $CellContext`sym$135366[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$135366[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$135366[$CellContext`season] = Part[
      $CellContext`sym$135366[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$135366[$CellContext`season, 
         "missing"]]]], $CellContext`sym$135366[$CellContext`size] = Part[
      $CellContext`sym$135366[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$135366[$CellContext`size, 
         "missing"]]]], $CellContext`sym$135366[$CellContext`speed] = Part[
      $CellContext`sym$135366[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$135366[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$135366[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$135366[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$135366, $CellContext`a1]], \
$CellContext`sym$135366[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$135366[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$135366[All], 
      All, $CellContext`i$136925], $CellContext`sym$135366[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$135366[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$135366, $CellContext`a2]], \
$CellContext`sym$135366[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$135366[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$135366[All], 
      All, $CellContext`i$136926], $CellContext`sym$135366[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$135366[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$135366, $CellContext`a3]], \
$CellContext`sym$135366[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$135366[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$135366[All], 
      All, $CellContext`i$136927], $CellContext`sym$135366[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$135366[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$135366, $CellContext`a4]], \
$CellContext`sym$135366[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$135366[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$135366[All], 
      All, $CellContext`i$136928], $CellContext`sym$135366[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$135366[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$135366, $CellContext`a5]], \
$CellContext`sym$135366[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$135366[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$135366[All], 
      All, $CellContext`i$136929], $CellContext`sym$135366[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$135366[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$135366, $CellContext`a6]], \
$CellContext`sym$135366[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$135366[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$135366[All], 
      All, $CellContext`i$136930], $CellContext`sym$135366[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$135366[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$135366, $CellContext`a7]], \
$CellContext`sym$135366[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$135366[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$135366[All], 
      All, $CellContext`i$136931], $CellContext`sym$135366[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$135366[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$135366[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$135366[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$135366, $CellContext`Chla]], \
$CellContext`sym$135366[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$135366[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$135366[All], 
      All, $CellContext`i$136924], $CellContext`sym$135366[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$135366[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$135366, $CellContext`Cl]], \
$CellContext`sym$135366[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$135366[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$135366[All], 
      All, $CellContext`i$136919], $CellContext`sym$135366[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$135366[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$135366, $CellContext`mnO2]], \
$CellContext`sym$135366[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$135366[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$135366[All], 
      All, $CellContext`i$136918], $CellContext`sym$135366[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$135366[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$135366, $CellContext`mxPH]], \
$CellContext`sym$135366[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$135366[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$135366[All], 
      All, $CellContext`i$136917], $CellContext`sym$135366[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$135366[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$135366, $CellContext`NH4]], \
$CellContext`sym$135366[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$135366[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$135366[All], 
      All, $CellContext`i$136921], $CellContext`sym$135366[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$135366[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$135366, $CellContext`NO3]], \
$CellContext`sym$135366[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$135366[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$135366[All], 
      All, $CellContext`i$136920], $CellContext`sym$135366[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$135366[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$135366, $CellContext`oPO4]], \
$CellContext`sym$135366[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$135366[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$135366[All], 
      All, $CellContext`i$136922], $CellContext`sym$135366[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$135366[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$135366, $CellContext`PO4]], \
$CellContext`sym$135366[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$135366[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$135366[All], 
      All, $CellContext`i$136923], \
$CellContext`sym$135366[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$135366[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$135366, $CellContext`season]], \
$CellContext`sym$135366[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$135366[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$135366[All], 
      All, $CellContext`i$135367], $CellContext`sym$135366[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$135366[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$135366, $CellContext`size]], \
$CellContext`sym$135366[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$135366[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$135366[All], 
      All, $CellContext`i$136915], $CellContext`sym$135366[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$135366[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$135366, $CellContext`speed]], \
$CellContext`sym$135366[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$135366[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$135366[All], All, $CellContext`i$136916], 
    Attributes[$CellContext`i$136921] = {Temporary}, $CellContext`i$136921 = 
    8, Attributes[$CellContext`i$136915] = {Temporary}, $CellContext`i$136915 = 
    2, Attributes[$CellContext`i$135367] = {Temporary}, $CellContext`i$135367 = 
    1, Attributes[$CellContext`i$136929] = {Temporary}, $CellContext`i$136929 = 
    16, Attributes[$CellContext`i$136916] = {
     Temporary}, $CellContext`i$136916 = 3, 
    Attributes[$CellContext`i$136926] = {Temporary}, $CellContext`i$136926 = 
    13, Attributes[$CellContext`i$136925] = {
     Temporary}, $CellContext`i$136925 = 12, 
    Attributes[$CellContext`i$136919] = {Temporary}, $CellContext`i$136919 = 
    6, Attributes[$CellContext`i$136923] = {Temporary}, $CellContext`i$136923 = 
    10, Attributes[$CellContext`i$136922] = {
     Temporary}, $CellContext`i$136922 = 9, 
    Attributes[$CellContext`i$136927] = {Temporary}, $CellContext`i$136927 = 
    14, Attributes[$CellContext`i$136924] = {
     Temporary}, $CellContext`i$136924 = 11, 
    Attributes[$CellContext`i$136928] = {Temporary}, $CellContext`i$136928 = 
    15, Attributes[$CellContext`i$136918] = {
     Temporary}, $CellContext`i$136918 = 5, 
    Attributes[$CellContext`i$136931] = {Temporary}, $CellContext`i$136931 = 
    18, Attributes[$CellContext`i$136920] = {
     Temporary}, $CellContext`i$136920 = 7, 
    Attributes[$CellContext`i$136917] = {Temporary}, $CellContext`i$136917 = 
    4, Attributes[$CellContext`i$136930] = {Temporary}, $CellContext`i$136930 = 
    17, Attributes[$CellContext`sym$63832] = {
     Temporary}, $CellContext`sym$63832[$CellContext`a1] = $CellContext`med[
     All], $CellContext`sym$63832[$CellContext`a2] = $CellContext`med[
     All], $CellContext`sym$63832[$CellContext`a3] = $CellContext`med[
     All], $CellContext`sym$63832[$CellContext`a4] = $CellContext`med[
     All], $CellContext`sym$63832[$CellContext`a5] = $CellContext`med[
     All], $CellContext`sym$63832[$CellContext`a6] = $CellContext`med[
     All], $CellContext`sym$63832[$CellContext`a7] = $CellContext`med[
     All], $CellContext`sym$63832[All] = $CellContext`med[
     All], $CellContext`sym$63832[$CellContext`Chla] = $CellContext`med[
     All], $CellContext`sym$63832[$CellContext`Cl] = $CellContext`med[
     All], $CellContext`sym$63832[$CellContext`mnO2] = $CellContext`med[
     All], $CellContext`sym$63832[$CellContext`mxPH] = $CellContext`med[
     All], $CellContext`sym$63832[$CellContext`NH4] = $CellContext`med[
     All], $CellContext`sym$63832[$CellContext`NO3] = $CellContext`med[
     All], $CellContext`sym$63832[$CellContext`oPO4] = $CellContext`med[
     All], $CellContext`sym$63832[$CellContext`PO4] = $CellContext`med[
     All], $CellContext`sym$63832[$CellContext`season] = $CellContext`med[
     All], $CellContext`sym$63832[$CellContext`size] = $CellContext`med[
     All], $CellContext`sym$63832[$CellContext`speed] = $CellContext`med[
     All], $CellContext`sym$63832[$CellContext`a1, "factorized"] = 
    True, $CellContext`sym$63832[$CellContext`a1, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$63832[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$63832[$CellContext`a1, "raw"] = Part[
      $CellContext`med[All], All, 12], $CellContext`sym$63832[$CellContext`a2,
       "factorized"] = 
    True, $CellContext`sym$63832[$CellContext`a2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$63832[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$63832[$CellContext`a2, "raw"] = Part[
      $CellContext`med[All], All, 13], $CellContext`sym$63832[$CellContext`a3,
       "factorized"] = 
    True, $CellContext`sym$63832[$CellContext`a3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$63832[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$63832[$CellContext`a3, "raw"] = Part[
      $CellContext`med[All], All, 14], $CellContext`sym$63832[$CellContext`a4,
       "factorized"] = 
    True, $CellContext`sym$63832[$CellContext`a4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$63832[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$63832[$CellContext`a4, "raw"] = Part[
      $CellContext`med[All], All, 15], $CellContext`sym$63832[$CellContext`a5,
       "factorized"] = 
    True, $CellContext`sym$63832[$CellContext`a5, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$63832[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$63832[$CellContext`a5, "raw"] = Part[
      $CellContext`med[All], All, 16], $CellContext`sym$63832[$CellContext`a6,
       "factorized"] = 
    True, $CellContext`sym$63832[$CellContext`a6, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$63832[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$63832[$CellContext`a6, "raw"] = Part[
      $CellContext`med[All], All, 17], $CellContext`sym$63832[$CellContext`a7,
       "factorized"] = 
    True, $CellContext`sym$63832[$CellContext`a7, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$63832[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$63832[$CellContext`a7, "raw"] = Part[
      $CellContext`med[All], All, 18], $CellContext`sym$63832[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$63832[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$63832[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$63832[$CellContext`Chla, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$63832[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$63832[$CellContext`Chla, "raw"] = Part[
      $CellContext`med[All], All, 11], $CellContext`sym$63832[$CellContext`Cl,
       "factorized"] = 
    True, $CellContext`sym$63832[$CellContext`Cl, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$63832[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$63832[$CellContext`Cl, "raw"] = Part[
      $CellContext`med[All], All, 
      6], $CellContext`sym$63832[$CellContext`mnO2, "factorized"] = 
    True, $CellContext`sym$63832[$CellContext`mnO2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$63832[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$63832[$CellContext`mnO2, "raw"] = Part[
      $CellContext`med[All], All, 
      5], $CellContext`sym$63832[$CellContext`mxPH, "factorized"] = 
    True, $CellContext`sym$63832[$CellContext`mxPH, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$63832[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$63832[$CellContext`mxPH, "raw"] = Part[
      $CellContext`med[All], All, 4], $CellContext`sym$63832[$CellContext`NH4,
       "factorized"] = 
    True, $CellContext`sym$63832[$CellContext`NH4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$63832[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$63832[$CellContext`NH4, "raw"] = Part[
      $CellContext`med[All], All, 8], $CellContext`sym$63832[$CellContext`NO3,
       "factorized"] = 
    True, $CellContext`sym$63832[$CellContext`NO3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$63832[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$63832[$CellContext`NO3, "raw"] = Part[
      $CellContext`med[All], All, 
      7], $CellContext`sym$63832[$CellContext`oPO4, "factorized"] = 
    True, $CellContext`sym$63832[$CellContext`oPO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$63832[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$63832[$CellContext`oPO4, "raw"] = Part[
      $CellContext`med[All], All, 9], $CellContext`sym$63832[$CellContext`PO4,
       "factorized"] = 
    True, $CellContext`sym$63832[$CellContext`PO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$63832[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$63832[$CellContext`PO4, "raw"] = Part[
      $CellContext`med[All], All, 
      10], $CellContext`sym$63832[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$63832[$CellContext`season, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$63832[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$63832[$CellContext`season, "raw"] = 
    Part[
      $CellContext`med[All], All, 
      1], $CellContext`sym$63832[$CellContext`size, "factorized"] = 
    True, $CellContext`sym$63832[$CellContext`size, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$63832[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$63832[$CellContext`size, "raw"] = Part[
      $CellContext`med[All], All, 
      2], $CellContext`sym$63832[$CellContext`speed, "factorized"] = 
    True, $CellContext`sym$63832[$CellContext`speed, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$63832[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$63832[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`med[All], All, 3], 
    Attributes[$CellContext`sym$10211] = {
     Temporary}, $CellContext`sym$10211[$CellContext`a1] = $CellContext`med[
     All], $CellContext`sym$10211[$CellContext`a2] = $CellContext`med[
     All], $CellContext`sym$10211[$CellContext`a3] = $CellContext`med[
     All], $CellContext`sym$10211[$CellContext`a4] = $CellContext`med[
     All], $CellContext`sym$10211[$CellContext`a5] = $CellContext`med[
     All], $CellContext`sym$10211[$CellContext`a6] = $CellContext`med[
     All], $CellContext`sym$10211[$CellContext`a7] = $CellContext`med[
     All], $CellContext`sym$10211[All] = $CellContext`med[
     All], $CellContext`sym$10211[$CellContext`Chla] = $CellContext`med[
     All], $CellContext`sym$10211[$CellContext`Cl] = $CellContext`med[
     All], $CellContext`sym$10211[$CellContext`mnO2] = $CellContext`med[
     All], $CellContext`sym$10211[$CellContext`mxPH] = $CellContext`med[
     All], $CellContext`sym$10211[$CellContext`NH4] = $CellContext`med[
     All], $CellContext`sym$10211[$CellContext`NO3] = $CellContext`med[
     All], $CellContext`sym$10211[$CellContext`oPO4] = $CellContext`med[
     All], $CellContext`sym$10211[$CellContext`PO4] = $CellContext`med[
     All], $CellContext`sym$10211[$CellContext`season] = $CellContext`med[
     All], $CellContext`sym$10211[$CellContext`size] = $CellContext`med[
     All], $CellContext`sym$10211[$CellContext`speed] = $CellContext`med[
     All], $CellContext`sym$10211[$CellContext`a1, "factorized"] = 
    True, $CellContext`sym$10211[$CellContext`a1, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$10211[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$10211[$CellContext`a1, "raw"] = Part[
      $CellContext`med[All], All, 12], $CellContext`sym$10211[$CellContext`a2,
       "factorized"] = 
    True, $CellContext`sym$10211[$CellContext`a2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$10211[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$10211[$CellContext`a2, "raw"] = Part[
      $CellContext`med[All], All, 13], $CellContext`sym$10211[$CellContext`a3,
       "factorized"] = 
    True, $CellContext`sym$10211[$CellContext`a3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$10211[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$10211[$CellContext`a3, "raw"] = Part[
      $CellContext`med[All], All, 14], $CellContext`sym$10211[$CellContext`a4,
       "factorized"] = 
    True, $CellContext`sym$10211[$CellContext`a4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$10211[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$10211[$CellContext`a4, "raw"] = Part[
      $CellContext`med[All], All, 15], $CellContext`sym$10211[$CellContext`a5,
       "factorized"] = 
    True, $CellContext`sym$10211[$CellContext`a5, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$10211[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$10211[$CellContext`a5, "raw"] = Part[
      $CellContext`med[All], All, 16], $CellContext`sym$10211[$CellContext`a6,
       "factorized"] = 
    True, $CellContext`sym$10211[$CellContext`a6, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$10211[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$10211[$CellContext`a6, "raw"] = Part[
      $CellContext`med[All], All, 17], $CellContext`sym$10211[$CellContext`a7,
       "factorized"] = 
    True, $CellContext`sym$10211[$CellContext`a7, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$10211[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$10211[$CellContext`a7, "raw"] = Part[
      $CellContext`med[All], All, 18], $CellContext`sym$10211[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$10211[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$10211[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$10211[$CellContext`Chla, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$10211[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$10211[$CellContext`Chla, "raw"] = Part[
      $CellContext`med[All], All, 11], $CellContext`sym$10211[$CellContext`Cl,
       "factorized"] = 
    True, $CellContext`sym$10211[$CellContext`Cl, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$10211[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$10211[$CellContext`Cl, "raw"] = Part[
      $CellContext`med[All], All, 
      6], $CellContext`sym$10211[$CellContext`mnO2, "factorized"] = 
    True, $CellContext`sym$10211[$CellContext`mnO2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$10211[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$10211[$CellContext`mnO2, "raw"] = Part[
      $CellContext`med[All], All, 
      5], $CellContext`sym$10211[$CellContext`mxPH, "factorized"] = 
    True, $CellContext`sym$10211[$CellContext`mxPH, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$10211[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$10211[$CellContext`mxPH, "raw"] = Part[
      $CellContext`med[All], All, 4], $CellContext`sym$10211[$CellContext`NH4,
       "factorized"] = 
    True, $CellContext`sym$10211[$CellContext`NH4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$10211[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$10211[$CellContext`NH4, "raw"] = Part[
      $CellContext`med[All], All, 8], $CellContext`sym$10211[$CellContext`NO3,
       "factorized"] = 
    True, $CellContext`sym$10211[$CellContext`NO3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$10211[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$10211[$CellContext`NO3, "raw"] = Part[
      $CellContext`med[All], All, 
      7], $CellContext`sym$10211[$CellContext`oPO4, "factorized"] = 
    True, $CellContext`sym$10211[$CellContext`oPO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$10211[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$10211[$CellContext`oPO4, "raw"] = Part[
      $CellContext`med[All], All, 9], $CellContext`sym$10211[$CellContext`PO4,
       "factorized"] = 
    True, $CellContext`sym$10211[$CellContext`PO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$10211[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$10211[$CellContext`PO4, "raw"] = Part[
      $CellContext`med[All], All, 
      10], $CellContext`sym$10211[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$10211[$CellContext`season, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$10211[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$10211[$CellContext`season, "raw"] = 
    Part[
      $CellContext`med[All], All, 
      1], $CellContext`sym$10211[$CellContext`size, "factorized"] = 
    True, $CellContext`sym$10211[$CellContext`size, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$10211[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$10211[$CellContext`size, "raw"] = Part[
      $CellContext`med[All], All, 
      2], $CellContext`sym$10211[$CellContext`speed, "factorized"] = 
    True, $CellContext`sym$10211[$CellContext`speed, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$10211[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$10211[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`med[All], All, 3], 
    Attributes[$CellContext`sym$108570] = {
     Temporary}, $CellContext`sym$108570[$CellContext`a1] = Part[
      $CellContext`sym$108570[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$108570[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$108570[$CellContext`a2] = Part[
      $CellContext`sym$108570[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$108570[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$108570[$CellContext`a3] = Part[
      $CellContext`sym$108570[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$108570[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$108570[$CellContext`a4] = Part[
      $CellContext`sym$108570[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$108570[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$108570[$CellContext`a5] = Part[
      $CellContext`sym$108570[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$108570[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$108570[$CellContext`a6] = Part[
      $CellContext`sym$108570[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$108570[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$108570[$CellContext`a7] = Part[
      $CellContext`sym$108570[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$108570[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$108570[All] = $CellContext`med[
     All], $CellContext`sym$108570[$CellContext`Chla] = Part[
      $CellContext`sym$108570[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$108570[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$108570[$CellContext`Cl] = Part[
      $CellContext`sym$108570[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$108570[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$108570[$CellContext`mnO2] = Part[
      $CellContext`sym$108570[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$108570[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$108570[$CellContext`mxPH] = Part[
      $CellContext`sym$108570[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$108570[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$108570[$CellContext`NH4] = Part[
      $CellContext`sym$108570[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$108570[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$108570[$CellContext`NO3] = Part[
      $CellContext`sym$108570[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$108570[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$108570[$CellContext`oPO4] = Part[
      $CellContext`sym$108570[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$108570[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$108570[$CellContext`PO4] = Part[
      $CellContext`sym$108570[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$108570[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$108570[$CellContext`season] = Part[
      $CellContext`sym$108570[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$108570[$CellContext`season, 
         "missing"]]]], $CellContext`sym$108570[$CellContext`size] = Part[
      $CellContext`sym$108570[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$108570[$CellContext`size, 
         "missing"]]]], $CellContext`sym$108570[$CellContext`speed] = Part[
      $CellContext`sym$108570[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$108570[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$108570[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$108570[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$108570, $CellContext`a1]], \
$CellContext`sym$108570[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$108570[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$108570[All], 
      All, $CellContext`i$110129], $CellContext`sym$108570[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$108570[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$108570, $CellContext`a2]], \
$CellContext`sym$108570[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$108570[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$108570[All], 
      All, $CellContext`i$110130], $CellContext`sym$108570[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$108570[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$108570, $CellContext`a3]], \
$CellContext`sym$108570[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$108570[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$108570[All], 
      All, $CellContext`i$110131], $CellContext`sym$108570[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$108570[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$108570, $CellContext`a4]], \
$CellContext`sym$108570[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$108570[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$108570[All], 
      All, $CellContext`i$110132], $CellContext`sym$108570[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$108570[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$108570, $CellContext`a5]], \
$CellContext`sym$108570[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$108570[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$108570[All], 
      All, $CellContext`i$110133], $CellContext`sym$108570[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$108570[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$108570, $CellContext`a6]], \
$CellContext`sym$108570[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$108570[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$108570[All], 
      All, $CellContext`i$110134], $CellContext`sym$108570[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$108570[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$108570, $CellContext`a7]], \
$CellContext`sym$108570[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$108570[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$108570[All], 
      All, $CellContext`i$110135], $CellContext`sym$108570[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$108570[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$108570[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$108570[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$108570, $CellContext`Chla]], \
$CellContext`sym$108570[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$108570[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$108570[All], 
      All, $CellContext`i$110128], $CellContext`sym$108570[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$108570[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$108570, $CellContext`Cl]], \
$CellContext`sym$108570[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$108570[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$108570[All], 
      All, $CellContext`i$110123], $CellContext`sym$108570[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$108570[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$108570, $CellContext`mnO2]], \
$CellContext`sym$108570[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$108570[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$108570[All], 
      All, $CellContext`i$110122], $CellContext`sym$108570[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$108570[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$108570, $CellContext`mxPH]], \
$CellContext`sym$108570[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$108570[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$108570[All], 
      All, $CellContext`i$110121], $CellContext`sym$108570[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$108570[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$108570, $CellContext`NH4]], \
$CellContext`sym$108570[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$108570[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$108570[All], 
      All, $CellContext`i$110125], $CellContext`sym$108570[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$108570[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$108570, $CellContext`NO3]], \
$CellContext`sym$108570[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$108570[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$108570[All], 
      All, $CellContext`i$110124], $CellContext`sym$108570[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$108570[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$108570, $CellContext`oPO4]], \
$CellContext`sym$108570[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$108570[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$108570[All], 
      All, $CellContext`i$110126], $CellContext`sym$108570[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$108570[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$108570, $CellContext`PO4]], \
$CellContext`sym$108570[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$108570[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$108570[All], 
      All, $CellContext`i$110127], \
$CellContext`sym$108570[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$108570[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$108570, $CellContext`season]], \
$CellContext`sym$108570[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$108570[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$108570[All], 
      All, $CellContext`i$108571], $CellContext`sym$108570[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$108570[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$108570, $CellContext`size]], \
$CellContext`sym$108570[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$108570[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$108570[All], 
      All, $CellContext`i$110119], $CellContext`sym$108570[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$108570[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$108570, $CellContext`speed]], \
$CellContext`sym$108570[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$108570[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$108570[All], All, $CellContext`i$110120], 
    Attributes[$CellContext`i$110120] = {Temporary}, $CellContext`i$110120 = 
    3, Attributes[$CellContext`i$110124] = {Temporary}, $CellContext`i$110124 = 
    7, Attributes[$CellContext`i$110122] = {Temporary}, $CellContext`i$110122 = 
    5, Attributes[$CellContext`i$110119] = {Temporary}, $CellContext`i$110119 = 
    2, Attributes[$CellContext`i$110131] = {Temporary}, $CellContext`i$110131 = 
    14, Attributes[$CellContext`i$110134] = {
     Temporary}, $CellContext`i$110134 = 17, 
    Attributes[$CellContext`i$110130] = {Temporary}, $CellContext`i$110130 = 
    13, Attributes[$CellContext`i$110133] = {
     Temporary}, $CellContext`i$110133 = 16, 
    Attributes[$CellContext`i$110128] = {Temporary}, $CellContext`i$110128 = 
    11, Attributes[$CellContext`i$110129] = {
     Temporary}, $CellContext`i$110129 = 12, 
    Attributes[$CellContext`i$108571] = {Temporary}, $CellContext`i$108571 = 
    1, Attributes[$CellContext`i$110127] = {Temporary}, $CellContext`i$110127 = 
    10, Attributes[$CellContext`i$110126] = {
     Temporary}, $CellContext`i$110126 = 9, 
    Attributes[$CellContext`i$110132] = {Temporary}, $CellContext`i$110132 = 
    15, Attributes[$CellContext`i$110135] = {
     Temporary}, $CellContext`i$110135 = 18, 
    Attributes[$CellContext`i$110123] = {Temporary}, $CellContext`i$110123 = 
    6, Attributes[$CellContext`i$110121] = {Temporary}, $CellContext`i$110121 = 
    4, Attributes[$CellContext`i$110125] = {Temporary}, $CellContext`i$110125 = 
    8, Attributes[$CellContext`sym$92939] = {
     Temporary}, $CellContext`sym$92939[$CellContext`a1] = Part[
      $CellContext`sym$92939[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$92939[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$92939[$CellContext`a2] = Part[
      $CellContext`sym$92939[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$92939[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$92939[$CellContext`a3] = Part[
      $CellContext`sym$92939[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$92939[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$92939[$CellContext`a4] = Part[
      $CellContext`sym$92939[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$92939[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$92939[$CellContext`a5] = Part[
      $CellContext`sym$92939[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$92939[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$92939[$CellContext`a6] = Part[
      $CellContext`sym$92939[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$92939[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$92939[$CellContext`a7] = Part[
      $CellContext`sym$92939[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$92939[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$92939[All] = $CellContext`med[
     All], $CellContext`sym$92939[$CellContext`Chla] = Part[
      $CellContext`sym$92939[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$92939[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$92939[$CellContext`Cl] = Part[
      $CellContext`sym$92939[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$92939[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$92939[$CellContext`mnO2] = Part[
      $CellContext`sym$92939[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$92939[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$92939[$CellContext`mxPH] = Part[
      $CellContext`sym$92939[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$92939[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$92939[$CellContext`NH4] = Part[
      $CellContext`sym$92939[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$92939[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$92939[$CellContext`NO3] = Part[
      $CellContext`sym$92939[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$92939[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$92939[$CellContext`oPO4] = Part[
      $CellContext`sym$92939[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$92939[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$92939[$CellContext`PO4] = Part[
      $CellContext`sym$92939[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$92939[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$92939[$CellContext`season] = Part[
      $CellContext`sym$92939[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$92939[$CellContext`season, 
         "missing"]]]], $CellContext`sym$92939[$CellContext`size] = Part[
      $CellContext`sym$92939[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$92939[$CellContext`size, 
         "missing"]]]], $CellContext`sym$92939[$CellContext`speed] = Part[
      $CellContext`sym$92939[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$92939[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$92939[$CellContext`a1, "factorized"] = 
    True, $CellContext`sym$92939[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$92939, $CellContext`a1]], \
$CellContext`sym$92939[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$92939[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$92939[All], 
      All, $CellContext`i$94498], $CellContext`sym$92939[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$92939[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$92939, $CellContext`a2]], \
$CellContext`sym$92939[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$92939[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$92939[All], 
      All, $CellContext`i$94499], $CellContext`sym$92939[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$92939[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$92939, $CellContext`a3]], \
$CellContext`sym$92939[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$92939[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$92939[All], 
      All, $CellContext`i$94500], $CellContext`sym$92939[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$92939[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$92939, $CellContext`a4]], \
$CellContext`sym$92939[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$92939[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$92939[All], 
      All, $CellContext`i$94501], $CellContext`sym$92939[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$92939[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$92939, $CellContext`a5]], \
$CellContext`sym$92939[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$92939[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$92939[All], 
      All, $CellContext`i$94502], $CellContext`sym$92939[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$92939[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$92939, $CellContext`a6]], \
$CellContext`sym$92939[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$92939[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$92939[All], 
      All, $CellContext`i$94503], $CellContext`sym$92939[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$92939[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$92939, $CellContext`a7]], \
$CellContext`sym$92939[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$92939[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$92939[All], 
      All, $CellContext`i$94504], $CellContext`sym$92939[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$92939[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$92939[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$92939[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$92939, $CellContext`Chla]], \
$CellContext`sym$92939[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$92939[$CellContext`Chla, "raw"] = Part[
      $CellContext`sym$92939[All], 
      All, $CellContext`i$94497], $CellContext`sym$92939[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$92939[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$92939, $CellContext`Cl]], \
$CellContext`sym$92939[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$92939[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$92939[All], 
      All, $CellContext`i$94492], $CellContext`sym$92939[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$92939[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$92939, $CellContext`mnO2]], \
$CellContext`sym$92939[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$92939[$CellContext`mnO2, "raw"] = Part[
      $CellContext`sym$92939[All], 
      All, $CellContext`i$94491], $CellContext`sym$92939[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$92939[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$92939, $CellContext`mxPH]], \
$CellContext`sym$92939[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$92939[$CellContext`mxPH, "raw"] = Part[
      $CellContext`sym$92939[All], 
      All, $CellContext`i$94490], $CellContext`sym$92939[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$92939[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$92939, $CellContext`NH4]], \
$CellContext`sym$92939[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$92939[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$92939[All], 
      All, $CellContext`i$94494], $CellContext`sym$92939[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$92939[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$92939, $CellContext`NO3]], \
$CellContext`sym$92939[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$92939[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$92939[All], 
      All, $CellContext`i$94493], $CellContext`sym$92939[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$92939[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$92939, $CellContext`oPO4]], \
$CellContext`sym$92939[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$92939[$CellContext`oPO4, "raw"] = Part[
      $CellContext`sym$92939[All], 
      All, $CellContext`i$94495], $CellContext`sym$92939[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$92939[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$92939, $CellContext`PO4]], \
$CellContext`sym$92939[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$92939[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$92939[All], 
      All, $CellContext`i$94496], $CellContext`sym$92939[$CellContext`season, 
      "factorized"] = 
    True, $CellContext`sym$92939[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$92939, $CellContext`season]], \
$CellContext`sym$92939[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$92939[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$92939[All], 
      All, $CellContext`i$92940], $CellContext`sym$92939[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$92939[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$92939, $CellContext`size]], \
$CellContext`sym$92939[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$92939[$CellContext`size, "raw"] = Part[
      $CellContext`sym$92939[All], 
      All, $CellContext`i$94488], $CellContext`sym$92939[$CellContext`speed, 
      "factorized"] = 
    True, $CellContext`sym$92939[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$92939, $CellContext`speed]], \
$CellContext`sym$92939[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$92939[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$92939[All], All, $CellContext`i$94489], 
    Attributes[$CellContext`i$94504] = {Temporary}, $CellContext`i$94504 = 18,
     Attributes[$CellContext`i$94492] = {Temporary}, $CellContext`i$94492 = 6,
     Attributes[$CellContext`i$94490] = {Temporary}, $CellContext`i$94490 = 4,
     Attributes[$CellContext`i$94489] = {Temporary}, $CellContext`i$94489 = 3,
     Attributes[$CellContext`i$94488] = {Temporary}, $CellContext`i$94488 = 2,
     Attributes[$CellContext`i$94491] = {Temporary}, $CellContext`i$94491 = 5,
     Attributes[$CellContext`i$94493] = {Temporary}, $CellContext`i$94493 = 7,
     Attributes[$CellContext`i$94497] = {Temporary}, $CellContext`i$94497 = 
    11, Attributes[$CellContext`i$94498] = {Temporary}, $CellContext`i$94498 = 
    12, Attributes[$CellContext`i$94502] = {Temporary}, $CellContext`i$94502 = 
    16, Attributes[$CellContext`i$94501] = {Temporary}, $CellContext`i$94501 = 
    15, Attributes[$CellContext`i$94500] = {Temporary}, $CellContext`i$94500 = 
    14, Attributes[$CellContext`i$94495] = {Temporary}, $CellContext`i$94495 = 
    9, Attributes[$CellContext`i$94496] = {Temporary}, $CellContext`i$94496 = 
    10, Attributes[$CellContext`i$94494] = {Temporary}, $CellContext`i$94494 = 
    8, Attributes[$CellContext`i$94503] = {Temporary}, $CellContext`i$94503 = 
    17, Attributes[$CellContext`i$94499] = {Temporary}, $CellContext`i$94499 = 
    13, Attributes[$CellContext`i$92940] = {Temporary}, $CellContext`i$92940 = 
    1, Attributes[$CellContext`sym$197890] = {
     Temporary}, $CellContext`sym$197890[$CellContext`a1] = Part[
      $CellContext`sym$197890[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$197890[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$197890[$CellContext`a2] = Part[
      $CellContext`sym$197890[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$197890[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$197890[$CellContext`a3] = Part[
      $CellContext`sym$197890[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$197890[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$197890[$CellContext`a4] = Part[
      $CellContext`sym$197890[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$197890[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$197890[$CellContext`a5] = Part[
      $CellContext`sym$197890[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$197890[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$197890[$CellContext`a6] = Part[
      $CellContext`sym$197890[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$197890[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$197890[$CellContext`a7] = Part[
      $CellContext`sym$197890[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$197890[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$197890[All] = $CellContext`med[
     All], $CellContext`sym$197890[$CellContext`Chla] = Part[
      $CellContext`sym$197890[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$197890[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$197890[$CellContext`Cl] = Part[
      $CellContext`sym$197890[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$197890[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$197890[$CellContext`mnO2] = Part[
      $CellContext`sym$197890[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$197890[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$197890[$CellContext`mxPH] = Part[
      $CellContext`sym$197890[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$197890[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$197890[$CellContext`NH4] = Part[
      $CellContext`sym$197890[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$197890[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$197890[$CellContext`NO3] = Part[
      $CellContext`sym$197890[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$197890[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$197890[$CellContext`oPO4] = Part[
      $CellContext`sym$197890[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$197890[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$197890[$CellContext`PO4] = Part[
      $CellContext`sym$197890[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$197890[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$197890[$CellContext`season] = Part[
      $CellContext`sym$197890[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$197890[$CellContext`season, 
         "missing"]]]], $CellContext`sym$197890[$CellContext`size] = Part[
      $CellContext`sym$197890[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$197890[$CellContext`size, 
         "missing"]]]], $CellContext`sym$197890[$CellContext`speed] = Part[
      $CellContext`sym$197890[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$197890[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$197890[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$197890[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$197890, $CellContext`a1]], \
$CellContext`sym$197890[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$197890[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$197890[All], 
      All, $CellContext`i$199449], $CellContext`sym$197890[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$197890[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$197890, $CellContext`a2]], \
$CellContext`sym$197890[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$197890[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$197890[All], 
      All, $CellContext`i$199450], $CellContext`sym$197890[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$197890[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$197890, $CellContext`a3]], \
$CellContext`sym$197890[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$197890[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$197890[All], 
      All, $CellContext`i$199451], $CellContext`sym$197890[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$197890[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$197890, $CellContext`a4]], \
$CellContext`sym$197890[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$197890[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$197890[All], 
      All, $CellContext`i$199452], $CellContext`sym$197890[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$197890[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$197890, $CellContext`a5]], \
$CellContext`sym$197890[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$197890[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$197890[All], 
      All, $CellContext`i$199453], $CellContext`sym$197890[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$197890[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$197890, $CellContext`a6]], \
$CellContext`sym$197890[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$197890[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$197890[All], 
      All, $CellContext`i$199454], $CellContext`sym$197890[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$197890[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$197890, $CellContext`a7]], \
$CellContext`sym$197890[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$197890[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$197890[All], 
      All, $CellContext`i$199455], $CellContext`sym$197890[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$197890[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$197890[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$197890[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$197890, $CellContext`Chla]], \
$CellContext`sym$197890[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$197890[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$197890[All], 
      All, $CellContext`i$199448], $CellContext`sym$197890[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$197890[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$197890, $CellContext`Cl]], \
$CellContext`sym$197890[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$197890[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$197890[All], 
      All, $CellContext`i$199443], $CellContext`sym$197890[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$197890[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$197890, $CellContext`mnO2]], \
$CellContext`sym$197890[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$197890[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$197890[All], 
      All, $CellContext`i$199442], $CellContext`sym$197890[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$197890[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$197890, $CellContext`mxPH]], \
$CellContext`sym$197890[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$197890[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$197890[All], 
      All, $CellContext`i$199441], $CellContext`sym$197890[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$197890[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$197890, $CellContext`NH4]], \
$CellContext`sym$197890[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$197890[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$197890[All], 
      All, $CellContext`i$199445], $CellContext`sym$197890[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$197890[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$197890, $CellContext`NO3]], \
$CellContext`sym$197890[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$197890[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$197890[All], 
      All, $CellContext`i$199444], $CellContext`sym$197890[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$197890[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$197890, $CellContext`oPO4]], \
$CellContext`sym$197890[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$197890[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$197890[All], 
      All, $CellContext`i$199446], $CellContext`sym$197890[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$197890[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$197890, $CellContext`PO4]], \
$CellContext`sym$197890[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$197890[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$197890[All], 
      All, $CellContext`i$199447], \
$CellContext`sym$197890[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$197890[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$197890, $CellContext`season]], \
$CellContext`sym$197890[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$197890[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$197890[All], 
      All, $CellContext`i$197891], $CellContext`sym$197890[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$197890[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$197890, $CellContext`size]], \
$CellContext`sym$197890[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$197890[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$197890[All], 
      All, $CellContext`i$199439], $CellContext`sym$197890[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$197890[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$197890, $CellContext`speed]], \
$CellContext`sym$197890[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$197890[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$197890[All], All, $CellContext`i$199440], 
    Attributes[$CellContext`i$199448] = {Temporary}, $CellContext`i$199448 = 
    11, Attributes[$CellContext`i$199441] = {
     Temporary}, $CellContext`i$199441 = 4, 
    Attributes[$CellContext`i$199443] = {Temporary}, $CellContext`i$199443 = 
    6, Attributes[$CellContext`i$199444] = {Temporary}, $CellContext`i$199444 = 
    7, Attributes[$CellContext`i$199455] = {Temporary}, $CellContext`i$199455 = 
    18, Attributes[$CellContext`i$197891] = {
     Temporary}, $CellContext`i$197891 = 1, 
    Attributes[$CellContext`i$199440] = {Temporary}, $CellContext`i$199440 = 
    3, Attributes[$CellContext`i$199442] = {Temporary}, $CellContext`i$199442 = 
    5, Attributes[$CellContext`i$199447] = {Temporary}, $CellContext`i$199447 = 
    10, Attributes[$CellContext`i$199452] = {
     Temporary}, $CellContext`i$199452 = 15, 
    Attributes[$CellContext`i$199453] = {Temporary}, $CellContext`i$199453 = 
    16, Attributes[$CellContext`i$199450] = {
     Temporary}, $CellContext`i$199450 = 13, 
    Attributes[$CellContext`i$199449] = {Temporary}, $CellContext`i$199449 = 
    12, Attributes[$CellContext`i$199454] = {
     Temporary}, $CellContext`i$199454 = 17, 
    Attributes[$CellContext`i$199439] = {Temporary}, $CellContext`i$199439 = 
    2, Attributes[$CellContext`i$199445] = {Temporary}, $CellContext`i$199445 = 
    8, Attributes[$CellContext`i$199451] = {Temporary}, $CellContext`i$199451 = 
    14, Attributes[$CellContext`i$199446] = {
     Temporary}, $CellContext`i$199446 = 9, 
    Attributes[$CellContext`sym$84007] = {
     Temporary}, $CellContext`sym$84007[$CellContext`a1] = Part[
      $CellContext`sym$84007[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$84007[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$84007[$CellContext`a2] = Part[
      $CellContext`sym$84007[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$84007[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$84007[$CellContext`a3] = Part[
      $CellContext`sym$84007[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$84007[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$84007[$CellContext`a4] = Part[
      $CellContext`sym$84007[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$84007[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$84007[$CellContext`a5] = Part[
      $CellContext`sym$84007[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$84007[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$84007[$CellContext`a6] = Part[
      $CellContext`sym$84007[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$84007[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$84007[$CellContext`a7] = Part[
      $CellContext`sym$84007[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$84007[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$84007[All] = $CellContext`med[
     All], $CellContext`sym$84007[$CellContext`Chla] = Part[
      $CellContext`sym$84007[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$84007[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$84007[$CellContext`Cl] = Part[
      $CellContext`sym$84007[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$84007[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$84007[$CellContext`mnO2] = Part[
      $CellContext`sym$84007[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$84007[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$84007[$CellContext`mxPH] = Part[
      $CellContext`sym$84007[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$84007[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$84007[$CellContext`NH4] = Part[
      $CellContext`sym$84007[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$84007[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$84007[$CellContext`NO3] = Part[
      $CellContext`sym$84007[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$84007[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$84007[$CellContext`oPO4] = Part[
      $CellContext`sym$84007[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$84007[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$84007[$CellContext`PO4] = Part[
      $CellContext`sym$84007[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$84007[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$84007[$CellContext`season] = Part[
      $CellContext`sym$84007[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$84007[$CellContext`season, 
         "missing"]]]], $CellContext`sym$84007[$CellContext`size] = Part[
      $CellContext`sym$84007[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$84007[$CellContext`size, 
         "missing"]]]], $CellContext`sym$84007[$CellContext`speed] = Part[
      $CellContext`sym$84007[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$84007[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$84007[$CellContext`a1, "factorized"] = 
    True, $CellContext`sym$84007[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$84007, $CellContext`a1]], \
$CellContext`sym$84007[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$84007[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$84007[All], 
      All, $CellContext`i$85566], $CellContext`sym$84007[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$84007[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$84007, $CellContext`a2]], \
$CellContext`sym$84007[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$84007[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$84007[All], 
      All, $CellContext`i$85567], $CellContext`sym$84007[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$84007[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$84007, $CellContext`a3]], \
$CellContext`sym$84007[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$84007[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$84007[All], 
      All, $CellContext`i$85568], $CellContext`sym$84007[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$84007[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$84007, $CellContext`a4]], \
$CellContext`sym$84007[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$84007[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$84007[All], 
      All, $CellContext`i$85569], $CellContext`sym$84007[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$84007[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$84007, $CellContext`a5]], \
$CellContext`sym$84007[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$84007[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$84007[All], 
      All, $CellContext`i$85570], $CellContext`sym$84007[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$84007[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$84007, $CellContext`a6]], \
$CellContext`sym$84007[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$84007[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$84007[All], 
      All, $CellContext`i$85571], $CellContext`sym$84007[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$84007[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$84007, $CellContext`a7]], \
$CellContext`sym$84007[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$84007[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$84007[All], 
      All, $CellContext`i$85572], $CellContext`sym$84007[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$84007[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$84007[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$84007[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$84007, $CellContext`Chla]], \
$CellContext`sym$84007[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$84007[$CellContext`Chla, "raw"] = Part[
      $CellContext`sym$84007[All], 
      All, $CellContext`i$85565], $CellContext`sym$84007[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$84007[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$84007, $CellContext`Cl]], \
$CellContext`sym$84007[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$84007[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$84007[All], 
      All, $CellContext`i$85560], $CellContext`sym$84007[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$84007[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$84007, $CellContext`mnO2]], \
$CellContext`sym$84007[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$84007[$CellContext`mnO2, "raw"] = Part[
      $CellContext`sym$84007[All], 
      All, $CellContext`i$85559], $CellContext`sym$84007[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$84007[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$84007, $CellContext`mxPH]], \
$CellContext`sym$84007[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$84007[$CellContext`mxPH, "raw"] = Part[
      $CellContext`sym$84007[All], 
      All, $CellContext`i$85558], $CellContext`sym$84007[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$84007[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$84007, $CellContext`NH4]], \
$CellContext`sym$84007[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$84007[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$84007[All], 
      All, $CellContext`i$85562], $CellContext`sym$84007[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$84007[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$84007, $CellContext`NO3]], \
$CellContext`sym$84007[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$84007[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$84007[All], 
      All, $CellContext`i$85561], $CellContext`sym$84007[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$84007[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$84007, $CellContext`oPO4]], \
$CellContext`sym$84007[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$84007[$CellContext`oPO4, "raw"] = Part[
      $CellContext`sym$84007[All], 
      All, $CellContext`i$85563], $CellContext`sym$84007[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$84007[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$84007, $CellContext`PO4]], \
$CellContext`sym$84007[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$84007[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$84007[All], 
      All, $CellContext`i$85564], $CellContext`sym$84007[$CellContext`season, 
      "factorized"] = 
    True, $CellContext`sym$84007[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$84007, $CellContext`season]], \
$CellContext`sym$84007[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$84007[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$84007[All], 
      All, $CellContext`i$84008], $CellContext`sym$84007[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$84007[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$84007, $CellContext`size]], \
$CellContext`sym$84007[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$84007[$CellContext`size, "raw"] = Part[
      $CellContext`sym$84007[All], 
      All, $CellContext`i$85556], $CellContext`sym$84007[$CellContext`speed, 
      "factorized"] = 
    True, $CellContext`sym$84007[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$84007, $CellContext`speed]], \
$CellContext`sym$84007[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$84007[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$84007[All], All, $CellContext`i$85557], 
    Attributes[$CellContext`i$85567] = {Temporary}, $CellContext`i$85567 = 13,
     Attributes[$CellContext`i$85558] = {Temporary}, $CellContext`i$85558 = 4,
     Attributes[$CellContext`i$85563] = {Temporary}, $CellContext`i$85563 = 9,
     Attributes[$CellContext`i$85568] = {Temporary}, $CellContext`i$85568 = 
    14, Attributes[$CellContext`i$85565] = {Temporary}, $CellContext`i$85565 = 
    11, Attributes[$CellContext`i$85566] = {Temporary}, $CellContext`i$85566 = 
    12, Attributes[$CellContext`i$85561] = {Temporary}, $CellContext`i$85561 = 
    7, Attributes[$CellContext`i$85571] = {Temporary}, $CellContext`i$85571 = 
    17, Attributes[$CellContext`i$85557] = {Temporary}, $CellContext`i$85557 = 
    3, Attributes[$CellContext`i$85570] = {Temporary}, $CellContext`i$85570 = 
    16, Attributes[$CellContext`i$85556] = {Temporary}, $CellContext`i$85556 = 
    2, Attributes[$CellContext`i$85559] = {Temporary}, $CellContext`i$85559 = 
    5, Attributes[$CellContext`i$85569] = {Temporary}, $CellContext`i$85569 = 
    15, Attributes[$CellContext`i$85572] = {Temporary}, $CellContext`i$85572 = 
    18, Attributes[$CellContext`i$85564] = {Temporary}, $CellContext`i$85564 = 
    10, Attributes[$CellContext`i$85562] = {Temporary}, $CellContext`i$85562 = 
    8, Attributes[$CellContext`i$85560] = {Temporary}, $CellContext`i$85560 = 
    6, Attributes[$CellContext`i$84008] = {Temporary}, $CellContext`i$84008 = 
    1, Attributes[$CellContext`sym$117502] = {
     Temporary}, $CellContext`sym$117502[$CellContext`a1] = Part[
      $CellContext`sym$117502[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$117502[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$117502[$CellContext`a2] = Part[
      $CellContext`sym$117502[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$117502[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$117502[$CellContext`a3] = Part[
      $CellContext`sym$117502[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$117502[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$117502[$CellContext`a4] = Part[
      $CellContext`sym$117502[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$117502[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$117502[$CellContext`a5] = Part[
      $CellContext`sym$117502[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$117502[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$117502[$CellContext`a6] = Part[
      $CellContext`sym$117502[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$117502[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$117502[$CellContext`a7] = Part[
      $CellContext`sym$117502[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$117502[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$117502[All] = $CellContext`med[
     All], $CellContext`sym$117502[$CellContext`Chla] = Part[
      $CellContext`sym$117502[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$117502[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$117502[$CellContext`Cl] = Part[
      $CellContext`sym$117502[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$117502[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$117502[$CellContext`mnO2] = Part[
      $CellContext`sym$117502[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$117502[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$117502[$CellContext`mxPH] = Part[
      $CellContext`sym$117502[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$117502[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$117502[$CellContext`NH4] = Part[
      $CellContext`sym$117502[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$117502[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$117502[$CellContext`NO3] = Part[
      $CellContext`sym$117502[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$117502[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$117502[$CellContext`oPO4] = Part[
      $CellContext`sym$117502[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$117502[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$117502[$CellContext`PO4] = Part[
      $CellContext`sym$117502[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$117502[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$117502[$CellContext`season] = Part[
      $CellContext`sym$117502[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$117502[$CellContext`season, 
         "missing"]]]], $CellContext`sym$117502[$CellContext`size] = Part[
      $CellContext`sym$117502[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$117502[$CellContext`size, 
         "missing"]]]], $CellContext`sym$117502[$CellContext`speed] = Part[
      $CellContext`sym$117502[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$117502[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$117502[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$117502[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$117502, $CellContext`a1]], \
$CellContext`sym$117502[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$117502[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$117502[All], 
      All, $CellContext`i$119061], $CellContext`sym$117502[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$117502[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$117502, $CellContext`a2]], \
$CellContext`sym$117502[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$117502[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$117502[All], 
      All, $CellContext`i$119062], $CellContext`sym$117502[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$117502[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$117502, $CellContext`a3]], \
$CellContext`sym$117502[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$117502[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$117502[All], 
      All, $CellContext`i$119063], $CellContext`sym$117502[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$117502[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$117502, $CellContext`a4]], \
$CellContext`sym$117502[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$117502[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$117502[All], 
      All, $CellContext`i$119064], $CellContext`sym$117502[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$117502[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$117502, $CellContext`a5]], \
$CellContext`sym$117502[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$117502[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$117502[All], 
      All, $CellContext`i$119065], $CellContext`sym$117502[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$117502[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$117502, $CellContext`a6]], \
$CellContext`sym$117502[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$117502[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$117502[All], 
      All, $CellContext`i$119066], $CellContext`sym$117502[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$117502[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$117502, $CellContext`a7]], \
$CellContext`sym$117502[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$117502[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$117502[All], 
      All, $CellContext`i$119067], $CellContext`sym$117502[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$117502[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$117502[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$117502[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$117502, $CellContext`Chla]], \
$CellContext`sym$117502[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$117502[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$117502[All], 
      All, $CellContext`i$119060], $CellContext`sym$117502[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$117502[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$117502, $CellContext`Cl]], \
$CellContext`sym$117502[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$117502[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$117502[All], 
      All, $CellContext`i$119055], $CellContext`sym$117502[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$117502[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$117502, $CellContext`mnO2]], \
$CellContext`sym$117502[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$117502[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$117502[All], 
      All, $CellContext`i$119054], $CellContext`sym$117502[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$117502[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$117502, $CellContext`mxPH]], \
$CellContext`sym$117502[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$117502[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$117502[All], 
      All, $CellContext`i$119053], $CellContext`sym$117502[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$117502[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$117502, $CellContext`NH4]], \
$CellContext`sym$117502[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$117502[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$117502[All], 
      All, $CellContext`i$119057], $CellContext`sym$117502[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$117502[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$117502, $CellContext`NO3]], \
$CellContext`sym$117502[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$117502[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$117502[All], 
      All, $CellContext`i$119056], $CellContext`sym$117502[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$117502[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$117502, $CellContext`oPO4]], \
$CellContext`sym$117502[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$117502[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$117502[All], 
      All, $CellContext`i$119058], $CellContext`sym$117502[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$117502[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$117502, $CellContext`PO4]], \
$CellContext`sym$117502[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$117502[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$117502[All], 
      All, $CellContext`i$119059], \
$CellContext`sym$117502[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$117502[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$117502, $CellContext`season]], \
$CellContext`sym$117502[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$117502[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$117502[All], 
      All, $CellContext`i$117503], $CellContext`sym$117502[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$117502[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$117502, $CellContext`size]], \
$CellContext`sym$117502[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$117502[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$117502[All], 
      All, $CellContext`i$119051], $CellContext`sym$117502[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$117502[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$117502, $CellContext`speed]], \
$CellContext`sym$117502[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$117502[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$117502[All], All, $CellContext`i$119052], 
    Attributes[$CellContext`i$119064] = {Temporary}, $CellContext`i$119064 = 
    15, Attributes[$CellContext`i$119063] = {
     Temporary}, $CellContext`i$119063 = 14, 
    Attributes[$CellContext`i$119054] = {Temporary}, $CellContext`i$119054 = 
    5, Attributes[$CellContext`i$119061] = {Temporary}, $CellContext`i$119061 = 
    12, Attributes[$CellContext`i$119057] = {
     Temporary}, $CellContext`i$119057 = 8, 
    Attributes[$CellContext`i$119066] = {Temporary}, $CellContext`i$119066 = 
    17, Attributes[$CellContext`i$119065] = {
     Temporary}, $CellContext`i$119065 = 16, 
    Attributes[$CellContext`i$119062] = {Temporary}, $CellContext`i$119062 = 
    13, Attributes[$CellContext`i$119051] = {
     Temporary}, $CellContext`i$119051 = 2, 
    Attributes[$CellContext`i$119060] = {Temporary}, $CellContext`i$119060 = 
    11, Attributes[$CellContext`i$119056] = {
     Temporary}, $CellContext`i$119056 = 7, 
    Attributes[$CellContext`i$119052] = {Temporary}, $CellContext`i$119052 = 
    3, Attributes[$CellContext`i$117503] = {Temporary}, $CellContext`i$117503 = 
    1, Attributes[$CellContext`i$119058] = {Temporary}, $CellContext`i$119058 = 
    9, Attributes[$CellContext`i$119059] = {Temporary}, $CellContext`i$119059 = 
    10, Attributes[$CellContext`i$119053] = {
     Temporary}, $CellContext`i$119053 = 4, 
    Attributes[$CellContext`i$119055] = {Temporary}, $CellContext`i$119055 = 
    6, Attributes[$CellContext`i$119067] = {Temporary}, $CellContext`i$119067 = 
    18, Attributes[$CellContext`sym$227522] = {
     Temporary}, $CellContext`sym$227522[$CellContext`a1] = Part[
      $CellContext`sym$227522[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227522[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$227522[$CellContext`a2] = Part[
      $CellContext`sym$227522[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227522[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$227522[$CellContext`a3] = Part[
      $CellContext`sym$227522[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227522[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$227522[$CellContext`a4] = Part[
      $CellContext`sym$227522[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227522[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$227522[$CellContext`a5] = Part[
      $CellContext`sym$227522[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227522[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$227522[$CellContext`a6] = Part[
      $CellContext`sym$227522[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227522[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$227522[$CellContext`a7] = Part[
      $CellContext`sym$227522[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227522[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$227522[All] = $CellContext`med[
     All], $CellContext`sym$227522[$CellContext`Chla] = Part[
      $CellContext`sym$227522[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227522[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$227522[$CellContext`Cl] = Part[
      $CellContext`sym$227522[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227522[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$227522[$CellContext`mnO2] = Part[
      $CellContext`sym$227522[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227522[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$227522[$CellContext`mxPH] = Part[
      $CellContext`sym$227522[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227522[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$227522[$CellContext`NH4] = Part[
      $CellContext`sym$227522[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227522[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$227522[$CellContext`NO3] = Part[
      $CellContext`sym$227522[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227522[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$227522[$CellContext`oPO4] = Part[
      $CellContext`sym$227522[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227522[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$227522[$CellContext`PO4] = Part[
      $CellContext`sym$227522[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227522[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$227522[$CellContext`season] = Part[
      $CellContext`sym$227522[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227522[$CellContext`season, 
         "missing"]]]], $CellContext`sym$227522[$CellContext`size] = Part[
      $CellContext`sym$227522[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227522[$CellContext`size, 
         "missing"]]]], $CellContext`sym$227522[$CellContext`speed] = Part[
      $CellContext`sym$227522[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227522[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$227522[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$227522[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227522, $CellContext`a1]], \
$CellContext`sym$227522[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$227522[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$227522[All], 
      All, $CellContext`i$227534], $CellContext`sym$227522[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$227522[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227522, $CellContext`a2]], \
$CellContext`sym$227522[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$227522[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$227522[All], 
      All, $CellContext`i$227535], $CellContext`sym$227522[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$227522[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227522, $CellContext`a3]], \
$CellContext`sym$227522[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$227522[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$227522[All], 
      All, $CellContext`i$227536], $CellContext`sym$227522[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$227522[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227522, $CellContext`a4]], \
$CellContext`sym$227522[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$227522[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$227522[All], 
      All, $CellContext`i$227537], $CellContext`sym$227522[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$227522[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227522, $CellContext`a5]], \
$CellContext`sym$227522[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$227522[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$227522[All], 
      All, $CellContext`i$227538], $CellContext`sym$227522[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$227522[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227522, $CellContext`a6]], \
$CellContext`sym$227522[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$227522[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$227522[All], 
      All, $CellContext`i$227539], $CellContext`sym$227522[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$227522[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227522, $CellContext`a7]], \
$CellContext`sym$227522[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$227522[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$227522[All], 
      All, $CellContext`i$227540], $CellContext`sym$227522[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$227522[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$227522[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$227522[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227522, $CellContext`Chla]], \
$CellContext`sym$227522[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$227522[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$227522[All], 
      All, $CellContext`i$227533], $CellContext`sym$227522[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$227522[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227522, $CellContext`Cl]], \
$CellContext`sym$227522[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$227522[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$227522[All], 
      All, $CellContext`i$227528], $CellContext`sym$227522[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$227522[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227522, $CellContext`mnO2]], \
$CellContext`sym$227522[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$227522[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$227522[All], 
      All, $CellContext`i$227527], $CellContext`sym$227522[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$227522[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227522, $CellContext`mxPH]], \
$CellContext`sym$227522[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$227522[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$227522[All], 
      All, $CellContext`i$227526], $CellContext`sym$227522[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$227522[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227522, $CellContext`NH4]], \
$CellContext`sym$227522[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$227522[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$227522[All], 
      All, $CellContext`i$227530], $CellContext`sym$227522[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$227522[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227522, $CellContext`NO3]], \
$CellContext`sym$227522[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$227522[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$227522[All], 
      All, $CellContext`i$227529], $CellContext`sym$227522[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$227522[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227522, $CellContext`oPO4]], \
$CellContext`sym$227522[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$227522[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$227522[All], 
      All, $CellContext`i$227531], $CellContext`sym$227522[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$227522[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227522, $CellContext`PO4]], \
$CellContext`sym$227522[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$227522[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$227522[All], 
      All, $CellContext`i$227532], \
$CellContext`sym$227522[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$227522[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227522, $CellContext`season]], \
$CellContext`sym$227522[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$227522[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$227522[All], 
      All, $CellContext`i$227523], $CellContext`sym$227522[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$227522[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227522, $CellContext`size]], \
$CellContext`sym$227522[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$227522[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$227522[All], 
      All, $CellContext`i$227524], $CellContext`sym$227522[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$227522[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227522, $CellContext`speed]], \
$CellContext`sym$227522[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$227522[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$227522[All], All, $CellContext`i$227525], 
    Attributes[$CellContext`i$227529] = {Temporary}, $CellContext`i$227529 = 
    7, Attributes[$CellContext`i$227534] = {Temporary}, $CellContext`i$227534 = 
    12, Attributes[$CellContext`i$227527] = {
     Temporary}, $CellContext`i$227527 = 5, 
    Attributes[$CellContext`i$227523] = {Temporary}, $CellContext`i$227523 = 
    1, Attributes[$CellContext`i$227528] = {Temporary}, $CellContext`i$227528 = 
    6, Attributes[$CellContext`i$227533] = {Temporary}, $CellContext`i$227533 = 
    11, Attributes[$CellContext`i$227525] = {
     Temporary}, $CellContext`i$227525 = 3, 
    Attributes[$CellContext`i$227530] = {Temporary}, $CellContext`i$227530 = 
    8, Attributes[$CellContext`i$227540] = {Temporary}, $CellContext`i$227540 = 
    18, Attributes[$CellContext`i$227524] = {
     Temporary}, $CellContext`i$227524 = 2, 
    Attributes[$CellContext`i$227539] = {Temporary}, $CellContext`i$227539 = 
    17, Attributes[$CellContext`i$227538] = {
     Temporary}, $CellContext`i$227538 = 16, 
    Attributes[$CellContext`i$227532] = {Temporary}, $CellContext`i$227532 = 
    10, Attributes[$CellContext`i$227535] = {
     Temporary}, $CellContext`i$227535 = 13, 
    Attributes[$CellContext`i$227536] = {Temporary}, $CellContext`i$227536 = 
    14, Attributes[$CellContext`i$227537] = {
     Temporary}, $CellContext`i$227537 = 15, 
    Attributes[$CellContext`i$227526] = {Temporary}, $CellContext`i$227526 = 
    4, Attributes[$CellContext`i$227531] = {Temporary}, $CellContext`i$227531 = 
    9, Attributes[$CellContext`sym$155463] = {
     Temporary}, $CellContext`sym$155463[$CellContext`a1] = Part[
      $CellContext`sym$155463[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$155463[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$155463[$CellContext`a2] = Part[
      $CellContext`sym$155463[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$155463[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$155463[$CellContext`a3] = Part[
      $CellContext`sym$155463[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$155463[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$155463[$CellContext`a4] = Part[
      $CellContext`sym$155463[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$155463[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$155463[$CellContext`a5] = Part[
      $CellContext`sym$155463[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$155463[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$155463[$CellContext`a6] = Part[
      $CellContext`sym$155463[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$155463[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$155463[$CellContext`a7] = Part[
      $CellContext`sym$155463[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$155463[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$155463[All] = $CellContext`med[
     All], $CellContext`sym$155463[$CellContext`Chla] = Part[
      $CellContext`sym$155463[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$155463[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$155463[$CellContext`Cl] = Part[
      $CellContext`sym$155463[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$155463[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$155463[$CellContext`mnO2] = Part[
      $CellContext`sym$155463[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$155463[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$155463[$CellContext`mxPH] = Part[
      $CellContext`sym$155463[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$155463[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$155463[$CellContext`NH4] = Part[
      $CellContext`sym$155463[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$155463[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$155463[$CellContext`NO3] = Part[
      $CellContext`sym$155463[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$155463[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$155463[$CellContext`oPO4] = Part[
      $CellContext`sym$155463[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$155463[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$155463[$CellContext`PO4] = Part[
      $CellContext`sym$155463[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$155463[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$155463[$CellContext`season] = Part[
      $CellContext`sym$155463[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$155463[$CellContext`season, 
         "missing"]]]], $CellContext`sym$155463[$CellContext`size] = Part[
      $CellContext`sym$155463[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$155463[$CellContext`size, 
         "missing"]]]], $CellContext`sym$155463[$CellContext`speed] = Part[
      $CellContext`sym$155463[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$155463[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$155463[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$155463[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$155463, $CellContext`a1]], \
$CellContext`sym$155463[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$155463[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$155463[All], 
      All, $CellContext`i$157022], $CellContext`sym$155463[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$155463[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$155463, $CellContext`a2]], \
$CellContext`sym$155463[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$155463[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$155463[All], 
      All, $CellContext`i$157023], $CellContext`sym$155463[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$155463[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$155463, $CellContext`a3]], \
$CellContext`sym$155463[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$155463[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$155463[All], 
      All, $CellContext`i$157024], $CellContext`sym$155463[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$155463[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$155463, $CellContext`a4]], \
$CellContext`sym$155463[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$155463[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$155463[All], 
      All, $CellContext`i$157025], $CellContext`sym$155463[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$155463[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$155463, $CellContext`a5]], \
$CellContext`sym$155463[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$155463[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$155463[All], 
      All, $CellContext`i$157026], $CellContext`sym$155463[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$155463[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$155463, $CellContext`a6]], \
$CellContext`sym$155463[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$155463[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$155463[All], 
      All, $CellContext`i$157027], $CellContext`sym$155463[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$155463[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$155463, $CellContext`a7]], \
$CellContext`sym$155463[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$155463[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$155463[All], 
      All, $CellContext`i$157028], $CellContext`sym$155463[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$155463[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$155463[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$155463[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$155463, $CellContext`Chla]], \
$CellContext`sym$155463[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$155463[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$155463[All], 
      All, $CellContext`i$157021], $CellContext`sym$155463[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$155463[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$155463, $CellContext`Cl]], \
$CellContext`sym$155463[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$155463[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$155463[All], 
      All, $CellContext`i$157016], $CellContext`sym$155463[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$155463[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$155463, $CellContext`mnO2]], \
$CellContext`sym$155463[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$155463[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$155463[All], 
      All, $CellContext`i$157015], $CellContext`sym$155463[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$155463[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$155463, $CellContext`mxPH]], \
$CellContext`sym$155463[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$155463[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$155463[All], 
      All, $CellContext`i$157014], $CellContext`sym$155463[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$155463[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$155463, $CellContext`NH4]], \
$CellContext`sym$155463[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$155463[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$155463[All], 
      All, $CellContext`i$157018], $CellContext`sym$155463[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$155463[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$155463, $CellContext`NO3]], \
$CellContext`sym$155463[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$155463[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$155463[All], 
      All, $CellContext`i$157017], $CellContext`sym$155463[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$155463[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$155463, $CellContext`oPO4]], \
$CellContext`sym$155463[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$155463[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$155463[All], 
      All, $CellContext`i$157019], $CellContext`sym$155463[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$155463[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$155463, $CellContext`PO4]], \
$CellContext`sym$155463[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$155463[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$155463[All], 
      All, $CellContext`i$157020], \
$CellContext`sym$155463[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$155463[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$155463, $CellContext`season]], \
$CellContext`sym$155463[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$155463[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$155463[All], 
      All, $CellContext`i$155464], $CellContext`sym$155463[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$155463[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$155463, $CellContext`size]], \
$CellContext`sym$155463[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$155463[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$155463[All], 
      All, $CellContext`i$157012], $CellContext`sym$155463[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$155463[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$155463, $CellContext`speed]], \
$CellContext`sym$155463[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$155463[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$155463[All], All, $CellContext`i$157013], 
    Attributes[$CellContext`i$157019] = {Temporary}, $CellContext`i$157019 = 
    9, Attributes[$CellContext`i$157016] = {Temporary}, $CellContext`i$157016 = 
    6, Attributes[$CellContext`i$157027] = {Temporary}, $CellContext`i$157027 = 
    17, Attributes[$CellContext`i$157018] = {
     Temporary}, $CellContext`i$157018 = 8, 
    Attributes[$CellContext`i$157026] = {Temporary}, $CellContext`i$157026 = 
    16, Attributes[$CellContext`i$157017] = {
     Temporary}, $CellContext`i$157017 = 7, 
    Attributes[$CellContext`i$157022] = {Temporary}, $CellContext`i$157022 = 
    12, Attributes[$CellContext`i$157013] = {
     Temporary}, $CellContext`i$157013 = 3, 
    Attributes[$CellContext`i$157028] = {Temporary}, $CellContext`i$157028 = 
    18, Attributes[$CellContext`i$157023] = {
     Temporary}, $CellContext`i$157023 = 13, 
    Attributes[$CellContext`i$157021] = {Temporary}, $CellContext`i$157021 = 
    11, Attributes[$CellContext`i$157014] = {
     Temporary}, $CellContext`i$157014 = 4, 
    Attributes[$CellContext`i$157015] = {Temporary}, $CellContext`i$157015 = 
    5, Attributes[$CellContext`i$157020] = {Temporary}, $CellContext`i$157020 = 
    10, Attributes[$CellContext`i$157012] = {
     Temporary}, $CellContext`i$157012 = 2, 
    Attributes[$CellContext`i$155464] = {Temporary}, $CellContext`i$155464 = 
    1, Attributes[$CellContext`i$157025] = {Temporary}, $CellContext`i$157025 = 
    15, Attributes[$CellContext`i$157024] = {
     Temporary}, $CellContext`i$157024 = 14, 
    Attributes[$CellContext`sym$204589] = {
     Temporary}, $CellContext`sym$204589[$CellContext`a1] = Part[
      $CellContext`sym$204589[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$204589[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$204589[$CellContext`a2] = Part[
      $CellContext`sym$204589[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$204589[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$204589[$CellContext`a3] = Part[
      $CellContext`sym$204589[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$204589[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$204589[$CellContext`a4] = Part[
      $CellContext`sym$204589[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$204589[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$204589[$CellContext`a5] = Part[
      $CellContext`sym$204589[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$204589[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$204589[$CellContext`a6] = Part[
      $CellContext`sym$204589[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$204589[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$204589[$CellContext`a7] = Part[
      $CellContext`sym$204589[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$204589[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$204589[All] = $CellContext`med[
     All], $CellContext`sym$204589[$CellContext`Chla] = Part[
      $CellContext`sym$204589[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$204589[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$204589[$CellContext`Cl] = Part[
      $CellContext`sym$204589[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$204589[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$204589[$CellContext`mnO2] = Part[
      $CellContext`sym$204589[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$204589[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$204589[$CellContext`mxPH] = Part[
      $CellContext`sym$204589[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$204589[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$204589[$CellContext`NH4] = Part[
      $CellContext`sym$204589[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$204589[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$204589[$CellContext`NO3] = Part[
      $CellContext`sym$204589[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$204589[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$204589[$CellContext`oPO4] = Part[
      $CellContext`sym$204589[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$204589[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$204589[$CellContext`PO4] = Part[
      $CellContext`sym$204589[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$204589[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$204589[$CellContext`season] = Part[
      $CellContext`sym$204589[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$204589[$CellContext`season, 
         "missing"]]]], $CellContext`sym$204589[$CellContext`size] = Part[
      $CellContext`sym$204589[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$204589[$CellContext`size, 
         "missing"]]]], $CellContext`sym$204589[$CellContext`speed] = Part[
      $CellContext`sym$204589[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$204589[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$204589[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$204589[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$204589, $CellContext`a1]], \
$CellContext`sym$204589[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$204589[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$204589[All], 
      All, $CellContext`i$206148], $CellContext`sym$204589[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$204589[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$204589, $CellContext`a2]], \
$CellContext`sym$204589[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$204589[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$204589[All], 
      All, $CellContext`i$206149], $CellContext`sym$204589[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$204589[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$204589, $CellContext`a3]], \
$CellContext`sym$204589[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$204589[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$204589[All], 
      All, $CellContext`i$206150], $CellContext`sym$204589[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$204589[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$204589, $CellContext`a4]], \
$CellContext`sym$204589[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$204589[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$204589[All], 
      All, $CellContext`i$206151], $CellContext`sym$204589[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$204589[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$204589, $CellContext`a5]], \
$CellContext`sym$204589[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$204589[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$204589[All], 
      All, $CellContext`i$206152], $CellContext`sym$204589[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$204589[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$204589, $CellContext`a6]], \
$CellContext`sym$204589[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$204589[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$204589[All], 
      All, $CellContext`i$206153], $CellContext`sym$204589[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$204589[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$204589, $CellContext`a7]], \
$CellContext`sym$204589[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$204589[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$204589[All], 
      All, $CellContext`i$206154], $CellContext`sym$204589[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$204589[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$204589[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$204589[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$204589, $CellContext`Chla]], \
$CellContext`sym$204589[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$204589[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$204589[All], 
      All, $CellContext`i$206147], $CellContext`sym$204589[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$204589[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$204589, $CellContext`Cl]], \
$CellContext`sym$204589[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$204589[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$204589[All], 
      All, $CellContext`i$206142], $CellContext`sym$204589[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$204589[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$204589, $CellContext`mnO2]], \
$CellContext`sym$204589[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$204589[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$204589[All], 
      All, $CellContext`i$206141], $CellContext`sym$204589[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$204589[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$204589, $CellContext`mxPH]], \
$CellContext`sym$204589[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$204589[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$204589[All], 
      All, $CellContext`i$206140], $CellContext`sym$204589[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$204589[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$204589, $CellContext`NH4]], \
$CellContext`sym$204589[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$204589[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$204589[All], 
      All, $CellContext`i$206144], $CellContext`sym$204589[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$204589[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$204589, $CellContext`NO3]], \
$CellContext`sym$204589[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$204589[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$204589[All], 
      All, $CellContext`i$206143], $CellContext`sym$204589[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$204589[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$204589, $CellContext`oPO4]], \
$CellContext`sym$204589[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$204589[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$204589[All], 
      All, $CellContext`i$206145], $CellContext`sym$204589[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$204589[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$204589, $CellContext`PO4]], \
$CellContext`sym$204589[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$204589[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$204589[All], 
      All, $CellContext`i$206146], \
$CellContext`sym$204589[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$204589[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$204589, $CellContext`season]], \
$CellContext`sym$204589[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$204589[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$204589[All], 
      All, $CellContext`i$204590], $CellContext`sym$204589[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$204589[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$204589, $CellContext`size]], \
$CellContext`sym$204589[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$204589[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$204589[All], 
      All, $CellContext`i$206138], $CellContext`sym$204589[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$204589[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$204589, $CellContext`speed]], \
$CellContext`sym$204589[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$204589[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$204589[All], All, $CellContext`i$206139], 
    Attributes[$CellContext`i$206138] = {Temporary}, $CellContext`i$206138 = 
    2, Attributes[$CellContext`i$204590] = {Temporary}, $CellContext`i$204590 = 
    1, Attributes[$CellContext`i$206139] = {Temporary}, $CellContext`i$206139 = 
    3, Attributes[$CellContext`i$206153] = {Temporary}, $CellContext`i$206153 = 
    17, Attributes[$CellContext`i$206152] = {
     Temporary}, $CellContext`i$206152 = 16, 
    Attributes[$CellContext`i$206142] = {Temporary}, $CellContext`i$206142 = 
    6, Attributes[$CellContext`i$206143] = {Temporary}, $CellContext`i$206143 = 
    7, Attributes[$CellContext`i$206140] = {Temporary}, $CellContext`i$206140 = 
    4, Attributes[$CellContext`i$206149] = {Temporary}, $CellContext`i$206149 = 
    13, Attributes[$CellContext`i$206147] = {
     Temporary}, $CellContext`i$206147 = 11, 
    Attributes[$CellContext`i$206150] = {Temporary}, $CellContext`i$206150 = 
    14, Attributes[$CellContext`i$206154] = {
     Temporary}, $CellContext`i$206154 = 18, 
    Attributes[$CellContext`i$206148] = {Temporary}, $CellContext`i$206148 = 
    12, Attributes[$CellContext`i$206144] = {
     Temporary}, $CellContext`i$206144 = 8, 
    Attributes[$CellContext`i$206145] = {Temporary}, $CellContext`i$206145 = 
    9, Attributes[$CellContext`i$206146] = {Temporary}, $CellContext`i$206146 = 
    10, Attributes[$CellContext`i$206141] = {
     Temporary}, $CellContext`i$206141 = 5, 
    Attributes[$CellContext`i$206151] = {Temporary}, $CellContext`i$206151 = 
    15, Attributes[$CellContext`sym$226925] = {
     Temporary}, $CellContext`sym$226925[$CellContext`a1] = Part[
      $CellContext`sym$226925[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$226925[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$226925[$CellContext`a2] = Part[
      $CellContext`sym$226925[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$226925[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$226925[$CellContext`a3] = Part[
      $CellContext`sym$226925[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$226925[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$226925[$CellContext`a4] = Part[
      $CellContext`sym$226925[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$226925[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$226925[$CellContext`a5] = Part[
      $CellContext`sym$226925[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$226925[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$226925[$CellContext`a6] = Part[
      $CellContext`sym$226925[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$226925[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$226925[$CellContext`a7] = Part[
      $CellContext`sym$226925[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$226925[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$226925[All] = $CellContext`med[
     All], $CellContext`sym$226925[$CellContext`Chla] = Part[
      $CellContext`sym$226925[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$226925[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$226925[$CellContext`Cl] = Part[
      $CellContext`sym$226925[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$226925[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$226925[$CellContext`mnO2] = Part[
      $CellContext`sym$226925[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$226925[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$226925[$CellContext`mxPH] = Part[
      $CellContext`sym$226925[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$226925[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$226925[$CellContext`NH4] = Part[
      $CellContext`sym$226925[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$226925[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$226925[$CellContext`NO3] = Part[
      $CellContext`sym$226925[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$226925[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$226925[$CellContext`oPO4] = Part[
      $CellContext`sym$226925[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$226925[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$226925[$CellContext`PO4] = Part[
      $CellContext`sym$226925[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$226925[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$226925[$CellContext`season] = Part[
      $CellContext`sym$226925[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$226925[$CellContext`season, 
         "missing"]]]], $CellContext`sym$226925[$CellContext`size] = Part[
      $CellContext`sym$226925[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$226925[$CellContext`size, 
         "missing"]]]], $CellContext`sym$226925[$CellContext`speed] = Part[
      $CellContext`sym$226925[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$226925[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$226925[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$226925[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$226925, $CellContext`a1]], \
$CellContext`sym$226925[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$226925[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$226925[All], 
      All, $CellContext`i$226937], $CellContext`sym$226925[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$226925[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$226925, $CellContext`a2]], \
$CellContext`sym$226925[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$226925[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$226925[All], 
      All, $CellContext`i$226938], $CellContext`sym$226925[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$226925[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$226925, $CellContext`a3]], \
$CellContext`sym$226925[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$226925[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$226925[All], 
      All, $CellContext`i$226939], $CellContext`sym$226925[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$226925[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$226925, $CellContext`a4]], \
$CellContext`sym$226925[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$226925[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$226925[All], 
      All, $CellContext`i$226940], $CellContext`sym$226925[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$226925[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$226925, $CellContext`a5]], \
$CellContext`sym$226925[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$226925[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$226925[All], 
      All, $CellContext`i$226941], $CellContext`sym$226925[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$226925[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$226925, $CellContext`a6]], \
$CellContext`sym$226925[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$226925[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$226925[All], 
      All, $CellContext`i$226942], $CellContext`sym$226925[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$226925[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$226925, $CellContext`a7]], \
$CellContext`sym$226925[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$226925[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$226925[All], 
      All, $CellContext`i$226943], $CellContext`sym$226925[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$226925[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$226925[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$226925[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$226925, $CellContext`Chla]], \
$CellContext`sym$226925[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$226925[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$226925[All], 
      All, $CellContext`i$226936], $CellContext`sym$226925[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$226925[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$226925, $CellContext`Cl]], \
$CellContext`sym$226925[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$226925[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$226925[All], 
      All, $CellContext`i$226931], $CellContext`sym$226925[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$226925[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$226925, $CellContext`mnO2]], \
$CellContext`sym$226925[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$226925[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$226925[All], 
      All, $CellContext`i$226930], $CellContext`sym$226925[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$226925[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$226925, $CellContext`mxPH]], \
$CellContext`sym$226925[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$226925[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$226925[All], 
      All, $CellContext`i$226929], $CellContext`sym$226925[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$226925[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$226925, $CellContext`NH4]], \
$CellContext`sym$226925[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$226925[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$226925[All], 
      All, $CellContext`i$226933], $CellContext`sym$226925[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$226925[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$226925, $CellContext`NO3]], \
$CellContext`sym$226925[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$226925[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$226925[All], 
      All, $CellContext`i$226932], $CellContext`sym$226925[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$226925[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$226925, $CellContext`oPO4]], \
$CellContext`sym$226925[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$226925[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$226925[All], 
      All, $CellContext`i$226934], $CellContext`sym$226925[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$226925[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$226925, $CellContext`PO4]], \
$CellContext`sym$226925[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$226925[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$226925[All], 
      All, $CellContext`i$226935], \
$CellContext`sym$226925[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$226925[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$226925, $CellContext`season]], \
$CellContext`sym$226925[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$226925[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$226925[All], 
      All, $CellContext`i$226926], $CellContext`sym$226925[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$226925[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$226925, $CellContext`size]], \
$CellContext`sym$226925[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$226925[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$226925[All], 
      All, $CellContext`i$226927], $CellContext`sym$226925[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$226925[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$226925, $CellContext`speed]], \
$CellContext`sym$226925[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$226925[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$226925[All], All, $CellContext`i$226928], 
    Attributes[$CellContext`i$226939] = {Temporary}, $CellContext`i$226939 = 
    14, Attributes[$CellContext`i$226941] = {
     Temporary}, $CellContext`i$226941 = 16, 
    Attributes[$CellContext`i$226929] = {Temporary}, $CellContext`i$226929 = 
    4, Attributes[$CellContext`i$226928] = {Temporary}, $CellContext`i$226928 = 
    3, Attributes[$CellContext`i$226933] = {Temporary}, $CellContext`i$226933 = 
    8, Attributes[$CellContext`i$226930] = {Temporary}, $CellContext`i$226930 = 
    5, Attributes[$CellContext`i$226931] = {Temporary}, $CellContext`i$226931 = 
    6, Attributes[$CellContext`i$226936] = {Temporary}, $CellContext`i$226936 = 
    11, Attributes[$CellContext`i$226940] = {
     Temporary}, $CellContext`i$226940 = 15, 
    Attributes[$CellContext`i$226926] = {Temporary}, $CellContext`i$226926 = 
    1, Attributes[$CellContext`i$226942] = {Temporary}, $CellContext`i$226942 = 
    17, Attributes[$CellContext`i$226927] = {
     Temporary}, $CellContext`i$226927 = 2, 
    Attributes[$CellContext`i$226938] = {Temporary}, $CellContext`i$226938 = 
    13, Attributes[$CellContext`i$226937] = {
     Temporary}, $CellContext`i$226937 = 12, 
    Attributes[$CellContext`i$226932] = {Temporary}, $CellContext`i$226932 = 
    7, Attributes[$CellContext`i$226943] = {Temporary}, $CellContext`i$226943 = 
    18, Attributes[$CellContext`i$226935] = {
     Temporary}, $CellContext`i$226935 = 10, 
    Attributes[$CellContext`i$226934] = {Temporary}, $CellContext`i$226934 = 
    9, Attributes[$CellContext`sym$48201] = {
     Temporary}, $CellContext`sym$48201[$CellContext`a1] = $CellContext`med[
     All], $CellContext`sym$48201[$CellContext`a2] = $CellContext`med[
     All], $CellContext`sym$48201[$CellContext`a3] = $CellContext`med[
     All], $CellContext`sym$48201[$CellContext`a4] = $CellContext`med[
     All], $CellContext`sym$48201[$CellContext`a5] = $CellContext`med[
     All], $CellContext`sym$48201[$CellContext`a6] = $CellContext`med[
     All], $CellContext`sym$48201[$CellContext`a7] = $CellContext`med[
     All], $CellContext`sym$48201[All] = $CellContext`med[
     All], $CellContext`sym$48201[$CellContext`Chla] = $CellContext`med[
     All], $CellContext`sym$48201[$CellContext`Cl] = $CellContext`med[
     All], $CellContext`sym$48201[$CellContext`mnO2] = $CellContext`med[
     All], $CellContext`sym$48201[$CellContext`mxPH] = $CellContext`med[
     All], $CellContext`sym$48201[$CellContext`NH4] = $CellContext`med[
     All], $CellContext`sym$48201[$CellContext`NO3] = $CellContext`med[
     All], $CellContext`sym$48201[$CellContext`oPO4] = $CellContext`med[
     All], $CellContext`sym$48201[$CellContext`PO4] = $CellContext`med[
     All], $CellContext`sym$48201[$CellContext`season] = $CellContext`med[
     All], $CellContext`sym$48201[$CellContext`size] = $CellContext`med[
     All], $CellContext`sym$48201[$CellContext`speed] = $CellContext`med[
     All], $CellContext`sym$48201[$CellContext`a1, "factorized"] = 
    True, $CellContext`sym$48201[$CellContext`a1, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$48201[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$48201[$CellContext`a1, "raw"] = Part[
      $CellContext`med[All], All, 12], $CellContext`sym$48201[$CellContext`a2,
       "factorized"] = 
    True, $CellContext`sym$48201[$CellContext`a2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$48201[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$48201[$CellContext`a2, "raw"] = Part[
      $CellContext`med[All], All, 13], $CellContext`sym$48201[$CellContext`a3,
       "factorized"] = 
    True, $CellContext`sym$48201[$CellContext`a3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$48201[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$48201[$CellContext`a3, "raw"] = Part[
      $CellContext`med[All], All, 14], $CellContext`sym$48201[$CellContext`a4,
       "factorized"] = 
    True, $CellContext`sym$48201[$CellContext`a4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$48201[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$48201[$CellContext`a4, "raw"] = Part[
      $CellContext`med[All], All, 15], $CellContext`sym$48201[$CellContext`a5,
       "factorized"] = 
    True, $CellContext`sym$48201[$CellContext`a5, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$48201[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$48201[$CellContext`a5, "raw"] = Part[
      $CellContext`med[All], All, 16], $CellContext`sym$48201[$CellContext`a6,
       "factorized"] = 
    True, $CellContext`sym$48201[$CellContext`a6, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$48201[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$48201[$CellContext`a6, "raw"] = Part[
      $CellContext`med[All], All, 17], $CellContext`sym$48201[$CellContext`a7,
       "factorized"] = 
    True, $CellContext`sym$48201[$CellContext`a7, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$48201[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$48201[$CellContext`a7, "raw"] = Part[
      $CellContext`med[All], All, 18], $CellContext`sym$48201[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$48201[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$48201[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$48201[$CellContext`Chla, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$48201[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$48201[$CellContext`Chla, "raw"] = Part[
      $CellContext`med[All], All, 11], $CellContext`sym$48201[$CellContext`Cl,
       "factorized"] = 
    True, $CellContext`sym$48201[$CellContext`Cl, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$48201[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$48201[$CellContext`Cl, "raw"] = Part[
      $CellContext`med[All], All, 
      6], $CellContext`sym$48201[$CellContext`mnO2, "factorized"] = 
    True, $CellContext`sym$48201[$CellContext`mnO2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$48201[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$48201[$CellContext`mnO2, "raw"] = Part[
      $CellContext`med[All], All, 
      5], $CellContext`sym$48201[$CellContext`mxPH, "factorized"] = 
    True, $CellContext`sym$48201[$CellContext`mxPH, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$48201[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$48201[$CellContext`mxPH, "raw"] = Part[
      $CellContext`med[All], All, 4], $CellContext`sym$48201[$CellContext`NH4,
       "factorized"] = 
    True, $CellContext`sym$48201[$CellContext`NH4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$48201[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$48201[$CellContext`NH4, "raw"] = Part[
      $CellContext`med[All], All, 8], $CellContext`sym$48201[$CellContext`NO3,
       "factorized"] = 
    True, $CellContext`sym$48201[$CellContext`NO3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$48201[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$48201[$CellContext`NO3, "raw"] = Part[
      $CellContext`med[All], All, 
      7], $CellContext`sym$48201[$CellContext`oPO4, "factorized"] = 
    True, $CellContext`sym$48201[$CellContext`oPO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$48201[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$48201[$CellContext`oPO4, "raw"] = Part[
      $CellContext`med[All], All, 9], $CellContext`sym$48201[$CellContext`PO4,
       "factorized"] = 
    True, $CellContext`sym$48201[$CellContext`PO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$48201[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$48201[$CellContext`PO4, "raw"] = Part[
      $CellContext`med[All], All, 
      10], $CellContext`sym$48201[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$48201[$CellContext`season, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$48201[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$48201[$CellContext`season, "raw"] = 
    Part[
      $CellContext`med[All], All, 
      1], $CellContext`sym$48201[$CellContext`size, "factorized"] = 
    True, $CellContext`sym$48201[$CellContext`size, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$48201[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$48201[$CellContext`size, "raw"] = Part[
      $CellContext`med[All], All, 
      2], $CellContext`sym$48201[$CellContext`speed, "factorized"] = 
    True, $CellContext`sym$48201[$CellContext`speed, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$48201[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$48201[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`med[All], All, 3], 
    Attributes[$CellContext`sym$70548] = {
     Temporary}, $CellContext`sym$70548[$CellContext`a1] = $CellContext`med[
     All], $CellContext`sym$70548[$CellContext`a2] = $CellContext`med[
     All], $CellContext`sym$70548[$CellContext`a3] = $CellContext`med[
     All], $CellContext`sym$70548[$CellContext`a4] = $CellContext`med[
     All], $CellContext`sym$70548[$CellContext`a5] = $CellContext`med[
     All], $CellContext`sym$70548[$CellContext`a6] = $CellContext`med[
     All], $CellContext`sym$70548[$CellContext`a7] = $CellContext`med[
     All], $CellContext`sym$70548[All] = $CellContext`med[
     All], $CellContext`sym$70548[$CellContext`Chla] = $CellContext`med[
     All], $CellContext`sym$70548[$CellContext`Cl] = $CellContext`med[
     All], $CellContext`sym$70548[$CellContext`mnO2] = $CellContext`med[
     All], $CellContext`sym$70548[$CellContext`mxPH] = $CellContext`med[
     All], $CellContext`sym$70548[$CellContext`NH4] = $CellContext`med[
     All], $CellContext`sym$70548[$CellContext`NO3] = $CellContext`med[
     All], $CellContext`sym$70548[$CellContext`oPO4] = $CellContext`med[
     All], $CellContext`sym$70548[$CellContext`PO4] = $CellContext`med[
     All], $CellContext`sym$70548[$CellContext`season] = $CellContext`med[
     All], $CellContext`sym$70548[$CellContext`size] = $CellContext`med[
     All], $CellContext`sym$70548[$CellContext`speed] = $CellContext`med[
     All], $CellContext`sym$70548[$CellContext`a1, "factorized"] = 
    True, $CellContext`sym$70548[$CellContext`a1, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$70548[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$70548[$CellContext`a1, "raw"] = Part[
      $CellContext`med[All], All, 12], $CellContext`sym$70548[$CellContext`a2,
       "factorized"] = 
    True, $CellContext`sym$70548[$CellContext`a2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$70548[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$70548[$CellContext`a2, "raw"] = Part[
      $CellContext`med[All], All, 13], $CellContext`sym$70548[$CellContext`a3,
       "factorized"] = 
    True, $CellContext`sym$70548[$CellContext`a3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$70548[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$70548[$CellContext`a3, "raw"] = Part[
      $CellContext`med[All], All, 14], $CellContext`sym$70548[$CellContext`a4,
       "factorized"] = 
    True, $CellContext`sym$70548[$CellContext`a4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$70548[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$70548[$CellContext`a4, "raw"] = Part[
      $CellContext`med[All], All, 15], $CellContext`sym$70548[$CellContext`a5,
       "factorized"] = 
    True, $CellContext`sym$70548[$CellContext`a5, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$70548[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$70548[$CellContext`a5, "raw"] = Part[
      $CellContext`med[All], All, 16], $CellContext`sym$70548[$CellContext`a6,
       "factorized"] = 
    True, $CellContext`sym$70548[$CellContext`a6, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$70548[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$70548[$CellContext`a6, "raw"] = Part[
      $CellContext`med[All], All, 17], $CellContext`sym$70548[$CellContext`a7,
       "factorized"] = 
    True, $CellContext`sym$70548[$CellContext`a7, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$70548[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$70548[$CellContext`a7, "raw"] = Part[
      $CellContext`med[All], All, 18], $CellContext`sym$70548[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$70548[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$70548[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$70548[$CellContext`Chla, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$70548[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$70548[$CellContext`Chla, "raw"] = Part[
      $CellContext`med[All], All, 11], $CellContext`sym$70548[$CellContext`Cl,
       "factorized"] = 
    True, $CellContext`sym$70548[$CellContext`Cl, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$70548[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$70548[$CellContext`Cl, "raw"] = Part[
      $CellContext`med[All], All, 
      6], $CellContext`sym$70548[$CellContext`mnO2, "factorized"] = 
    True, $CellContext`sym$70548[$CellContext`mnO2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$70548[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$70548[$CellContext`mnO2, "raw"] = Part[
      $CellContext`med[All], All, 
      5], $CellContext`sym$70548[$CellContext`mxPH, "factorized"] = 
    True, $CellContext`sym$70548[$CellContext`mxPH, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$70548[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$70548[$CellContext`mxPH, "raw"] = Part[
      $CellContext`med[All], All, 4], $CellContext`sym$70548[$CellContext`NH4,
       "factorized"] = 
    True, $CellContext`sym$70548[$CellContext`NH4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$70548[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$70548[$CellContext`NH4, "raw"] = Part[
      $CellContext`med[All], All, 8], $CellContext`sym$70548[$CellContext`NO3,
       "factorized"] = 
    True, $CellContext`sym$70548[$CellContext`NO3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$70548[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$70548[$CellContext`NO3, "raw"] = Part[
      $CellContext`med[All], All, 
      7], $CellContext`sym$70548[$CellContext`oPO4, "factorized"] = 
    True, $CellContext`sym$70548[$CellContext`oPO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$70548[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$70548[$CellContext`oPO4, "raw"] = Part[
      $CellContext`med[All], All, 9], $CellContext`sym$70548[$CellContext`PO4,
       "factorized"] = 
    True, $CellContext`sym$70548[$CellContext`PO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$70548[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$70548[$CellContext`PO4, "raw"] = Part[
      $CellContext`med[All], All, 
      10], $CellContext`sym$70548[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$70548[$CellContext`season, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$70548[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$70548[$CellContext`season, "raw"] = 
    Part[
      $CellContext`med[All], All, 
      1], $CellContext`sym$70548[$CellContext`size, "factorized"] = 
    True, $CellContext`sym$70548[$CellContext`size, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$70548[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$70548[$CellContext`size, "raw"] = Part[
      $CellContext`med[All], All, 
      2], $CellContext`sym$70548[$CellContext`speed, "factorized"] = 
    True, $CellContext`sym$70548[$CellContext`speed, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$70548[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$70548[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`med[All], All, 3], 
    Attributes[$CellContext`sym$173327] = {
     Temporary}, $CellContext`sym$173327[$CellContext`a1] = Part[
      $CellContext`sym$173327[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$173327[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$173327[$CellContext`a2] = Part[
      $CellContext`sym$173327[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$173327[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$173327[$CellContext`a3] = Part[
      $CellContext`sym$173327[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$173327[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$173327[$CellContext`a4] = Part[
      $CellContext`sym$173327[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$173327[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$173327[$CellContext`a5] = Part[
      $CellContext`sym$173327[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$173327[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$173327[$CellContext`a6] = Part[
      $CellContext`sym$173327[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$173327[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$173327[$CellContext`a7] = Part[
      $CellContext`sym$173327[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$173327[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$173327[All] = $CellContext`med[
     All], $CellContext`sym$173327[$CellContext`Chla] = Part[
      $CellContext`sym$173327[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$173327[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$173327[$CellContext`Cl] = Part[
      $CellContext`sym$173327[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$173327[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$173327[$CellContext`mnO2] = Part[
      $CellContext`sym$173327[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$173327[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$173327[$CellContext`mxPH] = Part[
      $CellContext`sym$173327[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$173327[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$173327[$CellContext`NH4] = Part[
      $CellContext`sym$173327[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$173327[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$173327[$CellContext`NO3] = Part[
      $CellContext`sym$173327[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$173327[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$173327[$CellContext`oPO4] = Part[
      $CellContext`sym$173327[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$173327[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$173327[$CellContext`PO4] = Part[
      $CellContext`sym$173327[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$173327[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$173327[$CellContext`season] = Part[
      $CellContext`sym$173327[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$173327[$CellContext`season, 
         "missing"]]]], $CellContext`sym$173327[$CellContext`size] = Part[
      $CellContext`sym$173327[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$173327[$CellContext`size, 
         "missing"]]]], $CellContext`sym$173327[$CellContext`speed] = Part[
      $CellContext`sym$173327[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$173327[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$173327[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$173327[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$173327, $CellContext`a1]], \
$CellContext`sym$173327[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$173327[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$173327[All], 
      All, $CellContext`i$174886], $CellContext`sym$173327[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$173327[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$173327, $CellContext`a2]], \
$CellContext`sym$173327[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$173327[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$173327[All], 
      All, $CellContext`i$174887], $CellContext`sym$173327[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$173327[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$173327, $CellContext`a3]], \
$CellContext`sym$173327[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$173327[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$173327[All], 
      All, $CellContext`i$174888], $CellContext`sym$173327[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$173327[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$173327, $CellContext`a4]], \
$CellContext`sym$173327[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$173327[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$173327[All], 
      All, $CellContext`i$174889], $CellContext`sym$173327[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$173327[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$173327, $CellContext`a5]], \
$CellContext`sym$173327[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$173327[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$173327[All], 
      All, $CellContext`i$174890], $CellContext`sym$173327[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$173327[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$173327, $CellContext`a6]], \
$CellContext`sym$173327[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$173327[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$173327[All], 
      All, $CellContext`i$174891], $CellContext`sym$173327[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$173327[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$173327, $CellContext`a7]], \
$CellContext`sym$173327[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$173327[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$173327[All], 
      All, $CellContext`i$174892], $CellContext`sym$173327[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$173327[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$173327[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$173327[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$173327, $CellContext`Chla]], \
$CellContext`sym$173327[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$173327[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$173327[All], 
      All, $CellContext`i$174885], $CellContext`sym$173327[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$173327[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$173327, $CellContext`Cl]], \
$CellContext`sym$173327[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$173327[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$173327[All], 
      All, $CellContext`i$174880], $CellContext`sym$173327[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$173327[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$173327, $CellContext`mnO2]], \
$CellContext`sym$173327[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$173327[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$173327[All], 
      All, $CellContext`i$174879], $CellContext`sym$173327[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$173327[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$173327, $CellContext`mxPH]], \
$CellContext`sym$173327[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$173327[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$173327[All], 
      All, $CellContext`i$174878], $CellContext`sym$173327[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$173327[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$173327, $CellContext`NH4]], \
$CellContext`sym$173327[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$173327[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$173327[All], 
      All, $CellContext`i$174882], $CellContext`sym$173327[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$173327[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$173327, $CellContext`NO3]], \
$CellContext`sym$173327[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$173327[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$173327[All], 
      All, $CellContext`i$174881], $CellContext`sym$173327[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$173327[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$173327, $CellContext`oPO4]], \
$CellContext`sym$173327[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$173327[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$173327[All], 
      All, $CellContext`i$174883], $CellContext`sym$173327[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$173327[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$173327, $CellContext`PO4]], \
$CellContext`sym$173327[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$173327[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$173327[All], 
      All, $CellContext`i$174884], \
$CellContext`sym$173327[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$173327[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$173327, $CellContext`season]], \
$CellContext`sym$173327[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$173327[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$173327[All], 
      All, $CellContext`i$173328], $CellContext`sym$173327[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$173327[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$173327, $CellContext`size]], \
$CellContext`sym$173327[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$173327[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$173327[All], 
      All, $CellContext`i$174876], $CellContext`sym$173327[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$173327[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$173327, $CellContext`speed]], \
$CellContext`sym$173327[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$173327[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$173327[All], All, $CellContext`i$174877], 
    Attributes[$CellContext`i$174884] = {Temporary}, $CellContext`i$174884 = 
    10, Attributes[$CellContext`i$174882] = {
     Temporary}, $CellContext`i$174882 = 8, 
    Attributes[$CellContext`i$174887] = {Temporary}, $CellContext`i$174887 = 
    13, Attributes[$CellContext`i$174877] = {
     Temporary}, $CellContext`i$174877 = 3, 
    Attributes[$CellContext`i$174876] = {Temporary}, $CellContext`i$174876 = 
    2, Attributes[$CellContext`i$174886] = {Temporary}, $CellContext`i$174886 = 
    12, Attributes[$CellContext`i$174892] = {
     Temporary}, $CellContext`i$174892 = 18, 
    Attributes[$CellContext`i$174879] = {Temporary}, $CellContext`i$174879 = 
    5, Attributes[$CellContext`i$173328] = {Temporary}, $CellContext`i$173328 = 
    1, Attributes[$CellContext`i$174878] = {Temporary}, $CellContext`i$174878 = 
    4, Attributes[$CellContext`i$174881] = {Temporary}, $CellContext`i$174881 = 
    7, Attributes[$CellContext`i$174880] = {Temporary}, $CellContext`i$174880 = 
    6, Attributes[$CellContext`i$174891] = {Temporary}, $CellContext`i$174891 = 
    17, Attributes[$CellContext`i$174885] = {
     Temporary}, $CellContext`i$174885 = 11, 
    Attributes[$CellContext`i$174883] = {Temporary}, $CellContext`i$174883 = 
    9, Attributes[$CellContext`i$174889] = {Temporary}, $CellContext`i$174889 = 
    15, Attributes[$CellContext`i$174888] = {
     Temporary}, $CellContext`i$174888 = 14, 
    Attributes[$CellContext`i$174890] = {Temporary}, $CellContext`i$174890 = 
    16, Attributes[$CellContext`sym$113036] = {
     Temporary}, $CellContext`sym$113036[$CellContext`a1] = Part[
      $CellContext`sym$113036[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$113036[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$113036[$CellContext`a2] = Part[
      $CellContext`sym$113036[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$113036[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$113036[$CellContext`a3] = Part[
      $CellContext`sym$113036[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$113036[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$113036[$CellContext`a4] = Part[
      $CellContext`sym$113036[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$113036[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$113036[$CellContext`a5] = Part[
      $CellContext`sym$113036[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$113036[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$113036[$CellContext`a6] = Part[
      $CellContext`sym$113036[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$113036[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$113036[$CellContext`a7] = Part[
      $CellContext`sym$113036[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$113036[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$113036[All] = $CellContext`med[
     All], $CellContext`sym$113036[$CellContext`Chla] = Part[
      $CellContext`sym$113036[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$113036[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$113036[$CellContext`Cl] = Part[
      $CellContext`sym$113036[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$113036[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$113036[$CellContext`mnO2] = Part[
      $CellContext`sym$113036[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$113036[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$113036[$CellContext`mxPH] = Part[
      $CellContext`sym$113036[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$113036[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$113036[$CellContext`NH4] = Part[
      $CellContext`sym$113036[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$113036[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$113036[$CellContext`NO3] = Part[
      $CellContext`sym$113036[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$113036[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$113036[$CellContext`oPO4] = Part[
      $CellContext`sym$113036[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$113036[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$113036[$CellContext`PO4] = Part[
      $CellContext`sym$113036[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$113036[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$113036[$CellContext`season] = Part[
      $CellContext`sym$113036[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$113036[$CellContext`season, 
         "missing"]]]], $CellContext`sym$113036[$CellContext`size] = Part[
      $CellContext`sym$113036[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$113036[$CellContext`size, 
         "missing"]]]], $CellContext`sym$113036[$CellContext`speed] = Part[
      $CellContext`sym$113036[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$113036[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$113036[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$113036[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$113036, $CellContext`a1]], \
$CellContext`sym$113036[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$113036[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$113036[All], 
      All, $CellContext`i$114595], $CellContext`sym$113036[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$113036[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$113036, $CellContext`a2]], \
$CellContext`sym$113036[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$113036[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$113036[All], 
      All, $CellContext`i$114596], $CellContext`sym$113036[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$113036[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$113036, $CellContext`a3]], \
$CellContext`sym$113036[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$113036[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$113036[All], 
      All, $CellContext`i$114597], $CellContext`sym$113036[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$113036[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$113036, $CellContext`a4]], \
$CellContext`sym$113036[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$113036[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$113036[All], 
      All, $CellContext`i$114598], $CellContext`sym$113036[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$113036[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$113036, $CellContext`a5]], \
$CellContext`sym$113036[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$113036[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$113036[All], 
      All, $CellContext`i$114599], $CellContext`sym$113036[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$113036[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$113036, $CellContext`a6]], \
$CellContext`sym$113036[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$113036[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$113036[All], 
      All, $CellContext`i$114600], $CellContext`sym$113036[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$113036[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$113036, $CellContext`a7]], \
$CellContext`sym$113036[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$113036[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$113036[All], 
      All, $CellContext`i$114601], $CellContext`sym$113036[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$113036[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$113036[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$113036[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$113036, $CellContext`Chla]], \
$CellContext`sym$113036[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$113036[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$113036[All], 
      All, $CellContext`i$114594], $CellContext`sym$113036[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$113036[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$113036, $CellContext`Cl]], \
$CellContext`sym$113036[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$113036[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$113036[All], 
      All, $CellContext`i$114589], $CellContext`sym$113036[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$113036[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$113036, $CellContext`mnO2]], \
$CellContext`sym$113036[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$113036[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$113036[All], 
      All, $CellContext`i$114588], $CellContext`sym$113036[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$113036[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$113036, $CellContext`mxPH]], \
$CellContext`sym$113036[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$113036[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$113036[All], 
      All, $CellContext`i$114587], $CellContext`sym$113036[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$113036[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$113036, $CellContext`NH4]], \
$CellContext`sym$113036[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$113036[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$113036[All], 
      All, $CellContext`i$114591], $CellContext`sym$113036[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$113036[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$113036, $CellContext`NO3]], \
$CellContext`sym$113036[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$113036[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$113036[All], 
      All, $CellContext`i$114590], $CellContext`sym$113036[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$113036[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$113036, $CellContext`oPO4]], \
$CellContext`sym$113036[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$113036[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$113036[All], 
      All, $CellContext`i$114592], $CellContext`sym$113036[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$113036[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$113036, $CellContext`PO4]], \
$CellContext`sym$113036[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$113036[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$113036[All], 
      All, $CellContext`i$114593], \
$CellContext`sym$113036[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$113036[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$113036, $CellContext`season]], \
$CellContext`sym$113036[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$113036[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$113036[All], 
      All, $CellContext`i$113037], $CellContext`sym$113036[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$113036[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$113036, $CellContext`size]], \
$CellContext`sym$113036[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$113036[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$113036[All], 
      All, $CellContext`i$114585], $CellContext`sym$113036[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$113036[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$113036, $CellContext`speed]], \
$CellContext`sym$113036[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$113036[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$113036[All], All, $CellContext`i$114586], 
    Attributes[$CellContext`i$114595] = {Temporary}, $CellContext`i$114595 = 
    12, Attributes[$CellContext`i$114586] = {
     Temporary}, $CellContext`i$114586 = 3, 
    Attributes[$CellContext`i$114590] = {Temporary}, $CellContext`i$114590 = 
    7, Attributes[$CellContext`i$114591] = {Temporary}, $CellContext`i$114591 = 
    8, Attributes[$CellContext`i$114588] = {Temporary}, $CellContext`i$114588 = 
    5, Attributes[$CellContext`i$113037] = {Temporary}, $CellContext`i$113037 = 
    1, Attributes[$CellContext`i$114587] = {Temporary}, $CellContext`i$114587 = 
    4, Attributes[$CellContext`i$114585] = {Temporary}, $CellContext`i$114585 = 
    2, Attributes[$CellContext`i$114592] = {Temporary}, $CellContext`i$114592 = 
    9, Attributes[$CellContext`i$114600] = {Temporary}, $CellContext`i$114600 = 
    17, Attributes[$CellContext`i$114594] = {
     Temporary}, $CellContext`i$114594 = 11, 
    Attributes[$CellContext`i$114598] = {Temporary}, $CellContext`i$114598 = 
    15, Attributes[$CellContext`i$114593] = {
     Temporary}, $CellContext`i$114593 = 10, 
    Attributes[$CellContext`i$114597] = {Temporary}, $CellContext`i$114597 = 
    14, Attributes[$CellContext`i$114589] = {
     Temporary}, $CellContext`i$114589 = 6, 
    Attributes[$CellContext`i$114596] = {Temporary}, $CellContext`i$114596 = 
    13, Attributes[$CellContext`i$114599] = {
     Temporary}, $CellContext`i$114599 = 16, 
    Attributes[$CellContext`i$114601] = {Temporary}, $CellContext`i$114601 = 
    18, Attributes[$CellContext`sym$106337] = {
     Temporary}, $CellContext`sym$106337[$CellContext`a1] = Part[
      $CellContext`sym$106337[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$106337[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$106337[$CellContext`a2] = Part[
      $CellContext`sym$106337[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$106337[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$106337[$CellContext`a3] = Part[
      $CellContext`sym$106337[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$106337[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$106337[$CellContext`a4] = Part[
      $CellContext`sym$106337[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$106337[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$106337[$CellContext`a5] = Part[
      $CellContext`sym$106337[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$106337[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$106337[$CellContext`a6] = Part[
      $CellContext`sym$106337[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$106337[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$106337[$CellContext`a7] = Part[
      $CellContext`sym$106337[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$106337[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$106337[All] = $CellContext`med[
     All], $CellContext`sym$106337[$CellContext`Chla] = Part[
      $CellContext`sym$106337[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$106337[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$106337[$CellContext`Cl] = Part[
      $CellContext`sym$106337[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$106337[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$106337[$CellContext`mnO2] = Part[
      $CellContext`sym$106337[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$106337[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$106337[$CellContext`mxPH] = Part[
      $CellContext`sym$106337[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$106337[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$106337[$CellContext`NH4] = Part[
      $CellContext`sym$106337[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$106337[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$106337[$CellContext`NO3] = Part[
      $CellContext`sym$106337[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$106337[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$106337[$CellContext`oPO4] = Part[
      $CellContext`sym$106337[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$106337[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$106337[$CellContext`PO4] = Part[
      $CellContext`sym$106337[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$106337[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$106337[$CellContext`season] = Part[
      $CellContext`sym$106337[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$106337[$CellContext`season, 
         "missing"]]]], $CellContext`sym$106337[$CellContext`size] = Part[
      $CellContext`sym$106337[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$106337[$CellContext`size, 
         "missing"]]]], $CellContext`sym$106337[$CellContext`speed] = Part[
      $CellContext`sym$106337[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$106337[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$106337[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$106337[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$106337, $CellContext`a1]], \
$CellContext`sym$106337[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$106337[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$106337[All], 
      All, $CellContext`i$107896], $CellContext`sym$106337[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$106337[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$106337, $CellContext`a2]], \
$CellContext`sym$106337[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$106337[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$106337[All], 
      All, $CellContext`i$107897], $CellContext`sym$106337[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$106337[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$106337, $CellContext`a3]], \
$CellContext`sym$106337[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$106337[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$106337[All], 
      All, $CellContext`i$107898], $CellContext`sym$106337[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$106337[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$106337, $CellContext`a4]], \
$CellContext`sym$106337[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$106337[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$106337[All], 
      All, $CellContext`i$107899], $CellContext`sym$106337[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$106337[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$106337, $CellContext`a5]], \
$CellContext`sym$106337[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$106337[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$106337[All], 
      All, $CellContext`i$107900], $CellContext`sym$106337[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$106337[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$106337, $CellContext`a6]], \
$CellContext`sym$106337[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$106337[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$106337[All], 
      All, $CellContext`i$107901], $CellContext`sym$106337[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$106337[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$106337, $CellContext`a7]], \
$CellContext`sym$106337[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$106337[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$106337[All], 
      All, $CellContext`i$107902], $CellContext`sym$106337[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$106337[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$106337[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$106337[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$106337, $CellContext`Chla]], \
$CellContext`sym$106337[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$106337[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$106337[All], 
      All, $CellContext`i$107895], $CellContext`sym$106337[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$106337[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$106337, $CellContext`Cl]], \
$CellContext`sym$106337[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$106337[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$106337[All], 
      All, $CellContext`i$107890], $CellContext`sym$106337[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$106337[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$106337, $CellContext`mnO2]], \
$CellContext`sym$106337[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$106337[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$106337[All], 
      All, $CellContext`i$107889], $CellContext`sym$106337[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$106337[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$106337, $CellContext`mxPH]], \
$CellContext`sym$106337[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$106337[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$106337[All], 
      All, $CellContext`i$107888], $CellContext`sym$106337[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$106337[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$106337, $CellContext`NH4]], \
$CellContext`sym$106337[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$106337[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$106337[All], 
      All, $CellContext`i$107892], $CellContext`sym$106337[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$106337[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$106337, $CellContext`NO3]], \
$CellContext`sym$106337[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$106337[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$106337[All], 
      All, $CellContext`i$107891], $CellContext`sym$106337[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$106337[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$106337, $CellContext`oPO4]], \
$CellContext`sym$106337[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$106337[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$106337[All], 
      All, $CellContext`i$107893], $CellContext`sym$106337[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$106337[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$106337, $CellContext`PO4]], \
$CellContext`sym$106337[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$106337[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$106337[All], 
      All, $CellContext`i$107894], \
$CellContext`sym$106337[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$106337[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$106337, $CellContext`season]], \
$CellContext`sym$106337[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$106337[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$106337[All], 
      All, $CellContext`i$106338], $CellContext`sym$106337[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$106337[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$106337, $CellContext`size]], \
$CellContext`sym$106337[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$106337[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$106337[All], 
      All, $CellContext`i$107886], $CellContext`sym$106337[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$106337[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$106337, $CellContext`speed]], \
$CellContext`sym$106337[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$106337[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$106337[All], All, $CellContext`i$107887], 
    Attributes[$CellContext`i$107896] = {Temporary}, $CellContext`i$107896 = 
    12, Attributes[$CellContext`i$106338] = {
     Temporary}, $CellContext`i$106338 = 1, 
    Attributes[$CellContext`i$107893] = {Temporary}, $CellContext`i$107893 = 
    9, Attributes[$CellContext`i$107891] = {Temporary}, $CellContext`i$107891 = 
    7, Attributes[$CellContext`i$107889] = {Temporary}, $CellContext`i$107889 = 
    5, Attributes[$CellContext`i$107895] = {Temporary}, $CellContext`i$107895 = 
    11, Attributes[$CellContext`i$107887] = {
     Temporary}, $CellContext`i$107887 = 3, 
    Attributes[$CellContext`i$107890] = {Temporary}, $CellContext`i$107890 = 
    6, Attributes[$CellContext`i$107897] = {Temporary}, $CellContext`i$107897 = 
    13, Attributes[$CellContext`i$107894] = {
     Temporary}, $CellContext`i$107894 = 10, 
    Attributes[$CellContext`i$107901] = {Temporary}, $CellContext`i$107901 = 
    17, Attributes[$CellContext`i$107886] = {
     Temporary}, $CellContext`i$107886 = 2, 
    Attributes[$CellContext`i$107888] = {Temporary}, $CellContext`i$107888 = 
    4, Attributes[$CellContext`i$107902] = {Temporary}, $CellContext`i$107902 = 
    18, Attributes[$CellContext`i$107892] = {
     Temporary}, $CellContext`i$107892 = 8, 
    Attributes[$CellContext`i$107898] = {Temporary}, $CellContext`i$107898 = 
    14, Attributes[$CellContext`i$107900] = {
     Temporary}, $CellContext`i$107900 = 16, 
    Attributes[$CellContext`i$107899] = {Temporary}, $CellContext`i$107899 = 
    15, Attributes[$CellContext`sym$227342] = {
     Temporary}, $CellContext`sym$227342[$CellContext`a1] = Part[
      $CellContext`sym$227342[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227342[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$227342[$CellContext`a2] = Part[
      $CellContext`sym$227342[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227342[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$227342[$CellContext`a3] = Part[
      $CellContext`sym$227342[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227342[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$227342[$CellContext`a4] = Part[
      $CellContext`sym$227342[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227342[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$227342[$CellContext`a5] = Part[
      $CellContext`sym$227342[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227342[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$227342[$CellContext`a6] = Part[
      $CellContext`sym$227342[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227342[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$227342[$CellContext`a7] = Part[
      $CellContext`sym$227342[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227342[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$227342[All] = $CellContext`med[
     All], $CellContext`sym$227342[$CellContext`Chla] = Part[
      $CellContext`sym$227342[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227342[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$227342[$CellContext`Cl] = Part[
      $CellContext`sym$227342[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227342[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$227342[$CellContext`mnO2] = Part[
      $CellContext`sym$227342[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227342[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$227342[$CellContext`mxPH] = Part[
      $CellContext`sym$227342[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227342[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$227342[$CellContext`NH4] = Part[
      $CellContext`sym$227342[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227342[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$227342[$CellContext`NO3] = Part[
      $CellContext`sym$227342[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227342[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$227342[$CellContext`oPO4] = Part[
      $CellContext`sym$227342[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227342[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$227342[$CellContext`PO4] = Part[
      $CellContext`sym$227342[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227342[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$227342[$CellContext`season] = Part[
      $CellContext`sym$227342[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227342[$CellContext`season, 
         "missing"]]]], $CellContext`sym$227342[$CellContext`size] = Part[
      $CellContext`sym$227342[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227342[$CellContext`size, 
         "missing"]]]], $CellContext`sym$227342[$CellContext`speed] = Part[
      $CellContext`sym$227342[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227342[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$227342[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$227342[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227342, $CellContext`a1]], \
$CellContext`sym$227342[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$227342[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$227342[All], 
      All, $CellContext`i$227354], $CellContext`sym$227342[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$227342[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227342, $CellContext`a2]], \
$CellContext`sym$227342[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$227342[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$227342[All], 
      All, $CellContext`i$227355], $CellContext`sym$227342[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$227342[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227342, $CellContext`a3]], \
$CellContext`sym$227342[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$227342[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$227342[All], 
      All, $CellContext`i$227356], $CellContext`sym$227342[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$227342[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227342, $CellContext`a4]], \
$CellContext`sym$227342[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$227342[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$227342[All], 
      All, $CellContext`i$227357], $CellContext`sym$227342[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$227342[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227342, $CellContext`a5]], \
$CellContext`sym$227342[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$227342[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$227342[All], 
      All, $CellContext`i$227358], $CellContext`sym$227342[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$227342[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227342, $CellContext`a6]], \
$CellContext`sym$227342[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$227342[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$227342[All], 
      All, $CellContext`i$227359], $CellContext`sym$227342[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$227342[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227342, $CellContext`a7]], \
$CellContext`sym$227342[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$227342[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$227342[All], 
      All, $CellContext`i$227360], $CellContext`sym$227342[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$227342[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$227342[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$227342[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227342, $CellContext`Chla]], \
$CellContext`sym$227342[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$227342[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$227342[All], 
      All, $CellContext`i$227353], $CellContext`sym$227342[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$227342[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227342, $CellContext`Cl]], \
$CellContext`sym$227342[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$227342[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$227342[All], 
      All, $CellContext`i$227348], $CellContext`sym$227342[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$227342[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227342, $CellContext`mnO2]], \
$CellContext`sym$227342[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$227342[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$227342[All], 
      All, $CellContext`i$227347], $CellContext`sym$227342[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$227342[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227342, $CellContext`mxPH]], \
$CellContext`sym$227342[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$227342[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$227342[All], 
      All, $CellContext`i$227346], $CellContext`sym$227342[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$227342[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227342, $CellContext`NH4]], \
$CellContext`sym$227342[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$227342[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$227342[All], 
      All, $CellContext`i$227350], $CellContext`sym$227342[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$227342[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227342, $CellContext`NO3]], \
$CellContext`sym$227342[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$227342[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$227342[All], 
      All, $CellContext`i$227349], $CellContext`sym$227342[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$227342[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227342, $CellContext`oPO4]], \
$CellContext`sym$227342[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$227342[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$227342[All], 
      All, $CellContext`i$227351], $CellContext`sym$227342[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$227342[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227342, $CellContext`PO4]], \
$CellContext`sym$227342[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$227342[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$227342[All], 
      All, $CellContext`i$227352], \
$CellContext`sym$227342[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$227342[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227342, $CellContext`season]], \
$CellContext`sym$227342[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$227342[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$227342[All], 
      All, $CellContext`i$227343], $CellContext`sym$227342[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$227342[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227342, $CellContext`size]], \
$CellContext`sym$227342[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$227342[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$227342[All], 
      All, $CellContext`i$227344], $CellContext`sym$227342[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$227342[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227342, $CellContext`speed]], \
$CellContext`sym$227342[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$227342[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$227342[All], All, $CellContext`i$227345], 
    Attributes[$CellContext`i$227345] = {Temporary}, $CellContext`i$227345 = 
    3, Attributes[$CellContext`i$227359] = {Temporary}, $CellContext`i$227359 = 
    17, Attributes[$CellContext`i$227351] = {
     Temporary}, $CellContext`i$227351 = 9, 
    Attributes[$CellContext`i$227355] = {Temporary}, $CellContext`i$227355 = 
    13, Attributes[$CellContext`i$227354] = {
     Temporary}, $CellContext`i$227354 = 12, 
    Attributes[$CellContext`i$227360] = {Temporary}, $CellContext`i$227360 = 
    18, Attributes[$CellContext`i$227343] = {
     Temporary}, $CellContext`i$227343 = 1, 
    Attributes[$CellContext`i$227348] = {Temporary}, $CellContext`i$227348 = 
    6, Attributes[$CellContext`i$227356] = {Temporary}, $CellContext`i$227356 = 
    14, Attributes[$CellContext`i$227346] = {
     Temporary}, $CellContext`i$227346 = 4, 
    Attributes[$CellContext`i$227357] = {Temporary}, $CellContext`i$227357 = 
    15, Attributes[$CellContext`i$227344] = {
     Temporary}, $CellContext`i$227344 = 2, 
    Attributes[$CellContext`i$227349] = {Temporary}, $CellContext`i$227349 = 
    7, Attributes[$CellContext`i$227352] = {Temporary}, $CellContext`i$227352 = 
    10, Attributes[$CellContext`i$227358] = {
     Temporary}, $CellContext`i$227358 = 16, 
    Attributes[$CellContext`i$227353] = {Temporary}, $CellContext`i$227353 = 
    11, Attributes[$CellContext`i$227350] = {
     Temporary}, $CellContext`i$227350 = 8, 
    Attributes[$CellContext`i$227347] = {Temporary}, $CellContext`i$227347 = 
    5, Attributes[$CellContext`sym$119735] = {
     Temporary}, $CellContext`sym$119735[$CellContext`a1] = Part[
      $CellContext`sym$119735[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$119735[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$119735[$CellContext`a2] = Part[
      $CellContext`sym$119735[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$119735[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$119735[$CellContext`a3] = Part[
      $CellContext`sym$119735[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$119735[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$119735[$CellContext`a4] = Part[
      $CellContext`sym$119735[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$119735[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$119735[$CellContext`a5] = Part[
      $CellContext`sym$119735[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$119735[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$119735[$CellContext`a6] = Part[
      $CellContext`sym$119735[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$119735[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$119735[$CellContext`a7] = Part[
      $CellContext`sym$119735[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$119735[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$119735[All] = $CellContext`med[
     All], $CellContext`sym$119735[$CellContext`Chla] = Part[
      $CellContext`sym$119735[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$119735[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$119735[$CellContext`Cl] = Part[
      $CellContext`sym$119735[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$119735[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$119735[$CellContext`mnO2] = Part[
      $CellContext`sym$119735[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$119735[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$119735[$CellContext`mxPH] = Part[
      $CellContext`sym$119735[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$119735[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$119735[$CellContext`NH4] = Part[
      $CellContext`sym$119735[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$119735[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$119735[$CellContext`NO3] = Part[
      $CellContext`sym$119735[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$119735[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$119735[$CellContext`oPO4] = Part[
      $CellContext`sym$119735[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$119735[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$119735[$CellContext`PO4] = Part[
      $CellContext`sym$119735[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$119735[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$119735[$CellContext`season] = Part[
      $CellContext`sym$119735[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$119735[$CellContext`season, 
         "missing"]]]], $CellContext`sym$119735[$CellContext`size] = Part[
      $CellContext`sym$119735[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$119735[$CellContext`size, 
         "missing"]]]], $CellContext`sym$119735[$CellContext`speed] = Part[
      $CellContext`sym$119735[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$119735[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$119735[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$119735[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$119735, $CellContext`a1]], \
$CellContext`sym$119735[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$119735[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$119735[All], 
      All, $CellContext`i$121294], $CellContext`sym$119735[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$119735[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$119735, $CellContext`a2]], \
$CellContext`sym$119735[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$119735[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$119735[All], 
      All, $CellContext`i$121295], $CellContext`sym$119735[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$119735[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$119735, $CellContext`a3]], \
$CellContext`sym$119735[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$119735[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$119735[All], 
      All, $CellContext`i$121296], $CellContext`sym$119735[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$119735[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$119735, $CellContext`a4]], \
$CellContext`sym$119735[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$119735[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$119735[All], 
      All, $CellContext`i$121297], $CellContext`sym$119735[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$119735[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$119735, $CellContext`a5]], \
$CellContext`sym$119735[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$119735[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$119735[All], 
      All, $CellContext`i$121298], $CellContext`sym$119735[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$119735[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$119735, $CellContext`a6]], \
$CellContext`sym$119735[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$119735[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$119735[All], 
      All, $CellContext`i$121299], $CellContext`sym$119735[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$119735[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$119735, $CellContext`a7]], \
$CellContext`sym$119735[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$119735[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$119735[All], 
      All, $CellContext`i$121300], $CellContext`sym$119735[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$119735[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$119735[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$119735[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$119735, $CellContext`Chla]], \
$CellContext`sym$119735[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$119735[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$119735[All], 
      All, $CellContext`i$121293], $CellContext`sym$119735[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$119735[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$119735, $CellContext`Cl]], \
$CellContext`sym$119735[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$119735[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$119735[All], 
      All, $CellContext`i$121288], $CellContext`sym$119735[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$119735[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$119735, $CellContext`mnO2]], \
$CellContext`sym$119735[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$119735[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$119735[All], 
      All, $CellContext`i$121287], $CellContext`sym$119735[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$119735[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$119735, $CellContext`mxPH]], \
$CellContext`sym$119735[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$119735[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$119735[All], 
      All, $CellContext`i$121286], $CellContext`sym$119735[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$119735[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$119735, $CellContext`NH4]], \
$CellContext`sym$119735[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$119735[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$119735[All], 
      All, $CellContext`i$121290], $CellContext`sym$119735[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$119735[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$119735, $CellContext`NO3]], \
$CellContext`sym$119735[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$119735[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$119735[All], 
      All, $CellContext`i$121289], $CellContext`sym$119735[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$119735[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$119735, $CellContext`oPO4]], \
$CellContext`sym$119735[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$119735[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$119735[All], 
      All, $CellContext`i$121291], $CellContext`sym$119735[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$119735[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$119735, $CellContext`PO4]], \
$CellContext`sym$119735[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$119735[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$119735[All], 
      All, $CellContext`i$121292], \
$CellContext`sym$119735[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$119735[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$119735, $CellContext`season]], \
$CellContext`sym$119735[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$119735[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$119735[All], 
      All, $CellContext`i$119736], $CellContext`sym$119735[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$119735[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$119735, $CellContext`size]], \
$CellContext`sym$119735[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$119735[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$119735[All], 
      All, $CellContext`i$121284], $CellContext`sym$119735[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$119735[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$119735, $CellContext`speed]], \
$CellContext`sym$119735[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$119735[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$119735[All], All, $CellContext`i$121285], 
    Attributes[$CellContext`i$121297] = {Temporary}, $CellContext`i$121297 = 
    15, Attributes[$CellContext`i$121286] = {
     Temporary}, $CellContext`i$121286 = 4, 
    Attributes[$CellContext`i$121293] = {Temporary}, $CellContext`i$121293 = 
    11, Attributes[$CellContext`i$121296] = {
     Temporary}, $CellContext`i$121296 = 14, 
    Attributes[$CellContext`i$121289] = {Temporary}, $CellContext`i$121289 = 
    7, Attributes[$CellContext`i$121294] = {Temporary}, $CellContext`i$121294 = 
    12, Attributes[$CellContext`i$121298] = {
     Temporary}, $CellContext`i$121298 = 16, 
    Attributes[$CellContext`i$121300] = {Temporary}, $CellContext`i$121300 = 
    18, Attributes[$CellContext`i$121295] = {
     Temporary}, $CellContext`i$121295 = 13, 
    Attributes[$CellContext`i$121285] = {Temporary}, $CellContext`i$121285 = 
    3, Attributes[$CellContext`i$121290] = {Temporary}, $CellContext`i$121290 = 
    8, Attributes[$CellContext`i$121299] = {Temporary}, $CellContext`i$121299 = 
    17, Attributes[$CellContext`i$121291] = {
     Temporary}, $CellContext`i$121291 = 9, 
    Attributes[$CellContext`i$121288] = {Temporary}, $CellContext`i$121288 = 
    6, Attributes[$CellContext`i$121284] = {Temporary}, $CellContext`i$121284 = 
    2, Attributes[$CellContext`i$119736] = {Temporary}, $CellContext`i$119736 = 
    1, Attributes[$CellContext`i$121287] = {Temporary}, $CellContext`i$121287 = 
    5, Attributes[$CellContext`i$121292] = {Temporary}, $CellContext`i$121292 = 
    10, Attributes[$CellContext`sym$227445] = {
     Temporary}, $CellContext`sym$227445[$CellContext`a1] = Part[
      $CellContext`sym$227445[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227445[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$227445[$CellContext`a2] = Part[
      $CellContext`sym$227445[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227445[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$227445[$CellContext`a3] = Part[
      $CellContext`sym$227445[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227445[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$227445[$CellContext`a4] = Part[
      $CellContext`sym$227445[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227445[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$227445[$CellContext`a5] = Part[
      $CellContext`sym$227445[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227445[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$227445[$CellContext`a6] = Part[
      $CellContext`sym$227445[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227445[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$227445[$CellContext`a7] = Part[
      $CellContext`sym$227445[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227445[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$227445[All] = $CellContext`med[
     All], $CellContext`sym$227445[$CellContext`Chla] = Part[
      $CellContext`sym$227445[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227445[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$227445[$CellContext`Cl] = Part[
      $CellContext`sym$227445[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227445[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$227445[$CellContext`mnO2] = Part[
      $CellContext`sym$227445[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227445[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$227445[$CellContext`mxPH] = Part[
      $CellContext`sym$227445[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227445[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$227445[$CellContext`NH4] = Part[
      $CellContext`sym$227445[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227445[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$227445[$CellContext`NO3] = Part[
      $CellContext`sym$227445[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227445[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$227445[$CellContext`oPO4] = Part[
      $CellContext`sym$227445[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227445[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$227445[$CellContext`PO4] = Part[
      $CellContext`sym$227445[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227445[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$227445[$CellContext`season] = Part[
      $CellContext`sym$227445[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227445[$CellContext`season, 
         "missing"]]]], $CellContext`sym$227445[$CellContext`size] = Part[
      $CellContext`sym$227445[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227445[$CellContext`size, 
         "missing"]]]], $CellContext`sym$227445[$CellContext`speed] = Part[
      $CellContext`sym$227445[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227445[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$227445[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$227445[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227445, $CellContext`a1]], \
$CellContext`sym$227445[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$227445[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$227445[All], 
      All, $CellContext`i$227457], $CellContext`sym$227445[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$227445[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227445, $CellContext`a2]], \
$CellContext`sym$227445[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$227445[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$227445[All], 
      All, $CellContext`i$227458], $CellContext`sym$227445[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$227445[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227445, $CellContext`a3]], \
$CellContext`sym$227445[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$227445[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$227445[All], 
      All, $CellContext`i$227459], $CellContext`sym$227445[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$227445[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227445, $CellContext`a4]], \
$CellContext`sym$227445[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$227445[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$227445[All], 
      All, $CellContext`i$227460], $CellContext`sym$227445[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$227445[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227445, $CellContext`a5]], \
$CellContext`sym$227445[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$227445[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$227445[All], 
      All, $CellContext`i$227461], $CellContext`sym$227445[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$227445[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227445, $CellContext`a6]], \
$CellContext`sym$227445[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$227445[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$227445[All], 
      All, $CellContext`i$227462], $CellContext`sym$227445[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$227445[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227445, $CellContext`a7]], \
$CellContext`sym$227445[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$227445[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$227445[All], 
      All, $CellContext`i$227463], $CellContext`sym$227445[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$227445[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$227445[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$227445[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227445, $CellContext`Chla]], \
$CellContext`sym$227445[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$227445[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$227445[All], 
      All, $CellContext`i$227456], $CellContext`sym$227445[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$227445[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227445, $CellContext`Cl]], \
$CellContext`sym$227445[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$227445[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$227445[All], 
      All, $CellContext`i$227451], $CellContext`sym$227445[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$227445[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227445, $CellContext`mnO2]], \
$CellContext`sym$227445[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$227445[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$227445[All], 
      All, $CellContext`i$227450], $CellContext`sym$227445[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$227445[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227445, $CellContext`mxPH]], \
$CellContext`sym$227445[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$227445[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$227445[All], 
      All, $CellContext`i$227449], $CellContext`sym$227445[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$227445[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227445, $CellContext`NH4]], \
$CellContext`sym$227445[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$227445[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$227445[All], 
      All, $CellContext`i$227453], $CellContext`sym$227445[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$227445[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227445, $CellContext`NO3]], \
$CellContext`sym$227445[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$227445[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$227445[All], 
      All, $CellContext`i$227452], $CellContext`sym$227445[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$227445[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227445, $CellContext`oPO4]], \
$CellContext`sym$227445[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$227445[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$227445[All], 
      All, $CellContext`i$227454], $CellContext`sym$227445[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$227445[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227445, $CellContext`PO4]], \
$CellContext`sym$227445[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$227445[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$227445[All], 
      All, $CellContext`i$227455], \
$CellContext`sym$227445[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$227445[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227445, $CellContext`season]], \
$CellContext`sym$227445[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$227445[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$227445[All], 
      All, $CellContext`i$227446], $CellContext`sym$227445[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$227445[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227445, $CellContext`size]], \
$CellContext`sym$227445[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$227445[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$227445[All], 
      All, $CellContext`i$227447], $CellContext`sym$227445[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$227445[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227445, $CellContext`speed]], \
$CellContext`sym$227445[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$227445[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$227445[All], All, $CellContext`i$227448], 
    Attributes[$CellContext`i$227457] = {Temporary}, $CellContext`i$227457 = 
    12, Attributes[$CellContext`i$227452] = {
     Temporary}, $CellContext`i$227452 = 7, 
    Attributes[$CellContext`i$227448] = {Temporary}, $CellContext`i$227448 = 
    3, Attributes[$CellContext`i$227453] = {Temporary}, $CellContext`i$227453 = 
    8, Attributes[$CellContext`i$227449] = {Temporary}, $CellContext`i$227449 = 
    4, Attributes[$CellContext`i$227446] = {Temporary}, $CellContext`i$227446 = 
    1, Attributes[$CellContext`i$227454] = {Temporary}, $CellContext`i$227454 = 
    9, Attributes[$CellContext`i$227451] = {Temporary}, $CellContext`i$227451 = 
    6, Attributes[$CellContext`i$227460] = {Temporary}, $CellContext`i$227460 = 
    15, Attributes[$CellContext`i$227462] = {
     Temporary}, $CellContext`i$227462 = 17, 
    Attributes[$CellContext`i$227458] = {Temporary}, $CellContext`i$227458 = 
    13, Attributes[$CellContext`i$227463] = {
     Temporary}, $CellContext`i$227463 = 18, 
    Attributes[$CellContext`i$227456] = {Temporary}, $CellContext`i$227456 = 
    11, Attributes[$CellContext`i$227461] = {
     Temporary}, $CellContext`i$227461 = 16, 
    Attributes[$CellContext`i$227459] = {Temporary}, $CellContext`i$227459 = 
    14, Attributes[$CellContext`i$227455] = {
     Temporary}, $CellContext`i$227455 = 10, 
    Attributes[$CellContext`i$227450] = {Temporary}, $CellContext`i$227450 = 
    5, Attributes[$CellContext`i$227447] = {Temporary}, $CellContext`i$227447 = 
    2, Attributes[$CellContext`sym$121968] = {
     Temporary}, $CellContext`sym$121968[$CellContext`a1] = Part[
      $CellContext`sym$121968[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$121968[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$121968[$CellContext`a2] = Part[
      $CellContext`sym$121968[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$121968[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$121968[$CellContext`a3] = Part[
      $CellContext`sym$121968[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$121968[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$121968[$CellContext`a4] = Part[
      $CellContext`sym$121968[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$121968[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$121968[$CellContext`a5] = Part[
      $CellContext`sym$121968[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$121968[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$121968[$CellContext`a6] = Part[
      $CellContext`sym$121968[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$121968[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$121968[$CellContext`a7] = Part[
      $CellContext`sym$121968[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$121968[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$121968[All] = $CellContext`med[
     All], $CellContext`sym$121968[$CellContext`Chla] = Part[
      $CellContext`sym$121968[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$121968[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$121968[$CellContext`Cl] = Part[
      $CellContext`sym$121968[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$121968[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$121968[$CellContext`mnO2] = Part[
      $CellContext`sym$121968[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$121968[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$121968[$CellContext`mxPH] = Part[
      $CellContext`sym$121968[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$121968[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$121968[$CellContext`NH4] = Part[
      $CellContext`sym$121968[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$121968[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$121968[$CellContext`NO3] = Part[
      $CellContext`sym$121968[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$121968[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$121968[$CellContext`oPO4] = Part[
      $CellContext`sym$121968[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$121968[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$121968[$CellContext`PO4] = Part[
      $CellContext`sym$121968[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$121968[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$121968[$CellContext`season] = Part[
      $CellContext`sym$121968[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$121968[$CellContext`season, 
         "missing"]]]], $CellContext`sym$121968[$CellContext`size] = Part[
      $CellContext`sym$121968[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$121968[$CellContext`size, 
         "missing"]]]], $CellContext`sym$121968[$CellContext`speed] = Part[
      $CellContext`sym$121968[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$121968[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$121968[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$121968[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$121968, $CellContext`a1]], \
$CellContext`sym$121968[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$121968[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$121968[All], 
      All, $CellContext`i$123527], $CellContext`sym$121968[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$121968[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$121968, $CellContext`a2]], \
$CellContext`sym$121968[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$121968[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$121968[All], 
      All, $CellContext`i$123528], $CellContext`sym$121968[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$121968[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$121968, $CellContext`a3]], \
$CellContext`sym$121968[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$121968[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$121968[All], 
      All, $CellContext`i$123529], $CellContext`sym$121968[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$121968[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$121968, $CellContext`a4]], \
$CellContext`sym$121968[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$121968[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$121968[All], 
      All, $CellContext`i$123530], $CellContext`sym$121968[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$121968[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$121968, $CellContext`a5]], \
$CellContext`sym$121968[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$121968[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$121968[All], 
      All, $CellContext`i$123531], $CellContext`sym$121968[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$121968[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$121968, $CellContext`a6]], \
$CellContext`sym$121968[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$121968[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$121968[All], 
      All, $CellContext`i$123532], $CellContext`sym$121968[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$121968[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$121968, $CellContext`a7]], \
$CellContext`sym$121968[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$121968[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$121968[All], 
      All, $CellContext`i$123533], $CellContext`sym$121968[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$121968[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$121968[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$121968[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$121968, $CellContext`Chla]], \
$CellContext`sym$121968[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$121968[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$121968[All], 
      All, $CellContext`i$123526], $CellContext`sym$121968[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$121968[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$121968, $CellContext`Cl]], \
$CellContext`sym$121968[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$121968[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$121968[All], 
      All, $CellContext`i$123521], $CellContext`sym$121968[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$121968[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$121968, $CellContext`mnO2]], \
$CellContext`sym$121968[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$121968[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$121968[All], 
      All, $CellContext`i$123520], $CellContext`sym$121968[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$121968[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$121968, $CellContext`mxPH]], \
$CellContext`sym$121968[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$121968[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$121968[All], 
      All, $CellContext`i$123519], $CellContext`sym$121968[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$121968[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$121968, $CellContext`NH4]], \
$CellContext`sym$121968[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$121968[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$121968[All], 
      All, $CellContext`i$123523], $CellContext`sym$121968[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$121968[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$121968, $CellContext`NO3]], \
$CellContext`sym$121968[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$121968[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$121968[All], 
      All, $CellContext`i$123522], $CellContext`sym$121968[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$121968[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$121968, $CellContext`oPO4]], \
$CellContext`sym$121968[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$121968[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$121968[All], 
      All, $CellContext`i$123524], $CellContext`sym$121968[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$121968[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$121968, $CellContext`PO4]], \
$CellContext`sym$121968[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$121968[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$121968[All], 
      All, $CellContext`i$123525], \
$CellContext`sym$121968[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$121968[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$121968, $CellContext`season]], \
$CellContext`sym$121968[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$121968[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$121968[All], 
      All, $CellContext`i$121969], $CellContext`sym$121968[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$121968[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$121968, $CellContext`size]], \
$CellContext`sym$121968[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$121968[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$121968[All], 
      All, $CellContext`i$123517], $CellContext`sym$121968[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$121968[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$121968, $CellContext`speed]], \
$CellContext`sym$121968[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$121968[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$121968[All], All, $CellContext`i$123518], 
    Attributes[$CellContext`i$123525] = {Temporary}, $CellContext`i$123525 = 
    10, Attributes[$CellContext`i$123533] = {
     Temporary}, $CellContext`i$123533 = 18, 
    Attributes[$CellContext`i$123530] = {Temporary}, $CellContext`i$123530 = 
    15, Attributes[$CellContext`i$121969] = {
     Temporary}, $CellContext`i$121969 = 1, 
    Attributes[$CellContext`i$123527] = {Temporary}, $CellContext`i$123527 = 
    12, Attributes[$CellContext`i$123523] = {
     Temporary}, $CellContext`i$123523 = 8, 
    Attributes[$CellContext`i$123522] = {Temporary}, $CellContext`i$123522 = 
    7, Attributes[$CellContext`i$123532] = {Temporary}, $CellContext`i$123532 = 
    17, Attributes[$CellContext`i$123520] = {
     Temporary}, $CellContext`i$123520 = 5, 
    Attributes[$CellContext`i$123528] = {Temporary}, $CellContext`i$123528 = 
    13, Attributes[$CellContext`i$123531] = {
     Temporary}, $CellContext`i$123531 = 16, 
    Attributes[$CellContext`i$123518] = {Temporary}, $CellContext`i$123518 = 
    3, Attributes[$CellContext`i$123521] = {Temporary}, $CellContext`i$123521 = 
    6, Attributes[$CellContext`i$123517] = {Temporary}, $CellContext`i$123517 = 
    2, Attributes[$CellContext`i$123529] = {Temporary}, $CellContext`i$123529 = 
    14, Attributes[$CellContext`i$123519] = {
     Temporary}, $CellContext`i$123519 = 4, 
    Attributes[$CellContext`i$123524] = {Temporary}, $CellContext`i$123524 = 
    9, Attributes[$CellContext`i$123526] = {Temporary}, $CellContext`i$123526 = 
    11, Attributes[$CellContext`sym$54900] = {
     Temporary}, $CellContext`sym$54900[$CellContext`a1] = $CellContext`med[
     All], $CellContext`sym$54900[$CellContext`a2] = $CellContext`med[
     All], $CellContext`sym$54900[$CellContext`a3] = $CellContext`med[
     All], $CellContext`sym$54900[$CellContext`a4] = $CellContext`med[
     All], $CellContext`sym$54900[$CellContext`a5] = $CellContext`med[
     All], $CellContext`sym$54900[$CellContext`a6] = $CellContext`med[
     All], $CellContext`sym$54900[$CellContext`a7] = $CellContext`med[
     All], $CellContext`sym$54900[All] = $CellContext`med[
     All], $CellContext`sym$54900[$CellContext`Chla] = $CellContext`med[
     All], $CellContext`sym$54900[$CellContext`Cl] = $CellContext`med[
     All], $CellContext`sym$54900[$CellContext`mnO2] = $CellContext`med[
     All], $CellContext`sym$54900[$CellContext`mxPH] = $CellContext`med[
     All], $CellContext`sym$54900[$CellContext`NH4] = $CellContext`med[
     All], $CellContext`sym$54900[$CellContext`NO3] = $CellContext`med[
     All], $CellContext`sym$54900[$CellContext`oPO4] = $CellContext`med[
     All], $CellContext`sym$54900[$CellContext`PO4] = $CellContext`med[
     All], $CellContext`sym$54900[$CellContext`season] = $CellContext`med[
     All], $CellContext`sym$54900[$CellContext`size] = $CellContext`med[
     All], $CellContext`sym$54900[$CellContext`speed] = $CellContext`med[
     All], $CellContext`sym$54900[$CellContext`a1, "factorized"] = 
    True, $CellContext`sym$54900[$CellContext`a1, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$54900[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$54900[$CellContext`a1, "raw"] = Part[
      $CellContext`med[All], All, 12], $CellContext`sym$54900[$CellContext`a2,
       "factorized"] = 
    True, $CellContext`sym$54900[$CellContext`a2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$54900[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$54900[$CellContext`a2, "raw"] = Part[
      $CellContext`med[All], All, 13], $CellContext`sym$54900[$CellContext`a3,
       "factorized"] = 
    True, $CellContext`sym$54900[$CellContext`a3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$54900[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$54900[$CellContext`a3, "raw"] = Part[
      $CellContext`med[All], All, 14], $CellContext`sym$54900[$CellContext`a4,
       "factorized"] = 
    True, $CellContext`sym$54900[$CellContext`a4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$54900[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$54900[$CellContext`a4, "raw"] = Part[
      $CellContext`med[All], All, 15], $CellContext`sym$54900[$CellContext`a5,
       "factorized"] = 
    True, $CellContext`sym$54900[$CellContext`a5, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$54900[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$54900[$CellContext`a5, "raw"] = Part[
      $CellContext`med[All], All, 16], $CellContext`sym$54900[$CellContext`a6,
       "factorized"] = 
    True, $CellContext`sym$54900[$CellContext`a6, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$54900[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$54900[$CellContext`a6, "raw"] = Part[
      $CellContext`med[All], All, 17], $CellContext`sym$54900[$CellContext`a7,
       "factorized"] = 
    True, $CellContext`sym$54900[$CellContext`a7, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$54900[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$54900[$CellContext`a7, "raw"] = Part[
      $CellContext`med[All], All, 18], $CellContext`sym$54900[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$54900[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$54900[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$54900[$CellContext`Chla, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$54900[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$54900[$CellContext`Chla, "raw"] = Part[
      $CellContext`med[All], All, 11], $CellContext`sym$54900[$CellContext`Cl,
       "factorized"] = 
    True, $CellContext`sym$54900[$CellContext`Cl, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$54900[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$54900[$CellContext`Cl, "raw"] = Part[
      $CellContext`med[All], All, 
      6], $CellContext`sym$54900[$CellContext`mnO2, "factorized"] = 
    True, $CellContext`sym$54900[$CellContext`mnO2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$54900[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$54900[$CellContext`mnO2, "raw"] = Part[
      $CellContext`med[All], All, 
      5], $CellContext`sym$54900[$CellContext`mxPH, "factorized"] = 
    True, $CellContext`sym$54900[$CellContext`mxPH, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$54900[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$54900[$CellContext`mxPH, "raw"] = Part[
      $CellContext`med[All], All, 4], $CellContext`sym$54900[$CellContext`NH4,
       "factorized"] = 
    True, $CellContext`sym$54900[$CellContext`NH4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$54900[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$54900[$CellContext`NH4, "raw"] = Part[
      $CellContext`med[All], All, 8], $CellContext`sym$54900[$CellContext`NO3,
       "factorized"] = 
    True, $CellContext`sym$54900[$CellContext`NO3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$54900[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$54900[$CellContext`NO3, "raw"] = Part[
      $CellContext`med[All], All, 
      7], $CellContext`sym$54900[$CellContext`oPO4, "factorized"] = 
    True, $CellContext`sym$54900[$CellContext`oPO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$54900[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$54900[$CellContext`oPO4, "raw"] = Part[
      $CellContext`med[All], All, 9], $CellContext`sym$54900[$CellContext`PO4,
       "factorized"] = 
    True, $CellContext`sym$54900[$CellContext`PO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$54900[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$54900[$CellContext`PO4, "raw"] = Part[
      $CellContext`med[All], All, 
      10], $CellContext`sym$54900[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$54900[$CellContext`season, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$54900[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$54900[$CellContext`season, "raw"] = 
    Part[
      $CellContext`med[All], All, 
      1], $CellContext`sym$54900[$CellContext`size, "factorized"] = 
    True, $CellContext`sym$54900[$CellContext`size, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$54900[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$54900[$CellContext`size, "raw"] = Part[
      $CellContext`med[All], All, 
      2], $CellContext`sym$54900[$CellContext`speed, "factorized"] = 
    True, $CellContext`sym$54900[$CellContext`speed, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$54900[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$54900[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`med[All], All, 3], 
    Attributes[$CellContext`sym$148764] = {
     Temporary}, $CellContext`sym$148764[$CellContext`a1] = Part[
      $CellContext`sym$148764[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$148764[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$148764[$CellContext`a2] = Part[
      $CellContext`sym$148764[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$148764[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$148764[$CellContext`a3] = Part[
      $CellContext`sym$148764[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$148764[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$148764[$CellContext`a4] = Part[
      $CellContext`sym$148764[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$148764[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$148764[$CellContext`a5] = Part[
      $CellContext`sym$148764[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$148764[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$148764[$CellContext`a6] = Part[
      $CellContext`sym$148764[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$148764[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$148764[$CellContext`a7] = Part[
      $CellContext`sym$148764[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$148764[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$148764[All] = $CellContext`med[
     All], $CellContext`sym$148764[$CellContext`Chla] = Part[
      $CellContext`sym$148764[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$148764[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$148764[$CellContext`Cl] = Part[
      $CellContext`sym$148764[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$148764[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$148764[$CellContext`mnO2] = Part[
      $CellContext`sym$148764[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$148764[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$148764[$CellContext`mxPH] = Part[
      $CellContext`sym$148764[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$148764[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$148764[$CellContext`NH4] = Part[
      $CellContext`sym$148764[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$148764[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$148764[$CellContext`NO3] = Part[
      $CellContext`sym$148764[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$148764[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$148764[$CellContext`oPO4] = Part[
      $CellContext`sym$148764[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$148764[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$148764[$CellContext`PO4] = Part[
      $CellContext`sym$148764[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$148764[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$148764[$CellContext`season] = Part[
      $CellContext`sym$148764[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$148764[$CellContext`season, 
         "missing"]]]], $CellContext`sym$148764[$CellContext`size] = Part[
      $CellContext`sym$148764[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$148764[$CellContext`size, 
         "missing"]]]], $CellContext`sym$148764[$CellContext`speed] = Part[
      $CellContext`sym$148764[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$148764[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$148764[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$148764[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$148764, $CellContext`a1]], \
$CellContext`sym$148764[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$148764[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$148764[All], 
      All, $CellContext`i$150323], $CellContext`sym$148764[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$148764[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$148764, $CellContext`a2]], \
$CellContext`sym$148764[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$148764[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$148764[All], 
      All, $CellContext`i$150324], $CellContext`sym$148764[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$148764[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$148764, $CellContext`a3]], \
$CellContext`sym$148764[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$148764[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$148764[All], 
      All, $CellContext`i$150325], $CellContext`sym$148764[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$148764[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$148764, $CellContext`a4]], \
$CellContext`sym$148764[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$148764[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$148764[All], 
      All, $CellContext`i$150326], $CellContext`sym$148764[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$148764[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$148764, $CellContext`a5]], \
$CellContext`sym$148764[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$148764[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$148764[All], 
      All, $CellContext`i$150327], $CellContext`sym$148764[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$148764[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$148764, $CellContext`a6]], \
$CellContext`sym$148764[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$148764[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$148764[All], 
      All, $CellContext`i$150328], $CellContext`sym$148764[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$148764[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$148764, $CellContext`a7]], \
$CellContext`sym$148764[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$148764[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$148764[All], 
      All, $CellContext`i$150329], $CellContext`sym$148764[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$148764[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$148764[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$148764[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$148764, $CellContext`Chla]], \
$CellContext`sym$148764[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$148764[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$148764[All], 
      All, $CellContext`i$150322], $CellContext`sym$148764[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$148764[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$148764, $CellContext`Cl]], \
$CellContext`sym$148764[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$148764[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$148764[All], 
      All, $CellContext`i$150317], $CellContext`sym$148764[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$148764[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$148764, $CellContext`mnO2]], \
$CellContext`sym$148764[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$148764[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$148764[All], 
      All, $CellContext`i$150316], $CellContext`sym$148764[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$148764[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$148764, $CellContext`mxPH]], \
$CellContext`sym$148764[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$148764[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$148764[All], 
      All, $CellContext`i$150315], $CellContext`sym$148764[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$148764[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$148764, $CellContext`NH4]], \
$CellContext`sym$148764[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$148764[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$148764[All], 
      All, $CellContext`i$150319], $CellContext`sym$148764[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$148764[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$148764, $CellContext`NO3]], \
$CellContext`sym$148764[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$148764[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$148764[All], 
      All, $CellContext`i$150318], $CellContext`sym$148764[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$148764[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$148764, $CellContext`oPO4]], \
$CellContext`sym$148764[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$148764[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$148764[All], 
      All, $CellContext`i$150320], $CellContext`sym$148764[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$148764[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$148764, $CellContext`PO4]], \
$CellContext`sym$148764[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$148764[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$148764[All], 
      All, $CellContext`i$150321], \
$CellContext`sym$148764[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$148764[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$148764, $CellContext`season]], \
$CellContext`sym$148764[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$148764[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$148764[All], 
      All, $CellContext`i$148765], $CellContext`sym$148764[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$148764[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$148764, $CellContext`size]], \
$CellContext`sym$148764[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$148764[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$148764[All], 
      All, $CellContext`i$150313], $CellContext`sym$148764[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$148764[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$148764, $CellContext`speed]], \
$CellContext`sym$148764[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$148764[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$148764[All], All, $CellContext`i$150314], 
    Attributes[$CellContext`i$150320] = {Temporary}, $CellContext`i$150320 = 
    9, Attributes[$CellContext`i$150329] = {Temporary}, $CellContext`i$150329 = 
    18, Attributes[$CellContext`i$150315] = {
     Temporary}, $CellContext`i$150315 = 4, 
    Attributes[$CellContext`i$150319] = {Temporary}, $CellContext`i$150319 = 
    8, Attributes[$CellContext`i$150316] = {Temporary}, $CellContext`i$150316 = 
    5, Attributes[$CellContext`i$148765] = {Temporary}, $CellContext`i$148765 = 
    1, Attributes[$CellContext`i$150314] = {Temporary}, $CellContext`i$150314 = 
    3, Attributes[$CellContext`i$150317] = {Temporary}, $CellContext`i$150317 = 
    6, Attributes[$CellContext`i$150318] = {Temporary}, $CellContext`i$150318 = 
    7, Attributes[$CellContext`i$150325] = {Temporary}, $CellContext`i$150325 = 
    14, Attributes[$CellContext`i$150328] = {
     Temporary}, $CellContext`i$150328 = 17, 
    Attributes[$CellContext`i$150322] = {Temporary}, $CellContext`i$150322 = 
    11, Attributes[$CellContext`i$150324] = {
     Temporary}, $CellContext`i$150324 = 13, 
    Attributes[$CellContext`i$150326] = {Temporary}, $CellContext`i$150326 = 
    15, Attributes[$CellContext`i$150321] = {
     Temporary}, $CellContext`i$150321 = 10, 
    Attributes[$CellContext`i$150323] = {Temporary}, $CellContext`i$150323 = 
    12, Attributes[$CellContext`i$150313] = {
     Temporary}, $CellContext`i$150313 = 2, 
    Attributes[$CellContext`i$150327] = {Temporary}, $CellContext`i$150327 = 
    16, Attributes[$CellContext`sym$32570] = {
     Temporary}, $CellContext`sym$32570[$CellContext`a1] = $CellContext`med[
     All], $CellContext`sym$32570[$CellContext`a2] = $CellContext`med[
     All], $CellContext`sym$32570[$CellContext`a3] = $CellContext`med[
     All], $CellContext`sym$32570[$CellContext`a4] = $CellContext`med[
     All], $CellContext`sym$32570[$CellContext`a5] = $CellContext`med[
     All], $CellContext`sym$32570[$CellContext`a6] = $CellContext`med[
     All], $CellContext`sym$32570[$CellContext`a7] = $CellContext`med[
     All], $CellContext`sym$32570[All] = $CellContext`med[
     All], $CellContext`sym$32570[$CellContext`Chla] = $CellContext`med[
     All], $CellContext`sym$32570[$CellContext`Cl] = $CellContext`med[
     All], $CellContext`sym$32570[$CellContext`mnO2] = $CellContext`med[
     All], $CellContext`sym$32570[$CellContext`mxPH] = $CellContext`med[
     All], $CellContext`sym$32570[$CellContext`NH4] = $CellContext`med[
     All], $CellContext`sym$32570[$CellContext`NO3] = $CellContext`med[
     All], $CellContext`sym$32570[$CellContext`oPO4] = $CellContext`med[
     All], $CellContext`sym$32570[$CellContext`PO4] = $CellContext`med[
     All], $CellContext`sym$32570[$CellContext`season] = $CellContext`med[
     All], $CellContext`sym$32570[$CellContext`size] = $CellContext`med[
     All], $CellContext`sym$32570[$CellContext`speed] = $CellContext`med[
     All], $CellContext`sym$32570[$CellContext`a1, "factorized"] = 
    True, $CellContext`sym$32570[$CellContext`a1, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$32570[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$32570[$CellContext`a1, "raw"] = Part[
      $CellContext`med[All], All, 12], $CellContext`sym$32570[$CellContext`a2,
       "factorized"] = 
    True, $CellContext`sym$32570[$CellContext`a2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$32570[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$32570[$CellContext`a2, "raw"] = Part[
      $CellContext`med[All], All, 13], $CellContext`sym$32570[$CellContext`a3,
       "factorized"] = 
    True, $CellContext`sym$32570[$CellContext`a3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$32570[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$32570[$CellContext`a3, "raw"] = Part[
      $CellContext`med[All], All, 14], $CellContext`sym$32570[$CellContext`a4,
       "factorized"] = 
    True, $CellContext`sym$32570[$CellContext`a4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$32570[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$32570[$CellContext`a4, "raw"] = Part[
      $CellContext`med[All], All, 15], $CellContext`sym$32570[$CellContext`a5,
       "factorized"] = 
    True, $CellContext`sym$32570[$CellContext`a5, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$32570[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$32570[$CellContext`a5, "raw"] = Part[
      $CellContext`med[All], All, 16], $CellContext`sym$32570[$CellContext`a6,
       "factorized"] = 
    True, $CellContext`sym$32570[$CellContext`a6, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$32570[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$32570[$CellContext`a6, "raw"] = Part[
      $CellContext`med[All], All, 17], $CellContext`sym$32570[$CellContext`a7,
       "factorized"] = 
    True, $CellContext`sym$32570[$CellContext`a7, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$32570[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$32570[$CellContext`a7, "raw"] = Part[
      $CellContext`med[All], All, 18], $CellContext`sym$32570[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$32570[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$32570[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$32570[$CellContext`Chla, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$32570[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$32570[$CellContext`Chla, "raw"] = Part[
      $CellContext`med[All], All, 11], $CellContext`sym$32570[$CellContext`Cl,
       "factorized"] = 
    True, $CellContext`sym$32570[$CellContext`Cl, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$32570[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$32570[$CellContext`Cl, "raw"] = Part[
      $CellContext`med[All], All, 
      6], $CellContext`sym$32570[$CellContext`mnO2, "factorized"] = 
    True, $CellContext`sym$32570[$CellContext`mnO2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$32570[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$32570[$CellContext`mnO2, "raw"] = Part[
      $CellContext`med[All], All, 
      5], $CellContext`sym$32570[$CellContext`mxPH, "factorized"] = 
    True, $CellContext`sym$32570[$CellContext`mxPH, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$32570[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$32570[$CellContext`mxPH, "raw"] = Part[
      $CellContext`med[All], All, 4], $CellContext`sym$32570[$CellContext`NH4,
       "factorized"] = 
    True, $CellContext`sym$32570[$CellContext`NH4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$32570[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$32570[$CellContext`NH4, "raw"] = Part[
      $CellContext`med[All], All, 8], $CellContext`sym$32570[$CellContext`NO3,
       "factorized"] = 
    True, $CellContext`sym$32570[$CellContext`NO3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$32570[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$32570[$CellContext`NO3, "raw"] = Part[
      $CellContext`med[All], All, 
      7], $CellContext`sym$32570[$CellContext`oPO4, "factorized"] = 
    True, $CellContext`sym$32570[$CellContext`oPO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$32570[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$32570[$CellContext`oPO4, "raw"] = Part[
      $CellContext`med[All], All, 9], $CellContext`sym$32570[$CellContext`PO4,
       "factorized"] = 
    True, $CellContext`sym$32570[$CellContext`PO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$32570[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$32570[$CellContext`PO4, "raw"] = Part[
      $CellContext`med[All], All, 
      10], $CellContext`sym$32570[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$32570[$CellContext`season, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$32570[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$32570[$CellContext`season, "raw"] = 
    Part[
      $CellContext`med[All], All, 
      1], $CellContext`sym$32570[$CellContext`size, "factorized"] = 
    True, $CellContext`sym$32570[$CellContext`size, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$32570[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$32570[$CellContext`size, "raw"] = Part[
      $CellContext`med[All], All, 
      2], $CellContext`sym$32570[$CellContext`speed, "factorized"] = 
    True, $CellContext`sym$32570[$CellContext`speed, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$32570[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$32570[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`med[All], All, 3], 
    Attributes[$CellContext`sym$126434] = {
     Temporary}, $CellContext`sym$126434[$CellContext`a1] = Part[
      $CellContext`sym$126434[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$126434[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$126434[$CellContext`a2] = Part[
      $CellContext`sym$126434[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$126434[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$126434[$CellContext`a3] = Part[
      $CellContext`sym$126434[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$126434[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$126434[$CellContext`a4] = Part[
      $CellContext`sym$126434[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$126434[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$126434[$CellContext`a5] = Part[
      $CellContext`sym$126434[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$126434[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$126434[$CellContext`a6] = Part[
      $CellContext`sym$126434[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$126434[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$126434[$CellContext`a7] = Part[
      $CellContext`sym$126434[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$126434[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$126434[All] = $CellContext`med[
     All], $CellContext`sym$126434[$CellContext`Chla] = Part[
      $CellContext`sym$126434[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$126434[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$126434[$CellContext`Cl] = Part[
      $CellContext`sym$126434[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$126434[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$126434[$CellContext`mnO2] = Part[
      $CellContext`sym$126434[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$126434[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$126434[$CellContext`mxPH] = Part[
      $CellContext`sym$126434[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$126434[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$126434[$CellContext`NH4] = Part[
      $CellContext`sym$126434[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$126434[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$126434[$CellContext`NO3] = Part[
      $CellContext`sym$126434[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$126434[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$126434[$CellContext`oPO4] = Part[
      $CellContext`sym$126434[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$126434[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$126434[$CellContext`PO4] = Part[
      $CellContext`sym$126434[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$126434[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$126434[$CellContext`season] = Part[
      $CellContext`sym$126434[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$126434[$CellContext`season, 
         "missing"]]]], $CellContext`sym$126434[$CellContext`size] = Part[
      $CellContext`sym$126434[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$126434[$CellContext`size, 
         "missing"]]]], $CellContext`sym$126434[$CellContext`speed] = Part[
      $CellContext`sym$126434[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$126434[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$126434[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$126434[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$126434, $CellContext`a1]], \
$CellContext`sym$126434[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$126434[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$126434[All], 
      All, $CellContext`i$127993], $CellContext`sym$126434[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$126434[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$126434, $CellContext`a2]], \
$CellContext`sym$126434[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$126434[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$126434[All], 
      All, $CellContext`i$127994], $CellContext`sym$126434[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$126434[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$126434, $CellContext`a3]], \
$CellContext`sym$126434[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$126434[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$126434[All], 
      All, $CellContext`i$127995], $CellContext`sym$126434[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$126434[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$126434, $CellContext`a4]], \
$CellContext`sym$126434[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$126434[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$126434[All], 
      All, $CellContext`i$127996], $CellContext`sym$126434[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$126434[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$126434, $CellContext`a5]], \
$CellContext`sym$126434[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$126434[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$126434[All], 
      All, $CellContext`i$127997], $CellContext`sym$126434[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$126434[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$126434, $CellContext`a6]], \
$CellContext`sym$126434[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$126434[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$126434[All], 
      All, $CellContext`i$127998], $CellContext`sym$126434[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$126434[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$126434, $CellContext`a7]], \
$CellContext`sym$126434[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$126434[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$126434[All], 
      All, $CellContext`i$127999], $CellContext`sym$126434[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$126434[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$126434[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$126434[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$126434, $CellContext`Chla]], \
$CellContext`sym$126434[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$126434[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$126434[All], 
      All, $CellContext`i$127992], $CellContext`sym$126434[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$126434[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$126434, $CellContext`Cl]], \
$CellContext`sym$126434[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$126434[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$126434[All], 
      All, $CellContext`i$127987], $CellContext`sym$126434[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$126434[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$126434, $CellContext`mnO2]], \
$CellContext`sym$126434[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$126434[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$126434[All], 
      All, $CellContext`i$127986], $CellContext`sym$126434[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$126434[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$126434, $CellContext`mxPH]], \
$CellContext`sym$126434[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$126434[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$126434[All], 
      All, $CellContext`i$127985], $CellContext`sym$126434[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$126434[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$126434, $CellContext`NH4]], \
$CellContext`sym$126434[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$126434[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$126434[All], 
      All, $CellContext`i$127989], $CellContext`sym$126434[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$126434[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$126434, $CellContext`NO3]], \
$CellContext`sym$126434[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$126434[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$126434[All], 
      All, $CellContext`i$127988], $CellContext`sym$126434[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$126434[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$126434, $CellContext`oPO4]], \
$CellContext`sym$126434[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$126434[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$126434[All], 
      All, $CellContext`i$127990], $CellContext`sym$126434[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$126434[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$126434, $CellContext`PO4]], \
$CellContext`sym$126434[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$126434[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$126434[All], 
      All, $CellContext`i$127991], \
$CellContext`sym$126434[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$126434[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$126434, $CellContext`season]], \
$CellContext`sym$126434[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$126434[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$126434[All], 
      All, $CellContext`i$126435], $CellContext`sym$126434[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$126434[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$126434, $CellContext`size]], \
$CellContext`sym$126434[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$126434[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$126434[All], 
      All, $CellContext`i$127983], $CellContext`sym$126434[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$126434[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$126434, $CellContext`speed]], \
$CellContext`sym$126434[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$126434[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$126434[All], All, $CellContext`i$127984], 
    Attributes[$CellContext`i$127983] = {Temporary}, $CellContext`i$127983 = 
    2, Attributes[$CellContext`i$127988] = {Temporary}, $CellContext`i$127988 = 
    7, Attributes[$CellContext`i$127997] = {Temporary}, $CellContext`i$127997 = 
    16, Attributes[$CellContext`i$127986] = {
     Temporary}, $CellContext`i$127986 = 5, 
    Attributes[$CellContext`i$127998] = {Temporary}, $CellContext`i$127998 = 
    17, Attributes[$CellContext`i$127991] = {
     Temporary}, $CellContext`i$127991 = 10, 
    Attributes[$CellContext`i$127984] = {Temporary}, $CellContext`i$127984 = 
    3, Attributes[$CellContext`i$127989] = {Temporary}, $CellContext`i$127989 = 
    8, Attributes[$CellContext`i$126435] = {Temporary}, $CellContext`i$126435 = 
    1, Attributes[$CellContext`i$127985] = {Temporary}, $CellContext`i$127985 = 
    4, Attributes[$CellContext`i$127993] = {Temporary}, $CellContext`i$127993 = 
    12, Attributes[$CellContext`i$127999] = {
     Temporary}, $CellContext`i$127999 = 18, 
    Attributes[$CellContext`i$127992] = {Temporary}, $CellContext`i$127992 = 
    11, Attributes[$CellContext`i$127990] = {
     Temporary}, $CellContext`i$127990 = 9, 
    Attributes[$CellContext`i$127995] = {Temporary}, $CellContext`i$127995 = 
    14, Attributes[$CellContext`i$127994] = {
     Temporary}, $CellContext`i$127994 = 13, 
    Attributes[$CellContext`i$127987] = {Temporary}, $CellContext`i$127987 = 
    6, Attributes[$CellContext`i$127996] = {Temporary}, $CellContext`i$127996 = 
    15, Attributes[$CellContext`sym$3488] = {
     Temporary}, $CellContext`sym$3488[$CellContext`a1] = $CellContext`med[
     All], $CellContext`sym$3488[$CellContext`a2] = $CellContext`med[
     All], $CellContext`sym$3488[$CellContext`a3] = $CellContext`med[
     All], $CellContext`sym$3488[$CellContext`a4] = $CellContext`med[
     All], $CellContext`sym$3488[$CellContext`a5] = $CellContext`med[
     All], $CellContext`sym$3488[$CellContext`a6] = $CellContext`med[
     All], $CellContext`sym$3488[$CellContext`a7] = $CellContext`med[
     All], $CellContext`sym$3488[All] = $CellContext`med[
     All], $CellContext`sym$3488[$CellContext`Chla] = $CellContext`med[
     All], $CellContext`sym$3488[$CellContext`Cl] = $CellContext`med[
     All], $CellContext`sym$3488[$CellContext`mnO2] = $CellContext`med[
     All], $CellContext`sym$3488[$CellContext`mxPH] = $CellContext`med[
     All], $CellContext`sym$3488[$CellContext`NH4] = $CellContext`med[
     All], $CellContext`sym$3488[$CellContext`NO3] = $CellContext`med[
     All], $CellContext`sym$3488[$CellContext`oPO4] = $CellContext`med[
     All], $CellContext`sym$3488[$CellContext`PO4] = $CellContext`med[
     All], $CellContext`sym$3488[$CellContext`season] = $CellContext`med[
     All], $CellContext`sym$3488[$CellContext`size] = $CellContext`med[
     All], $CellContext`sym$3488[$CellContext`speed] = $CellContext`med[
     All], $CellContext`sym$3488[$CellContext`a1, "factorized"] = 
    True, $CellContext`sym$3488[$CellContext`a1, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$3488[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$3488[$CellContext`a1, "raw"] = Part[
      $CellContext`med[All], All, 12], $CellContext`sym$3488[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$3488[$CellContext`a2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$3488[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$3488[$CellContext`a2, "raw"] = Part[
      $CellContext`med[All], All, 13], $CellContext`sym$3488[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$3488[$CellContext`a3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$3488[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$3488[$CellContext`a3, "raw"] = Part[
      $CellContext`med[All], All, 14], $CellContext`sym$3488[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$3488[$CellContext`a4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$3488[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$3488[$CellContext`a4, "raw"] = Part[
      $CellContext`med[All], All, 15], $CellContext`sym$3488[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$3488[$CellContext`a5, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$3488[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$3488[$CellContext`a5, "raw"] = Part[
      $CellContext`med[All], All, 16], $CellContext`sym$3488[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$3488[$CellContext`a6, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$3488[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$3488[$CellContext`a6, "raw"] = Part[
      $CellContext`med[All], All, 17], $CellContext`sym$3488[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$3488[$CellContext`a7, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$3488[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$3488[$CellContext`a7, "raw"] = Part[
      $CellContext`med[All], All, 18], $CellContext`sym$3488[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$3488[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$3488[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$3488[$CellContext`Chla, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$3488[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$3488[$CellContext`Chla, "raw"] = Part[
      $CellContext`med[All], All, 11], $CellContext`sym$3488[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$3488[$CellContext`Cl, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$3488[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$3488[$CellContext`Cl, "raw"] = Part[
      $CellContext`med[All], All, 6], $CellContext`sym$3488[$CellContext`mnO2,
       "factorized"] = 
    True, $CellContext`sym$3488[$CellContext`mnO2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$3488[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$3488[$CellContext`mnO2, "raw"] = Part[
      $CellContext`med[All], All, 5], $CellContext`sym$3488[$CellContext`mxPH,
       "factorized"] = 
    True, $CellContext`sym$3488[$CellContext`mxPH, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$3488[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$3488[$CellContext`mxPH, "raw"] = Part[
      $CellContext`med[All], All, 4], $CellContext`sym$3488[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$3488[$CellContext`NH4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$3488[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$3488[$CellContext`NH4, "raw"] = Part[
      $CellContext`med[All], All, 8], $CellContext`sym$3488[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$3488[$CellContext`NO3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$3488[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$3488[$CellContext`NO3, "raw"] = Part[
      $CellContext`med[All], All, 7], $CellContext`sym$3488[$CellContext`oPO4,
       "factorized"] = 
    True, $CellContext`sym$3488[$CellContext`oPO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$3488[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$3488[$CellContext`oPO4, "raw"] = Part[
      $CellContext`med[All], All, 9], $CellContext`sym$3488[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$3488[$CellContext`PO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$3488[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$3488[$CellContext`PO4, "raw"] = Part[
      $CellContext`med[All], All, 
      10], $CellContext`sym$3488[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$3488[$CellContext`season, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$3488[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$3488[$CellContext`season, "raw"] = 
    Part[
      $CellContext`med[All], All, 1], $CellContext`sym$3488[$CellContext`size,
       "factorized"] = 
    True, $CellContext`sym$3488[$CellContext`size, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$3488[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$3488[$CellContext`size, "raw"] = Part[
      $CellContext`med[All], All, 
      2], $CellContext`sym$3488[$CellContext`speed, "factorized"] = 
    True, $CellContext`sym$3488[$CellContext`speed, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$3488[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$3488[$CellContext`speed, "raw"] = Part[
      $CellContext`med[All], All, 3], 
    Attributes[$CellContext`sym$14705] = {
     Temporary}, $CellContext`sym$14705[$CellContext`a1] = $CellContext`med[
     All], $CellContext`sym$14705[$CellContext`a2] = $CellContext`med[
     All], $CellContext`sym$14705[$CellContext`a3] = $CellContext`med[
     All], $CellContext`sym$14705[$CellContext`a4] = $CellContext`med[
     All], $CellContext`sym$14705[$CellContext`a5] = $CellContext`med[
     All], $CellContext`sym$14705[$CellContext`a6] = $CellContext`med[
     All], $CellContext`sym$14705[$CellContext`a7] = $CellContext`med[
     All], $CellContext`sym$14705[All] = $CellContext`med[
     All], $CellContext`sym$14705[$CellContext`Chla] = $CellContext`med[
     All], $CellContext`sym$14705[$CellContext`Cl] = $CellContext`med[
     All], $CellContext`sym$14705[$CellContext`mnO2] = $CellContext`med[
     All], $CellContext`sym$14705[$CellContext`mxPH] = $CellContext`med[
     All], $CellContext`sym$14705[$CellContext`NH4] = $CellContext`med[
     All], $CellContext`sym$14705[$CellContext`NO3] = $CellContext`med[
     All], $CellContext`sym$14705[$CellContext`oPO4] = $CellContext`med[All], 
    $CellContext`sym$14705[$CellContext`PO4] = $CellContext`med[
     All], $CellContext`sym$14705[$CellContext`season] = $CellContext`med[
     All], $CellContext`sym$14705[$CellContext`size] = $CellContext`med[
     All], $CellContext`sym$14705[$CellContext`speed] = $CellContext`med[
     All], $CellContext`sym$14705[$CellContext`a1, "factorized"] = 
    True, $CellContext`sym$14705[$CellContext`a1, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$14705[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$14705[$CellContext`a1, "raw"] = Part[
      $CellContext`med[All], All, 12], $CellContext`sym$14705[$CellContext`a2,
       "factorized"] = 
    True, $CellContext`sym$14705[$CellContext`a2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$14705[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$14705[$CellContext`a2, "raw"] = Part[
      $CellContext`med[All], All, 13], $CellContext`sym$14705[$CellContext`a3,
       "factorized"] = 
    True, $CellContext`sym$14705[$CellContext`a3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$14705[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$14705[$CellContext`a3, "raw"] = Part[
      $CellContext`med[All], All, 14], $CellContext`sym$14705[$CellContext`a4,
       "factorized"] = 
    True, $CellContext`sym$14705[$CellContext`a4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$14705[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$14705[$CellContext`a4, "raw"] = Part[
      $CellContext`med[All], All, 15], $CellContext`sym$14705[$CellContext`a5,
       "factorized"] = 
    True, $CellContext`sym$14705[$CellContext`a5, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$14705[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$14705[$CellContext`a5, "raw"] = Part[
      $CellContext`med[All], All, 16], $CellContext`sym$14705[$CellContext`a6,
       "factorized"] = 
    True, $CellContext`sym$14705[$CellContext`a6, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$14705[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$14705[$CellContext`a6, "raw"] = Part[
      $CellContext`med[All], All, 17], $CellContext`sym$14705[$CellContext`a7,
       "factorized"] = 
    True, $CellContext`sym$14705[$CellContext`a7, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$14705[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$14705[$CellContext`a7, "raw"] = Part[
      $CellContext`med[All], All, 18], $CellContext`sym$14705[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$14705[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$14705[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$14705[$CellContext`Chla, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$14705[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$14705[$CellContext`Chla, "raw"] = Part[
      $CellContext`med[All], All, 11], $CellContext`sym$14705[$CellContext`Cl,
       "factorized"] = 
    True, $CellContext`sym$14705[$CellContext`Cl, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$14705[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$14705[$CellContext`Cl, "raw"] = Part[
      $CellContext`med[All], All, 
      6], $CellContext`sym$14705[$CellContext`mnO2, "factorized"] = 
    True, $CellContext`sym$14705[$CellContext`mnO2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$14705[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$14705[$CellContext`mnO2, "raw"] = Part[
      $CellContext`med[All], All, 
      5], $CellContext`sym$14705[$CellContext`mxPH, "factorized"] = 
    True, $CellContext`sym$14705[$CellContext`mxPH, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$14705[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$14705[$CellContext`mxPH, "raw"] = Part[
      $CellContext`med[All], All, 4], $CellContext`sym$14705[$CellContext`NH4,
       "factorized"] = 
    True, $CellContext`sym$14705[$CellContext`NH4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$14705[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$14705[$CellContext`NH4, "raw"] = Part[
      $CellContext`med[All], All, 8], $CellContext`sym$14705[$CellContext`NO3,
       "factorized"] = 
    True, $CellContext`sym$14705[$CellContext`NO3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$14705[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$14705[$CellContext`NO3, "raw"] = Part[
      $CellContext`med[All], All, 
      7], $CellContext`sym$14705[$CellContext`oPO4, "factorized"] = 
    True, $CellContext`sym$14705[$CellContext`oPO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$14705[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$14705[$CellContext`oPO4, "raw"] = Part[
      $CellContext`med[All], All, 9], $CellContext`sym$14705[$CellContext`PO4,
       "factorized"] = 
    True, $CellContext`sym$14705[$CellContext`PO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$14705[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$14705[$CellContext`PO4, "raw"] = Part[
      $CellContext`med[All], All, 
      10], $CellContext`sym$14705[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$14705[$CellContext`season, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$14705[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$14705[$CellContext`season, "raw"] = 
    Part[
      $CellContext`med[All], All, 
      1], $CellContext`sym$14705[$CellContext`size, "factorized"] = 
    True, $CellContext`sym$14705[$CellContext`size, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$14705[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$14705[$CellContext`size, "raw"] = Part[
      $CellContext`med[All], All, 
      2], $CellContext`sym$14705[$CellContext`speed, "factorized"] = 
    True, $CellContext`sym$14705[$CellContext`speed, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$14705[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$14705[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`med[All], All, 3], 
    Attributes[$CellContext`sym$45968] = {
     Temporary}, $CellContext`sym$45968[$CellContext`a1] = $CellContext`med[
     All], $CellContext`sym$45968[$CellContext`a2] = $CellContext`med[
     All], $CellContext`sym$45968[$CellContext`a3] = $CellContext`med[
     All], $CellContext`sym$45968[$CellContext`a4] = $CellContext`med[
     All], $CellContext`sym$45968[$CellContext`a5] = $CellContext`med[
     All], $CellContext`sym$45968[$CellContext`a6] = $CellContext`med[
     All], $CellContext`sym$45968[$CellContext`a7] = $CellContext`med[
     All], $CellContext`sym$45968[All] = $CellContext`med[
     All], $CellContext`sym$45968[$CellContext`Chla] = $CellContext`med[
     All], $CellContext`sym$45968[$CellContext`Cl] = $CellContext`med[
     All], $CellContext`sym$45968[$CellContext`mnO2] = $CellContext`med[
     All], $CellContext`sym$45968[$CellContext`mxPH] = $CellContext`med[
     All], $CellContext`sym$45968[$CellContext`NH4] = $CellContext`med[
     All], $CellContext`sym$45968[$CellContext`NO3] = $CellContext`med[
     All], $CellContext`sym$45968[$CellContext`oPO4] = $CellContext`med[
     All], $CellContext`sym$45968[$CellContext`PO4] = $CellContext`med[
     All], $CellContext`sym$45968[$CellContext`season] = $CellContext`med[
     All], $CellContext`sym$45968[$CellContext`size] = $CellContext`med[
     All], $CellContext`sym$45968[$CellContext`speed] = $CellContext`med[
     All], $CellContext`sym$45968[$CellContext`a1, "factorized"] = 
    True, $CellContext`sym$45968[$CellContext`a1, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$45968[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$45968[$CellContext`a1, "raw"] = Part[
      $CellContext`med[All], All, 12], $CellContext`sym$45968[$CellContext`a2,
       "factorized"] = 
    True, $CellContext`sym$45968[$CellContext`a2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$45968[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$45968[$CellContext`a2, "raw"] = Part[
      $CellContext`med[All], All, 13], $CellContext`sym$45968[$CellContext`a3,
       "factorized"] = 
    True, $CellContext`sym$45968[$CellContext`a3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$45968[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$45968[$CellContext`a3, "raw"] = Part[
      $CellContext`med[All], All, 14], $CellContext`sym$45968[$CellContext`a4,
       "factorized"] = 
    True, $CellContext`sym$45968[$CellContext`a4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$45968[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$45968[$CellContext`a4, "raw"] = Part[
      $CellContext`med[All], All, 15], $CellContext`sym$45968[$CellContext`a5,
       "factorized"] = 
    True, $CellContext`sym$45968[$CellContext`a5, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$45968[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$45968[$CellContext`a5, "raw"] = Part[
      $CellContext`med[All], All, 16], $CellContext`sym$45968[$CellContext`a6,
       "factorized"] = 
    True, $CellContext`sym$45968[$CellContext`a6, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$45968[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$45968[$CellContext`a6, "raw"] = Part[
      $CellContext`med[All], All, 17], $CellContext`sym$45968[$CellContext`a7,
       "factorized"] = 
    True, $CellContext`sym$45968[$CellContext`a7, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$45968[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$45968[$CellContext`a7, "raw"] = Part[
      $CellContext`med[All], All, 18], $CellContext`sym$45968[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$45968[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$45968[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$45968[$CellContext`Chla, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$45968[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$45968[$CellContext`Chla, "raw"] = Part[
      $CellContext`med[All], All, 11], $CellContext`sym$45968[$CellContext`Cl,
       "factorized"] = 
    True, $CellContext`sym$45968[$CellContext`Cl, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$45968[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$45968[$CellContext`Cl, "raw"] = Part[
      $CellContext`med[All], All, 
      6], $CellContext`sym$45968[$CellContext`mnO2, "factorized"] = 
    True, $CellContext`sym$45968[$CellContext`mnO2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$45968[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$45968[$CellContext`mnO2, "raw"] = Part[
      $CellContext`med[All], All, 
      5], $CellContext`sym$45968[$CellContext`mxPH, "factorized"] = 
    True, $CellContext`sym$45968[$CellContext`mxPH, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$45968[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$45968[$CellContext`mxPH, "raw"] = Part[
      $CellContext`med[All], All, 4], $CellContext`sym$45968[$CellContext`NH4,
       "factorized"] = 
    True, $CellContext`sym$45968[$CellContext`NH4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$45968[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$45968[$CellContext`NH4, "raw"] = Part[
      $CellContext`med[All], All, 8], $CellContext`sym$45968[$CellContext`NO3,
       "factorized"] = 
    True, $CellContext`sym$45968[$CellContext`NO3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$45968[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$45968[$CellContext`NO3, "raw"] = Part[
      $CellContext`med[All], All, 
      7], $CellContext`sym$45968[$CellContext`oPO4, "factorized"] = 
    True, $CellContext`sym$45968[$CellContext`oPO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$45968[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$45968[$CellContext`oPO4, "raw"] = Part[
      $CellContext`med[All], All, 9], $CellContext`sym$45968[$CellContext`PO4,
       "factorized"] = 
    True, $CellContext`sym$45968[$CellContext`PO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$45968[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$45968[$CellContext`PO4, "raw"] = Part[
      $CellContext`med[All], All, 
      10], $CellContext`sym$45968[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$45968[$CellContext`season, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$45968[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$45968[$CellContext`season, "raw"] = 
    Part[
      $CellContext`med[All], All, 
      1], $CellContext`sym$45968[$CellContext`size, "factorized"] = 
    True, $CellContext`sym$45968[$CellContext`size, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$45968[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$45968[$CellContext`size, "raw"] = Part[
      $CellContext`med[All], All, 
      2], $CellContext`sym$45968[$CellContext`speed, "factorized"] = 
    True, $CellContext`sym$45968[$CellContext`speed, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$45968[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$45968[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`med[All], All, 3], 
    Attributes[$CellContext`sym$39269] = {
     Temporary}, $CellContext`sym$39269[$CellContext`a1] = $CellContext`med[
     All], $CellContext`sym$39269[$CellContext`a2] = $CellContext`med[
     All], $CellContext`sym$39269[$CellContext`a3] = $CellContext`med[
     All], $CellContext`sym$39269[$CellContext`a4] = $CellContext`med[
     All], $CellContext`sym$39269[$CellContext`a5] = $CellContext`med[
     All], $CellContext`sym$39269[$CellContext`a6] = $CellContext`med[
     All], $CellContext`sym$39269[$CellContext`a7] = $CellContext`med[
     All], $CellContext`sym$39269[All] = $CellContext`med[
     All], $CellContext`sym$39269[$CellContext`Chla] = $CellContext`med[
     All], $CellContext`sym$39269[$CellContext`Cl] = $CellContext`med[
     All], $CellContext`sym$39269[$CellContext`mnO2] = $CellContext`med[
     All], $CellContext`sym$39269[$CellContext`mxPH] = $CellContext`med[
     All], $CellContext`sym$39269[$CellContext`NH4] = $CellContext`med[
     All], $CellContext`sym$39269[$CellContext`NO3] = $CellContext`med[
     All], $CellContext`sym$39269[$CellContext`oPO4] = $CellContext`med[
     All], $CellContext`sym$39269[$CellContext`PO4] = $CellContext`med[
     All], $CellContext`sym$39269[$CellContext`season] = $CellContext`med[
     All], $CellContext`sym$39269[$CellContext`size] = $CellContext`med[
     All], $CellContext`sym$39269[$CellContext`speed] = $CellContext`med[
     All], $CellContext`sym$39269[$CellContext`a1, "factorized"] = 
    True, $CellContext`sym$39269[$CellContext`a1, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$39269[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$39269[$CellContext`a1, "raw"] = Part[
      $CellContext`med[All], All, 12], $CellContext`sym$39269[$CellContext`a2,
       "factorized"] = 
    True, $CellContext`sym$39269[$CellContext`a2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$39269[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$39269[$CellContext`a2, "raw"] = Part[
      $CellContext`med[All], All, 13], $CellContext`sym$39269[$CellContext`a3,
       "factorized"] = 
    True, $CellContext`sym$39269[$CellContext`a3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$39269[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$39269[$CellContext`a3, "raw"] = Part[
      $CellContext`med[All], All, 14], $CellContext`sym$39269[$CellContext`a4,
       "factorized"] = 
    True, $CellContext`sym$39269[$CellContext`a4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$39269[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$39269[$CellContext`a4, "raw"] = Part[
      $CellContext`med[All], All, 15], $CellContext`sym$39269[$CellContext`a5,
       "factorized"] = 
    True, $CellContext`sym$39269[$CellContext`a5, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$39269[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$39269[$CellContext`a5, "raw"] = Part[
      $CellContext`med[All], All, 16], $CellContext`sym$39269[$CellContext`a6,
       "factorized"] = 
    True, $CellContext`sym$39269[$CellContext`a6, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$39269[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$39269[$CellContext`a6, "raw"] = Part[
      $CellContext`med[All], All, 17], $CellContext`sym$39269[$CellContext`a7,
       "factorized"] = 
    True, $CellContext`sym$39269[$CellContext`a7, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$39269[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$39269[$CellContext`a7, "raw"] = Part[
      $CellContext`med[All], All, 18], $CellContext`sym$39269[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$39269[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$39269[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$39269[$CellContext`Chla, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$39269[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$39269[$CellContext`Chla, "raw"] = Part[
      $CellContext`med[All], All, 11], $CellContext`sym$39269[$CellContext`Cl,
       "factorized"] = 
    True, $CellContext`sym$39269[$CellContext`Cl, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$39269[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$39269[$CellContext`Cl, "raw"] = Part[
      $CellContext`med[All], All, 
      6], $CellContext`sym$39269[$CellContext`mnO2, "factorized"] = 
    True, $CellContext`sym$39269[$CellContext`mnO2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$39269[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$39269[$CellContext`mnO2, "raw"] = Part[
      $CellContext`med[All], All, 
      5], $CellContext`sym$39269[$CellContext`mxPH, "factorized"] = 
    True, $CellContext`sym$39269[$CellContext`mxPH, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$39269[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$39269[$CellContext`mxPH, "raw"] = Part[
      $CellContext`med[All], All, 4], $CellContext`sym$39269[$CellContext`NH4,
       "factorized"] = 
    True, $CellContext`sym$39269[$CellContext`NH4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$39269[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$39269[$CellContext`NH4, "raw"] = Part[
      $CellContext`med[All], All, 8], $CellContext`sym$39269[$CellContext`NO3,
       "factorized"] = 
    True, $CellContext`sym$39269[$CellContext`NO3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$39269[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$39269[$CellContext`NO3, "raw"] = Part[
      $CellContext`med[All], All, 
      7], $CellContext`sym$39269[$CellContext`oPO4, "factorized"] = 
    True, $CellContext`sym$39269[$CellContext`oPO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$39269[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$39269[$CellContext`oPO4, "raw"] = Part[
      $CellContext`med[All], All, 9], $CellContext`sym$39269[$CellContext`PO4,
       "factorized"] = 
    True, $CellContext`sym$39269[$CellContext`PO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$39269[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$39269[$CellContext`PO4, "raw"] = Part[
      $CellContext`med[All], All, 
      10], $CellContext`sym$39269[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$39269[$CellContext`season, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$39269[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$39269[$CellContext`season, "raw"] = 
    Part[
      $CellContext`med[All], All, 
      1], $CellContext`sym$39269[$CellContext`size, "factorized"] = 
    True, $CellContext`sym$39269[$CellContext`size, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$39269[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$39269[$CellContext`size, "raw"] = Part[
      $CellContext`med[All], All, 
      2], $CellContext`sym$39269[$CellContext`speed, "factorized"] = 
    True, $CellContext`sym$39269[$CellContext`speed, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$39269[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$39269[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`med[All], All, 3], 
    Attributes[$CellContext`sym$10239] = {
     Temporary}, $CellContext`sym$10239[$CellContext`a1] = $CellContext`med[
     All], $CellContext`sym$10239[$CellContext`a2] = $CellContext`med[
     All], $CellContext`sym$10239[$CellContext`a3] = $CellContext`med[
     All], $CellContext`sym$10239[$CellContext`a4] = $CellContext`med[
     All], $CellContext`sym$10239[$CellContext`a5] = $CellContext`med[
     All], $CellContext`sym$10239[$CellContext`a6] = $CellContext`med[
     All], $CellContext`sym$10239[$CellContext`a7] = $CellContext`med[
     All], $CellContext`sym$10239[All] = $CellContext`med[
     All], $CellContext`sym$10239[$CellContext`Chla] = $CellContext`med[
     All], $CellContext`sym$10239[$CellContext`Cl] = $CellContext`med[
     All], $CellContext`sym$10239[$CellContext`mnO2] = $CellContext`med[
     All], $CellContext`sym$10239[$CellContext`mxPH] = $CellContext`med[
     All], $CellContext`sym$10239[$CellContext`NH4] = $CellContext`med[
     All], $CellContext`sym$10239[$CellContext`NO3] = $CellContext`med[
     All], $CellContext`sym$10239[$CellContext`oPO4] = $CellContext`med[
     All], $CellContext`sym$10239[$CellContext`PO4] = $CellContext`med[
     All], $CellContext`sym$10239[$CellContext`season] = $CellContext`med[
     All], $CellContext`sym$10239[$CellContext`size] = $CellContext`med[
     All], $CellContext`sym$10239[$CellContext`speed] = $CellContext`med[
     All], $CellContext`sym$10239[$CellContext`a1, "factorized"] = 
    True, $CellContext`sym$10239[$CellContext`a1, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$10239[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$10239[$CellContext`a1, "raw"] = Part[
      $CellContext`med[All], All, 12], $CellContext`sym$10239[$CellContext`a2,
       "factorized"] = 
    True, $CellContext`sym$10239[$CellContext`a2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$10239[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$10239[$CellContext`a2, "raw"] = Part[
      $CellContext`med[All], All, 13], $CellContext`sym$10239[$CellContext`a3,
       "factorized"] = 
    True, $CellContext`sym$10239[$CellContext`a3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$10239[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$10239[$CellContext`a3, "raw"] = Part[
      $CellContext`med[All], All, 14], $CellContext`sym$10239[$CellContext`a4,
       "factorized"] = 
    True, $CellContext`sym$10239[$CellContext`a4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$10239[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$10239[$CellContext`a4, "raw"] = Part[
      $CellContext`med[All], All, 15], $CellContext`sym$10239[$CellContext`a5,
       "factorized"] = 
    True, $CellContext`sym$10239[$CellContext`a5, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$10239[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$10239[$CellContext`a5, "raw"] = Part[
      $CellContext`med[All], All, 16], $CellContext`sym$10239[$CellContext`a6,
       "factorized"] = 
    True, $CellContext`sym$10239[$CellContext`a6, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$10239[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$10239[$CellContext`a6, "raw"] = Part[
      $CellContext`med[All], All, 17], $CellContext`sym$10239[$CellContext`a7,
       "factorized"] = 
    True, $CellContext`sym$10239[$CellContext`a7, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$10239[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$10239[$CellContext`a7, "raw"] = Part[
      $CellContext`med[All], All, 18], $CellContext`sym$10239[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$10239[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$10239[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$10239[$CellContext`Chla, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$10239[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$10239[$CellContext`Chla, "raw"] = Part[
      $CellContext`med[All], All, 11], $CellContext`sym$10239[$CellContext`Cl,
       "factorized"] = 
    True, $CellContext`sym$10239[$CellContext`Cl, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$10239[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$10239[$CellContext`Cl, "raw"] = Part[
      $CellContext`med[All], All, 
      6], $CellContext`sym$10239[$CellContext`mnO2, "factorized"] = 
    True, $CellContext`sym$10239[$CellContext`mnO2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$10239[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$10239[$CellContext`mnO2, "raw"] = Part[
      $CellContext`med[All], All, 
      5], $CellContext`sym$10239[$CellContext`mxPH, "factorized"] = 
    True, $CellContext`sym$10239[$CellContext`mxPH, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$10239[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$10239[$CellContext`mxPH, "raw"] = Part[
      $CellContext`med[All], All, 4], $CellContext`sym$10239[$CellContext`NH4,
       "factorized"] = 
    True, $CellContext`sym$10239[$CellContext`NH4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$10239[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$10239[$CellContext`NH4, "raw"] = Part[
      $CellContext`med[All], All, 8], $CellContext`sym$10239[$CellContext`NO3,
       "factorized"] = 
    True, $CellContext`sym$10239[$CellContext`NO3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$10239[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$10239[$CellContext`NO3, "raw"] = Part[
      $CellContext`med[All], All, 
      7], $CellContext`sym$10239[$CellContext`oPO4, "factorized"] = 
    True, $CellContext`sym$10239[$CellContext`oPO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$10239[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$10239[$CellContext`oPO4, "raw"] = Part[
      $CellContext`med[All], All, 9], $CellContext`sym$10239[$CellContext`PO4,
       "factorized"] = 
    True, $CellContext`sym$10239[$CellContext`PO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$10239[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$10239[$CellContext`PO4, "raw"] = Part[
      $CellContext`med[All], All, 
      10], $CellContext`sym$10239[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$10239[$CellContext`season, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$10239[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$10239[$CellContext`season, "raw"] = 
    Part[
      $CellContext`med[All], All, 
      1], $CellContext`sym$10239[$CellContext`size, "factorized"] = 
    True, $CellContext`sym$10239[$CellContext`size, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$10239[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$10239[$CellContext`size, "raw"] = Part[
      $CellContext`med[All], All, 
      2], $CellContext`sym$10239[$CellContext`speed, "factorized"] = 
    True, $CellContext`sym$10239[$CellContext`speed, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$10239[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$10239[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`med[All], All, 3], 
    Attributes[$CellContext`sym$144298] = {
     Temporary}, $CellContext`sym$144298[$CellContext`a1] = Part[
      $CellContext`sym$144298[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$144298[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$144298[$CellContext`a2] = Part[
      $CellContext`sym$144298[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$144298[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$144298[$CellContext`a3] = Part[
      $CellContext`sym$144298[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$144298[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$144298[$CellContext`a4] = Part[
      $CellContext`sym$144298[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$144298[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$144298[$CellContext`a5] = Part[
      $CellContext`sym$144298[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$144298[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$144298[$CellContext`a6] = Part[
      $CellContext`sym$144298[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$144298[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$144298[$CellContext`a7] = Part[
      $CellContext`sym$144298[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$144298[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$144298[All] = $CellContext`med[
     All], $CellContext`sym$144298[$CellContext`Chla] = Part[
      $CellContext`sym$144298[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$144298[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$144298[$CellContext`Cl] = Part[
      $CellContext`sym$144298[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$144298[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$144298[$CellContext`mnO2] = Part[
      $CellContext`sym$144298[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$144298[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$144298[$CellContext`mxPH] = Part[
      $CellContext`sym$144298[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$144298[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$144298[$CellContext`NH4] = Part[
      $CellContext`sym$144298[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$144298[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$144298[$CellContext`NO3] = Part[
      $CellContext`sym$144298[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$144298[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$144298[$CellContext`oPO4] = Part[
      $CellContext`sym$144298[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$144298[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$144298[$CellContext`PO4] = Part[
      $CellContext`sym$144298[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$144298[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$144298[$CellContext`season] = Part[
      $CellContext`sym$144298[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$144298[$CellContext`season, 
         "missing"]]]], $CellContext`sym$144298[$CellContext`size] = Part[
      $CellContext`sym$144298[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$144298[$CellContext`size, 
         "missing"]]]], $CellContext`sym$144298[$CellContext`speed] = Part[
      $CellContext`sym$144298[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$144298[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$144298[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$144298[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$144298, $CellContext`a1]], \
$CellContext`sym$144298[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$144298[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$144298[All], 
      All, $CellContext`i$145857], $CellContext`sym$144298[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$144298[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$144298, $CellContext`a2]], \
$CellContext`sym$144298[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$144298[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$144298[All], 
      All, $CellContext`i$145858], $CellContext`sym$144298[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$144298[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$144298, $CellContext`a3]], \
$CellContext`sym$144298[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$144298[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$144298[All], 
      All, $CellContext`i$145859], $CellContext`sym$144298[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$144298[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$144298, $CellContext`a4]], \
$CellContext`sym$144298[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$144298[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$144298[All], 
      All, $CellContext`i$145860], $CellContext`sym$144298[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$144298[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$144298, $CellContext`a5]], \
$CellContext`sym$144298[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$144298[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$144298[All], 
      All, $CellContext`i$145861], $CellContext`sym$144298[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$144298[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$144298, $CellContext`a6]], \
$CellContext`sym$144298[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$144298[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$144298[All], 
      All, $CellContext`i$145862], $CellContext`sym$144298[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$144298[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$144298, $CellContext`a7]], \
$CellContext`sym$144298[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$144298[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$144298[All], 
      All, $CellContext`i$145863], $CellContext`sym$144298[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$144298[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$144298[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$144298[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$144298, $CellContext`Chla]], \
$CellContext`sym$144298[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$144298[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$144298[All], 
      All, $CellContext`i$145856], $CellContext`sym$144298[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$144298[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$144298, $CellContext`Cl]], \
$CellContext`sym$144298[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$144298[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$144298[All], 
      All, $CellContext`i$145851], $CellContext`sym$144298[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$144298[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$144298, $CellContext`mnO2]], \
$CellContext`sym$144298[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$144298[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$144298[All], 
      All, $CellContext`i$145850], $CellContext`sym$144298[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$144298[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$144298, $CellContext`mxPH]], \
$CellContext`sym$144298[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$144298[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$144298[All], 
      All, $CellContext`i$145849], $CellContext`sym$144298[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$144298[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$144298, $CellContext`NH4]], \
$CellContext`sym$144298[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$144298[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$144298[All], 
      All, $CellContext`i$145853], $CellContext`sym$144298[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$144298[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$144298, $CellContext`NO3]], \
$CellContext`sym$144298[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$144298[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$144298[All], 
      All, $CellContext`i$145852], $CellContext`sym$144298[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$144298[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$144298, $CellContext`oPO4]], \
$CellContext`sym$144298[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$144298[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$144298[All], 
      All, $CellContext`i$145854], $CellContext`sym$144298[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$144298[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$144298, $CellContext`PO4]], \
$CellContext`sym$144298[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$144298[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$144298[All], 
      All, $CellContext`i$145855], \
$CellContext`sym$144298[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$144298[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$144298, $CellContext`season]], \
$CellContext`sym$144298[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$144298[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$144298[All], 
      All, $CellContext`i$144299], $CellContext`sym$144298[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$144298[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$144298, $CellContext`size]], \
$CellContext`sym$144298[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$144298[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$144298[All], 
      All, $CellContext`i$145847], $CellContext`sym$144298[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$144298[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$144298, $CellContext`speed]], \
$CellContext`sym$144298[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$144298[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$144298[All], All, $CellContext`i$145848], 
    Attributes[$CellContext`i$145856] = {Temporary}, $CellContext`i$145856 = 
    11, Attributes[$CellContext`i$145853] = {
     Temporary}, $CellContext`i$145853 = 8, 
    Attributes[$CellContext`i$145847] = {Temporary}, $CellContext`i$145847 = 
    2, Attributes[$CellContext`i$144299] = {Temporary}, $CellContext`i$144299 = 
    1, Attributes[$CellContext`i$145851] = {Temporary}, $CellContext`i$145851 = 
    6, Attributes[$CellContext`i$145850] = {Temporary}, $CellContext`i$145850 = 
    5, Attributes[$CellContext`i$145857] = {Temporary}, $CellContext`i$145857 = 
    12, Attributes[$CellContext`i$145860] = {
     Temporary}, $CellContext`i$145860 = 15, 
    Attributes[$CellContext`i$145855] = {Temporary}, $CellContext`i$145855 = 
    10, Attributes[$CellContext`i$145862] = {
     Temporary}, $CellContext`i$145862 = 17, 
    Attributes[$CellContext`i$145852] = {Temporary}, $CellContext`i$145852 = 
    7, Attributes[$CellContext`i$145858] = {Temporary}, $CellContext`i$145858 = 
    13, Attributes[$CellContext`i$145848] = {
     Temporary}, $CellContext`i$145848 = 3, 
    Attributes[$CellContext`i$145849] = {Temporary}, $CellContext`i$145849 = 
    4, Attributes[$CellContext`i$145854] = {Temporary}, $CellContext`i$145854 = 
    9, Attributes[$CellContext`i$145863] = {Temporary}, $CellContext`i$145863 = 
    18, Attributes[$CellContext`i$145861] = {
     Temporary}, $CellContext`i$145861 = 16, 
    Attributes[$CellContext`i$145859] = {Temporary}, $CellContext`i$145859 = 
    14, Attributes[$CellContext`sym$59366] = {
     Temporary}, $CellContext`sym$59366[$CellContext`a1] = $CellContext`med[
     All], $CellContext`sym$59366[$CellContext`a2] = $CellContext`med[
     All], $CellContext`sym$59366[$CellContext`a3] = $CellContext`med[
     All], $CellContext`sym$59366[$CellContext`a4] = $CellContext`med[
     All], $CellContext`sym$59366[$CellContext`a5] = $CellContext`med[
     All], $CellContext`sym$59366[$CellContext`a6] = $CellContext`med[
     All], $CellContext`sym$59366[$CellContext`a7] = $CellContext`med[
     All], $CellContext`sym$59366[All] = $CellContext`med[
     All], $CellContext`sym$59366[$CellContext`Chla] = $CellContext`med[
     All], $CellContext`sym$59366[$CellContext`Cl] = $CellContext`med[
     All], $CellContext`sym$59366[$CellContext`mnO2] = $CellContext`med[
     All], $CellContext`sym$59366[$CellContext`mxPH] = $CellContext`med[
     All], $CellContext`sym$59366[$CellContext`NH4] = $CellContext`med[
     All], $CellContext`sym$59366[$CellContext`NO3] = $CellContext`med[
     All], $CellContext`sym$59366[$CellContext`oPO4] = $CellContext`med[
     All], $CellContext`sym$59366[$CellContext`PO4] = $CellContext`med[
     All], $CellContext`sym$59366[$CellContext`season] = $CellContext`med[
     All], $CellContext`sym$59366[$CellContext`size] = $CellContext`med[
     All], $CellContext`sym$59366[$CellContext`speed] = $CellContext`med[
     All], $CellContext`sym$59366[$CellContext`a1, "factorized"] = 
    True, $CellContext`sym$59366[$CellContext`a1, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$59366[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$59366[$CellContext`a1, "raw"] = Part[
      $CellContext`med[All], All, 12], $CellContext`sym$59366[$CellContext`a2,
       "factorized"] = 
    True, $CellContext`sym$59366[$CellContext`a2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$59366[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$59366[$CellContext`a2, "raw"] = Part[
      $CellContext`med[All], All, 13], $CellContext`sym$59366[$CellContext`a3,
       "factorized"] = 
    True, $CellContext`sym$59366[$CellContext`a3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$59366[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$59366[$CellContext`a3, "raw"] = Part[
      $CellContext`med[All], All, 14], $CellContext`sym$59366[$CellContext`a4,
       "factorized"] = 
    True, $CellContext`sym$59366[$CellContext`a4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$59366[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$59366[$CellContext`a4, "raw"] = Part[
      $CellContext`med[All], All, 15], $CellContext`sym$59366[$CellContext`a5,
       "factorized"] = 
    True, $CellContext`sym$59366[$CellContext`a5, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$59366[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$59366[$CellContext`a5, "raw"] = Part[
      $CellContext`med[All], All, 16], $CellContext`sym$59366[$CellContext`a6,
       "factorized"] = 
    True, $CellContext`sym$59366[$CellContext`a6, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$59366[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$59366[$CellContext`a6, "raw"] = Part[
      $CellContext`med[All], All, 17], $CellContext`sym$59366[$CellContext`a7,
       "factorized"] = 
    True, $CellContext`sym$59366[$CellContext`a7, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$59366[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$59366[$CellContext`a7, "raw"] = Part[
      $CellContext`med[All], All, 18], $CellContext`sym$59366[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$59366[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$59366[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$59366[$CellContext`Chla, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$59366[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$59366[$CellContext`Chla, "raw"] = Part[
      $CellContext`med[All], All, 11], $CellContext`sym$59366[$CellContext`Cl,
       "factorized"] = 
    True, $CellContext`sym$59366[$CellContext`Cl, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$59366[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$59366[$CellContext`Cl, "raw"] = Part[
      $CellContext`med[All], All, 
      6], $CellContext`sym$59366[$CellContext`mnO2, "factorized"] = 
    True, $CellContext`sym$59366[$CellContext`mnO2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$59366[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$59366[$CellContext`mnO2, "raw"] = Part[
      $CellContext`med[All], All, 
      5], $CellContext`sym$59366[$CellContext`mxPH, "factorized"] = 
    True, $CellContext`sym$59366[$CellContext`mxPH, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$59366[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$59366[$CellContext`mxPH, "raw"] = Part[
      $CellContext`med[All], All, 4], $CellContext`sym$59366[$CellContext`NH4,
       "factorized"] = 
    True, $CellContext`sym$59366[$CellContext`NH4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$59366[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$59366[$CellContext`NH4, "raw"] = Part[
      $CellContext`med[All], All, 8], $CellContext`sym$59366[$CellContext`NO3,
       "factorized"] = 
    True, $CellContext`sym$59366[$CellContext`NO3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$59366[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$59366[$CellContext`NO3, "raw"] = Part[
      $CellContext`med[All], All, 
      7], $CellContext`sym$59366[$CellContext`oPO4, "factorized"] = 
    True, $CellContext`sym$59366[$CellContext`oPO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$59366[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$59366[$CellContext`oPO4, "raw"] = Part[
      $CellContext`med[All], All, 9], $CellContext`sym$59366[$CellContext`PO4,
       "factorized"] = 
    True, $CellContext`sym$59366[$CellContext`PO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$59366[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$59366[$CellContext`PO4, "raw"] = Part[
      $CellContext`med[All], All, 
      10], $CellContext`sym$59366[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$59366[$CellContext`season, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$59366[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$59366[$CellContext`season, "raw"] = 
    Part[
      $CellContext`med[All], All, 
      1], $CellContext`sym$59366[$CellContext`size, "factorized"] = 
    True, $CellContext`sym$59366[$CellContext`size, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$59366[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$59366[$CellContext`size, "raw"] = Part[
      $CellContext`med[All], All, 
      2], $CellContext`sym$59366[$CellContext`speed, "factorized"] = 
    True, $CellContext`sym$59366[$CellContext`speed, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$59366[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$59366[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`med[All], All, 3], 
    Attributes[$CellContext`sym$57133] = {
     Temporary}, $CellContext`sym$57133[$CellContext`a1] = $CellContext`med[
     All], $CellContext`sym$57133[$CellContext`a2] = $CellContext`med[
     All], $CellContext`sym$57133[$CellContext`a3] = $CellContext`med[
     All], $CellContext`sym$57133[$CellContext`a4] = $CellContext`med[
     All], $CellContext`sym$57133[$CellContext`a5] = $CellContext`med[
     All], $CellContext`sym$57133[$CellContext`a6] = $CellContext`med[
     All], $CellContext`sym$57133[$CellContext`a7] = $CellContext`med[
     All], $CellContext`sym$57133[All] = $CellContext`med[
     All], $CellContext`sym$57133[$CellContext`Chla] = $CellContext`med[
     All], $CellContext`sym$57133[$CellContext`Cl] = $CellContext`med[
     All], $CellContext`sym$57133[$CellContext`mnO2] = $CellContext`med[
     All], $CellContext`sym$57133[$CellContext`mxPH] = $CellContext`med[
     All], $CellContext`sym$57133[$CellContext`NH4] = $CellContext`med[
     All], $CellContext`sym$57133[$CellContext`NO3] = $CellContext`med[
     All], $CellContext`sym$57133[$CellContext`oPO4] = $CellContext`med[
     All], $CellContext`sym$57133[$CellContext`PO4] = $CellContext`med[
     All], $CellContext`sym$57133[$CellContext`season] = $CellContext`med[
     All], $CellContext`sym$57133[$CellContext`size] = $CellContext`med[
     All], $CellContext`sym$57133[$CellContext`speed] = $CellContext`med[
     All], $CellContext`sym$57133[$CellContext`a1, "factorized"] = 
    True, $CellContext`sym$57133[$CellContext`a1, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$57133[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$57133[$CellContext`a1, "raw"] = Part[
      $CellContext`med[All], All, 12], $CellContext`sym$57133[$CellContext`a2,
       "factorized"] = 
    True, $CellContext`sym$57133[$CellContext`a2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$57133[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$57133[$CellContext`a2, "raw"] = Part[
      $CellContext`med[All], All, 13], $CellContext`sym$57133[$CellContext`a3,
       "factorized"] = 
    True, $CellContext`sym$57133[$CellContext`a3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$57133[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$57133[$CellContext`a3, "raw"] = Part[
      $CellContext`med[All], All, 14], $CellContext`sym$57133[$CellContext`a4,
       "factorized"] = 
    True, $CellContext`sym$57133[$CellContext`a4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$57133[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$57133[$CellContext`a4, "raw"] = Part[
      $CellContext`med[All], All, 15], $CellContext`sym$57133[$CellContext`a5,
       "factorized"] = 
    True, $CellContext`sym$57133[$CellContext`a5, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$57133[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$57133[$CellContext`a5, "raw"] = Part[
      $CellContext`med[All], All, 16], $CellContext`sym$57133[$CellContext`a6,
       "factorized"] = 
    True, $CellContext`sym$57133[$CellContext`a6, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$57133[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$57133[$CellContext`a6, "raw"] = Part[
      $CellContext`med[All], All, 17], $CellContext`sym$57133[$CellContext`a7,
       "factorized"] = 
    True, $CellContext`sym$57133[$CellContext`a7, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$57133[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$57133[$CellContext`a7, "raw"] = Part[
      $CellContext`med[All], All, 18], $CellContext`sym$57133[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$57133[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$57133[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$57133[$CellContext`Chla, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$57133[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$57133[$CellContext`Chla, "raw"] = Part[
      $CellContext`med[All], All, 11], $CellContext`sym$57133[$CellContext`Cl,
       "factorized"] = 
    True, $CellContext`sym$57133[$CellContext`Cl, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$57133[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$57133[$CellContext`Cl, "raw"] = Part[
      $CellContext`med[All], All, 
      6], $CellContext`sym$57133[$CellContext`mnO2, "factorized"] = 
    True, $CellContext`sym$57133[$CellContext`mnO2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$57133[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$57133[$CellContext`mnO2, "raw"] = Part[
      $CellContext`med[All], All, 
      5], $CellContext`sym$57133[$CellContext`mxPH, "factorized"] = 
    True, $CellContext`sym$57133[$CellContext`mxPH, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$57133[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$57133[$CellContext`mxPH, "raw"] = Part[
      $CellContext`med[All], All, 4], $CellContext`sym$57133[$CellContext`NH4,
       "factorized"] = 
    True, $CellContext`sym$57133[$CellContext`NH4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$57133[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$57133[$CellContext`NH4, "raw"] = Part[
      $CellContext`med[All], All, 8], $CellContext`sym$57133[$CellContext`NO3,
       "factorized"] = 
    True, $CellContext`sym$57133[$CellContext`NO3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$57133[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$57133[$CellContext`NO3, "raw"] = Part[
      $CellContext`med[All], All, 
      7], $CellContext`sym$57133[$CellContext`oPO4, "factorized"] = 
    True, $CellContext`sym$57133[$CellContext`oPO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$57133[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$57133[$CellContext`oPO4, "raw"] = Part[
      $CellContext`med[All], All, 9], $CellContext`sym$57133[$CellContext`PO4,
       "factorized"] = 
    True, $CellContext`sym$57133[$CellContext`PO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$57133[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$57133[$CellContext`PO4, "raw"] = Part[
      $CellContext`med[All], All, 
      10], $CellContext`sym$57133[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$57133[$CellContext`season, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$57133[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$57133[$CellContext`season, "raw"] = 
    Part[
      $CellContext`med[All], All, 
      1], $CellContext`sym$57133[$CellContext`size, "factorized"] = 
    True, $CellContext`sym$57133[$CellContext`size, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$57133[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$57133[$CellContext`size, "raw"] = Part[
      $CellContext`med[All], All, 
      2], $CellContext`sym$57133[$CellContext`speed, "factorized"] = 
    True, $CellContext`sym$57133[$CellContext`speed, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$57133[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$57133[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`med[All], All, 3], 
    Attributes[$CellContext`sym$139832] = {
     Temporary}, $CellContext`sym$139832[$CellContext`a1] = Part[
      $CellContext`sym$139832[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$139832[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$139832[$CellContext`a2] = Part[
      $CellContext`sym$139832[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$139832[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$139832[$CellContext`a3] = Part[
      $CellContext`sym$139832[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$139832[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$139832[$CellContext`a4] = Part[
      $CellContext`sym$139832[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$139832[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$139832[$CellContext`a5] = Part[
      $CellContext`sym$139832[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$139832[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$139832[$CellContext`a6] = Part[
      $CellContext`sym$139832[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$139832[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$139832[$CellContext`a7] = Part[
      $CellContext`sym$139832[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$139832[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$139832[All] = $CellContext`med[
     All], $CellContext`sym$139832[$CellContext`Chla] = Part[
      $CellContext`sym$139832[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$139832[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$139832[$CellContext`Cl] = Part[
      $CellContext`sym$139832[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$139832[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$139832[$CellContext`mnO2] = Part[
      $CellContext`sym$139832[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$139832[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$139832[$CellContext`mxPH] = Part[
      $CellContext`sym$139832[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$139832[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$139832[$CellContext`NH4] = Part[
      $CellContext`sym$139832[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$139832[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$139832[$CellContext`NO3] = Part[
      $CellContext`sym$139832[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$139832[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$139832[$CellContext`oPO4] = Part[
      $CellContext`sym$139832[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$139832[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$139832[$CellContext`PO4] = Part[
      $CellContext`sym$139832[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$139832[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$139832[$CellContext`season] = Part[
      $CellContext`sym$139832[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$139832[$CellContext`season, 
         "missing"]]]], $CellContext`sym$139832[$CellContext`size] = Part[
      $CellContext`sym$139832[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$139832[$CellContext`size, 
         "missing"]]]], $CellContext`sym$139832[$CellContext`speed] = Part[
      $CellContext`sym$139832[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$139832[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$139832[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$139832[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$139832, $CellContext`a1]], \
$CellContext`sym$139832[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$139832[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$139832[All], 
      All, $CellContext`i$141391], $CellContext`sym$139832[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$139832[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$139832, $CellContext`a2]], \
$CellContext`sym$139832[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$139832[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$139832[All], 
      All, $CellContext`i$141392], $CellContext`sym$139832[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$139832[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$139832, $CellContext`a3]], \
$CellContext`sym$139832[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$139832[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$139832[All], 
      All, $CellContext`i$141393], $CellContext`sym$139832[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$139832[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$139832, $CellContext`a4]], \
$CellContext`sym$139832[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$139832[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$139832[All], 
      All, $CellContext`i$141394], $CellContext`sym$139832[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$139832[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$139832, $CellContext`a5]], \
$CellContext`sym$139832[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$139832[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$139832[All], 
      All, $CellContext`i$141395], $CellContext`sym$139832[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$139832[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$139832, $CellContext`a6]], \
$CellContext`sym$139832[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$139832[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$139832[All], 
      All, $CellContext`i$141396], $CellContext`sym$139832[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$139832[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$139832, $CellContext`a7]], \
$CellContext`sym$139832[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$139832[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$139832[All], 
      All, $CellContext`i$141397], $CellContext`sym$139832[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$139832[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$139832[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$139832[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$139832, $CellContext`Chla]], \
$CellContext`sym$139832[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$139832[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$139832[All], 
      All, $CellContext`i$141390], $CellContext`sym$139832[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$139832[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$139832, $CellContext`Cl]], \
$CellContext`sym$139832[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$139832[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$139832[All], 
      All, $CellContext`i$141385], $CellContext`sym$139832[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$139832[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$139832, $CellContext`mnO2]], \
$CellContext`sym$139832[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$139832[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$139832[All], 
      All, $CellContext`i$141384], $CellContext`sym$139832[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$139832[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$139832, $CellContext`mxPH]], \
$CellContext`sym$139832[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$139832[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$139832[All], 
      All, $CellContext`i$141383], $CellContext`sym$139832[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$139832[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$139832, $CellContext`NH4]], \
$CellContext`sym$139832[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$139832[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$139832[All], 
      All, $CellContext`i$141387], $CellContext`sym$139832[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$139832[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$139832, $CellContext`NO3]], \
$CellContext`sym$139832[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$139832[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$139832[All], 
      All, $CellContext`i$141386], $CellContext`sym$139832[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$139832[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$139832, $CellContext`oPO4]], \
$CellContext`sym$139832[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$139832[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$139832[All], 
      All, $CellContext`i$141388], $CellContext`sym$139832[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$139832[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$139832, $CellContext`PO4]], \
$CellContext`sym$139832[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$139832[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$139832[All], 
      All, $CellContext`i$141389], \
$CellContext`sym$139832[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$139832[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$139832, $CellContext`season]], \
$CellContext`sym$139832[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$139832[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$139832[All], 
      All, $CellContext`i$139833], $CellContext`sym$139832[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$139832[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$139832, $CellContext`size]], \
$CellContext`sym$139832[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$139832[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$139832[All], 
      All, $CellContext`i$141381], $CellContext`sym$139832[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$139832[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$139832, $CellContext`speed]], \
$CellContext`sym$139832[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$139832[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$139832[All], All, $CellContext`i$141382], 
    Attributes[$CellContext`i$141384] = {Temporary}, $CellContext`i$141384 = 
    5, Attributes[$CellContext`i$141394] = {Temporary}, $CellContext`i$141394 = 
    15, Attributes[$CellContext`i$141395] = {
     Temporary}, $CellContext`i$141395 = 16, 
    Attributes[$CellContext`i$141382] = {Temporary}, $CellContext`i$141382 = 
    3, Attributes[$CellContext`i$141386] = {Temporary}, $CellContext`i$141386 = 
    7, Attributes[$CellContext`i$141385] = {Temporary}, $CellContext`i$141385 = 
    6, Attributes[$CellContext`i$141397] = {Temporary}, $CellContext`i$141397 = 
    18, Attributes[$CellContext`i$141383] = {
     Temporary}, $CellContext`i$141383 = 4, 
    Attributes[$CellContext`i$141381] = {Temporary}, $CellContext`i$141381 = 
    2, Attributes[$CellContext`i$141389] = {Temporary}, $CellContext`i$141389 = 
    10, Attributes[$CellContext`i$141390] = {
     Temporary}, $CellContext`i$141390 = 11, 
    Attributes[$CellContext`i$141392] = {Temporary}, $CellContext`i$141392 = 
    13, Attributes[$CellContext`i$141387] = {
     Temporary}, $CellContext`i$141387 = 8, 
    Attributes[$CellContext`i$141396] = {Temporary}, $CellContext`i$141396 = 
    17, Attributes[$CellContext`i$141393] = {
     Temporary}, $CellContext`i$141393 = 14, 
    Attributes[$CellContext`i$139833] = {Temporary}, $CellContext`i$139833 = 
    1, Attributes[$CellContext`i$141391] = {Temporary}, $CellContext`i$141391 = 
    12, Attributes[$CellContext`i$141388] = {
     Temporary}, $CellContext`i$141388 = 9, 
    Attributes[$CellContext`sym$168861] = {
     Temporary}, $CellContext`sym$168861[$CellContext`a1] = Part[
      $CellContext`sym$168861[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$168861[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$168861[$CellContext`a2] = Part[
      $CellContext`sym$168861[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$168861[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$168861[$CellContext`a3] = Part[
      $CellContext`sym$168861[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$168861[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$168861[$CellContext`a4] = Part[
      $CellContext`sym$168861[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$168861[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$168861[$CellContext`a5] = Part[
      $CellContext`sym$168861[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$168861[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$168861[$CellContext`a6] = Part[
      $CellContext`sym$168861[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$168861[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$168861[$CellContext`a7] = Part[
      $CellContext`sym$168861[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$168861[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$168861[All] = $CellContext`med[
     All], $CellContext`sym$168861[$CellContext`Chla] = Part[
      $CellContext`sym$168861[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$168861[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$168861[$CellContext`Cl] = Part[
      $CellContext`sym$168861[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$168861[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$168861[$CellContext`mnO2] = Part[
      $CellContext`sym$168861[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$168861[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$168861[$CellContext`mxPH] = Part[
      $CellContext`sym$168861[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$168861[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$168861[$CellContext`NH4] = Part[
      $CellContext`sym$168861[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$168861[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$168861[$CellContext`NO3] = Part[
      $CellContext`sym$168861[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$168861[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$168861[$CellContext`oPO4] = Part[
      $CellContext`sym$168861[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$168861[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$168861[$CellContext`PO4] = Part[
      $CellContext`sym$168861[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$168861[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$168861[$CellContext`season] = Part[
      $CellContext`sym$168861[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$168861[$CellContext`season, 
         "missing"]]]], $CellContext`sym$168861[$CellContext`size] = Part[
      $CellContext`sym$168861[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$168861[$CellContext`size, 
         "missing"]]]], $CellContext`sym$168861[$CellContext`speed] = Part[
      $CellContext`sym$168861[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$168861[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$168861[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$168861[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$168861, $CellContext`a1]], \
$CellContext`sym$168861[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$168861[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$168861[All], 
      All, $CellContext`i$170420], $CellContext`sym$168861[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$168861[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$168861, $CellContext`a2]], \
$CellContext`sym$168861[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$168861[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$168861[All], 
      All, $CellContext`i$170421], $CellContext`sym$168861[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$168861[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$168861, $CellContext`a3]], \
$CellContext`sym$168861[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$168861[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$168861[All], 
      All, $CellContext`i$170422], $CellContext`sym$168861[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$168861[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$168861, $CellContext`a4]], \
$CellContext`sym$168861[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$168861[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$168861[All], 
      All, $CellContext`i$170423], $CellContext`sym$168861[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$168861[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$168861, $CellContext`a5]], \
$CellContext`sym$168861[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$168861[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$168861[All], 
      All, $CellContext`i$170424], $CellContext`sym$168861[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$168861[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$168861, $CellContext`a6]], \
$CellContext`sym$168861[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$168861[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$168861[All], 
      All, $CellContext`i$170425], $CellContext`sym$168861[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$168861[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$168861, $CellContext`a7]], \
$CellContext`sym$168861[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$168861[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$168861[All], 
      All, $CellContext`i$170426], $CellContext`sym$168861[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$168861[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$168861[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$168861[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$168861, $CellContext`Chla]], \
$CellContext`sym$168861[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$168861[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$168861[All], 
      All, $CellContext`i$170419], $CellContext`sym$168861[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$168861[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$168861, $CellContext`Cl]], \
$CellContext`sym$168861[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$168861[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$168861[All], 
      All, $CellContext`i$170414], $CellContext`sym$168861[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$168861[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$168861, $CellContext`mnO2]], \
$CellContext`sym$168861[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$168861[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$168861[All], 
      All, $CellContext`i$170413], $CellContext`sym$168861[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$168861[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$168861, $CellContext`mxPH]], \
$CellContext`sym$168861[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$168861[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$168861[All], 
      All, $CellContext`i$170412], $CellContext`sym$168861[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$168861[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$168861, $CellContext`NH4]], \
$CellContext`sym$168861[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$168861[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$168861[All], 
      All, $CellContext`i$170416], $CellContext`sym$168861[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$168861[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$168861, $CellContext`NO3]], \
$CellContext`sym$168861[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$168861[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$168861[All], 
      All, $CellContext`i$170415], $CellContext`sym$168861[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$168861[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$168861, $CellContext`oPO4]], \
$CellContext`sym$168861[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$168861[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$168861[All], 
      All, $CellContext`i$170417], $CellContext`sym$168861[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$168861[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$168861, $CellContext`PO4]], \
$CellContext`sym$168861[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$168861[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$168861[All], 
      All, $CellContext`i$170418], \
$CellContext`sym$168861[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$168861[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$168861, $CellContext`season]], \
$CellContext`sym$168861[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$168861[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$168861[All], 
      All, $CellContext`i$168862], $CellContext`sym$168861[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$168861[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$168861, $CellContext`size]], \
$CellContext`sym$168861[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$168861[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$168861[All], 
      All, $CellContext`i$170410], $CellContext`sym$168861[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$168861[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$168861, $CellContext`speed]], \
$CellContext`sym$168861[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$168861[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$168861[All], All, $CellContext`i$170411], 
    Attributes[$CellContext`i$170417] = {Temporary}, $CellContext`i$170417 = 
    9, Attributes[$CellContext`i$170425] = {Temporary}, $CellContext`i$170425 = 
    17, Attributes[$CellContext`i$170420] = {
     Temporary}, $CellContext`i$170420 = 12, 
    Attributes[$CellContext`i$168862] = {Temporary}, $CellContext`i$168862 = 
    1, Attributes[$CellContext`i$170411] = {Temporary}, $CellContext`i$170411 = 
    3, Attributes[$CellContext`i$170418] = {Temporary}, $CellContext`i$170418 = 
    10, Attributes[$CellContext`i$170422] = {
     Temporary}, $CellContext`i$170422 = 14, 
    Attributes[$CellContext`i$170415] = {Temporary}, $CellContext`i$170415 = 
    7, Attributes[$CellContext`i$170413] = {Temporary}, $CellContext`i$170413 = 
    5, Attributes[$CellContext`i$170414] = {Temporary}, $CellContext`i$170414 = 
    6, Attributes[$CellContext`i$170423] = {Temporary}, $CellContext`i$170423 = 
    15, Attributes[$CellContext`i$170416] = {
     Temporary}, $CellContext`i$170416 = 8, 
    Attributes[$CellContext`i$170424] = {Temporary}, $CellContext`i$170424 = 
    16, Attributes[$CellContext`i$170419] = {
     Temporary}, $CellContext`i$170419 = 11, 
    Attributes[$CellContext`i$170421] = {Temporary}, $CellContext`i$170421 = 
    13, Attributes[$CellContext`i$170410] = {
     Temporary}, $CellContext`i$170410 = 2, 
    Attributes[$CellContext`i$170426] = {Temporary}, $CellContext`i$170426 = 
    18, Attributes[$CellContext`i$170412] = {
     Temporary}, $CellContext`i$170412 = 4, 
    Attributes[$CellContext`sym$227254] = {
     Temporary}, $CellContext`sym$227254[$CellContext`a1] = Part[
      $CellContext`sym$227254[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227254[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$227254[$CellContext`a2] = Part[
      $CellContext`sym$227254[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227254[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$227254[$CellContext`a3] = Part[
      $CellContext`sym$227254[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227254[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$227254[$CellContext`a4] = Part[
      $CellContext`sym$227254[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227254[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$227254[$CellContext`a5] = Part[
      $CellContext`sym$227254[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227254[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$227254[$CellContext`a6] = Part[
      $CellContext`sym$227254[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227254[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$227254[$CellContext`a7] = Part[
      $CellContext`sym$227254[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227254[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$227254[All] = $CellContext`med[
     All], $CellContext`sym$227254[$CellContext`Chla] = Part[
      $CellContext`sym$227254[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227254[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$227254[$CellContext`Cl] = Part[
      $CellContext`sym$227254[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227254[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$227254[$CellContext`mnO2] = Part[
      $CellContext`sym$227254[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227254[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$227254[$CellContext`mxPH] = Part[
      $CellContext`sym$227254[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227254[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$227254[$CellContext`NH4] = Part[
      $CellContext`sym$227254[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227254[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$227254[$CellContext`NO3] = Part[
      $CellContext`sym$227254[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227254[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$227254[$CellContext`oPO4] = Part[
      $CellContext`sym$227254[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227254[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$227254[$CellContext`PO4] = Part[
      $CellContext`sym$227254[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227254[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$227254[$CellContext`season] = Part[
      $CellContext`sym$227254[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227254[$CellContext`season, 
         "missing"]]]], $CellContext`sym$227254[$CellContext`size] = Part[
      $CellContext`sym$227254[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227254[$CellContext`size, 
         "missing"]]]], $CellContext`sym$227254[$CellContext`speed] = Part[
      $CellContext`sym$227254[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227254[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$227254[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$227254[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227254, $CellContext`a1]], \
$CellContext`sym$227254[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$227254[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$227254[All], 
      All, $CellContext`i$227266], $CellContext`sym$227254[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$227254[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227254, $CellContext`a2]], \
$CellContext`sym$227254[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$227254[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$227254[All], 
      All, $CellContext`i$227267], $CellContext`sym$227254[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$227254[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227254, $CellContext`a3]], \
$CellContext`sym$227254[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$227254[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$227254[All], 
      All, $CellContext`i$227268], $CellContext`sym$227254[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$227254[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227254, $CellContext`a4]], \
$CellContext`sym$227254[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$227254[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$227254[All], 
      All, $CellContext`i$227269], $CellContext`sym$227254[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$227254[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227254, $CellContext`a5]], \
$CellContext`sym$227254[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$227254[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$227254[All], 
      All, $CellContext`i$227270], $CellContext`sym$227254[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$227254[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227254, $CellContext`a6]], \
$CellContext`sym$227254[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$227254[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$227254[All], 
      All, $CellContext`i$227271], $CellContext`sym$227254[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$227254[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227254, $CellContext`a7]], \
$CellContext`sym$227254[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$227254[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$227254[All], 
      All, $CellContext`i$227272], $CellContext`sym$227254[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$227254[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$227254[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$227254[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227254, $CellContext`Chla]], \
$CellContext`sym$227254[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$227254[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$227254[All], 
      All, $CellContext`i$227265], $CellContext`sym$227254[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$227254[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227254, $CellContext`Cl]], \
$CellContext`sym$227254[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$227254[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$227254[All], 
      All, $CellContext`i$227260], $CellContext`sym$227254[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$227254[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227254, $CellContext`mnO2]], \
$CellContext`sym$227254[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$227254[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$227254[All], 
      All, $CellContext`i$227259], $CellContext`sym$227254[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$227254[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227254, $CellContext`mxPH]], \
$CellContext`sym$227254[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$227254[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$227254[All], 
      All, $CellContext`i$227258], $CellContext`sym$227254[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$227254[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227254, $CellContext`NH4]], \
$CellContext`sym$227254[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$227254[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$227254[All], 
      All, $CellContext`i$227262], $CellContext`sym$227254[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$227254[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227254, $CellContext`NO3]], \
$CellContext`sym$227254[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$227254[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$227254[All], 
      All, $CellContext`i$227261], $CellContext`sym$227254[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$227254[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227254, $CellContext`oPO4]], \
$CellContext`sym$227254[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$227254[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$227254[All], 
      All, $CellContext`i$227263], $CellContext`sym$227254[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$227254[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227254, $CellContext`PO4]], \
$CellContext`sym$227254[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$227254[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$227254[All], 
      All, $CellContext`i$227264], \
$CellContext`sym$227254[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$227254[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227254, $CellContext`season]], \
$CellContext`sym$227254[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$227254[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$227254[All], 
      All, $CellContext`i$227255], $CellContext`sym$227254[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$227254[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227254, $CellContext`size]], \
$CellContext`sym$227254[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$227254[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$227254[All], 
      All, $CellContext`i$227256], $CellContext`sym$227254[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$227254[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227254, $CellContext`speed]], \
$CellContext`sym$227254[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$227254[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$227254[All], All, $CellContext`i$227257], 
    Attributes[$CellContext`i$227266] = {Temporary}, $CellContext`i$227266 = 
    12, Attributes[$CellContext`i$227258] = {
     Temporary}, $CellContext`i$227258 = 4, 
    Attributes[$CellContext`i$227257] = {Temporary}, $CellContext`i$227257 = 
    3, Attributes[$CellContext`i$227255] = {Temporary}, $CellContext`i$227255 = 
    1, Attributes[$CellContext`i$227259] = {Temporary}, $CellContext`i$227259 = 
    5, Attributes[$CellContext`i$227264] = {Temporary}, $CellContext`i$227264 = 
    10, Attributes[$CellContext`i$227272] = {
     Temporary}, $CellContext`i$227272 = 18, 
    Attributes[$CellContext`i$227270] = {Temporary}, $CellContext`i$227270 = 
    16, Attributes[$CellContext`i$227262] = {
     Temporary}, $CellContext`i$227262 = 8, 
    Attributes[$CellContext`i$227261] = {Temporary}, $CellContext`i$227261 = 
    7, Attributes[$CellContext`i$227256] = {Temporary}, $CellContext`i$227256 = 
    2, Attributes[$CellContext`i$227260] = {Temporary}, $CellContext`i$227260 = 
    6, Attributes[$CellContext`i$227263] = {Temporary}, $CellContext`i$227263 = 
    9, Attributes[$CellContext`i$227268] = {Temporary}, $CellContext`i$227268 = 
    14, Attributes[$CellContext`i$227265] = {
     Temporary}, $CellContext`i$227265 = 11, 
    Attributes[$CellContext`i$227271] = {Temporary}, $CellContext`i$227271 = 
    17, Attributes[$CellContext`i$227267] = {
     Temporary}, $CellContext`i$227267 = 13, 
    Attributes[$CellContext`i$227269] = {Temporary}, $CellContext`i$227269 = 
    15, Attributes[$CellContext`sym$110803] = {
     Temporary}, $CellContext`sym$110803[$CellContext`a1] = Part[
      $CellContext`sym$110803[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$110803[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$110803[$CellContext`a2] = Part[
      $CellContext`sym$110803[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$110803[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$110803[$CellContext`a3] = Part[
      $CellContext`sym$110803[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$110803[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$110803[$CellContext`a4] = Part[
      $CellContext`sym$110803[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$110803[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$110803[$CellContext`a5] = Part[
      $CellContext`sym$110803[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$110803[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$110803[$CellContext`a6] = Part[
      $CellContext`sym$110803[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$110803[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$110803[$CellContext`a7] = Part[
      $CellContext`sym$110803[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$110803[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$110803[All] = $CellContext`med[
     All], $CellContext`sym$110803[$CellContext`Chla] = Part[
      $CellContext`sym$110803[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$110803[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$110803[$CellContext`Cl] = Part[
      $CellContext`sym$110803[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$110803[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$110803[$CellContext`mnO2] = Part[
      $CellContext`sym$110803[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$110803[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$110803[$CellContext`mxPH] = Part[
      $CellContext`sym$110803[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$110803[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$110803[$CellContext`NH4] = Part[
      $CellContext`sym$110803[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$110803[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$110803[$CellContext`NO3] = Part[
      $CellContext`sym$110803[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$110803[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$110803[$CellContext`oPO4] = Part[
      $CellContext`sym$110803[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$110803[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$110803[$CellContext`PO4] = Part[
      $CellContext`sym$110803[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$110803[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$110803[$CellContext`season] = Part[
      $CellContext`sym$110803[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$110803[$CellContext`season, 
         "missing"]]]], $CellContext`sym$110803[$CellContext`size] = Part[
      $CellContext`sym$110803[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$110803[$CellContext`size, 
         "missing"]]]], $CellContext`sym$110803[$CellContext`speed] = Part[
      $CellContext`sym$110803[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$110803[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$110803[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$110803[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$110803, $CellContext`a1]], \
$CellContext`sym$110803[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$110803[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$110803[All], 
      All, $CellContext`i$112362], $CellContext`sym$110803[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$110803[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$110803, $CellContext`a2]], \
$CellContext`sym$110803[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$110803[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$110803[All], 
      All, $CellContext`i$112363], $CellContext`sym$110803[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$110803[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$110803, $CellContext`a3]], \
$CellContext`sym$110803[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$110803[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$110803[All], 
      All, $CellContext`i$112364], $CellContext`sym$110803[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$110803[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$110803, $CellContext`a4]], \
$CellContext`sym$110803[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$110803[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$110803[All], 
      All, $CellContext`i$112365], $CellContext`sym$110803[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$110803[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$110803, $CellContext`a5]], \
$CellContext`sym$110803[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$110803[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$110803[All], 
      All, $CellContext`i$112366], $CellContext`sym$110803[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$110803[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$110803, $CellContext`a6]], \
$CellContext`sym$110803[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$110803[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$110803[All], 
      All, $CellContext`i$112367], $CellContext`sym$110803[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$110803[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$110803, $CellContext`a7]], \
$CellContext`sym$110803[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$110803[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$110803[All], 
      All, $CellContext`i$112368], $CellContext`sym$110803[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$110803[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$110803[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$110803[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$110803, $CellContext`Chla]], \
$CellContext`sym$110803[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$110803[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$110803[All], 
      All, $CellContext`i$112361], $CellContext`sym$110803[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$110803[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$110803, $CellContext`Cl]], \
$CellContext`sym$110803[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$110803[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$110803[All], 
      All, $CellContext`i$112356], $CellContext`sym$110803[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$110803[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$110803, $CellContext`mnO2]], \
$CellContext`sym$110803[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$110803[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$110803[All], 
      All, $CellContext`i$112355], $CellContext`sym$110803[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$110803[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$110803, $CellContext`mxPH]], \
$CellContext`sym$110803[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$110803[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$110803[All], 
      All, $CellContext`i$112354], $CellContext`sym$110803[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$110803[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$110803, $CellContext`NH4]], \
$CellContext`sym$110803[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$110803[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$110803[All], 
      All, $CellContext`i$112358], $CellContext`sym$110803[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$110803[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$110803, $CellContext`NO3]], \
$CellContext`sym$110803[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$110803[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$110803[All], 
      All, $CellContext`i$112357], $CellContext`sym$110803[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$110803[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$110803, $CellContext`oPO4]], \
$CellContext`sym$110803[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$110803[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$110803[All], 
      All, $CellContext`i$112359], $CellContext`sym$110803[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$110803[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$110803, $CellContext`PO4]], \
$CellContext`sym$110803[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$110803[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$110803[All], 
      All, $CellContext`i$112360], \
$CellContext`sym$110803[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$110803[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$110803, $CellContext`season]], \
$CellContext`sym$110803[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$110803[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$110803[All], 
      All, $CellContext`i$110804], $CellContext`sym$110803[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$110803[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$110803, $CellContext`size]], \
$CellContext`sym$110803[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$110803[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$110803[All], 
      All, $CellContext`i$112352], $CellContext`sym$110803[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$110803[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$110803, $CellContext`speed]], \
$CellContext`sym$110803[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$110803[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$110803[All], All, $CellContext`i$112353], 
    Attributes[$CellContext`i$112352] = {Temporary}, $CellContext`i$112352 = 
    2, Attributes[$CellContext`i$112367] = {Temporary}, $CellContext`i$112367 = 
    17, Attributes[$CellContext`i$112366] = {
     Temporary}, $CellContext`i$112366 = 16, 
    Attributes[$CellContext`i$112354] = {Temporary}, $CellContext`i$112354 = 
    4, Attributes[$CellContext`i$112365] = {Temporary}, $CellContext`i$112365 = 
    15, Attributes[$CellContext`i$112361] = {
     Temporary}, $CellContext`i$112361 = 11, 
    Attributes[$CellContext`i$112357] = {Temporary}, $CellContext`i$112357 = 
    7, Attributes[$CellContext`i$112356] = {Temporary}, $CellContext`i$112356 = 
    6, Attributes[$CellContext`i$112362] = {Temporary}, $CellContext`i$112362 = 
    12, Attributes[$CellContext`i$112355] = {
     Temporary}, $CellContext`i$112355 = 5, 
    Attributes[$CellContext`i$112368] = {Temporary}, $CellContext`i$112368 = 
    18, Attributes[$CellContext`i$112358] = {
     Temporary}, $CellContext`i$112358 = 8, 
    Attributes[$CellContext`i$112364] = {Temporary}, $CellContext`i$112364 = 
    14, Attributes[$CellContext`i$110804] = {
     Temporary}, $CellContext`i$110804 = 1, 
    Attributes[$CellContext`i$112353] = {Temporary}, $CellContext`i$112353 = 
    3, Attributes[$CellContext`i$112360] = {Temporary}, $CellContext`i$112360 = 
    10, Attributes[$CellContext`i$112363] = {
     Temporary}, $CellContext`i$112363 = 13, 
    Attributes[$CellContext`i$112359] = {Temporary}, $CellContext`i$112359 = 
    9, Attributes[$CellContext`sym$215754] = {
     Temporary}, $CellContext`sym$215754[$CellContext`a1] = Part[
      $CellContext`sym$215754[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$215754[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$215754[$CellContext`a2] = Part[
      $CellContext`sym$215754[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$215754[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$215754[$CellContext`a3] = Part[
      $CellContext`sym$215754[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$215754[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$215754[$CellContext`a4] = Part[
      $CellContext`sym$215754[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$215754[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$215754[$CellContext`a5] = Part[
      $CellContext`sym$215754[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$215754[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$215754[$CellContext`a6] = Part[
      $CellContext`sym$215754[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$215754[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$215754[$CellContext`a7] = Part[
      $CellContext`sym$215754[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$215754[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$215754[All] = $CellContext`med[
     All], $CellContext`sym$215754[$CellContext`Chla] = Part[
      $CellContext`sym$215754[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$215754[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$215754[$CellContext`Cl] = Part[
      $CellContext`sym$215754[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$215754[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$215754[$CellContext`mnO2] = Part[
      $CellContext`sym$215754[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$215754[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$215754[$CellContext`mxPH] = Part[
      $CellContext`sym$215754[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$215754[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$215754[$CellContext`NH4] = Part[
      $CellContext`sym$215754[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$215754[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$215754[$CellContext`NO3] = Part[
      $CellContext`sym$215754[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$215754[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$215754[$CellContext`oPO4] = Part[
      $CellContext`sym$215754[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$215754[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$215754[$CellContext`PO4] = Part[
      $CellContext`sym$215754[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$215754[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$215754[$CellContext`season] = Part[
      $CellContext`sym$215754[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$215754[$CellContext`season, 
         "missing"]]]], $CellContext`sym$215754[$CellContext`size] = Part[
      $CellContext`sym$215754[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$215754[$CellContext`size, 
         "missing"]]]], $CellContext`sym$215754[$CellContext`speed] = Part[
      $CellContext`sym$215754[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$215754[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$215754[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$215754[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$215754, $CellContext`a1]], \
$CellContext`sym$215754[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$215754[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$215754[All], 
      All, $CellContext`i$217313], $CellContext`sym$215754[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$215754[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$215754, $CellContext`a2]], \
$CellContext`sym$215754[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$215754[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$215754[All], 
      All, $CellContext`i$217314], $CellContext`sym$215754[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$215754[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$215754, $CellContext`a3]], \
$CellContext`sym$215754[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$215754[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$215754[All], 
      All, $CellContext`i$217315], $CellContext`sym$215754[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$215754[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$215754, $CellContext`a4]], \
$CellContext`sym$215754[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$215754[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$215754[All], 
      All, $CellContext`i$217316], $CellContext`sym$215754[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$215754[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$215754, $CellContext`a5]], \
$CellContext`sym$215754[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$215754[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$215754[All], 
      All, $CellContext`i$217317], $CellContext`sym$215754[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$215754[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$215754, $CellContext`a6]], \
$CellContext`sym$215754[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$215754[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$215754[All], 
      All, $CellContext`i$217318], $CellContext`sym$215754[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$215754[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$215754, $CellContext`a7]], \
$CellContext`sym$215754[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$215754[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$215754[All], 
      All, $CellContext`i$217319], $CellContext`sym$215754[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$215754[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$215754[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$215754[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$215754, $CellContext`Chla]], \
$CellContext`sym$215754[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$215754[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$215754[All], 
      All, $CellContext`i$217312], $CellContext`sym$215754[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$215754[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$215754, $CellContext`Cl]], \
$CellContext`sym$215754[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$215754[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$215754[All], 
      All, $CellContext`i$217307], $CellContext`sym$215754[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$215754[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$215754, $CellContext`mnO2]], \
$CellContext`sym$215754[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$215754[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$215754[All], 
      All, $CellContext`i$217306], $CellContext`sym$215754[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$215754[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$215754, $CellContext`mxPH]], \
$CellContext`sym$215754[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$215754[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$215754[All], 
      All, $CellContext`i$217305], $CellContext`sym$215754[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$215754[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$215754, $CellContext`NH4]], \
$CellContext`sym$215754[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$215754[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$215754[All], 
      All, $CellContext`i$217309], $CellContext`sym$215754[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$215754[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$215754, $CellContext`NO3]], \
$CellContext`sym$215754[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$215754[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$215754[All], 
      All, $CellContext`i$217308], $CellContext`sym$215754[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$215754[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$215754, $CellContext`oPO4]], \
$CellContext`sym$215754[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$215754[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$215754[All], 
      All, $CellContext`i$217310], $CellContext`sym$215754[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$215754[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$215754, $CellContext`PO4]], \
$CellContext`sym$215754[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$215754[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$215754[All], 
      All, $CellContext`i$217311], \
$CellContext`sym$215754[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$215754[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$215754, $CellContext`season]], \
$CellContext`sym$215754[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$215754[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$215754[All], 
      All, $CellContext`i$215755], $CellContext`sym$215754[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$215754[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$215754, $CellContext`size]], \
$CellContext`sym$215754[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$215754[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$215754[All], 
      All, $CellContext`i$217303], $CellContext`sym$215754[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$215754[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$215754, $CellContext`speed]], \
$CellContext`sym$215754[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$215754[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$215754[All], All, $CellContext`i$217304], 
    Attributes[$CellContext`i$217313] = {Temporary}, $CellContext`i$217313 = 
    12, Attributes[$CellContext`i$217311] = {
     Temporary}, $CellContext`i$217311 = 10, 
    Attributes[$CellContext`i$217316] = {Temporary}, $CellContext`i$217316 = 
    15, Attributes[$CellContext`i$217312] = {
     Temporary}, $CellContext`i$217312 = 11, 
    Attributes[$CellContext`i$217307] = {Temporary}, $CellContext`i$217307 = 
    6, Attributes[$CellContext`i$217314] = {Temporary}, $CellContext`i$217314 = 
    13, Attributes[$CellContext`i$217305] = {
     Temporary}, $CellContext`i$217305 = 4, 
    Attributes[$CellContext`i$217317] = {Temporary}, $CellContext`i$217317 = 
    16, Attributes[$CellContext`i$217303] = {
     Temporary}, $CellContext`i$217303 = 2, 
    Attributes[$CellContext`i$215755] = {Temporary}, $CellContext`i$215755 = 
    1, Attributes[$CellContext`i$217310] = {Temporary}, $CellContext`i$217310 = 
    9, Attributes[$CellContext`i$217308] = {Temporary}, $CellContext`i$217308 = 
    7, Attributes[$CellContext`i$217318] = {Temporary}, $CellContext`i$217318 = 
    17, Attributes[$CellContext`i$217309] = {
     Temporary}, $CellContext`i$217309 = 8, 
    Attributes[$CellContext`i$217306] = {Temporary}, $CellContext`i$217306 = 
    5, Attributes[$CellContext`i$217315] = {Temporary}, $CellContext`i$217315 = 
    14, Attributes[$CellContext`i$217304] = {
     Temporary}, $CellContext`i$217304 = 3, 
    Attributes[$CellContext`i$217319] = {Temporary}, $CellContext`i$217319 = 
    18, Attributes[$CellContext`sym$25870] = {
     Temporary}, $CellContext`sym$25870[$CellContext`a1] = $CellContext`med[
     All], $CellContext`sym$25870[$CellContext`a2] = $CellContext`med[
     All], $CellContext`sym$25870[$CellContext`a3] = $CellContext`med[
     All], $CellContext`sym$25870[$CellContext`a4] = $CellContext`med[
     All], $CellContext`sym$25870[$CellContext`a5] = $CellContext`med[
     All], $CellContext`sym$25870[$CellContext`a6] = $CellContext`med[
     All], $CellContext`sym$25870[$CellContext`a7] = $CellContext`med[
     All], $CellContext`sym$25870[All] = $CellContext`med[
     All], $CellContext`sym$25870[$CellContext`Chla] = $CellContext`med[
     All], $CellContext`sym$25870[$CellContext`Cl] = $CellContext`med[
     All], $CellContext`sym$25870[$CellContext`mnO2] = $CellContext`med[
     All], $CellContext`sym$25870[$CellContext`mxPH] = $CellContext`med[
     All], $CellContext`sym$25870[$CellContext`NH4] = $CellContext`med[
     All], $CellContext`sym$25870[$CellContext`NO3] = $CellContext`med[
     All], $CellContext`sym$25870[$CellContext`oPO4] = $CellContext`med[
     All], $CellContext`sym$25870[$CellContext`PO4] = $CellContext`med[
     All], $CellContext`sym$25870[$CellContext`season] = $CellContext`med[
     All], $CellContext`sym$25870[$CellContext`size] = $CellContext`med[
     All], $CellContext`sym$25870[$CellContext`speed] = $CellContext`med[
     All], $CellContext`sym$25870[$CellContext`a1, "factorized"] = 
    True, $CellContext`sym$25870[$CellContext`a1, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$25870[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$25870[$CellContext`a1, "raw"] = Part[
      $CellContext`med[All], All, 12], $CellContext`sym$25870[$CellContext`a2,
       "factorized"] = 
    True, $CellContext`sym$25870[$CellContext`a2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$25870[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$25870[$CellContext`a2, "raw"] = Part[
      $CellContext`med[All], All, 13], $CellContext`sym$25870[$CellContext`a3,
       "factorized"] = 
    True, $CellContext`sym$25870[$CellContext`a3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$25870[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$25870[$CellContext`a3, "raw"] = Part[
      $CellContext`med[All], All, 14], $CellContext`sym$25870[$CellContext`a4,
       "factorized"] = 
    True, $CellContext`sym$25870[$CellContext`a4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$25870[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$25870[$CellContext`a4, "raw"] = Part[
      $CellContext`med[All], All, 15], $CellContext`sym$25870[$CellContext`a5,
       "factorized"] = 
    True, $CellContext`sym$25870[$CellContext`a5, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$25870[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$25870[$CellContext`a5, "raw"] = Part[
      $CellContext`med[All], All, 16], $CellContext`sym$25870[$CellContext`a6,
       "factorized"] = 
    True, $CellContext`sym$25870[$CellContext`a6, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$25870[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$25870[$CellContext`a6, "raw"] = Part[
      $CellContext`med[All], All, 17], $CellContext`sym$25870[$CellContext`a7,
       "factorized"] = 
    True, $CellContext`sym$25870[$CellContext`a7, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$25870[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$25870[$CellContext`a7, "raw"] = Part[
      $CellContext`med[All], All, 18], $CellContext`sym$25870[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$25870[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$25870[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$25870[$CellContext`Chla, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$25870[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$25870[$CellContext`Chla, "raw"] = Part[
      $CellContext`med[All], All, 11], $CellContext`sym$25870[$CellContext`Cl,
       "factorized"] = 
    True, $CellContext`sym$25870[$CellContext`Cl, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$25870[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$25870[$CellContext`Cl, "raw"] = Part[
      $CellContext`med[All], All, 
      6], $CellContext`sym$25870[$CellContext`mnO2, "factorized"] = 
    True, $CellContext`sym$25870[$CellContext`mnO2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$25870[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$25870[$CellContext`mnO2, "raw"] = Part[
      $CellContext`med[All], All, 
      5], $CellContext`sym$25870[$CellContext`mxPH, "factorized"] = 
    True, $CellContext`sym$25870[$CellContext`mxPH, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$25870[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$25870[$CellContext`mxPH, "raw"] = Part[
      $CellContext`med[All], All, 4], $CellContext`sym$25870[$CellContext`NH4,
       "factorized"] = 
    True, $CellContext`sym$25870[$CellContext`NH4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$25870[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$25870[$CellContext`NH4, "raw"] = Part[
      $CellContext`med[All], All, 8], $CellContext`sym$25870[$CellContext`NO3,
       "factorized"] = 
    True, $CellContext`sym$25870[$CellContext`NO3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$25870[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$25870[$CellContext`NO3, "raw"] = Part[
      $CellContext`med[All], All, 
      7], $CellContext`sym$25870[$CellContext`oPO4, "factorized"] = 
    True, $CellContext`sym$25870[$CellContext`oPO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$25870[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$25870[$CellContext`oPO4, "raw"] = Part[
      $CellContext`med[All], All, 9], $CellContext`sym$25870[$CellContext`PO4,
       "factorized"] = 
    True, $CellContext`sym$25870[$CellContext`PO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$25870[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$25870[$CellContext`PO4, "raw"] = Part[
      $CellContext`med[All], All, 
      10], $CellContext`sym$25870[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$25870[$CellContext`season, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$25870[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$25870[$CellContext`season, "raw"] = 
    Part[
      $CellContext`med[All], All, 
      1], $CellContext`sym$25870[$CellContext`size, "factorized"] = 
    True, $CellContext`sym$25870[$CellContext`size, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$25870[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$25870[$CellContext`size, "raw"] = Part[
      $CellContext`med[All], All, 
      2], $CellContext`sym$25870[$CellContext`speed, "factorized"] = 
    True, $CellContext`sym$25870[$CellContext`speed, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$25870[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$25870[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`med[All], All, 3], 
    Attributes[$CellContext`sym$227589] = {
     Temporary}, $CellContext`sym$227589[$CellContext`a1] = Part[
      $CellContext`sym$227589[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227589[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$227589[$CellContext`a2] = Part[
      $CellContext`sym$227589[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227589[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$227589[$CellContext`a3] = Part[
      $CellContext`sym$227589[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227589[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$227589[$CellContext`a4] = Part[
      $CellContext`sym$227589[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227589[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$227589[$CellContext`a5] = Part[
      $CellContext`sym$227589[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227589[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$227589[$CellContext`a6] = Part[
      $CellContext`sym$227589[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227589[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$227589[$CellContext`a7] = Part[
      $CellContext`sym$227589[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227589[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$227589[All] = $CellContext`med[
     All], $CellContext`sym$227589[$CellContext`Chla] = Part[
      $CellContext`sym$227589[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227589[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$227589[$CellContext`Cl] = Part[
      $CellContext`sym$227589[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227589[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$227589[$CellContext`mnO2] = Part[
      $CellContext`sym$227589[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227589[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$227589[$CellContext`mxPH] = Part[
      $CellContext`sym$227589[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227589[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$227589[$CellContext`NH4] = Part[
      $CellContext`sym$227589[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227589[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$227589[$CellContext`NO3] = Part[
      $CellContext`sym$227589[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227589[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$227589[$CellContext`oPO4] = Part[
      $CellContext`sym$227589[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227589[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$227589[$CellContext`PO4] = Part[
      $CellContext`sym$227589[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227589[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$227589[$CellContext`season] = Part[
      $CellContext`sym$227589[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227589[$CellContext`season, 
         "missing"]]]], $CellContext`sym$227589[$CellContext`size] = Part[
      $CellContext`sym$227589[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227589[$CellContext`size, 
         "missing"]]]], $CellContext`sym$227589[$CellContext`speed] = Part[
      $CellContext`sym$227589[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227589[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$227589[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$227589[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227589, $CellContext`a1]], \
$CellContext`sym$227589[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$227589[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$227589[All], 
      All, $CellContext`i$227601], $CellContext`sym$227589[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$227589[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227589, $CellContext`a2]], \
$CellContext`sym$227589[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$227589[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$227589[All], 
      All, $CellContext`i$227602], $CellContext`sym$227589[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$227589[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227589, $CellContext`a3]], \
$CellContext`sym$227589[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$227589[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$227589[All], 
      All, $CellContext`i$227603], $CellContext`sym$227589[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$227589[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227589, $CellContext`a4]], \
$CellContext`sym$227589[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$227589[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$227589[All], 
      All, $CellContext`i$227604], $CellContext`sym$227589[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$227589[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227589, $CellContext`a5]], \
$CellContext`sym$227589[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$227589[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$227589[All], 
      All, $CellContext`i$227605], $CellContext`sym$227589[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$227589[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227589, $CellContext`a6]], \
$CellContext`sym$227589[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$227589[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$227589[All], 
      All, $CellContext`i$227606], $CellContext`sym$227589[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$227589[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227589, $CellContext`a7]], \
$CellContext`sym$227589[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$227589[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$227589[All], 
      All, $CellContext`i$227607], $CellContext`sym$227589[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$227589[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$227589[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$227589[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227589, $CellContext`Chla]], \
$CellContext`sym$227589[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$227589[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$227589[All], 
      All, $CellContext`i$227600], $CellContext`sym$227589[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$227589[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227589, $CellContext`Cl]], \
$CellContext`sym$227589[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$227589[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$227589[All], 
      All, $CellContext`i$227595], $CellContext`sym$227589[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$227589[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227589, $CellContext`mnO2]], \
$CellContext`sym$227589[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$227589[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$227589[All], 
      All, $CellContext`i$227594], $CellContext`sym$227589[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$227589[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227589, $CellContext`mxPH]], \
$CellContext`sym$227589[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$227589[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$227589[All], 
      All, $CellContext`i$227593], $CellContext`sym$227589[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$227589[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227589, $CellContext`NH4]], \
$CellContext`sym$227589[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$227589[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$227589[All], 
      All, $CellContext`i$227597], $CellContext`sym$227589[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$227589[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227589, $CellContext`NO3]], \
$CellContext`sym$227589[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$227589[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$227589[All], 
      All, $CellContext`i$227596], $CellContext`sym$227589[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$227589[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227589, $CellContext`oPO4]], \
$CellContext`sym$227589[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$227589[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$227589[All], 
      All, $CellContext`i$227598], $CellContext`sym$227589[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$227589[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227589, $CellContext`PO4]], \
$CellContext`sym$227589[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$227589[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$227589[All], 
      All, $CellContext`i$227599], \
$CellContext`sym$227589[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$227589[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227589, $CellContext`season]], \
$CellContext`sym$227589[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$227589[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$227589[All], 
      All, $CellContext`i$227590], $CellContext`sym$227589[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$227589[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227589, $CellContext`size]], \
$CellContext`sym$227589[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$227589[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$227589[All], 
      All, $CellContext`i$227591], $CellContext`sym$227589[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$227589[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227589, $CellContext`speed]], \
$CellContext`sym$227589[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$227589[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$227589[All], All, $CellContext`i$227592], 
    Attributes[$CellContext`i$227606] = {Temporary}, $CellContext`i$227606 = 
    17, Attributes[$CellContext`i$227600] = {
     Temporary}, $CellContext`i$227600 = 11, 
    Attributes[$CellContext`i$227599] = {Temporary}, $CellContext`i$227599 = 
    10, Attributes[$CellContext`i$227595] = {
     Temporary}, $CellContext`i$227595 = 6, 
    Attributes[$CellContext`i$227596] = {Temporary}, $CellContext`i$227596 = 
    7, Attributes[$CellContext`i$227598] = {Temporary}, $CellContext`i$227598 = 
    9, Attributes[$CellContext`i$227590] = {Temporary}, $CellContext`i$227590 = 
    1, Attributes[$CellContext`i$227591] = {Temporary}, $CellContext`i$227591 = 
    2, Attributes[$CellContext`i$227592] = {Temporary}, $CellContext`i$227592 = 
    3, Attributes[$CellContext`i$227604] = {Temporary}, $CellContext`i$227604 = 
    15, Attributes[$CellContext`i$227605] = {
     Temporary}, $CellContext`i$227605 = 16, 
    Attributes[$CellContext`i$227607] = {Temporary}, $CellContext`i$227607 = 
    18, Attributes[$CellContext`i$227602] = {
     Temporary}, $CellContext`i$227602 = 13, 
    Attributes[$CellContext`i$227597] = {Temporary}, $CellContext`i$227597 = 
    8, Attributes[$CellContext`i$227603] = {Temporary}, $CellContext`i$227603 = 
    14, Attributes[$CellContext`i$227593] = {
     Temporary}, $CellContext`i$227593 = 4, 
    Attributes[$CellContext`i$227594] = {Temporary}, $CellContext`i$227594 = 
    5, Attributes[$CellContext`i$227601] = {Temporary}, $CellContext`i$227601 = 
    12, Attributes[$CellContext`sym$209055] = {
     Temporary}, $CellContext`sym$209055[$CellContext`a1] = Part[
      $CellContext`sym$209055[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$209055[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$209055[$CellContext`a2] = Part[
      $CellContext`sym$209055[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$209055[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$209055[$CellContext`a3] = Part[
      $CellContext`sym$209055[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$209055[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$209055[$CellContext`a4] = Part[
      $CellContext`sym$209055[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$209055[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$209055[$CellContext`a5] = Part[
      $CellContext`sym$209055[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$209055[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$209055[$CellContext`a6] = Part[
      $CellContext`sym$209055[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$209055[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$209055[$CellContext`a7] = Part[
      $CellContext`sym$209055[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$209055[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$209055[All] = $CellContext`med[
     All], $CellContext`sym$209055[$CellContext`Chla] = Part[
      $CellContext`sym$209055[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$209055[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$209055[$CellContext`Cl] = Part[
      $CellContext`sym$209055[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$209055[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$209055[$CellContext`mnO2] = Part[
      $CellContext`sym$209055[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$209055[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$209055[$CellContext`mxPH] = Part[
      $CellContext`sym$209055[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$209055[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$209055[$CellContext`NH4] = Part[
      $CellContext`sym$209055[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$209055[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$209055[$CellContext`NO3] = Part[
      $CellContext`sym$209055[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$209055[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$209055[$CellContext`oPO4] = Part[
      $CellContext`sym$209055[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$209055[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$209055[$CellContext`PO4] = Part[
      $CellContext`sym$209055[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$209055[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$209055[$CellContext`season] = Part[
      $CellContext`sym$209055[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$209055[$CellContext`season, 
         "missing"]]]], $CellContext`sym$209055[$CellContext`size] = Part[
      $CellContext`sym$209055[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$209055[$CellContext`size, 
         "missing"]]]], $CellContext`sym$209055[$CellContext`speed] = Part[
      $CellContext`sym$209055[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$209055[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$209055[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$209055[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$209055, $CellContext`a1]], \
$CellContext`sym$209055[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$209055[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$209055[All], 
      All, $CellContext`i$210614], $CellContext`sym$209055[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$209055[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$209055, $CellContext`a2]], \
$CellContext`sym$209055[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$209055[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$209055[All], 
      All, $CellContext`i$210615], $CellContext`sym$209055[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$209055[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$209055, $CellContext`a3]], \
$CellContext`sym$209055[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$209055[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$209055[All], 
      All, $CellContext`i$210616], $CellContext`sym$209055[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$209055[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$209055, $CellContext`a4]], \
$CellContext`sym$209055[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$209055[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$209055[All], 
      All, $CellContext`i$210617], $CellContext`sym$209055[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$209055[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$209055, $CellContext`a5]], \
$CellContext`sym$209055[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$209055[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$209055[All], 
      All, $CellContext`i$210618], $CellContext`sym$209055[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$209055[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$209055, $CellContext`a6]], \
$CellContext`sym$209055[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$209055[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$209055[All], 
      All, $CellContext`i$210619], $CellContext`sym$209055[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$209055[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$209055, $CellContext`a7]], \
$CellContext`sym$209055[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$209055[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$209055[All], 
      All, $CellContext`i$210620], $CellContext`sym$209055[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$209055[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$209055[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$209055[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$209055, $CellContext`Chla]], \
$CellContext`sym$209055[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$209055[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$209055[All], 
      All, $CellContext`i$210613], $CellContext`sym$209055[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$209055[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$209055, $CellContext`Cl]], \
$CellContext`sym$209055[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$209055[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$209055[All], 
      All, $CellContext`i$210608], $CellContext`sym$209055[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$209055[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$209055, $CellContext`mnO2]], \
$CellContext`sym$209055[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$209055[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$209055[All], 
      All, $CellContext`i$210607], $CellContext`sym$209055[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$209055[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$209055, $CellContext`mxPH]], \
$CellContext`sym$209055[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$209055[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$209055[All], 
      All, $CellContext`i$210606], $CellContext`sym$209055[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$209055[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$209055, $CellContext`NH4]], \
$CellContext`sym$209055[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$209055[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$209055[All], 
      All, $CellContext`i$210610], $CellContext`sym$209055[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$209055[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$209055, $CellContext`NO3]], \
$CellContext`sym$209055[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$209055[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$209055[All], 
      All, $CellContext`i$210609], $CellContext`sym$209055[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$209055[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$209055, $CellContext`oPO4]], \
$CellContext`sym$209055[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$209055[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$209055[All], 
      All, $CellContext`i$210611], $CellContext`sym$209055[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$209055[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$209055, $CellContext`PO4]], \
$CellContext`sym$209055[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$209055[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$209055[All], 
      All, $CellContext`i$210612], \
$CellContext`sym$209055[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$209055[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$209055, $CellContext`season]], \
$CellContext`sym$209055[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$209055[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$209055[All], 
      All, $CellContext`i$209056], $CellContext`sym$209055[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$209055[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$209055, $CellContext`size]], \
$CellContext`sym$209055[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$209055[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$209055[All], 
      All, $CellContext`i$210604], $CellContext`sym$209055[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$209055[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$209055, $CellContext`speed]], \
$CellContext`sym$209055[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$209055[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$209055[All], All, $CellContext`i$210605], 
    Attributes[$CellContext`i$210608] = {Temporary}, $CellContext`i$210608 = 
    6, Attributes[$CellContext`i$210605] = {Temporary}, $CellContext`i$210605 = 
    3, Attributes[$CellContext`i$210613] = {Temporary}, $CellContext`i$210613 = 
    11, Attributes[$CellContext`i$210612] = {
     Temporary}, $CellContext`i$210612 = 10, 
    Attributes[$CellContext`i$210606] = {Temporary}, $CellContext`i$210606 = 
    4, Attributes[$CellContext`i$210619] = {Temporary}, $CellContext`i$210619 = 
    17, Attributes[$CellContext`i$210615] = {
     Temporary}, $CellContext`i$210615 = 13, 
    Attributes[$CellContext`i$210609] = {Temporary}, $CellContext`i$210609 = 
    7, Attributes[$CellContext`i$209056] = {Temporary}, $CellContext`i$209056 = 
    1, Attributes[$CellContext`i$210604] = {Temporary}, $CellContext`i$210604 = 
    2, Attributes[$CellContext`i$210620] = {Temporary}, $CellContext`i$210620 = 
    18, Attributes[$CellContext`i$210610] = {
     Temporary}, $CellContext`i$210610 = 8, 
    Attributes[$CellContext`i$210614] = {Temporary}, $CellContext`i$210614 = 
    12, Attributes[$CellContext`i$210618] = {
     Temporary}, $CellContext`i$210618 = 16, 
    Attributes[$CellContext`i$210617] = {Temporary}, $CellContext`i$210617 = 
    15, Attributes[$CellContext`i$210616] = {
     Temporary}, $CellContext`i$210616 = 14, 
    Attributes[$CellContext`i$210607] = {Temporary}, $CellContext`i$210607 = 
    5, Attributes[$CellContext`i$210611] = {Temporary}, $CellContext`i$210611 = 
    9, Attributes[$CellContext`sym$16938] = {
     Temporary}, $CellContext`sym$16938[$CellContext`a1] = $CellContext`med[
     All], $CellContext`sym$16938[$CellContext`a2] = $CellContext`med[
     All], $CellContext`sym$16938[$CellContext`a3] = $CellContext`med[
     All], $CellContext`sym$16938[$CellContext`a4] = $CellContext`med[
     All], $CellContext`sym$16938[$CellContext`a5] = $CellContext`med[
     All], $CellContext`sym$16938[$CellContext`a6] = $CellContext`med[
     All], $CellContext`sym$16938[$CellContext`a7] = $CellContext`med[
     All], $CellContext`sym$16938[All] = $CellContext`med[
     All], $CellContext`sym$16938[$CellContext`Chla] = $CellContext`med[
     All], $CellContext`sym$16938[$CellContext`Cl] = $CellContext`med[
     All], $CellContext`sym$16938[$CellContext`mnO2] = $CellContext`med[
     All], $CellContext`sym$16938[$CellContext`mxPH] = $CellContext`med[
     All], $CellContext`sym$16938[$CellContext`NH4] = $CellContext`med[
     All], $CellContext`sym$16938[$CellContext`NO3] = $CellContext`med[
     All], $CellContext`sym$16938[$CellContext`oPO4] = $CellContext`med[
     All], $CellContext`sym$16938[$CellContext`PO4] = $CellContext`med[
     All], $CellContext`sym$16938[$CellContext`season] = $CellContext`med[
     All], $CellContext`sym$16938[$CellContext`size] = $CellContext`med[
     All], $CellContext`sym$16938[$CellContext`speed] = $CellContext`med[
     All], $CellContext`sym$16938[$CellContext`a1, "factorized"] = 
    True, $CellContext`sym$16938[$CellContext`a1, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$16938[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$16938[$CellContext`a1, "raw"] = Part[
      $CellContext`med[All], All, 12], $CellContext`sym$16938[$CellContext`a2,
       "factorized"] = 
    True, $CellContext`sym$16938[$CellContext`a2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$16938[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$16938[$CellContext`a2, "raw"] = Part[
      $CellContext`med[All], All, 13], $CellContext`sym$16938[$CellContext`a3,
       "factorized"] = 
    True, $CellContext`sym$16938[$CellContext`a3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$16938[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$16938[$CellContext`a3, "raw"] = Part[
      $CellContext`med[All], All, 14], $CellContext`sym$16938[$CellContext`a4,
       "factorized"] = 
    True, $CellContext`sym$16938[$CellContext`a4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$16938[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$16938[$CellContext`a4, "raw"] = Part[
      $CellContext`med[All], All, 15], $CellContext`sym$16938[$CellContext`a5,
       "factorized"] = 
    True, $CellContext`sym$16938[$CellContext`a5, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$16938[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$16938[$CellContext`a5, "raw"] = Part[
      $CellContext`med[All], All, 16], $CellContext`sym$16938[$CellContext`a6,
       "factorized"] = 
    True, $CellContext`sym$16938[$CellContext`a6, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$16938[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$16938[$CellContext`a6, "raw"] = Part[
      $CellContext`med[All], All, 17], $CellContext`sym$16938[$CellContext`a7,
       "factorized"] = 
    True, $CellContext`sym$16938[$CellContext`a7, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$16938[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$16938[$CellContext`a7, "raw"] = Part[
      $CellContext`med[All], All, 18], $CellContext`sym$16938[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$16938[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$16938[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$16938[$CellContext`Chla, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$16938[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$16938[$CellContext`Chla, "raw"] = Part[
      $CellContext`med[All], All, 11], $CellContext`sym$16938[$CellContext`Cl,
       "factorized"] = 
    True, $CellContext`sym$16938[$CellContext`Cl, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$16938[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$16938[$CellContext`Cl, "raw"] = Part[
      $CellContext`med[All], All, 
      6], $CellContext`sym$16938[$CellContext`mnO2, "factorized"] = 
    True, $CellContext`sym$16938[$CellContext`mnO2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$16938[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$16938[$CellContext`mnO2, "raw"] = Part[
      $CellContext`med[All], All, 
      5], $CellContext`sym$16938[$CellContext`mxPH, "factorized"] = 
    True, $CellContext`sym$16938[$CellContext`mxPH, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$16938[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$16938[$CellContext`mxPH, "raw"] = Part[
      $CellContext`med[All], All, 4], $CellContext`sym$16938[$CellContext`NH4,
       "factorized"] = 
    True, $CellContext`sym$16938[$CellContext`NH4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$16938[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$16938[$CellContext`NH4, "raw"] = Part[
      $CellContext`med[All], All, 8], $CellContext`sym$16938[$CellContext`NO3,
       "factorized"] = 
    True, $CellContext`sym$16938[$CellContext`NO3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$16938[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$16938[$CellContext`NO3, "raw"] = Part[
      $CellContext`med[All], All, 
      7], $CellContext`sym$16938[$CellContext`oPO4, "factorized"] = 
    True, $CellContext`sym$16938[$CellContext`oPO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$16938[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$16938[$CellContext`oPO4, "raw"] = Part[
      $CellContext`med[All], All, 9], $CellContext`sym$16938[$CellContext`PO4,
       "factorized"] = 
    True, $CellContext`sym$16938[$CellContext`PO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$16938[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$16938[$CellContext`PO4, "raw"] = Part[
      $CellContext`med[All], All, 
      10], $CellContext`sym$16938[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$16938[$CellContext`season, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$16938[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$16938[$CellContext`season, "raw"] = 
    Part[
      $CellContext`med[All], All, 
      1], $CellContext`sym$16938[$CellContext`size, "factorized"] = 
    True, $CellContext`sym$16938[$CellContext`size, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$16938[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$16938[$CellContext`size, "raw"] = Part[
      $CellContext`med[All], All, 
      2], $CellContext`sym$16938[$CellContext`speed, "factorized"] = 
    True, $CellContext`sym$16938[$CellContext`speed, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$16938[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$16938[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`med[All], All, 3], 
    Attributes[$CellContext`sym$146531] = {
     Temporary}, $CellContext`sym$146531[$CellContext`a1] = Part[
      $CellContext`sym$146531[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$146531[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$146531[$CellContext`a2] = Part[
      $CellContext`sym$146531[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$146531[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$146531[$CellContext`a3] = Part[
      $CellContext`sym$146531[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$146531[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$146531[$CellContext`a4] = Part[
      $CellContext`sym$146531[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$146531[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$146531[$CellContext`a5] = Part[
      $CellContext`sym$146531[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$146531[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$146531[$CellContext`a6] = Part[
      $CellContext`sym$146531[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$146531[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$146531[$CellContext`a7] = Part[
      $CellContext`sym$146531[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$146531[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$146531[All] = $CellContext`med[
     All], $CellContext`sym$146531[$CellContext`Chla] = Part[
      $CellContext`sym$146531[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$146531[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$146531[$CellContext`Cl] = Part[
      $CellContext`sym$146531[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$146531[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$146531[$CellContext`mnO2] = Part[
      $CellContext`sym$146531[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$146531[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$146531[$CellContext`mxPH] = Part[
      $CellContext`sym$146531[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$146531[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$146531[$CellContext`NH4] = Part[
      $CellContext`sym$146531[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$146531[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$146531[$CellContext`NO3] = Part[
      $CellContext`sym$146531[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$146531[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$146531[$CellContext`oPO4] = Part[
      $CellContext`sym$146531[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$146531[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$146531[$CellContext`PO4] = Part[
      $CellContext`sym$146531[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$146531[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$146531[$CellContext`season] = Part[
      $CellContext`sym$146531[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$146531[$CellContext`season, 
         "missing"]]]], $CellContext`sym$146531[$CellContext`size] = Part[
      $CellContext`sym$146531[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$146531[$CellContext`size, 
         "missing"]]]], $CellContext`sym$146531[$CellContext`speed] = Part[
      $CellContext`sym$146531[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$146531[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$146531[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$146531[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$146531, $CellContext`a1]], \
$CellContext`sym$146531[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$146531[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$146531[All], 
      All, $CellContext`i$148090], $CellContext`sym$146531[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$146531[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$146531, $CellContext`a2]], \
$CellContext`sym$146531[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$146531[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$146531[All], 
      All, $CellContext`i$148091], $CellContext`sym$146531[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$146531[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$146531, $CellContext`a3]], \
$CellContext`sym$146531[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$146531[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$146531[All], 
      All, $CellContext`i$148092], $CellContext`sym$146531[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$146531[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$146531, $CellContext`a4]], \
$CellContext`sym$146531[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$146531[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$146531[All], 
      All, $CellContext`i$148093], $CellContext`sym$146531[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$146531[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$146531, $CellContext`a5]], \
$CellContext`sym$146531[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$146531[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$146531[All], 
      All, $CellContext`i$148094], $CellContext`sym$146531[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$146531[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$146531, $CellContext`a6]], \
$CellContext`sym$146531[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$146531[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$146531[All], 
      All, $CellContext`i$148095], $CellContext`sym$146531[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$146531[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$146531, $CellContext`a7]], \
$CellContext`sym$146531[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$146531[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$146531[All], 
      All, $CellContext`i$148096], $CellContext`sym$146531[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$146531[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$146531[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$146531[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$146531, $CellContext`Chla]], \
$CellContext`sym$146531[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$146531[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$146531[All], 
      All, $CellContext`i$148089], $CellContext`sym$146531[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$146531[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$146531, $CellContext`Cl]], \
$CellContext`sym$146531[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$146531[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$146531[All], 
      All, $CellContext`i$148084], $CellContext`sym$146531[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$146531[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$146531, $CellContext`mnO2]], \
$CellContext`sym$146531[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$146531[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$146531[All], 
      All, $CellContext`i$148083], $CellContext`sym$146531[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$146531[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$146531, $CellContext`mxPH]], \
$CellContext`sym$146531[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$146531[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$146531[All], 
      All, $CellContext`i$148082], $CellContext`sym$146531[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$146531[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$146531, $CellContext`NH4]], \
$CellContext`sym$146531[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$146531[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$146531[All], 
      All, $CellContext`i$148086], $CellContext`sym$146531[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$146531[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$146531, $CellContext`NO3]], \
$CellContext`sym$146531[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$146531[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$146531[All], 
      All, $CellContext`i$148085], $CellContext`sym$146531[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$146531[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$146531, $CellContext`oPO4]], \
$CellContext`sym$146531[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$146531[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$146531[All], 
      All, $CellContext`i$148087], $CellContext`sym$146531[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$146531[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$146531, $CellContext`PO4]], \
$CellContext`sym$146531[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$146531[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$146531[All], 
      All, $CellContext`i$148088], \
$CellContext`sym$146531[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$146531[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$146531, $CellContext`season]], \
$CellContext`sym$146531[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$146531[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$146531[All], 
      All, $CellContext`i$146532], $CellContext`sym$146531[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$146531[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$146531, $CellContext`size]], \
$CellContext`sym$146531[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$146531[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$146531[All], 
      All, $CellContext`i$148080], $CellContext`sym$146531[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$146531[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$146531, $CellContext`speed]], \
$CellContext`sym$146531[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$146531[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$146531[All], All, $CellContext`i$148081], 
    Attributes[$CellContext`i$148096] = {Temporary}, $CellContext`i$148096 = 
    18, Attributes[$CellContext`i$148081] = {
     Temporary}, $CellContext`i$148081 = 3, 
    Attributes[$CellContext`i$148091] = {Temporary}, $CellContext`i$148091 = 
    13, Attributes[$CellContext`i$146532] = {
     Temporary}, $CellContext`i$146532 = 1, 
    Attributes[$CellContext`i$148093] = {Temporary}, $CellContext`i$148093 = 
    15, Attributes[$CellContext`i$148087] = {
     Temporary}, $CellContext`i$148087 = 9, 
    Attributes[$CellContext`i$148085] = {Temporary}, $CellContext`i$148085 = 
    7, Attributes[$CellContext`i$148090] = {Temporary}, $CellContext`i$148090 = 
    12, Attributes[$CellContext`i$148089] = {
     Temporary}, $CellContext`i$148089 = 11, 
    Attributes[$CellContext`i$148092] = {Temporary}, $CellContext`i$148092 = 
    14, Attributes[$CellContext`i$148095] = {
     Temporary}, $CellContext`i$148095 = 17, 
    Attributes[$CellContext`i$148083] = {Temporary}, $CellContext`i$148083 = 
    5, Attributes[$CellContext`i$148088] = {Temporary}, $CellContext`i$148088 = 
    10, Attributes[$CellContext`i$148086] = {
     Temporary}, $CellContext`i$148086 = 8, 
    Attributes[$CellContext`i$148080] = {Temporary}, $CellContext`i$148080 = 
    2, Attributes[$CellContext`i$148082] = {Temporary}, $CellContext`i$148082 = 
    4, Attributes[$CellContext`i$148084] = {Temporary}, $CellContext`i$148084 = 
    6, Attributes[$CellContext`i$148094] = {Temporary}, $CellContext`i$148094 = 
    16, Attributes[$CellContext`sym$159929] = {
     Temporary}, $CellContext`sym$159929[$CellContext`a1] = Part[
      $CellContext`sym$159929[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$159929[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$159929[$CellContext`a2] = Part[
      $CellContext`sym$159929[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$159929[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$159929[$CellContext`a3] = Part[
      $CellContext`sym$159929[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$159929[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$159929[$CellContext`a4] = Part[
      $CellContext`sym$159929[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$159929[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$159929[$CellContext`a5] = Part[
      $CellContext`sym$159929[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$159929[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$159929[$CellContext`a6] = Part[
      $CellContext`sym$159929[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$159929[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$159929[$CellContext`a7] = Part[
      $CellContext`sym$159929[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$159929[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$159929[All] = $CellContext`med[
     All], $CellContext`sym$159929[$CellContext`Chla] = Part[
      $CellContext`sym$159929[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$159929[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$159929[$CellContext`Cl] = Part[
      $CellContext`sym$159929[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$159929[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$159929[$CellContext`mnO2] = Part[
      $CellContext`sym$159929[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$159929[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$159929[$CellContext`mxPH] = Part[
      $CellContext`sym$159929[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$159929[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$159929[$CellContext`NH4] = Part[
      $CellContext`sym$159929[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$159929[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$159929[$CellContext`NO3] = Part[
      $CellContext`sym$159929[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$159929[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$159929[$CellContext`oPO4] = Part[
      $CellContext`sym$159929[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$159929[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$159929[$CellContext`PO4] = Part[
      $CellContext`sym$159929[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$159929[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$159929[$CellContext`season] = Part[
      $CellContext`sym$159929[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$159929[$CellContext`season, 
         "missing"]]]], $CellContext`sym$159929[$CellContext`size] = Part[
      $CellContext`sym$159929[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$159929[$CellContext`size, 
         "missing"]]]], $CellContext`sym$159929[$CellContext`speed] = Part[
      $CellContext`sym$159929[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$159929[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$159929[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$159929[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$159929, $CellContext`a1]], \
$CellContext`sym$159929[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$159929[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$159929[All], 
      All, $CellContext`i$161488], $CellContext`sym$159929[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$159929[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$159929, $CellContext`a2]], \
$CellContext`sym$159929[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$159929[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$159929[All], 
      All, $CellContext`i$161489], $CellContext`sym$159929[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$159929[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$159929, $CellContext`a3]], \
$CellContext`sym$159929[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$159929[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$159929[All], 
      All, $CellContext`i$161490], $CellContext`sym$159929[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$159929[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$159929, $CellContext`a4]], \
$CellContext`sym$159929[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$159929[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$159929[All], 
      All, $CellContext`i$161491], $CellContext`sym$159929[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$159929[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$159929, $CellContext`a5]], \
$CellContext`sym$159929[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$159929[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$159929[All], 
      All, $CellContext`i$161492], $CellContext`sym$159929[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$159929[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$159929, $CellContext`a6]], \
$CellContext`sym$159929[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$159929[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$159929[All], 
      All, $CellContext`i$161493], $CellContext`sym$159929[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$159929[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$159929, $CellContext`a7]], \
$CellContext`sym$159929[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$159929[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$159929[All], 
      All, $CellContext`i$161494], $CellContext`sym$159929[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$159929[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$159929[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$159929[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$159929, $CellContext`Chla]], \
$CellContext`sym$159929[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$159929[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$159929[All], 
      All, $CellContext`i$161487], $CellContext`sym$159929[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$159929[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$159929, $CellContext`Cl]], \
$CellContext`sym$159929[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$159929[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$159929[All], 
      All, $CellContext`i$161482], $CellContext`sym$159929[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$159929[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$159929, $CellContext`mnO2]], \
$CellContext`sym$159929[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$159929[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$159929[All], 
      All, $CellContext`i$161481], $CellContext`sym$159929[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$159929[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$159929, $CellContext`mxPH]], \
$CellContext`sym$159929[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$159929[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$159929[All], 
      All, $CellContext`i$161480], $CellContext`sym$159929[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$159929[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$159929, $CellContext`NH4]], \
$CellContext`sym$159929[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$159929[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$159929[All], 
      All, $CellContext`i$161484], $CellContext`sym$159929[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$159929[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$159929, $CellContext`NO3]], \
$CellContext`sym$159929[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$159929[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$159929[All], 
      All, $CellContext`i$161483], $CellContext`sym$159929[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$159929[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$159929, $CellContext`oPO4]], \
$CellContext`sym$159929[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$159929[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$159929[All], 
      All, $CellContext`i$161485], $CellContext`sym$159929[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$159929[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$159929, $CellContext`PO4]], \
$CellContext`sym$159929[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$159929[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$159929[All], 
      All, $CellContext`i$161486], \
$CellContext`sym$159929[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$159929[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$159929, $CellContext`season]], \
$CellContext`sym$159929[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$159929[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$159929[All], 
      All, $CellContext`i$159930], $CellContext`sym$159929[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$159929[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$159929, $CellContext`size]], \
$CellContext`sym$159929[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$159929[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$159929[All], 
      All, $CellContext`i$161478], $CellContext`sym$159929[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$159929[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$159929, $CellContext`speed]], \
$CellContext`sym$159929[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$159929[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$159929[All], All, $CellContext`i$161479], 
    Attributes[$CellContext`i$161487] = {Temporary}, $CellContext`i$161487 = 
    11, Attributes[$CellContext`i$161481] = {
     Temporary}, $CellContext`i$161481 = 5, 
    Attributes[$CellContext`i$161478] = {Temporary}, $CellContext`i$161478 = 
    2, Attributes[$CellContext`i$161490] = {Temporary}, $CellContext`i$161490 = 
    14, Attributes[$CellContext`i$161486] = {
     Temporary}, $CellContext`i$161486 = 10, 
    Attributes[$CellContext`i$159930] = {Temporary}, $CellContext`i$159930 = 
    1, Attributes[$CellContext`i$161479] = {Temporary}, $CellContext`i$161479 = 
    3, Attributes[$CellContext`i$161491] = {Temporary}, $CellContext`i$161491 = 
    15, Attributes[$CellContext`i$161494] = {
     Temporary}, $CellContext`i$161494 = 18, 
    Attributes[$CellContext`i$161492] = {Temporary}, $CellContext`i$161492 = 
    16, Attributes[$CellContext`i$161482] = {
     Temporary}, $CellContext`i$161482 = 6, 
    Attributes[$CellContext`i$161484] = {Temporary}, $CellContext`i$161484 = 
    8, Attributes[$CellContext`i$161480] = {Temporary}, $CellContext`i$161480 = 
    4, Attributes[$CellContext`i$161485] = {Temporary}, $CellContext`i$161485 = 
    9, Attributes[$CellContext`i$161493] = {Temporary}, $CellContext`i$161493 = 
    17, Attributes[$CellContext`i$161489] = {
     Temporary}, $CellContext`i$161489 = 13, 
    Attributes[$CellContext`i$161483] = {Temporary}, $CellContext`i$161483 = 
    7, Attributes[$CellContext`i$161488] = {Temporary}, $CellContext`i$161488 = 
    12, Attributes[$CellContext`sym$184492] = {
     Temporary}, $CellContext`sym$184492[$CellContext`a1] = Part[
      $CellContext`sym$184492[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$184492[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$184492[$CellContext`a2] = Part[
      $CellContext`sym$184492[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$184492[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$184492[$CellContext`a3] = Part[
      $CellContext`sym$184492[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$184492[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$184492[$CellContext`a4] = Part[
      $CellContext`sym$184492[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$184492[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$184492[$CellContext`a5] = Part[
      $CellContext`sym$184492[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$184492[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$184492[$CellContext`a6] = Part[
      $CellContext`sym$184492[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$184492[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$184492[$CellContext`a7] = Part[
      $CellContext`sym$184492[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$184492[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$184492[All] = $CellContext`med[
     All], $CellContext`sym$184492[$CellContext`Chla] = Part[
      $CellContext`sym$184492[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$184492[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$184492[$CellContext`Cl] = Part[
      $CellContext`sym$184492[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$184492[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$184492[$CellContext`mnO2] = Part[
      $CellContext`sym$184492[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$184492[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$184492[$CellContext`mxPH] = Part[
      $CellContext`sym$184492[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$184492[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$184492[$CellContext`NH4] = Part[
      $CellContext`sym$184492[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$184492[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$184492[$CellContext`NO3] = Part[
      $CellContext`sym$184492[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$184492[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$184492[$CellContext`oPO4] = Part[
      $CellContext`sym$184492[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$184492[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$184492[$CellContext`PO4] = Part[
      $CellContext`sym$184492[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$184492[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$184492[$CellContext`season] = Part[
      $CellContext`sym$184492[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$184492[$CellContext`season, 
         "missing"]]]], $CellContext`sym$184492[$CellContext`size] = Part[
      $CellContext`sym$184492[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$184492[$CellContext`size, 
         "missing"]]]], $CellContext`sym$184492[$CellContext`speed] = Part[
      $CellContext`sym$184492[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$184492[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$184492[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$184492[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$184492, $CellContext`a1]], \
$CellContext`sym$184492[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$184492[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$184492[All], 
      All, $CellContext`i$186051], $CellContext`sym$184492[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$184492[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$184492, $CellContext`a2]], \
$CellContext`sym$184492[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$184492[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$184492[All], 
      All, $CellContext`i$186052], $CellContext`sym$184492[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$184492[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$184492, $CellContext`a3]], \
$CellContext`sym$184492[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$184492[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$184492[All], 
      All, $CellContext`i$186053], $CellContext`sym$184492[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$184492[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$184492, $CellContext`a4]], \
$CellContext`sym$184492[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$184492[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$184492[All], 
      All, $CellContext`i$186054], $CellContext`sym$184492[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$184492[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$184492, $CellContext`a5]], \
$CellContext`sym$184492[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$184492[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$184492[All], 
      All, $CellContext`i$186055], $CellContext`sym$184492[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$184492[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$184492, $CellContext`a6]], \
$CellContext`sym$184492[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$184492[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$184492[All], 
      All, $CellContext`i$186056], $CellContext`sym$184492[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$184492[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$184492, $CellContext`a7]], \
$CellContext`sym$184492[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$184492[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$184492[All], 
      All, $CellContext`i$186057], $CellContext`sym$184492[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$184492[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$184492[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$184492[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$184492, $CellContext`Chla]], \
$CellContext`sym$184492[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$184492[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$184492[All], 
      All, $CellContext`i$186050], $CellContext`sym$184492[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$184492[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$184492, $CellContext`Cl]], \
$CellContext`sym$184492[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$184492[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$184492[All], 
      All, $CellContext`i$186045], $CellContext`sym$184492[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$184492[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$184492, $CellContext`mnO2]], \
$CellContext`sym$184492[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$184492[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$184492[All], 
      All, $CellContext`i$186044], $CellContext`sym$184492[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$184492[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$184492, $CellContext`mxPH]], \
$CellContext`sym$184492[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$184492[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$184492[All], 
      All, $CellContext`i$186043], $CellContext`sym$184492[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$184492[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$184492, $CellContext`NH4]], \
$CellContext`sym$184492[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$184492[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$184492[All], 
      All, $CellContext`i$186047], $CellContext`sym$184492[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$184492[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$184492, $CellContext`NO3]], \
$CellContext`sym$184492[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$184492[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$184492[All], 
      All, $CellContext`i$186046], $CellContext`sym$184492[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$184492[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$184492, $CellContext`oPO4]], \
$CellContext`sym$184492[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$184492[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$184492[All], 
      All, $CellContext`i$186048], $CellContext`sym$184492[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$184492[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$184492, $CellContext`PO4]], \
$CellContext`sym$184492[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$184492[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$184492[All], 
      All, $CellContext`i$186049], \
$CellContext`sym$184492[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$184492[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$184492, $CellContext`season]], \
$CellContext`sym$184492[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$184492[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$184492[All], 
      All, $CellContext`i$184493], $CellContext`sym$184492[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$184492[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$184492, $CellContext`size]], \
$CellContext`sym$184492[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$184492[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$184492[All], 
      All, $CellContext`i$186041], $CellContext`sym$184492[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$184492[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$184492, $CellContext`speed]], \
$CellContext`sym$184492[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$184492[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$184492[All], All, $CellContext`i$186042], 
    Attributes[$CellContext`i$186043] = {Temporary}, $CellContext`i$186043 = 
    4, Attributes[$CellContext`i$186048] = {Temporary}, $CellContext`i$186048 = 
    9, Attributes[$CellContext`i$186042] = {Temporary}, $CellContext`i$186042 = 
    3, Attributes[$CellContext`i$186054] = {Temporary}, $CellContext`i$186054 = 
    15, Attributes[$CellContext`i$184493] = {
     Temporary}, $CellContext`i$184493 = 1, 
    Attributes[$CellContext`i$186044] = {Temporary}, $CellContext`i$186044 = 
    5, Attributes[$CellContext`i$186046] = {Temporary}, $CellContext`i$186046 = 
    7, Attributes[$CellContext`i$186045] = {Temporary}, $CellContext`i$186045 = 
    6, Attributes[$CellContext`i$186052] = {Temporary}, $CellContext`i$186052 = 
    13, Attributes[$CellContext`i$186057] = {
     Temporary}, $CellContext`i$186057 = 18, 
    Attributes[$CellContext`i$186047] = {Temporary}, $CellContext`i$186047 = 
    8, Attributes[$CellContext`i$186051] = {Temporary}, $CellContext`i$186051 = 
    12, Attributes[$CellContext`i$186050] = {
     Temporary}, $CellContext`i$186050 = 11, 
    Attributes[$CellContext`i$186049] = {Temporary}, $CellContext`i$186049 = 
    10, Attributes[$CellContext`i$186056] = {
     Temporary}, $CellContext`i$186056 = 17, 
    Attributes[$CellContext`i$186041] = {Temporary}, $CellContext`i$186041 = 
    2, Attributes[$CellContext`i$186053] = {Temporary}, $CellContext`i$186053 = 
    14, Attributes[$CellContext`i$186055] = {
     Temporary}, $CellContext`i$186055 = 16, 
    Attributes[$CellContext`sym$227634] = {
     Temporary}, $CellContext`sym$227634[$CellContext`a1] = Part[
      $CellContext`sym$227634[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227634[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$227634[$CellContext`a2] = Part[
      $CellContext`sym$227634[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227634[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$227634[$CellContext`a3] = Part[
      $CellContext`sym$227634[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227634[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$227634[$CellContext`a4] = Part[
      $CellContext`sym$227634[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227634[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$227634[$CellContext`a5] = Part[
      $CellContext`sym$227634[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227634[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$227634[$CellContext`a6] = Part[
      $CellContext`sym$227634[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227634[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$227634[$CellContext`a7] = Part[
      $CellContext`sym$227634[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227634[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$227634[All] = $CellContext`med[
     All], $CellContext`sym$227634[$CellContext`Chla] = Part[
      $CellContext`sym$227634[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227634[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$227634[$CellContext`Cl] = Part[
      $CellContext`sym$227634[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227634[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$227634[$CellContext`mnO2] = Part[
      $CellContext`sym$227634[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227634[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$227634[$CellContext`mxPH] = Part[
      $CellContext`sym$227634[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227634[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$227634[$CellContext`NH4] = Part[
      $CellContext`sym$227634[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227634[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$227634[$CellContext`NO3] = Part[
      $CellContext`sym$227634[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227634[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$227634[$CellContext`oPO4] = Part[
      $CellContext`sym$227634[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227634[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$227634[$CellContext`PO4] = Part[
      $CellContext`sym$227634[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227634[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$227634[$CellContext`season] = Part[
      $CellContext`sym$227634[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227634[$CellContext`season, 
         "missing"]]]], $CellContext`sym$227634[$CellContext`size] = Part[
      $CellContext`sym$227634[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227634[$CellContext`size, 
         "missing"]]]], $CellContext`sym$227634[$CellContext`speed] = Part[
      $CellContext`sym$227634[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227634[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$227634[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$227634[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227634, $CellContext`a1]], \
$CellContext`sym$227634[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$227634[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$227634[All], 
      All, $CellContext`i$227646], $CellContext`sym$227634[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$227634[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227634, $CellContext`a2]], \
$CellContext`sym$227634[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$227634[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$227634[All], 
      All, $CellContext`i$227647], $CellContext`sym$227634[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$227634[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227634, $CellContext`a3]], \
$CellContext`sym$227634[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$227634[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$227634[All], 
      All, $CellContext`i$227648], $CellContext`sym$227634[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$227634[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227634, $CellContext`a4]], \
$CellContext`sym$227634[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$227634[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$227634[All], 
      All, $CellContext`i$227649], $CellContext`sym$227634[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$227634[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227634, $CellContext`a5]], \
$CellContext`sym$227634[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$227634[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$227634[All], 
      All, $CellContext`i$227650], $CellContext`sym$227634[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$227634[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227634, $CellContext`a6]], \
$CellContext`sym$227634[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$227634[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$227634[All], 
      All, $CellContext`i$227651], $CellContext`sym$227634[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$227634[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227634, $CellContext`a7]], \
$CellContext`sym$227634[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$227634[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$227634[All], 
      All, $CellContext`i$227652], $CellContext`sym$227634[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$227634[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$227634[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$227634[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227634, $CellContext`Chla]], \
$CellContext`sym$227634[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$227634[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$227634[All], 
      All, $CellContext`i$227645], $CellContext`sym$227634[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$227634[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227634, $CellContext`Cl]], \
$CellContext`sym$227634[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$227634[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$227634[All], 
      All, $CellContext`i$227640], $CellContext`sym$227634[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$227634[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227634, $CellContext`mnO2]], \
$CellContext`sym$227634[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$227634[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$227634[All], 
      All, $CellContext`i$227639], $CellContext`sym$227634[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$227634[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227634, $CellContext`mxPH]], \
$CellContext`sym$227634[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$227634[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$227634[All], 
      All, $CellContext`i$227638], $CellContext`sym$227634[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$227634[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227634, $CellContext`NH4]], \
$CellContext`sym$227634[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$227634[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$227634[All], 
      All, $CellContext`i$227642], $CellContext`sym$227634[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$227634[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227634, $CellContext`NO3]], \
$CellContext`sym$227634[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$227634[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$227634[All], 
      All, $CellContext`i$227641], $CellContext`sym$227634[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$227634[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227634, $CellContext`oPO4]], \
$CellContext`sym$227634[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$227634[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$227634[All], 
      All, $CellContext`i$227643], $CellContext`sym$227634[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$227634[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227634, $CellContext`PO4]], \
$CellContext`sym$227634[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$227634[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$227634[All], 
      All, $CellContext`i$227644], \
$CellContext`sym$227634[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$227634[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227634, $CellContext`season]], \
$CellContext`sym$227634[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$227634[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$227634[All], 
      All, $CellContext`i$227635], $CellContext`sym$227634[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$227634[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227634, $CellContext`size]], \
$CellContext`sym$227634[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$227634[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$227634[All], 
      All, $CellContext`i$227636], $CellContext`sym$227634[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$227634[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227634, $CellContext`speed]], \
$CellContext`sym$227634[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$227634[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$227634[All], All, $CellContext`i$227637], 
    Attributes[$CellContext`i$227649] = {Temporary}, $CellContext`i$227649 = 
    15, Attributes[$CellContext`i$227641] = {
     Temporary}, $CellContext`i$227641 = 7, 
    Attributes[$CellContext`i$227642] = {Temporary}, $CellContext`i$227642 = 
    8, Attributes[$CellContext`i$227637] = {Temporary}, $CellContext`i$227637 = 
    3, Attributes[$CellContext`i$227647] = {Temporary}, $CellContext`i$227647 = 
    13, Attributes[$CellContext`i$227648] = {
     Temporary}, $CellContext`i$227648 = 14, 
    Attributes[$CellContext`i$227638] = {Temporary}, $CellContext`i$227638 = 
    4, Attributes[$CellContext`i$227636] = {Temporary}, $CellContext`i$227636 = 
    2, Attributes[$CellContext`i$227646] = {Temporary}, $CellContext`i$227646 = 
    12, Attributes[$CellContext`i$227635] = {
     Temporary}, $CellContext`i$227635 = 1, 
    Attributes[$CellContext`i$227644] = {Temporary}, $CellContext`i$227644 = 
    10, Attributes[$CellContext`i$227651] = {
     Temporary}, $CellContext`i$227651 = 17, 
    Attributes[$CellContext`i$227639] = {Temporary}, $CellContext`i$227639 = 
    5, Attributes[$CellContext`i$227643] = {Temporary}, $CellContext`i$227643 = 
    9, Attributes[$CellContext`i$227640] = {Temporary}, $CellContext`i$227640 = 
    6, Attributes[$CellContext`i$227645] = {Temporary}, $CellContext`i$227645 = 
    11, Attributes[$CellContext`i$227652] = {
     Temporary}, $CellContext`i$227652 = 18, 
    Attributes[$CellContext`i$227650] = {Temporary}, $CellContext`i$227650 = 
    16, Attributes[$CellContext`sym$191191] = {
     Temporary}, $CellContext`sym$191191[$CellContext`a1] = Part[
      $CellContext`sym$191191[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$191191[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$191191[$CellContext`a2] = Part[
      $CellContext`sym$191191[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$191191[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$191191[$CellContext`a3] = Part[
      $CellContext`sym$191191[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$191191[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$191191[$CellContext`a4] = Part[
      $CellContext`sym$191191[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$191191[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$191191[$CellContext`a5] = Part[
      $CellContext`sym$191191[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$191191[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$191191[$CellContext`a6] = Part[
      $CellContext`sym$191191[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$191191[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$191191[$CellContext`a7] = Part[
      $CellContext`sym$191191[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$191191[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$191191[All] = $CellContext`med[
     All], $CellContext`sym$191191[$CellContext`Chla] = Part[
      $CellContext`sym$191191[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$191191[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$191191[$CellContext`Cl] = Part[
      $CellContext`sym$191191[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$191191[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$191191[$CellContext`mnO2] = Part[
      $CellContext`sym$191191[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$191191[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$191191[$CellContext`mxPH] = Part[
      $CellContext`sym$191191[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$191191[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$191191[$CellContext`NH4] = Part[
      $CellContext`sym$191191[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$191191[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$191191[$CellContext`NO3] = Part[
      $CellContext`sym$191191[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$191191[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$191191[$CellContext`oPO4] = Part[
      $CellContext`sym$191191[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$191191[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$191191[$CellContext`PO4] = Part[
      $CellContext`sym$191191[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$191191[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$191191[$CellContext`season] = Part[
      $CellContext`sym$191191[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$191191[$CellContext`season, 
         "missing"]]]], $CellContext`sym$191191[$CellContext`size] = Part[
      $CellContext`sym$191191[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$191191[$CellContext`size, 
         "missing"]]]], $CellContext`sym$191191[$CellContext`speed] = Part[
      $CellContext`sym$191191[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$191191[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$191191[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$191191[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$191191, $CellContext`a1]], \
$CellContext`sym$191191[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$191191[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$191191[All], 
      All, $CellContext`i$192750], $CellContext`sym$191191[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$191191[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$191191, $CellContext`a2]], \
$CellContext`sym$191191[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$191191[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$191191[All], 
      All, $CellContext`i$192751], $CellContext`sym$191191[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$191191[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$191191, $CellContext`a3]], \
$CellContext`sym$191191[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$191191[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$191191[All], 
      All, $CellContext`i$192752], $CellContext`sym$191191[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$191191[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$191191, $CellContext`a4]], \
$CellContext`sym$191191[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$191191[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$191191[All], 
      All, $CellContext`i$192753], $CellContext`sym$191191[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$191191[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$191191, $CellContext`a5]], \
$CellContext`sym$191191[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$191191[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$191191[All], 
      All, $CellContext`i$192754], $CellContext`sym$191191[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$191191[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$191191, $CellContext`a6]], \
$CellContext`sym$191191[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$191191[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$191191[All], 
      All, $CellContext`i$192755], $CellContext`sym$191191[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$191191[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$191191, $CellContext`a7]], \
$CellContext`sym$191191[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$191191[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$191191[All], 
      All, $CellContext`i$192756], $CellContext`sym$191191[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$191191[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$191191[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$191191[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$191191, $CellContext`Chla]], \
$CellContext`sym$191191[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$191191[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$191191[All], 
      All, $CellContext`i$192749], $CellContext`sym$191191[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$191191[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$191191, $CellContext`Cl]], \
$CellContext`sym$191191[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$191191[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$191191[All], 
      All, $CellContext`i$192744], $CellContext`sym$191191[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$191191[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$191191, $CellContext`mnO2]], \
$CellContext`sym$191191[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$191191[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$191191[All], 
      All, $CellContext`i$192743], $CellContext`sym$191191[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$191191[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$191191, $CellContext`mxPH]], \
$CellContext`sym$191191[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$191191[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$191191[All], 
      All, $CellContext`i$192742], $CellContext`sym$191191[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$191191[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$191191, $CellContext`NH4]], \
$CellContext`sym$191191[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$191191[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$191191[All], 
      All, $CellContext`i$192746], $CellContext`sym$191191[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$191191[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$191191, $CellContext`NO3]], \
$CellContext`sym$191191[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$191191[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$191191[All], 
      All, $CellContext`i$192745], $CellContext`sym$191191[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$191191[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$191191, $CellContext`oPO4]], \
$CellContext`sym$191191[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$191191[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$191191[All], 
      All, $CellContext`i$192747], $CellContext`sym$191191[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$191191[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$191191, $CellContext`PO4]], \
$CellContext`sym$191191[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$191191[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$191191[All], 
      All, $CellContext`i$192748], \
$CellContext`sym$191191[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$191191[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$191191, $CellContext`season]], \
$CellContext`sym$191191[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$191191[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$191191[All], 
      All, $CellContext`i$191192], $CellContext`sym$191191[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$191191[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$191191, $CellContext`size]], \
$CellContext`sym$191191[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$191191[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$191191[All], 
      All, $CellContext`i$192740], $CellContext`sym$191191[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$191191[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$191191, $CellContext`speed]], \
$CellContext`sym$191191[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$191191[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$191191[All], All, $CellContext`i$192741], 
    Attributes[$CellContext`i$192756] = {Temporary}, $CellContext`i$192756 = 
    18, Attributes[$CellContext`i$192751] = {
     Temporary}, $CellContext`i$192751 = 13, 
    Attributes[$CellContext`i$192745] = {Temporary}, $CellContext`i$192745 = 
    7, Attributes[$CellContext`i$192754] = {Temporary}, $CellContext`i$192754 = 
    16, Attributes[$CellContext`i$192742] = {
     Temporary}, $CellContext`i$192742 = 4, 
    Attributes[$CellContext`i$192750] = {Temporary}, $CellContext`i$192750 = 
    12, Attributes[$CellContext`i$192753] = {
     Temporary}, $CellContext`i$192753 = 15, 
    Attributes[$CellContext`i$192747] = {Temporary}, $CellContext`i$192747 = 
    9, Attributes[$CellContext`i$192740] = {Temporary}, $CellContext`i$192740 = 
    2, Attributes[$CellContext`i$192746] = {Temporary}, $CellContext`i$192746 = 
    8, Attributes[$CellContext`i$192755] = {Temporary}, $CellContext`i$192755 = 
    17, Attributes[$CellContext`i$192752] = {
     Temporary}, $CellContext`i$192752 = 14, 
    Attributes[$CellContext`i$191192] = {Temporary}, $CellContext`i$191192 = 
    1, Attributes[$CellContext`i$192748] = {Temporary}, $CellContext`i$192748 = 
    10, Attributes[$CellContext`i$192749] = {
     Temporary}, $CellContext`i$192749 = 11, 
    Attributes[$CellContext`i$192741] = {Temporary}, $CellContext`i$192741 = 
    3, Attributes[$CellContext`i$192744] = {Temporary}, $CellContext`i$192744 = 
    6, Attributes[$CellContext`i$192743] = {Temporary}, $CellContext`i$192743 = 
    5, Attributes[$CellContext`sym$157696] = {
     Temporary}, $CellContext`sym$157696[$CellContext`a1] = Part[
      $CellContext`sym$157696[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$157696[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$157696[$CellContext`a2] = Part[
      $CellContext`sym$157696[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$157696[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$157696[$CellContext`a3] = Part[
      $CellContext`sym$157696[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$157696[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$157696[$CellContext`a4] = Part[
      $CellContext`sym$157696[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$157696[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$157696[$CellContext`a5] = Part[
      $CellContext`sym$157696[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$157696[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$157696[$CellContext`a6] = Part[
      $CellContext`sym$157696[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$157696[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$157696[$CellContext`a7] = Part[
      $CellContext`sym$157696[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$157696[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$157696[All] = $CellContext`med[
     All], $CellContext`sym$157696[$CellContext`Chla] = Part[
      $CellContext`sym$157696[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$157696[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$157696[$CellContext`Cl] = Part[
      $CellContext`sym$157696[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$157696[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$157696[$CellContext`mnO2] = Part[
      $CellContext`sym$157696[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$157696[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$157696[$CellContext`mxPH] = Part[
      $CellContext`sym$157696[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$157696[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$157696[$CellContext`NH4] = Part[
      $CellContext`sym$157696[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$157696[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$157696[$CellContext`NO3] = Part[
      $CellContext`sym$157696[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$157696[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$157696[$CellContext`oPO4] = Part[
      $CellContext`sym$157696[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$157696[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$157696[$CellContext`PO4] = Part[
      $CellContext`sym$157696[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$157696[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$157696[$CellContext`season] = Part[
      $CellContext`sym$157696[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$157696[$CellContext`season, 
         "missing"]]]], $CellContext`sym$157696[$CellContext`size] = Part[
      $CellContext`sym$157696[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$157696[$CellContext`size, 
         "missing"]]]], $CellContext`sym$157696[$CellContext`speed] = Part[
      $CellContext`sym$157696[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$157696[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$157696[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$157696[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$157696, $CellContext`a1]], \
$CellContext`sym$157696[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$157696[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$157696[All], 
      All, $CellContext`i$159255], $CellContext`sym$157696[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$157696[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$157696, $CellContext`a2]], \
$CellContext`sym$157696[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$157696[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$157696[All], 
      All, $CellContext`i$159256], $CellContext`sym$157696[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$157696[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$157696, $CellContext`a3]], \
$CellContext`sym$157696[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$157696[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$157696[All], 
      All, $CellContext`i$159257], $CellContext`sym$157696[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$157696[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$157696, $CellContext`a4]], \
$CellContext`sym$157696[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$157696[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$157696[All], 
      All, $CellContext`i$159258], $CellContext`sym$157696[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$157696[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$157696, $CellContext`a5]], \
$CellContext`sym$157696[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$157696[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$157696[All], 
      All, $CellContext`i$159259], $CellContext`sym$157696[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$157696[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$157696, $CellContext`a6]], \
$CellContext`sym$157696[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$157696[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$157696[All], 
      All, $CellContext`i$159260], $CellContext`sym$157696[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$157696[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$157696, $CellContext`a7]], \
$CellContext`sym$157696[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$157696[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$157696[All], 
      All, $CellContext`i$159261], $CellContext`sym$157696[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$157696[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$157696[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$157696[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$157696, $CellContext`Chla]], \
$CellContext`sym$157696[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$157696[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$157696[All], 
      All, $CellContext`i$159254], $CellContext`sym$157696[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$157696[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$157696, $CellContext`Cl]], \
$CellContext`sym$157696[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$157696[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$157696[All], 
      All, $CellContext`i$159249], $CellContext`sym$157696[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$157696[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$157696, $CellContext`mnO2]], \
$CellContext`sym$157696[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$157696[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$157696[All], 
      All, $CellContext`i$159248], $CellContext`sym$157696[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$157696[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$157696, $CellContext`mxPH]], \
$CellContext`sym$157696[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$157696[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$157696[All], 
      All, $CellContext`i$159247], $CellContext`sym$157696[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$157696[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$157696, $CellContext`NH4]], \
$CellContext`sym$157696[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$157696[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$157696[All], 
      All, $CellContext`i$159251], $CellContext`sym$157696[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$157696[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$157696, $CellContext`NO3]], \
$CellContext`sym$157696[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$157696[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$157696[All], 
      All, $CellContext`i$159250], $CellContext`sym$157696[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$157696[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$157696, $CellContext`oPO4]], \
$CellContext`sym$157696[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$157696[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$157696[All], 
      All, $CellContext`i$159252], $CellContext`sym$157696[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$157696[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$157696, $CellContext`PO4]], \
$CellContext`sym$157696[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$157696[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$157696[All], 
      All, $CellContext`i$159253], \
$CellContext`sym$157696[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$157696[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$157696, $CellContext`season]], \
$CellContext`sym$157696[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$157696[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$157696[All], 
      All, $CellContext`i$157697], $CellContext`sym$157696[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$157696[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$157696, $CellContext`size]], \
$CellContext`sym$157696[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$157696[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$157696[All], 
      All, $CellContext`i$159245], $CellContext`sym$157696[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$157696[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$157696, $CellContext`speed]], \
$CellContext`sym$157696[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$157696[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$157696[All], All, $CellContext`i$159246], 
    Attributes[$CellContext`i$157697] = {Temporary}, $CellContext`i$157697 = 
    1, Attributes[$CellContext`i$159248] = {Temporary}, $CellContext`i$159248 = 
    5, Attributes[$CellContext`i$159257] = {Temporary}, $CellContext`i$159257 = 
    14, Attributes[$CellContext`i$159258] = {
     Temporary}, $CellContext`i$159258 = 15, 
    Attributes[$CellContext`i$159245] = {Temporary}, $CellContext`i$159245 = 
    2, Attributes[$CellContext`i$159254] = {Temporary}, $CellContext`i$159254 = 
    11, Attributes[$CellContext`i$159246] = {
     Temporary}, $CellContext`i$159246 = 3, 
    Attributes[$CellContext`i$159256] = {Temporary}, $CellContext`i$159256 = 
    13, Attributes[$CellContext`i$159260] = {
     Temporary}, $CellContext`i$159260 = 17, 
    Attributes[$CellContext`i$159259] = {Temporary}, $CellContext`i$159259 = 
    16, Attributes[$CellContext`i$159250] = {
     Temporary}, $CellContext`i$159250 = 7, 
    Attributes[$CellContext`i$159261] = {Temporary}, $CellContext`i$159261 = 
    18, Attributes[$CellContext`i$159255] = {
     Temporary}, $CellContext`i$159255 = 12, 
    Attributes[$CellContext`i$159252] = {Temporary}, $CellContext`i$159252 = 
    9, Attributes[$CellContext`i$159247] = {Temporary}, $CellContext`i$159247 = 
    4, Attributes[$CellContext`i$159251] = {Temporary}, $CellContext`i$159251 = 
    8, Attributes[$CellContext`i$159253] = {Temporary}, $CellContext`i$159253 = 
    10, Attributes[$CellContext`i$159249] = {
     Temporary}, $CellContext`i$159249 = 6, 
    Attributes[$CellContext`sym$75045] = {
     Temporary}, $CellContext`sym$75045[$CellContext`a1] = Part[
      $CellContext`sym$75045[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$75045[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$75045[$CellContext`a2] = Part[
      $CellContext`sym$75045[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$75045[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$75045[$CellContext`a3] = Part[
      $CellContext`sym$75045[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$75045[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$75045[$CellContext`a4] = Part[
      $CellContext`sym$75045[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$75045[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$75045[$CellContext`a5] = Part[
      $CellContext`sym$75045[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$75045[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$75045[$CellContext`a6] = Part[
      $CellContext`sym$75045[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$75045[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$75045[$CellContext`a7] = Part[
      $CellContext`sym$75045[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$75045[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$75045[All] = $CellContext`med[
     All], $CellContext`sym$75045[$CellContext`Chla] = Part[
      $CellContext`sym$75045[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$75045[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$75045[$CellContext`Cl] = Part[
      $CellContext`sym$75045[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$75045[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$75045[$CellContext`mnO2] = Part[
      $CellContext`sym$75045[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$75045[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$75045[$CellContext`mxPH] = Part[
      $CellContext`sym$75045[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$75045[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$75045[$CellContext`NH4] = Part[
      $CellContext`sym$75045[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$75045[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$75045[$CellContext`NO3] = Part[
      $CellContext`sym$75045[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$75045[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$75045[$CellContext`oPO4] = Part[
      $CellContext`sym$75045[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$75045[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$75045[$CellContext`PO4] = Part[
      $CellContext`sym$75045[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$75045[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$75045[$CellContext`season] = Part[
      $CellContext`sym$75045[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$75045[$CellContext`season, 
         "missing"]]]], $CellContext`sym$75045[$CellContext`size] = Part[
      $CellContext`sym$75045[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$75045[$CellContext`size, 
         "missing"]]]], $CellContext`sym$75045[$CellContext`speed] = Part[
      $CellContext`sym$75045[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$75045[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$75045[$CellContext`a1, "factorized"] = 
    True, $CellContext`sym$75045[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$75045, $CellContext`a1]], \
$CellContext`sym$75045[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$75045[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$75045[All], 
      All, $CellContext`i$76604], $CellContext`sym$75045[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$75045[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$75045, $CellContext`a2]], \
$CellContext`sym$75045[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$75045[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$75045[All], 
      All, $CellContext`i$76605], $CellContext`sym$75045[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$75045[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$75045, $CellContext`a3]], \
$CellContext`sym$75045[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$75045[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$75045[All], 
      All, $CellContext`i$76606], $CellContext`sym$75045[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$75045[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$75045, $CellContext`a4]], \
$CellContext`sym$75045[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$75045[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$75045[All], 
      All, $CellContext`i$76607], $CellContext`sym$75045[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$75045[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$75045, $CellContext`a5]], \
$CellContext`sym$75045[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$75045[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$75045[All], 
      All, $CellContext`i$76608], $CellContext`sym$75045[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$75045[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$75045, $CellContext`a6]], \
$CellContext`sym$75045[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$75045[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$75045[All], 
      All, $CellContext`i$76609], $CellContext`sym$75045[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$75045[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$75045, $CellContext`a7]], \
$CellContext`sym$75045[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$75045[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$75045[All], 
      All, $CellContext`i$76610], $CellContext`sym$75045[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$75045[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$75045[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$75045[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$75045, $CellContext`Chla]], \
$CellContext`sym$75045[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$75045[$CellContext`Chla, "raw"] = Part[
      $CellContext`sym$75045[All], 
      All, $CellContext`i$76603], $CellContext`sym$75045[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$75045[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$75045, $CellContext`Cl]], \
$CellContext`sym$75045[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$75045[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$75045[All], 
      All, $CellContext`i$76598], $CellContext`sym$75045[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$75045[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$75045, $CellContext`mnO2]], \
$CellContext`sym$75045[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$75045[$CellContext`mnO2, "raw"] = Part[
      $CellContext`sym$75045[All], 
      All, $CellContext`i$76597], $CellContext`sym$75045[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$75045[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$75045, $CellContext`mxPH]], \
$CellContext`sym$75045[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$75045[$CellContext`mxPH, "raw"] = Part[
      $CellContext`sym$75045[All], 
      All, $CellContext`i$76596], $CellContext`sym$75045[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$75045[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$75045, $CellContext`NH4]], \
$CellContext`sym$75045[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$75045[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$75045[All], 
      All, $CellContext`i$76600], $CellContext`sym$75045[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$75045[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$75045, $CellContext`NO3]], \
$CellContext`sym$75045[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$75045[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$75045[All], 
      All, $CellContext`i$76599], $CellContext`sym$75045[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$75045[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$75045, $CellContext`oPO4]], \
$CellContext`sym$75045[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$75045[$CellContext`oPO4, "raw"] = Part[
      $CellContext`sym$75045[All], 
      All, $CellContext`i$76601], $CellContext`sym$75045[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$75045[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$75045, $CellContext`PO4]], \
$CellContext`sym$75045[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$75045[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$75045[All], 
      All, $CellContext`i$76602], $CellContext`sym$75045[$CellContext`season, 
      "factorized"] = 
    True, $CellContext`sym$75045[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$75045, $CellContext`season]], \
$CellContext`sym$75045[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$75045[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$75045[All], 
      All, $CellContext`i$75046], $CellContext`sym$75045[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$75045[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$75045, $CellContext`size]], \
$CellContext`sym$75045[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$75045[$CellContext`size, "raw"] = Part[
      $CellContext`sym$75045[All], 
      All, $CellContext`i$76594], $CellContext`sym$75045[$CellContext`speed, 
      "factorized"] = 
    True, $CellContext`sym$75045[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$75045, $CellContext`speed]], \
$CellContext`sym$75045[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$75045[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$75045[All], All, $CellContext`i$76595], 
    Attributes[$CellContext`i$76607] = {Temporary}, $CellContext`i$76607 = 15,
     Attributes[$CellContext`i$76608] = {Temporary}, $CellContext`i$76608 = 
    16, Attributes[$CellContext`i$75046] = {Temporary}, $CellContext`i$75046 = 
    1, Attributes[$CellContext`i$76594] = {Temporary}, $CellContext`i$76594 = 
    2, Attributes[$CellContext`i$76595] = {Temporary}, $CellContext`i$76595 = 
    3, Attributes[$CellContext`i$76598] = {Temporary}, $CellContext`i$76598 = 
    6, Attributes[$CellContext`i$76609] = {Temporary}, $CellContext`i$76609 = 
    17, Attributes[$CellContext`i$76599] = {Temporary}, $CellContext`i$76599 = 
    7, Attributes[$CellContext`i$76610] = {Temporary}, $CellContext`i$76610 = 
    18, Attributes[$CellContext`i$76596] = {Temporary}, $CellContext`i$76596 = 
    4, Attributes[$CellContext`i$76601] = {Temporary}, $CellContext`i$76601 = 
    9, Attributes[$CellContext`i$76603] = {Temporary}, $CellContext`i$76603 = 
    11, Attributes[$CellContext`i$76602] = {Temporary}, $CellContext`i$76602 = 
    10, Attributes[$CellContext`i$76606] = {Temporary}, $CellContext`i$76606 = 
    14, Attributes[$CellContext`i$76597] = {Temporary}, $CellContext`i$76597 = 
    5, Attributes[$CellContext`i$76604] = {Temporary}, $CellContext`i$76604 = 
    12, Attributes[$CellContext`i$76600] = {Temporary}, $CellContext`i$76600 = 
    8, Attributes[$CellContext`i$76605] = {Temporary}, $CellContext`i$76605 = 
    13, Attributes[$CellContext`sym$50434] = {
     Temporary}, $CellContext`sym$50434[$CellContext`a1] = $CellContext`med[
     All], $CellContext`sym$50434[$CellContext`a2] = $CellContext`med[
     All], $CellContext`sym$50434[$CellContext`a3] = $CellContext`med[
     All], $CellContext`sym$50434[$CellContext`a4] = $CellContext`med[
     All], $CellContext`sym$50434[$CellContext`a5] = $CellContext`med[
     All], $CellContext`sym$50434[$CellContext`a6] = $CellContext`med[
     All], $CellContext`sym$50434[$CellContext`a7] = $CellContext`med[
     All], $CellContext`sym$50434[All] = $CellContext`med[
     All], $CellContext`sym$50434[$CellContext`Chla] = $CellContext`med[
     All], $CellContext`sym$50434[$CellContext`Cl] = $CellContext`med[
     All], $CellContext`sym$50434[$CellContext`mnO2] = $CellContext`med[
     All], $CellContext`sym$50434[$CellContext`mxPH] = $CellContext`med[
     All], $CellContext`sym$50434[$CellContext`NH4] = $CellContext`med[
     All], $CellContext`sym$50434[$CellContext`NO3] = $CellContext`med[
     All], $CellContext`sym$50434[$CellContext`oPO4] = $CellContext`med[
     All], $CellContext`sym$50434[$CellContext`PO4] = $CellContext`med[
     All], $CellContext`sym$50434[$CellContext`season] = $CellContext`med[
     All], $CellContext`sym$50434[$CellContext`size] = $CellContext`med[
     All], $CellContext`sym$50434[$CellContext`speed] = $CellContext`med[
     All], $CellContext`sym$50434[$CellContext`a1, "factorized"] = 
    True, $CellContext`sym$50434[$CellContext`a1, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$50434[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$50434[$CellContext`a1, "raw"] = Part[
      $CellContext`med[All], All, 12], $CellContext`sym$50434[$CellContext`a2,
       "factorized"] = 
    True, $CellContext`sym$50434[$CellContext`a2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$50434[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$50434[$CellContext`a2, "raw"] = Part[
      $CellContext`med[All], All, 13], $CellContext`sym$50434[$CellContext`a3,
       "factorized"] = 
    True, $CellContext`sym$50434[$CellContext`a3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$50434[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$50434[$CellContext`a3, "raw"] = Part[
      $CellContext`med[All], All, 14], $CellContext`sym$50434[$CellContext`a4,
       "factorized"] = 
    True, $CellContext`sym$50434[$CellContext`a4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$50434[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$50434[$CellContext`a4, "raw"] = Part[
      $CellContext`med[All], All, 15], $CellContext`sym$50434[$CellContext`a5,
       "factorized"] = 
    True, $CellContext`sym$50434[$CellContext`a5, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$50434[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$50434[$CellContext`a5, "raw"] = Part[
      $CellContext`med[All], All, 16], $CellContext`sym$50434[$CellContext`a6,
       "factorized"] = 
    True, $CellContext`sym$50434[$CellContext`a6, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$50434[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$50434[$CellContext`a6, "raw"] = Part[
      $CellContext`med[All], All, 17], $CellContext`sym$50434[$CellContext`a7,
       "factorized"] = 
    True, $CellContext`sym$50434[$CellContext`a7, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$50434[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$50434[$CellContext`a7, "raw"] = Part[
      $CellContext`med[All], All, 18], $CellContext`sym$50434[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$50434[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$50434[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$50434[$CellContext`Chla, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$50434[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$50434[$CellContext`Chla, "raw"] = Part[
      $CellContext`med[All], All, 11], $CellContext`sym$50434[$CellContext`Cl,
       "factorized"] = 
    True, $CellContext`sym$50434[$CellContext`Cl, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$50434[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$50434[$CellContext`Cl, "raw"] = Part[
      $CellContext`med[All], All, 
      6], $CellContext`sym$50434[$CellContext`mnO2, "factorized"] = 
    True, $CellContext`sym$50434[$CellContext`mnO2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$50434[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$50434[$CellContext`mnO2, "raw"] = Part[
      $CellContext`med[All], All, 
      5], $CellContext`sym$50434[$CellContext`mxPH, "factorized"] = 
    True, $CellContext`sym$50434[$CellContext`mxPH, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$50434[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$50434[$CellContext`mxPH, "raw"] = Part[
      $CellContext`med[All], All, 4], $CellContext`sym$50434[$CellContext`NH4,
       "factorized"] = 
    True, $CellContext`sym$50434[$CellContext`NH4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$50434[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$50434[$CellContext`NH4, "raw"] = Part[
      $CellContext`med[All], All, 8], $CellContext`sym$50434[$CellContext`NO3,
       "factorized"] = 
    True, $CellContext`sym$50434[$CellContext`NO3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$50434[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$50434[$CellContext`NO3, "raw"] = Part[
      $CellContext`med[All], All, 
      7], $CellContext`sym$50434[$CellContext`oPO4, "factorized"] = 
    True, $CellContext`sym$50434[$CellContext`oPO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$50434[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$50434[$CellContext`oPO4, "raw"] = Part[
      $CellContext`med[All], All, 9], $CellContext`sym$50434[$CellContext`PO4,
       "factorized"] = 
    True, $CellContext`sym$50434[$CellContext`PO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$50434[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$50434[$CellContext`PO4, "raw"] = Part[
      $CellContext`med[All], All, 
      10], $CellContext`sym$50434[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$50434[$CellContext`season, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$50434[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$50434[$CellContext`season, "raw"] = 
    Part[
      $CellContext`med[All], All, 
      1], $CellContext`sym$50434[$CellContext`size, "factorized"] = 
    True, $CellContext`sym$50434[$CellContext`size, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$50434[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$50434[$CellContext`size, "raw"] = Part[
      $CellContext`med[All], All, 
      2], $CellContext`sym$50434[$CellContext`speed, "factorized"] = 
    True, $CellContext`sym$50434[$CellContext`speed, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$50434[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$50434[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`med[All], All, 3], 
    Attributes[$CellContext`sym$61599] = {
     Temporary}, $CellContext`sym$61599[$CellContext`a1] = $CellContext`med[
     All], $CellContext`sym$61599[$CellContext`a2] = $CellContext`med[
     All], $CellContext`sym$61599[$CellContext`a3] = $CellContext`med[
     All], $CellContext`sym$61599[$CellContext`a4] = $CellContext`med[
     All], $CellContext`sym$61599[$CellContext`a5] = $CellContext`med[
     All], $CellContext`sym$61599[$CellContext`a6] = $CellContext`med[
     All], $CellContext`sym$61599[$CellContext`a7] = $CellContext`med[
     All], $CellContext`sym$61599[All] = $CellContext`med[
     All], $CellContext`sym$61599[$CellContext`Chla] = $CellContext`med[
     All], $CellContext`sym$61599[$CellContext`Cl] = $CellContext`med[
     All], $CellContext`sym$61599[$CellContext`mnO2] = $CellContext`med[
     All], $CellContext`sym$61599[$CellContext`mxPH] = $CellContext`med[
     All], $CellContext`sym$61599[$CellContext`NH4] = $CellContext`med[
     All], $CellContext`sym$61599[$CellContext`NO3] = $CellContext`med[
     All], $CellContext`sym$61599[$CellContext`oPO4] = $CellContext`med[
     All], $CellContext`sym$61599[$CellContext`PO4] = $CellContext`med[
     All], $CellContext`sym$61599[$CellContext`season] = $CellContext`med[
     All], $CellContext`sym$61599[$CellContext`size] = $CellContext`med[
     All], $CellContext`sym$61599[$CellContext`speed] = $CellContext`med[
     All], $CellContext`sym$61599[$CellContext`a1, "factorized"] = 
    True, $CellContext`sym$61599[$CellContext`a1, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$61599[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$61599[$CellContext`a1, "raw"] = Part[
      $CellContext`med[All], All, 12], $CellContext`sym$61599[$CellContext`a2,
       "factorized"] = 
    True, $CellContext`sym$61599[$CellContext`a2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$61599[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$61599[$CellContext`a2, "raw"] = Part[
      $CellContext`med[All], All, 13], $CellContext`sym$61599[$CellContext`a3,
       "factorized"] = 
    True, $CellContext`sym$61599[$CellContext`a3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$61599[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$61599[$CellContext`a3, "raw"] = Part[
      $CellContext`med[All], All, 14], $CellContext`sym$61599[$CellContext`a4,
       "factorized"] = 
    True, $CellContext`sym$61599[$CellContext`a4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$61599[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$61599[$CellContext`a4, "raw"] = Part[
      $CellContext`med[All], All, 15], $CellContext`sym$61599[$CellContext`a5,
       "factorized"] = 
    True, $CellContext`sym$61599[$CellContext`a5, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$61599[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$61599[$CellContext`a5, "raw"] = Part[
      $CellContext`med[All], All, 16], $CellContext`sym$61599[$CellContext`a6,
       "factorized"] = 
    True, $CellContext`sym$61599[$CellContext`a6, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$61599[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$61599[$CellContext`a6, "raw"] = Part[
      $CellContext`med[All], All, 17], $CellContext`sym$61599[$CellContext`a7,
       "factorized"] = 
    True, $CellContext`sym$61599[$CellContext`a7, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$61599[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$61599[$CellContext`a7, "raw"] = Part[
      $CellContext`med[All], All, 18], $CellContext`sym$61599[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$61599[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$61599[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$61599[$CellContext`Chla, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$61599[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$61599[$CellContext`Chla, "raw"] = Part[
      $CellContext`med[All], All, 11], $CellContext`sym$61599[$CellContext`Cl,
       "factorized"] = 
    True, $CellContext`sym$61599[$CellContext`Cl, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$61599[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$61599[$CellContext`Cl, "raw"] = Part[
      $CellContext`med[All], All, 
      6], $CellContext`sym$61599[$CellContext`mnO2, "factorized"] = 
    True, $CellContext`sym$61599[$CellContext`mnO2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$61599[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$61599[$CellContext`mnO2, "raw"] = Part[
      $CellContext`med[All], All, 
      5], $CellContext`sym$61599[$CellContext`mxPH, "factorized"] = 
    True, $CellContext`sym$61599[$CellContext`mxPH, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$61599[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$61599[$CellContext`mxPH, "raw"] = Part[
      $CellContext`med[All], All, 4], $CellContext`sym$61599[$CellContext`NH4,
       "factorized"] = 
    True, $CellContext`sym$61599[$CellContext`NH4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$61599[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$61599[$CellContext`NH4, "raw"] = Part[
      $CellContext`med[All], All, 8], $CellContext`sym$61599[$CellContext`NO3,
       "factorized"] = 
    True, $CellContext`sym$61599[$CellContext`NO3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$61599[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$61599[$CellContext`NO3, "raw"] = Part[
      $CellContext`med[All], All, 
      7], $CellContext`sym$61599[$CellContext`oPO4, "factorized"] = 
    True, $CellContext`sym$61599[$CellContext`oPO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$61599[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$61599[$CellContext`oPO4, "raw"] = Part[
      $CellContext`med[All], All, 9], $CellContext`sym$61599[$CellContext`PO4,
       "factorized"] = 
    True, $CellContext`sym$61599[$CellContext`PO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$61599[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$61599[$CellContext`PO4, "raw"] = Part[
      $CellContext`med[All], All, 
      10], $CellContext`sym$61599[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$61599[$CellContext`season, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$61599[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$61599[$CellContext`season, "raw"] = 
    Part[
      $CellContext`med[All], All, 
      1], $CellContext`sym$61599[$CellContext`size, "factorized"] = 
    True, $CellContext`sym$61599[$CellContext`size, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$61599[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$61599[$CellContext`size, "raw"] = Part[
      $CellContext`med[All], All, 
      2], $CellContext`sym$61599[$CellContext`speed, "factorized"] = 
    True, $CellContext`sym$61599[$CellContext`speed, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$61599[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$61599[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`med[All], All, 3], 
    Attributes[$CellContext`sym$171094] = {
     Temporary}, $CellContext`sym$171094[$CellContext`a1] = Part[
      $CellContext`sym$171094[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$171094[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$171094[$CellContext`a2] = Part[
      $CellContext`sym$171094[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$171094[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$171094[$CellContext`a3] = Part[
      $CellContext`sym$171094[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$171094[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$171094[$CellContext`a4] = Part[
      $CellContext`sym$171094[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$171094[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$171094[$CellContext`a5] = Part[
      $CellContext`sym$171094[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$171094[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$171094[$CellContext`a6] = Part[
      $CellContext`sym$171094[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$171094[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$171094[$CellContext`a7] = Part[
      $CellContext`sym$171094[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$171094[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$171094[All] = $CellContext`med[
     All], $CellContext`sym$171094[$CellContext`Chla] = Part[
      $CellContext`sym$171094[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$171094[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$171094[$CellContext`Cl] = Part[
      $CellContext`sym$171094[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$171094[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$171094[$CellContext`mnO2] = Part[
      $CellContext`sym$171094[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$171094[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$171094[$CellContext`mxPH] = Part[
      $CellContext`sym$171094[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$171094[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$171094[$CellContext`NH4] = Part[
      $CellContext`sym$171094[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$171094[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$171094[$CellContext`NO3] = Part[
      $CellContext`sym$171094[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$171094[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$171094[$CellContext`oPO4] = Part[
      $CellContext`sym$171094[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$171094[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$171094[$CellContext`PO4] = Part[
      $CellContext`sym$171094[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$171094[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$171094[$CellContext`season] = Part[
      $CellContext`sym$171094[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$171094[$CellContext`season, 
         "missing"]]]], $CellContext`sym$171094[$CellContext`size] = Part[
      $CellContext`sym$171094[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$171094[$CellContext`size, 
         "missing"]]]], $CellContext`sym$171094[$CellContext`speed] = Part[
      $CellContext`sym$171094[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$171094[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$171094[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$171094[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$171094, $CellContext`a1]], \
$CellContext`sym$171094[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$171094[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$171094[All], 
      All, $CellContext`i$172653], $CellContext`sym$171094[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$171094[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$171094, $CellContext`a2]], \
$CellContext`sym$171094[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$171094[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$171094[All], 
      All, $CellContext`i$172654], $CellContext`sym$171094[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$171094[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$171094, $CellContext`a3]], \
$CellContext`sym$171094[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$171094[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$171094[All], 
      All, $CellContext`i$172655], $CellContext`sym$171094[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$171094[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$171094, $CellContext`a4]], \
$CellContext`sym$171094[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$171094[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$171094[All], 
      All, $CellContext`i$172656], $CellContext`sym$171094[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$171094[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$171094, $CellContext`a5]], \
$CellContext`sym$171094[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$171094[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$171094[All], 
      All, $CellContext`i$172657], $CellContext`sym$171094[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$171094[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$171094, $CellContext`a6]], \
$CellContext`sym$171094[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$171094[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$171094[All], 
      All, $CellContext`i$172658], $CellContext`sym$171094[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$171094[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$171094, $CellContext`a7]], \
$CellContext`sym$171094[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$171094[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$171094[All], 
      All, $CellContext`i$172659], $CellContext`sym$171094[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$171094[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$171094[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$171094[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$171094, $CellContext`Chla]], \
$CellContext`sym$171094[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$171094[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$171094[All], 
      All, $CellContext`i$172652], $CellContext`sym$171094[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$171094[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$171094, $CellContext`Cl]], \
$CellContext`sym$171094[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$171094[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$171094[All], 
      All, $CellContext`i$172647], $CellContext`sym$171094[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$171094[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$171094, $CellContext`mnO2]], \
$CellContext`sym$171094[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$171094[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$171094[All], 
      All, $CellContext`i$172646], $CellContext`sym$171094[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$171094[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$171094, $CellContext`mxPH]], \
$CellContext`sym$171094[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$171094[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$171094[All], 
      All, $CellContext`i$172645], $CellContext`sym$171094[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$171094[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$171094, $CellContext`NH4]], \
$CellContext`sym$171094[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$171094[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$171094[All], 
      All, $CellContext`i$172649], $CellContext`sym$171094[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$171094[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$171094, $CellContext`NO3]], \
$CellContext`sym$171094[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$171094[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$171094[All], 
      All, $CellContext`i$172648], $CellContext`sym$171094[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$171094[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$171094, $CellContext`oPO4]], \
$CellContext`sym$171094[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$171094[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$171094[All], 
      All, $CellContext`i$172650], $CellContext`sym$171094[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$171094[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$171094, $CellContext`PO4]], \
$CellContext`sym$171094[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$171094[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$171094[All], 
      All, $CellContext`i$172651], \
$CellContext`sym$171094[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$171094[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$171094, $CellContext`season]], \
$CellContext`sym$171094[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$171094[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$171094[All], 
      All, $CellContext`i$171095], $CellContext`sym$171094[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$171094[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$171094, $CellContext`size]], \
$CellContext`sym$171094[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$171094[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$171094[All], 
      All, $CellContext`i$172643], $CellContext`sym$171094[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$171094[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$171094, $CellContext`speed]], \
$CellContext`sym$171094[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$171094[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$171094[All], All, $CellContext`i$172644], 
    Attributes[$CellContext`i$172649] = {Temporary}, $CellContext`i$172649 = 
    8, Attributes[$CellContext`i$172659] = {Temporary}, $CellContext`i$172659 = 
    18, Attributes[$CellContext`i$172646] = {
     Temporary}, $CellContext`i$172646 = 5, 
    Attributes[$CellContext`i$172655] = {Temporary}, $CellContext`i$172655 = 
    14, Attributes[$CellContext`i$172652] = {
     Temporary}, $CellContext`i$172652 = 11, 
    Attributes[$CellContext`i$172643] = {Temporary}, $CellContext`i$172643 = 
    2, Attributes[$CellContext`i$172656] = {Temporary}, $CellContext`i$172656 = 
    15, Attributes[$CellContext`i$172657] = {
     Temporary}, $CellContext`i$172657 = 16, 
    Attributes[$CellContext`i$172650] = {Temporary}, $CellContext`i$172650 = 
    9, Attributes[$CellContext`i$172653] = {Temporary}, $CellContext`i$172653 = 
    12, Attributes[$CellContext`i$172648] = {
     Temporary}, $CellContext`i$172648 = 7, 
    Attributes[$CellContext`i$172651] = {Temporary}, $CellContext`i$172651 = 
    10, Attributes[$CellContext`i$172647] = {
     Temporary}, $CellContext`i$172647 = 6, 
    Attributes[$CellContext`i$172645] = {Temporary}, $CellContext`i$172645 = 
    4, Attributes[$CellContext`i$172654] = {Temporary}, $CellContext`i$172654 = 
    13, Attributes[$CellContext`i$172644] = {
     Temporary}, $CellContext`i$172644 = 3, 
    Attributes[$CellContext`i$171095] = {Temporary}, $CellContext`i$171095 = 
    1, Attributes[$CellContext`i$172658] = {Temporary}, $CellContext`i$172658 = 
    17, Attributes[$CellContext`sym$128667] = {
     Temporary}, $CellContext`sym$128667[$CellContext`a1] = Part[
      $CellContext`sym$128667[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$128667[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$128667[$CellContext`a2] = Part[
      $CellContext`sym$128667[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$128667[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$128667[$CellContext`a3] = Part[
      $CellContext`sym$128667[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$128667[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$128667[$CellContext`a4] = Part[
      $CellContext`sym$128667[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$128667[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$128667[$CellContext`a5] = Part[
      $CellContext`sym$128667[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$128667[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$128667[$CellContext`a6] = Part[
      $CellContext`sym$128667[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$128667[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$128667[$CellContext`a7] = Part[
      $CellContext`sym$128667[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$128667[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$128667[All] = $CellContext`med[
     All], $CellContext`sym$128667[$CellContext`Chla] = Part[
      $CellContext`sym$128667[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$128667[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$128667[$CellContext`Cl] = Part[
      $CellContext`sym$128667[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$128667[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$128667[$CellContext`mnO2] = Part[
      $CellContext`sym$128667[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$128667[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$128667[$CellContext`mxPH] = Part[
      $CellContext`sym$128667[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$128667[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$128667[$CellContext`NH4] = Part[
      $CellContext`sym$128667[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$128667[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$128667[$CellContext`NO3] = Part[
      $CellContext`sym$128667[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$128667[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$128667[$CellContext`oPO4] = Part[
      $CellContext`sym$128667[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$128667[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$128667[$CellContext`PO4] = Part[
      $CellContext`sym$128667[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$128667[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$128667[$CellContext`season] = Part[
      $CellContext`sym$128667[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$128667[$CellContext`season, 
         "missing"]]]], $CellContext`sym$128667[$CellContext`size] = Part[
      $CellContext`sym$128667[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$128667[$CellContext`size, 
         "missing"]]]], $CellContext`sym$128667[$CellContext`speed] = Part[
      $CellContext`sym$128667[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$128667[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$128667[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$128667[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$128667, $CellContext`a1]], \
$CellContext`sym$128667[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$128667[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$128667[All], 
      All, $CellContext`i$130226], $CellContext`sym$128667[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$128667[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$128667, $CellContext`a2]], \
$CellContext`sym$128667[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$128667[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$128667[All], 
      All, $CellContext`i$130227], $CellContext`sym$128667[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$128667[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$128667, $CellContext`a3]], \
$CellContext`sym$128667[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$128667[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$128667[All], 
      All, $CellContext`i$130228], $CellContext`sym$128667[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$128667[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$128667, $CellContext`a4]], \
$CellContext`sym$128667[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$128667[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$128667[All], 
      All, $CellContext`i$130229], $CellContext`sym$128667[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$128667[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$128667, $CellContext`a5]], \
$CellContext`sym$128667[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$128667[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$128667[All], 
      All, $CellContext`i$130230], $CellContext`sym$128667[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$128667[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$128667, $CellContext`a6]], \
$CellContext`sym$128667[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$128667[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$128667[All], 
      All, $CellContext`i$130231], $CellContext`sym$128667[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$128667[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$128667, $CellContext`a7]], \
$CellContext`sym$128667[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$128667[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$128667[All], 
      All, $CellContext`i$130232], $CellContext`sym$128667[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$128667[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$128667[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$128667[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$128667, $CellContext`Chla]], \
$CellContext`sym$128667[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$128667[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$128667[All], 
      All, $CellContext`i$130225], $CellContext`sym$128667[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$128667[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$128667, $CellContext`Cl]], \
$CellContext`sym$128667[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$128667[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$128667[All], 
      All, $CellContext`i$130220], $CellContext`sym$128667[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$128667[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$128667, $CellContext`mnO2]], \
$CellContext`sym$128667[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$128667[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$128667[All], 
      All, $CellContext`i$130219], $CellContext`sym$128667[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$128667[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$128667, $CellContext`mxPH]], \
$CellContext`sym$128667[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$128667[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$128667[All], 
      All, $CellContext`i$130218], $CellContext`sym$128667[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$128667[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$128667, $CellContext`NH4]], \
$CellContext`sym$128667[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$128667[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$128667[All], 
      All, $CellContext`i$130222], $CellContext`sym$128667[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$128667[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$128667, $CellContext`NO3]], \
$CellContext`sym$128667[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$128667[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$128667[All], 
      All, $CellContext`i$130221], $CellContext`sym$128667[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$128667[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$128667, $CellContext`oPO4]], \
$CellContext`sym$128667[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$128667[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$128667[All], 
      All, $CellContext`i$130223], $CellContext`sym$128667[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$128667[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$128667, $CellContext`PO4]], \
$CellContext`sym$128667[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$128667[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$128667[All], 
      All, $CellContext`i$130224], \
$CellContext`sym$128667[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$128667[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$128667, $CellContext`season]], \
$CellContext`sym$128667[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$128667[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$128667[All], 
      All, $CellContext`i$128668], $CellContext`sym$128667[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$128667[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$128667, $CellContext`size]], \
$CellContext`sym$128667[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$128667[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$128667[All], 
      All, $CellContext`i$130216], $CellContext`sym$128667[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$128667[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$128667, $CellContext`speed]], \
$CellContext`sym$128667[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$128667[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$128667[All], All, $CellContext`i$130217], 
    Attributes[$CellContext`i$130231] = {Temporary}, $CellContext`i$130231 = 
    17, Attributes[$CellContext`i$130221] = {
     Temporary}, $CellContext`i$130221 = 7, 
    Attributes[$CellContext`i$128668] = {Temporary}, $CellContext`i$128668 = 
    1, Attributes[$CellContext`i$130229] = {Temporary}, $CellContext`i$130229 = 
    15, Attributes[$CellContext`i$130226] = {
     Temporary}, $CellContext`i$130226 = 12, 
    Attributes[$CellContext`i$130224] = {Temporary}, $CellContext`i$130224 = 
    10, Attributes[$CellContext`i$130216] = {
     Temporary}, $CellContext`i$130216 = 2, 
    Attributes[$CellContext`i$130228] = {Temporary}, $CellContext`i$130228 = 
    14, Attributes[$CellContext`i$130232] = {
     Temporary}, $CellContext`i$130232 = 18, 
    Attributes[$CellContext`i$130219] = {Temporary}, $CellContext`i$130219 = 
    5, Attributes[$CellContext`i$130225] = {Temporary}, $CellContext`i$130225 = 
    11, Attributes[$CellContext`i$130222] = {
     Temporary}, $CellContext`i$130222 = 8, 
    Attributes[$CellContext`i$130227] = {Temporary}, $CellContext`i$130227 = 
    13, Attributes[$CellContext`i$130218] = {
     Temporary}, $CellContext`i$130218 = 4, 
    Attributes[$CellContext`i$130223] = {Temporary}, $CellContext`i$130223 = 
    9, Attributes[$CellContext`i$130230] = {Temporary}, $CellContext`i$130230 = 
    16, Attributes[$CellContext`i$130220] = {
     Temporary}, $CellContext`i$130220 = 6, 
    Attributes[$CellContext`i$130217] = {Temporary}, $CellContext`i$130217 = 
    3, Attributes[$CellContext`sym$21404] = {
     Temporary}, $CellContext`sym$21404[$CellContext`a1] = $CellContext`med[
     All], $CellContext`sym$21404[$CellContext`a2] = $CellContext`med[
     All], $CellContext`sym$21404[$CellContext`a3] = $CellContext`med[
     All], $CellContext`sym$21404[$CellContext`a4] = $CellContext`med[
     All], $CellContext`sym$21404[$CellContext`a5] = $CellContext`med[
     All], $CellContext`sym$21404[$CellContext`a6] = $CellContext`med[
     All], $CellContext`sym$21404[$CellContext`a7] = $CellContext`med[
     All], $CellContext`sym$21404[All] = $CellContext`med[
     All], $CellContext`sym$21404[$CellContext`Chla] = $CellContext`med[
     All], $CellContext`sym$21404[$CellContext`Cl] = $CellContext`med[
     All], $CellContext`sym$21404[$CellContext`mnO2] = $CellContext`med[
     All], $CellContext`sym$21404[$CellContext`mxPH] = $CellContext`med[
     All], $CellContext`sym$21404[$CellContext`NH4] = $CellContext`med[
     All], $CellContext`sym$21404[$CellContext`NO3] = $CellContext`med[
     All], $CellContext`sym$21404[$CellContext`oPO4] = $CellContext`med[
     All], $CellContext`sym$21404[$CellContext`PO4] = $CellContext`med[
     All], $CellContext`sym$21404[$CellContext`season] = $CellContext`med[
     All], $CellContext`sym$21404[$CellContext`size] = $CellContext`med[
     All], $CellContext`sym$21404[$CellContext`speed] = $CellContext`med[
     All], $CellContext`sym$21404[$CellContext`a1, "factorized"] = 
    True, $CellContext`sym$21404[$CellContext`a1, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$21404[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$21404[$CellContext`a1, "raw"] = Part[
      $CellContext`med[All], All, 12], $CellContext`sym$21404[$CellContext`a2,
       "factorized"] = 
    True, $CellContext`sym$21404[$CellContext`a2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$21404[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$21404[$CellContext`a2, "raw"] = Part[
      $CellContext`med[All], All, 13], $CellContext`sym$21404[$CellContext`a3,
       "factorized"] = 
    True, $CellContext`sym$21404[$CellContext`a3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$21404[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$21404[$CellContext`a3, "raw"] = Part[
      $CellContext`med[All], All, 14], $CellContext`sym$21404[$CellContext`a4,
       "factorized"] = 
    True, $CellContext`sym$21404[$CellContext`a4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$21404[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$21404[$CellContext`a4, "raw"] = Part[
      $CellContext`med[All], All, 15], $CellContext`sym$21404[$CellContext`a5,
       "factorized"] = 
    True, $CellContext`sym$21404[$CellContext`a5, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$21404[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$21404[$CellContext`a5, "raw"] = Part[
      $CellContext`med[All], All, 16], $CellContext`sym$21404[$CellContext`a6,
       "factorized"] = 
    True, $CellContext`sym$21404[$CellContext`a6, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$21404[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$21404[$CellContext`a6, "raw"] = Part[
      $CellContext`med[All], All, 17], $CellContext`sym$21404[$CellContext`a7,
       "factorized"] = 
    True, $CellContext`sym$21404[$CellContext`a7, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$21404[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$21404[$CellContext`a7, "raw"] = Part[
      $CellContext`med[All], All, 18], $CellContext`sym$21404[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$21404[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$21404[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$21404[$CellContext`Chla, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$21404[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$21404[$CellContext`Chla, "raw"] = Part[
      $CellContext`med[All], All, 11], $CellContext`sym$21404[$CellContext`Cl,
       "factorized"] = 
    True, $CellContext`sym$21404[$CellContext`Cl, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$21404[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$21404[$CellContext`Cl, "raw"] = Part[
      $CellContext`med[All], All, 
      6], $CellContext`sym$21404[$CellContext`mnO2, "factorized"] = 
    True, $CellContext`sym$21404[$CellContext`mnO2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$21404[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$21404[$CellContext`mnO2, "raw"] = Part[
      $CellContext`med[All], All, 
      5], $CellContext`sym$21404[$CellContext`mxPH, "factorized"] = 
    True, $CellContext`sym$21404[$CellContext`mxPH, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$21404[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$21404[$CellContext`mxPH, "raw"] = Part[
      $CellContext`med[All], All, 4], $CellContext`sym$21404[$CellContext`NH4,
       "factorized"] = 
    True, $CellContext`sym$21404[$CellContext`NH4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$21404[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$21404[$CellContext`NH4, "raw"] = Part[
      $CellContext`med[All], All, 8], $CellContext`sym$21404[$CellContext`NO3,
       "factorized"] = 
    True, $CellContext`sym$21404[$CellContext`NO3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$21404[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$21404[$CellContext`NO3, "raw"] = Part[
      $CellContext`med[All], All, 
      7], $CellContext`sym$21404[$CellContext`oPO4, "factorized"] = 
    True, $CellContext`sym$21404[$CellContext`oPO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$21404[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$21404[$CellContext`oPO4, "raw"] = Part[
      $CellContext`med[All], All, 9], $CellContext`sym$21404[$CellContext`PO4,
       "factorized"] = 
    True, $CellContext`sym$21404[$CellContext`PO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$21404[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$21404[$CellContext`PO4, "raw"] = Part[
      $CellContext`med[All], All, 
      10], $CellContext`sym$21404[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$21404[$CellContext`season, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$21404[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$21404[$CellContext`season, "raw"] = 
    Part[
      $CellContext`med[All], All, 
      1], $CellContext`sym$21404[$CellContext`size, "factorized"] = 
    True, $CellContext`sym$21404[$CellContext`size, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$21404[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$21404[$CellContext`size, "raw"] = Part[
      $CellContext`med[All], All, 
      2], $CellContext`sym$21404[$CellContext`speed, "factorized"] = 
    True, $CellContext`sym$21404[$CellContext`speed, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$21404[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$21404[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`med[All], All, 3], 
    Attributes[$CellContext`sym$34803] = {
     Temporary}, $CellContext`sym$34803[$CellContext`a1] = $CellContext`med[
     All], $CellContext`sym$34803[$CellContext`a2] = $CellContext`med[
     All], $CellContext`sym$34803[$CellContext`a3] = $CellContext`med[
     All], $CellContext`sym$34803[$CellContext`a4] = $CellContext`med[
     All], $CellContext`sym$34803[$CellContext`a5] = $CellContext`med[
     All], $CellContext`sym$34803[$CellContext`a6] = $CellContext`med[
     All], $CellContext`sym$34803[$CellContext`a7] = $CellContext`med[
     All], $CellContext`sym$34803[All] = $CellContext`med[
     All], $CellContext`sym$34803[$CellContext`Chla] = $CellContext`med[
     All], $CellContext`sym$34803[$CellContext`Cl] = $CellContext`med[
     All], $CellContext`sym$34803[$CellContext`mnO2] = $CellContext`med[
     All], $CellContext`sym$34803[$CellContext`mxPH] = $CellContext`med[
     All], $CellContext`sym$34803[$CellContext`NH4] = $CellContext`med[
     All], $CellContext`sym$34803[$CellContext`NO3] = $CellContext`med[
     All], $CellContext`sym$34803[$CellContext`oPO4] = $CellContext`med[
     All], $CellContext`sym$34803[$CellContext`PO4] = $CellContext`med[
     All], $CellContext`sym$34803[$CellContext`season] = $CellContext`med[
     All], $CellContext`sym$34803[$CellContext`size] = $CellContext`med[
     All], $CellContext`sym$34803[$CellContext`speed] = $CellContext`med[
     All], $CellContext`sym$34803[$CellContext`a1, "factorized"] = 
    True, $CellContext`sym$34803[$CellContext`a1, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$34803[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$34803[$CellContext`a1, "raw"] = Part[
      $CellContext`med[All], All, 12], $CellContext`sym$34803[$CellContext`a2,
       "factorized"] = 
    True, $CellContext`sym$34803[$CellContext`a2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$34803[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$34803[$CellContext`a2, "raw"] = Part[
      $CellContext`med[All], All, 13], $CellContext`sym$34803[$CellContext`a3,
       "factorized"] = 
    True, $CellContext`sym$34803[$CellContext`a3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$34803[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$34803[$CellContext`a3, "raw"] = Part[
      $CellContext`med[All], All, 14], $CellContext`sym$34803[$CellContext`a4,
       "factorized"] = 
    True, $CellContext`sym$34803[$CellContext`a4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$34803[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$34803[$CellContext`a4, "raw"] = Part[
      $CellContext`med[All], All, 15], $CellContext`sym$34803[$CellContext`a5,
       "factorized"] = 
    True, $CellContext`sym$34803[$CellContext`a5, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$34803[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$34803[$CellContext`a5, "raw"] = Part[
      $CellContext`med[All], All, 16], $CellContext`sym$34803[$CellContext`a6,
       "factorized"] = 
    True, $CellContext`sym$34803[$CellContext`a6, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$34803[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$34803[$CellContext`a6, "raw"] = Part[
      $CellContext`med[All], All, 17], $CellContext`sym$34803[$CellContext`a7,
       "factorized"] = 
    True, $CellContext`sym$34803[$CellContext`a7, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$34803[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$34803[$CellContext`a7, "raw"] = Part[
      $CellContext`med[All], All, 18], $CellContext`sym$34803[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$34803[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$34803[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$34803[$CellContext`Chla, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$34803[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$34803[$CellContext`Chla, "raw"] = Part[
      $CellContext`med[All], All, 11], $CellContext`sym$34803[$CellContext`Cl,
       "factorized"] = 
    True, $CellContext`sym$34803[$CellContext`Cl, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$34803[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$34803[$CellContext`Cl, "raw"] = Part[
      $CellContext`med[All], All, 
      6], $CellContext`sym$34803[$CellContext`mnO2, "factorized"] = 
    True, $CellContext`sym$34803[$CellContext`mnO2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$34803[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$34803[$CellContext`mnO2, "raw"] = Part[
      $CellContext`med[All], All, 
      5], $CellContext`sym$34803[$CellContext`mxPH, "factorized"] = 
    True, $CellContext`sym$34803[$CellContext`mxPH, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$34803[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$34803[$CellContext`mxPH, "raw"] = Part[
      $CellContext`med[All], All, 4], $CellContext`sym$34803[$CellContext`NH4,
       "factorized"] = 
    True, $CellContext`sym$34803[$CellContext`NH4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$34803[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$34803[$CellContext`NH4, "raw"] = Part[
      $CellContext`med[All], All, 8], $CellContext`sym$34803[$CellContext`NO3,
       "factorized"] = 
    True, $CellContext`sym$34803[$CellContext`NO3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$34803[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$34803[$CellContext`NO3, "raw"] = Part[
      $CellContext`med[All], All, 
      7], $CellContext`sym$34803[$CellContext`oPO4, "factorized"] = 
    True, $CellContext`sym$34803[$CellContext`oPO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$34803[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$34803[$CellContext`oPO4, "raw"] = Part[
      $CellContext`med[All], All, 9], $CellContext`sym$34803[$CellContext`PO4,
       "factorized"] = 
    True, $CellContext`sym$34803[$CellContext`PO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$34803[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$34803[$CellContext`PO4, "raw"] = Part[
      $CellContext`med[All], All, 
      10], $CellContext`sym$34803[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$34803[$CellContext`season, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$34803[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$34803[$CellContext`season, "raw"] = 
    Part[
      $CellContext`med[All], All, 
      1], $CellContext`sym$34803[$CellContext`size, "factorized"] = 
    True, $CellContext`sym$34803[$CellContext`size, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$34803[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$34803[$CellContext`size, "raw"] = Part[
      $CellContext`med[All], All, 
      2], $CellContext`sym$34803[$CellContext`speed, "factorized"] = 
    True, $CellContext`sym$34803[$CellContext`speed, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$34803[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$34803[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`med[All], All, 3], 
    Attributes[$CellContext`sym$150997] = {
     Temporary}, $CellContext`sym$150997[$CellContext`a1] = Part[
      $CellContext`sym$150997[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$150997[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$150997[$CellContext`a2] = Part[
      $CellContext`sym$150997[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$150997[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$150997[$CellContext`a3] = Part[
      $CellContext`sym$150997[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$150997[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$150997[$CellContext`a4] = Part[
      $CellContext`sym$150997[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$150997[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$150997[$CellContext`a5] = Part[
      $CellContext`sym$150997[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$150997[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$150997[$CellContext`a6] = Part[
      $CellContext`sym$150997[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$150997[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$150997[$CellContext`a7] = Part[
      $CellContext`sym$150997[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$150997[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$150997[All] = $CellContext`med[
     All], $CellContext`sym$150997[$CellContext`Chla] = Part[
      $CellContext`sym$150997[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$150997[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$150997[$CellContext`Cl] = Part[
      $CellContext`sym$150997[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$150997[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$150997[$CellContext`mnO2] = Part[
      $CellContext`sym$150997[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$150997[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$150997[$CellContext`mxPH] = Part[
      $CellContext`sym$150997[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$150997[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$150997[$CellContext`NH4] = Part[
      $CellContext`sym$150997[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$150997[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$150997[$CellContext`NO3] = Part[
      $CellContext`sym$150997[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$150997[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$150997[$CellContext`oPO4] = Part[
      $CellContext`sym$150997[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$150997[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$150997[$CellContext`PO4] = Part[
      $CellContext`sym$150997[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$150997[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$150997[$CellContext`season] = Part[
      $CellContext`sym$150997[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$150997[$CellContext`season, 
         "missing"]]]], $CellContext`sym$150997[$CellContext`size] = Part[
      $CellContext`sym$150997[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$150997[$CellContext`size, 
         "missing"]]]], $CellContext`sym$150997[$CellContext`speed] = Part[
      $CellContext`sym$150997[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$150997[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$150997[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$150997[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$150997, $CellContext`a1]], \
$CellContext`sym$150997[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$150997[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$150997[All], 
      All, $CellContext`i$152556], $CellContext`sym$150997[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$150997[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$150997, $CellContext`a2]], \
$CellContext`sym$150997[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$150997[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$150997[All], 
      All, $CellContext`i$152557], $CellContext`sym$150997[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$150997[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$150997, $CellContext`a3]], \
$CellContext`sym$150997[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$150997[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$150997[All], 
      All, $CellContext`i$152558], $CellContext`sym$150997[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$150997[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$150997, $CellContext`a4]], \
$CellContext`sym$150997[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$150997[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$150997[All], 
      All, $CellContext`i$152559], $CellContext`sym$150997[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$150997[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$150997, $CellContext`a5]], \
$CellContext`sym$150997[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$150997[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$150997[All], 
      All, $CellContext`i$152560], $CellContext`sym$150997[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$150997[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$150997, $CellContext`a6]], \
$CellContext`sym$150997[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$150997[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$150997[All], 
      All, $CellContext`i$152561], $CellContext`sym$150997[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$150997[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$150997, $CellContext`a7]], \
$CellContext`sym$150997[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$150997[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$150997[All], 
      All, $CellContext`i$152562], $CellContext`sym$150997[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$150997[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$150997[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$150997[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$150997, $CellContext`Chla]], \
$CellContext`sym$150997[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$150997[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$150997[All], 
      All, $CellContext`i$152555], $CellContext`sym$150997[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$150997[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$150997, $CellContext`Cl]], \
$CellContext`sym$150997[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$150997[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$150997[All], 
      All, $CellContext`i$152550], $CellContext`sym$150997[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$150997[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$150997, $CellContext`mnO2]], \
$CellContext`sym$150997[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$150997[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$150997[All], 
      All, $CellContext`i$152549], $CellContext`sym$150997[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$150997[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$150997, $CellContext`mxPH]], \
$CellContext`sym$150997[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$150997[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$150997[All], 
      All, $CellContext`i$152548], $CellContext`sym$150997[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$150997[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$150997, $CellContext`NH4]], \
$CellContext`sym$150997[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$150997[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$150997[All], 
      All, $CellContext`i$152552], $CellContext`sym$150997[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$150997[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$150997, $CellContext`NO3]], \
$CellContext`sym$150997[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$150997[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$150997[All], 
      All, $CellContext`i$152551], $CellContext`sym$150997[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$150997[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$150997, $CellContext`oPO4]], \
$CellContext`sym$150997[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$150997[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$150997[All], 
      All, $CellContext`i$152553], $CellContext`sym$150997[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$150997[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$150997, $CellContext`PO4]], \
$CellContext`sym$150997[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$150997[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$150997[All], 
      All, $CellContext`i$152554], \
$CellContext`sym$150997[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$150997[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$150997, $CellContext`season]], \
$CellContext`sym$150997[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$150997[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$150997[All], 
      All, $CellContext`i$150998], $CellContext`sym$150997[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$150997[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$150997, $CellContext`size]], \
$CellContext`sym$150997[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$150997[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$150997[All], 
      All, $CellContext`i$152546], $CellContext`sym$150997[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$150997[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$150997, $CellContext`speed]], \
$CellContext`sym$150997[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$150997[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$150997[All], All, $CellContext`i$152547], 
    Attributes[$CellContext`i$150998] = {Temporary}, $CellContext`i$150998 = 
    1, Attributes[$CellContext`i$152561] = {Temporary}, $CellContext`i$152561 = 
    17, Attributes[$CellContext`i$152547] = {
     Temporary}, $CellContext`i$152547 = 3, 
    Attributes[$CellContext`i$152556] = {Temporary}, $CellContext`i$152556 = 
    12, Attributes[$CellContext`i$152552] = {
     Temporary}, $CellContext`i$152552 = 8, 
    Attributes[$CellContext`i$152558] = {Temporary}, $CellContext`i$152558 = 
    14, Attributes[$CellContext`i$152546] = {
     Temporary}, $CellContext`i$152546 = 2, 
    Attributes[$CellContext`i$152557] = {Temporary}, $CellContext`i$152557 = 
    13, Attributes[$CellContext`i$152553] = {
     Temporary}, $CellContext`i$152553 = 9, 
    Attributes[$CellContext`i$152562] = {Temporary}, $CellContext`i$152562 = 
    18, Attributes[$CellContext`i$152549] = {
     Temporary}, $CellContext`i$152549 = 5, 
    Attributes[$CellContext`i$152554] = {Temporary}, $CellContext`i$152554 = 
    10, Attributes[$CellContext`i$152551] = {
     Temporary}, $CellContext`i$152551 = 7, 
    Attributes[$CellContext`i$152560] = {Temporary}, $CellContext`i$152560 = 
    16, Attributes[$CellContext`i$152548] = {
     Temporary}, $CellContext`i$152548 = 4, 
    Attributes[$CellContext`i$152559] = {Temporary}, $CellContext`i$152559 = 
    15, Attributes[$CellContext`i$152550] = {
     Temporary}, $CellContext`i$152550 = 6, 
    Attributes[$CellContext`i$152555] = {Temporary}, $CellContext`i$152555 = 
    11, Attributes[$CellContext`sym$12472] = {
     Temporary}, $CellContext`sym$12472[$CellContext`a1] = $CellContext`med[
     All], $CellContext`sym$12472[$CellContext`a2] = $CellContext`med[
     All], $CellContext`sym$12472[$CellContext`a3] = $CellContext`med[
     All], $CellContext`sym$12472[$CellContext`a4] = $CellContext`med[
     All], $CellContext`sym$12472[$CellContext`a5] = $CellContext`med[
     All], $CellContext`sym$12472[$CellContext`a6] = $CellContext`med[
     All], $CellContext`sym$12472[$CellContext`a7] = $CellContext`med[
     All], $CellContext`sym$12472[All] = $CellContext`med[
     All], $CellContext`sym$12472[$CellContext`Chla] = $CellContext`med[
     All], $CellContext`sym$12472[$CellContext`Cl] = $CellContext`med[
     All], $CellContext`sym$12472[$CellContext`mnO2] = $CellContext`med[
     All], $CellContext`sym$12472[$CellContext`mxPH] = $CellContext`med[
     All], $CellContext`sym$12472[$CellContext`NH4] = $CellContext`med[
     All], $CellContext`sym$12472[$CellContext`NO3] = $CellContext`med[
     All], $CellContext`sym$12472[$CellContext`oPO4] = $CellContext`med[
     All], $CellContext`sym$12472[$CellContext`PO4] = $CellContext`med[
     All], $CellContext`sym$12472[$CellContext`season] = $CellContext`med[
     All], $CellContext`sym$12472[$CellContext`size] = $CellContext`med[
     All], $CellContext`sym$12472[$CellContext`speed] = $CellContext`med[
     All], $CellContext`sym$12472[$CellContext`a1, "factorized"] = 
    True, $CellContext`sym$12472[$CellContext`a1, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$12472[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$12472[$CellContext`a1, "raw"] = Part[
      $CellContext`med[All], All, 12], $CellContext`sym$12472[$CellContext`a2,
       "factorized"] = 
    True, $CellContext`sym$12472[$CellContext`a2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$12472[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$12472[$CellContext`a2, "raw"] = Part[
      $CellContext`med[All], All, 13], $CellContext`sym$12472[$CellContext`a3,
       "factorized"] = 
    True, $CellContext`sym$12472[$CellContext`a3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$12472[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$12472[$CellContext`a3, "raw"] = Part[
      $CellContext`med[All], All, 14], $CellContext`sym$12472[$CellContext`a4,
       "factorized"] = 
    True, $CellContext`sym$12472[$CellContext`a4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$12472[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$12472[$CellContext`a4, "raw"] = Part[
      $CellContext`med[All], All, 15], $CellContext`sym$12472[$CellContext`a5,
       "factorized"] = 
    True, $CellContext`sym$12472[$CellContext`a5, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$12472[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$12472[$CellContext`a5, "raw"] = Part[
      $CellContext`med[All], All, 16], $CellContext`sym$12472[$CellContext`a6,
       "factorized"] = 
    True, $CellContext`sym$12472[$CellContext`a6, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$12472[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$12472[$CellContext`a6, "raw"] = Part[
      $CellContext`med[All], All, 17], $CellContext`sym$12472[$CellContext`a7,
       "factorized"] = 
    True, $CellContext`sym$12472[$CellContext`a7, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$12472[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$12472[$CellContext`a7, "raw"] = Part[
      $CellContext`med[All], All, 18], $CellContext`sym$12472[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$12472[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$12472[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$12472[$CellContext`Chla, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$12472[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$12472[$CellContext`Chla, "raw"] = Part[
      $CellContext`med[All], All, 11], $CellContext`sym$12472[$CellContext`Cl,
       "factorized"] = 
    True, $CellContext`sym$12472[$CellContext`Cl, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$12472[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$12472[$CellContext`Cl, "raw"] = Part[
      $CellContext`med[All], All, 
      6], $CellContext`sym$12472[$CellContext`mnO2, "factorized"] = 
    True, $CellContext`sym$12472[$CellContext`mnO2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$12472[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$12472[$CellContext`mnO2, "raw"] = Part[
      $CellContext`med[All], All, 
      5], $CellContext`sym$12472[$CellContext`mxPH, "factorized"] = 
    True, $CellContext`sym$12472[$CellContext`mxPH, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$12472[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$12472[$CellContext`mxPH, "raw"] = Part[
      $CellContext`med[All], All, 4], $CellContext`sym$12472[$CellContext`NH4,
       "factorized"] = 
    True, $CellContext`sym$12472[$CellContext`NH4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$12472[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$12472[$CellContext`NH4, "raw"] = Part[
      $CellContext`med[All], All, 8], $CellContext`sym$12472[$CellContext`NO3,
       "factorized"] = 
    True, $CellContext`sym$12472[$CellContext`NO3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$12472[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$12472[$CellContext`NO3, "raw"] = Part[
      $CellContext`med[All], All, 
      7], $CellContext`sym$12472[$CellContext`oPO4, "factorized"] = 
    True, $CellContext`sym$12472[$CellContext`oPO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$12472[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$12472[$CellContext`oPO4, "raw"] = Part[
      $CellContext`med[All], All, 9], $CellContext`sym$12472[$CellContext`PO4,
       "factorized"] = 
    True, $CellContext`sym$12472[$CellContext`PO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$12472[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$12472[$CellContext`PO4, "raw"] = Part[
      $CellContext`med[All], All, 
      10], $CellContext`sym$12472[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$12472[$CellContext`season, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$12472[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$12472[$CellContext`season, "raw"] = 
    Part[
      $CellContext`med[All], All, 
      1], $CellContext`sym$12472[$CellContext`size, "factorized"] = 
    True, $CellContext`sym$12472[$CellContext`size, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$12472[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$12472[$CellContext`size, "raw"] = Part[
      $CellContext`med[All], All, 
      2], $CellContext`sym$12472[$CellContext`speed, "factorized"] = 
    True, $CellContext`sym$12472[$CellContext`speed, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$12472[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$12472[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`med[All], All, 3], 
    Attributes[$CellContext`sym$28103] = {
     Temporary}, $CellContext`sym$28103[$CellContext`a1] = $CellContext`med[
     All], $CellContext`sym$28103[$CellContext`a2] = $CellContext`med[
     All], $CellContext`sym$28103[$CellContext`a3] = $CellContext`med[
     All], $CellContext`sym$28103[$CellContext`a4] = $CellContext`med[
     All], $CellContext`sym$28103[$CellContext`a5] = $CellContext`med[
     All], $CellContext`sym$28103[$CellContext`a6] = $CellContext`med[
     All], $CellContext`sym$28103[$CellContext`a7] = $CellContext`med[
     All], $CellContext`sym$28103[All] = $CellContext`med[
     All], $CellContext`sym$28103[$CellContext`Chla] = $CellContext`med[
     All], $CellContext`sym$28103[$CellContext`Cl] = $CellContext`med[
     All], $CellContext`sym$28103[$CellContext`mnO2] = $CellContext`med[
     All], $CellContext`sym$28103[$CellContext`mxPH] = $CellContext`med[
     All], $CellContext`sym$28103[$CellContext`NH4] = $CellContext`med[
     All], $CellContext`sym$28103[$CellContext`NO3] = $CellContext`med[
     All], $CellContext`sym$28103[$CellContext`oPO4] = $CellContext`med[
     All], $CellContext`sym$28103[$CellContext`PO4] = $CellContext`med[
     All], $CellContext`sym$28103[$CellContext`season] = $CellContext`med[
     All], $CellContext`sym$28103[$CellContext`size] = $CellContext`med[
     All], $CellContext`sym$28103[$CellContext`speed] = $CellContext`med[
     All], $CellContext`sym$28103[$CellContext`a1, "factorized"] = 
    True, $CellContext`sym$28103[$CellContext`a1, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$28103[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$28103[$CellContext`a1, "raw"] = Part[
      $CellContext`med[All], All, 12], $CellContext`sym$28103[$CellContext`a2,
       "factorized"] = 
    True, $CellContext`sym$28103[$CellContext`a2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$28103[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$28103[$CellContext`a2, "raw"] = Part[
      $CellContext`med[All], All, 13], $CellContext`sym$28103[$CellContext`a3,
       "factorized"] = 
    True, $CellContext`sym$28103[$CellContext`a3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$28103[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$28103[$CellContext`a3, "raw"] = Part[
      $CellContext`med[All], All, 14], $CellContext`sym$28103[$CellContext`a4,
       "factorized"] = 
    True, $CellContext`sym$28103[$CellContext`a4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$28103[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$28103[$CellContext`a4, "raw"] = Part[
      $CellContext`med[All], All, 15], $CellContext`sym$28103[$CellContext`a5,
       "factorized"] = 
    True, $CellContext`sym$28103[$CellContext`a5, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$28103[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$28103[$CellContext`a5, "raw"] = Part[
      $CellContext`med[All], All, 16], $CellContext`sym$28103[$CellContext`a6,
       "factorized"] = 
    True, $CellContext`sym$28103[$CellContext`a6, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$28103[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$28103[$CellContext`a6, "raw"] = Part[
      $CellContext`med[All], All, 17], $CellContext`sym$28103[$CellContext`a7,
       "factorized"] = 
    True, $CellContext`sym$28103[$CellContext`a7, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$28103[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$28103[$CellContext`a7, "raw"] = Part[
      $CellContext`med[All], All, 18], $CellContext`sym$28103[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$28103[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$28103[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$28103[$CellContext`Chla, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$28103[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$28103[$CellContext`Chla, "raw"] = Part[
      $CellContext`med[All], All, 11], $CellContext`sym$28103[$CellContext`Cl,
       "factorized"] = 
    True, $CellContext`sym$28103[$CellContext`Cl, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$28103[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$28103[$CellContext`Cl, "raw"] = Part[
      $CellContext`med[All], All, 
      6], $CellContext`sym$28103[$CellContext`mnO2, "factorized"] = 
    True, $CellContext`sym$28103[$CellContext`mnO2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$28103[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$28103[$CellContext`mnO2, "raw"] = Part[
      $CellContext`med[All], All, 
      5], $CellContext`sym$28103[$CellContext`mxPH, "factorized"] = 
    True, $CellContext`sym$28103[$CellContext`mxPH, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$28103[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$28103[$CellContext`mxPH, "raw"] = Part[
      $CellContext`med[All], All, 4], $CellContext`sym$28103[$CellContext`NH4,
       "factorized"] = 
    True, $CellContext`sym$28103[$CellContext`NH4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$28103[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$28103[$CellContext`NH4, "raw"] = Part[
      $CellContext`med[All], All, 8], $CellContext`sym$28103[$CellContext`NO3,
       "factorized"] = 
    True, $CellContext`sym$28103[$CellContext`NO3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$28103[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$28103[$CellContext`NO3, "raw"] = Part[
      $CellContext`med[All], All, 
      7], $CellContext`sym$28103[$CellContext`oPO4, "factorized"] = 
    True, $CellContext`sym$28103[$CellContext`oPO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$28103[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$28103[$CellContext`oPO4, "raw"] = Part[
      $CellContext`med[All], All, 9], $CellContext`sym$28103[$CellContext`PO4,
       "factorized"] = 
    True, $CellContext`sym$28103[$CellContext`PO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$28103[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$28103[$CellContext`PO4, "raw"] = Part[
      $CellContext`med[All], All, 
      10], $CellContext`sym$28103[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$28103[$CellContext`season, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$28103[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$28103[$CellContext`season, "raw"] = 
    Part[
      $CellContext`med[All], All, 
      1], $CellContext`sym$28103[$CellContext`size, "factorized"] = 
    True, $CellContext`sym$28103[$CellContext`size, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$28103[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$28103[$CellContext`size, "raw"] = Part[
      $CellContext`med[All], All, 
      2], $CellContext`sym$28103[$CellContext`speed, "factorized"] = 
    True, $CellContext`sym$28103[$CellContext`speed, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$28103[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$28103[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`med[All], All, 3], 
    Attributes[$CellContext`sym$177793] = {
     Temporary}, $CellContext`sym$177793[$CellContext`a1] = Part[
      $CellContext`sym$177793[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$177793[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$177793[$CellContext`a2] = Part[
      $CellContext`sym$177793[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$177793[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$177793[$CellContext`a3] = Part[
      $CellContext`sym$177793[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$177793[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$177793[$CellContext`a4] = Part[
      $CellContext`sym$177793[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$177793[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$177793[$CellContext`a5] = Part[
      $CellContext`sym$177793[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$177793[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$177793[$CellContext`a6] = Part[
      $CellContext`sym$177793[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$177793[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$177793[$CellContext`a7] = Part[
      $CellContext`sym$177793[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$177793[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$177793[All] = $CellContext`med[
     All], $CellContext`sym$177793[$CellContext`Chla] = Part[
      $CellContext`sym$177793[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$177793[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$177793[$CellContext`Cl] = Part[
      $CellContext`sym$177793[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$177793[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$177793[$CellContext`mnO2] = Part[
      $CellContext`sym$177793[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$177793[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$177793[$CellContext`mxPH] = Part[
      $CellContext`sym$177793[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$177793[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$177793[$CellContext`NH4] = Part[
      $CellContext`sym$177793[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$177793[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$177793[$CellContext`NO3] = Part[
      $CellContext`sym$177793[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$177793[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$177793[$CellContext`oPO4] = Part[
      $CellContext`sym$177793[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$177793[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$177793[$CellContext`PO4] = Part[
      $CellContext`sym$177793[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$177793[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$177793[$CellContext`season] = Part[
      $CellContext`sym$177793[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$177793[$CellContext`season, 
         "missing"]]]], $CellContext`sym$177793[$CellContext`size] = Part[
      $CellContext`sym$177793[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$177793[$CellContext`size, 
         "missing"]]]], $CellContext`sym$177793[$CellContext`speed] = Part[
      $CellContext`sym$177793[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$177793[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$177793[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$177793[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$177793, $CellContext`a1]], \
$CellContext`sym$177793[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$177793[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$177793[All], 
      All, $CellContext`i$179352], $CellContext`sym$177793[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$177793[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$177793, $CellContext`a2]], \
$CellContext`sym$177793[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$177793[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$177793[All], 
      All, $CellContext`i$179353], $CellContext`sym$177793[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$177793[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$177793, $CellContext`a3]], \
$CellContext`sym$177793[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$177793[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$177793[All], 
      All, $CellContext`i$179354], $CellContext`sym$177793[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$177793[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$177793, $CellContext`a4]], \
$CellContext`sym$177793[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$177793[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$177793[All], 
      All, $CellContext`i$179355], $CellContext`sym$177793[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$177793[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$177793, $CellContext`a5]], \
$CellContext`sym$177793[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$177793[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$177793[All], 
      All, $CellContext`i$179356], $CellContext`sym$177793[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$177793[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$177793, $CellContext`a6]], \
$CellContext`sym$177793[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$177793[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$177793[All], 
      All, $CellContext`i$179357], $CellContext`sym$177793[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$177793[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$177793, $CellContext`a7]], \
$CellContext`sym$177793[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$177793[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$177793[All], 
      All, $CellContext`i$179358], $CellContext`sym$177793[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$177793[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$177793[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$177793[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$177793, $CellContext`Chla]], \
$CellContext`sym$177793[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$177793[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$177793[All], 
      All, $CellContext`i$179351], $CellContext`sym$177793[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$177793[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$177793, $CellContext`Cl]], \
$CellContext`sym$177793[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$177793[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$177793[All], 
      All, $CellContext`i$179346], $CellContext`sym$177793[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$177793[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$177793, $CellContext`mnO2]], \
$CellContext`sym$177793[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$177793[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$177793[All], 
      All, $CellContext`i$179345], $CellContext`sym$177793[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$177793[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$177793, $CellContext`mxPH]], \
$CellContext`sym$177793[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$177793[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$177793[All], 
      All, $CellContext`i$179344], $CellContext`sym$177793[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$177793[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$177793, $CellContext`NH4]], \
$CellContext`sym$177793[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$177793[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$177793[All], 
      All, $CellContext`i$179348], $CellContext`sym$177793[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$177793[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$177793, $CellContext`NO3]], \
$CellContext`sym$177793[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$177793[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$177793[All], 
      All, $CellContext`i$179347], $CellContext`sym$177793[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$177793[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$177793, $CellContext`oPO4]], \
$CellContext`sym$177793[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$177793[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$177793[All], 
      All, $CellContext`i$179349], $CellContext`sym$177793[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$177793[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$177793, $CellContext`PO4]], \
$CellContext`sym$177793[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$177793[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$177793[All], 
      All, $CellContext`i$179350], \
$CellContext`sym$177793[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$177793[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$177793, $CellContext`season]], \
$CellContext`sym$177793[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$177793[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$177793[All], 
      All, $CellContext`i$177794], $CellContext`sym$177793[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$177793[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$177793, $CellContext`size]], \
$CellContext`sym$177793[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$177793[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$177793[All], 
      All, $CellContext`i$179342], $CellContext`sym$177793[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$177793[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$177793, $CellContext`speed]], \
$CellContext`sym$177793[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$177793[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$177793[All], All, $CellContext`i$179343], 
    Attributes[$CellContext`i$179355] = {Temporary}, $CellContext`i$179355 = 
    15, Attributes[$CellContext`i$179351] = {
     Temporary}, $CellContext`i$179351 = 11, 
    Attributes[$CellContext`i$179343] = {Temporary}, $CellContext`i$179343 = 
    3, Attributes[$CellContext`i$179342] = {Temporary}, $CellContext`i$179342 = 
    2, Attributes[$CellContext`i$179348] = {Temporary}, $CellContext`i$179348 = 
    8, Attributes[$CellContext`i$179349] = {Temporary}, $CellContext`i$179349 = 
    9, Attributes[$CellContext`i$179347] = {Temporary}, $CellContext`i$179347 = 
    7, Attributes[$CellContext`i$179354] = {Temporary}, $CellContext`i$179354 = 
    14, Attributes[$CellContext`i$179345] = {
     Temporary}, $CellContext`i$179345 = 5, 
    Attributes[$CellContext`i$179353] = {Temporary}, $CellContext`i$179353 = 
    13, Attributes[$CellContext`i$179358] = {
     Temporary}, $CellContext`i$179358 = 18, 
    Attributes[$CellContext`i$179352] = {Temporary}, $CellContext`i$179352 = 
    12, Attributes[$CellContext`i$179344] = {
     Temporary}, $CellContext`i$179344 = 4, 
    Attributes[$CellContext`i$179356] = {Temporary}, $CellContext`i$179356 = 
    16, Attributes[$CellContext`i$179357] = {
     Temporary}, $CellContext`i$179357 = 17, 
    Attributes[$CellContext`i$179346] = {Temporary}, $CellContext`i$179346 = 
    6, Attributes[$CellContext`i$179350] = {Temporary}, $CellContext`i$179350 = 
    10, Attributes[$CellContext`i$177794] = {
     Temporary}, $CellContext`i$177794 = 1, 
    Attributes[$CellContext`sym$229942] = {
     Temporary}, $CellContext`sym$229942[$CellContext`a1] = Part[
      $CellContext`sym$229942[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229942[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$229942[$CellContext`a2] = Part[
      $CellContext`sym$229942[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229942[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$229942[$CellContext`a3] = Part[
      $CellContext`sym$229942[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229942[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$229942[$CellContext`a4] = Part[
      $CellContext`sym$229942[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229942[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$229942[$CellContext`a5] = Part[
      $CellContext`sym$229942[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229942[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$229942[$CellContext`a6] = Part[
      $CellContext`sym$229942[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229942[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$229942[$CellContext`a7] = Part[
      $CellContext`sym$229942[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229942[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$229942[
     All] = {{"winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 
       170., 50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
      "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
       558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
      "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 125.667,
        187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
      "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 61.182, 
       138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
      "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222, 
       97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
      "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
       56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
      "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
       111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
      "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 44.667, 
       77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
      "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 71., 
       5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 0.8, 
       17., 0., 0., 2.9, 0., 0., 1.7}, {
      "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 20.75, 
       0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
      "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 19.,
        0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
      "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 41., 
       43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
      "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5, 
       31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
      "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 0.3, 
       52.2, 5., 7.8, 0., 4., 0., 0.}, {
      "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 98.25, 
       1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50., 
       1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
      "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 57.833, 
       0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
      "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 0.8, 
       50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
      "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
       564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
      "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 586.,
        16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
      "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 0.5, 
       15.5, 0., 0., 2.3, 0., 0., 0.}, {
      "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 7.6,
        23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
      "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
       27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
      "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 1.5,
        13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
      "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 44.136, 
       3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
      "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 0.5, 
       29.7, 0., 0., 4.9, 0., 0., 0.}, {
      "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
       Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
      "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 17.1,
        0., 19.6, 0., 0., 0., 2.5}, {
      "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5, 
       33.9, 1., 14.6, 0., 0., 0., 0.}, {
      "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 4.9, 
       3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
      "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 2.8, 
       6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
      "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 130.75, 
       5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
      "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47., 
       2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
      "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23., 
       0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
      "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 58.875, 
       84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
      "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 0.2,
        66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
       Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0., 
       0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
       196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
      "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
       182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
      "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001, 
       296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
      "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 59.429,
        175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
      "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
       344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
      "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 276.85001, 
       326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
      "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 40.667, 
       3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
      "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 3.3, 
       29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
      "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 0.8, 
       54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
       Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 0., 
       0.}, {"spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121.,
        2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 20.812,
        12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
      "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
       49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
      "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 22.9, 
       4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
      "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 11.8, 
       0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818, 
       0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
      "winter", "small", "high", 6.6, 10.8, 
       Missing[], 3.245, 10., 1., 6.5, 
       Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "medium", 5.6, 11.8, 
       Missing[], 2.22, 5., 1., 1., 
       Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 5.7, 10.8, 
       Missing[], 2.55, 10., 1., 4., 
       Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
      "spring", "small", "high", 6.6, 9.5, 
       Missing[], 1.32, 20., 1., 6., 
       Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
      "summer", "small", "high", 6.6, 10.8, 
       Missing[], 2.64, 10., 2., 11., 
       Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
      "autumn", "small", "medium", 6.6, 11.3, 
       Missing[], 4.17, 10., 1., 6., 
       Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
      "spring", "small", "medium", 6.5, 10.4, 
       Missing[], 5.97, 10., 2., 14., 
       Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
      "summer", "small", "medium", 6.4, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 14., 
       Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
      "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 6.667, 
       Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75, 1.,
        20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
      "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2, 
       0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
      "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 0.6,
        55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
      "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 10.75, 
       2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
      "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 0.5, 
       64.2, 0., 3., 0., 0., 0., 0.}, {
      "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75, 
       351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
      "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
       209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
      "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 151.125,
        279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
      "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
       152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
      "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
       58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
      "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
       249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
      "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 100., 
       233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
      "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 215.5, 
       18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
      "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 25.167, 
       102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
      "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
       105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
      "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
       111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
      "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 1.3, 
       6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
      "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 56.667, 
       2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
      "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 4.3,
        1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
      "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
       104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
      "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 69.93,
        3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
      "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
       214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
      "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
       254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
      "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 57.6,
        169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
      "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
       412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
      "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
       282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
      "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
       197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
      "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 267.75, 
       391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
      "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 191.75, 
       265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
      "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
       232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
      "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 144.66701, 
       244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
      "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 218., 
       6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
      "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 138.5,
        20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
      "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222, 
       239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
      "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
       235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
      "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75, 
       205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
      "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 31.333, 
       211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
      "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625, 
       186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
      "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 12.889, 
       154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
      "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 51.111, 
       183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
      "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
       292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
      "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
       285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
      "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
       201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
      "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
       275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
      "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
       124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
      "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 60.833, 
       141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
      "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71., 
       132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
      "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
       17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
      "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 0.3, 
       46.6, 0., 2.5, 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 8.692, 
       16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
      "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 37.857, 
       102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
      "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
       86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
      "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
       10.111, 
       Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 16.833, 
       18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
      "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545, 
       13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
      "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 261.60001, 
       432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
      "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
       320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
      "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 144., 
       287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
      "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
       166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
      "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
       222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
      "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 36.909, 
       122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
      "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556, 
       127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
      "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
       89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
      "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 55., 
       284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
      "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 102.333, 
       277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
      "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 75.875, 
       177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
      "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
       72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
      "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 48.667, 
       82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
      "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 48.625, 
       66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
      "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 23., 
       173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
      "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 317., 
       5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
      "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 84., 
       4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
      "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 2., 
       10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
      "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 88.5, 
       2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
      "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115., 
       11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
      "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 98.143, 
       2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
      "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
       143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
      "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
       197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
      "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 1., 
       19., 0., 22., 5., 1.1, 5.4, 0.}, {
      "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 10.583, 
       23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
      "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 200.231, 
       19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
      "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 77.333, 
       147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
      "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5, 
       276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
      "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
       123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
      "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 75.207,
        23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
      "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 116.2,
        7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
      "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
       188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
      "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
       72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
      "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 16., 
       0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
      "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 34., 
       53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
      "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 27.5, 
       76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
      "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
       58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
      "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 175.66701, 
       361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
      "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
       22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
      "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 26.8,
        0., 28., 0., 0., 0., 0., 15.1}, {
      "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
       54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
      "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333, 
       34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
      "spring", "large", "low", 9., 5.8, 
       Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 0., 
       0.}, {"spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
       151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
      "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
       269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
      "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 46.438, 
       81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
      "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 85., 
       2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
      "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 66.4, 
       171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
      "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 102.364, 
       232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
      "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 84.3, 
       146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
      "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
       246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
      "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 205.636, 
       219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
      "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 236.39999,
        272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
      "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 1081.66003, 
       346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 5.9, 1.7}, {
      "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 82.222,
        167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
      "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 64.389, 
       137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
      "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 87.333,
        194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
      "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
       159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
      "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 21.3, 
       1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
      "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 0.6,
        37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
      "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
       14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
      "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222, 7.,
        1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 0.8, 
       50.4, 3.8, 0., 0., 0., 0., 0.}, {
      "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 7.654, 
       4., 56.8, 5., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 2.86, 
       17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
      "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 56.091, 
       Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
      "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
       52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
      "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 104.727, 
       228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
      "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 85.4, 
       17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
      "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 87.125,
        14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
      "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 101.455, 
       18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
      "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 50.889, 
       127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
      "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
       81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
      "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 19.727, 
       50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
      "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111, 
       120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
      "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 51.111, 
       91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
      "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 19.111, 
       61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
      "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625, 
       79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
      "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333, 
       75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
      "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333, 
       140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
      "winter", "large", "medium", 8., 7.6, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
      "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
       140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 
       5.8}}, $CellContext`sym$229942[$CellContext`Chla] = Part[
      $CellContext`sym$229942[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229942[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$229942[$CellContext`Cl] = Part[
      $CellContext`sym$229942[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229942[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$229942[$CellContext`mnO2] = Part[
      $CellContext`sym$229942[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229942[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$229942[$CellContext`mxPH] = Part[
      $CellContext`sym$229942[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229942[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$229942[$CellContext`NH4] = Part[
      $CellContext`sym$229942[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229942[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$229942[$CellContext`NO3] = Part[
      $CellContext`sym$229942[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229942[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$229942[$CellContext`oPO4] = Part[
      $CellContext`sym$229942[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229942[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$229942[$CellContext`PO4] = Part[
      $CellContext`sym$229942[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229942[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$229942[$CellContext`season] = Part[
      $CellContext`sym$229942[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229942[$CellContext`season, 
         "missing"]]]], $CellContext`sym$229942[$CellContext`size] = Part[
      $CellContext`sym$229942[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229942[$CellContext`size, 
         "missing"]]]], $CellContext`sym$229942[$CellContext`speed] = Part[
      $CellContext`sym$229942[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229942[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$229942[$CellContext`a1, 
      "factorized"] = 
    False, $CellContext`sym$229942[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$229942[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$229942[All], 
      All, $CellContext`i$229954], $CellContext`sym$229942[$CellContext`a2, 
      "factorized"] = 
    False, $CellContext`sym$229942[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$229942[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$229942[All], 
      All, $CellContext`i$229955], $CellContext`sym$229942[$CellContext`a3, 
      "factorized"] = 
    False, $CellContext`sym$229942[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$229942[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$229942[All], 
      All, $CellContext`i$229956], $CellContext`sym$229942[$CellContext`a4, 
      "factorized"] = 
    False, $CellContext`sym$229942[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$229942[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$229942[All], 
      All, $CellContext`i$229957], $CellContext`sym$229942[$CellContext`a5, 
      "factorized"] = 
    False, $CellContext`sym$229942[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$229942[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$229942[All], 
      All, $CellContext`i$229958], $CellContext`sym$229942[$CellContext`a6, 
      "factorized"] = 
    False, $CellContext`sym$229942[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$229942[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$229942[All], 
      All, $CellContext`i$229959], $CellContext`sym$229942[$CellContext`a7, 
      "factorized"] = 
    False, $CellContext`sym$229942[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$229942[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$229942[All], 
      All, $CellContext`i$229960], $CellContext`sym$229942[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$229942[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed}, $CellContext`sym$229942[$CellContext`Chla, "factorized"] = 
    False, $CellContext`sym$229942[$CellContext`Chla, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {63}, {116}, {184}, {
     199}}, $CellContext`sym$229942[$CellContext`Chla, "raw"] = Part[
      $CellContext`sym$229942[All], 
      All, $CellContext`i$229953], $CellContext`sym$229942[$CellContext`Cl, 
      "factorized"] = 
    False, $CellContext`sym$229942[$CellContext`Cl, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {161}, {
     199}}, $CellContext`sym$229942[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$229942[All], 
      All, $CellContext`i$229948], $CellContext`sym$229942[$CellContext`mnO2, 
      "factorized"] = 
    False, $CellContext`sym$229942[$CellContext`mnO2, "missing"] = {{38}, {
     62}}, $CellContext`sym$229942[$CellContext`mnO2, "raw"] = Part[
      $CellContext`sym$229942[All], 
      All, $CellContext`i$229947], $CellContext`sym$229942[$CellContext`mxPH, 
      "factorized"] = 
    False, $CellContext`sym$229942[$CellContext`mxPH, "missing"] = {{
     48}}, $CellContext`sym$229942[$CellContext`mxPH, "raw"] = Part[
      $CellContext`sym$229942[All], 
      All, $CellContext`i$229946], $CellContext`sym$229942[$CellContext`NH4, 
      "factorized"] = 
    False, $CellContext`sym$229942[$CellContext`NH4, "missing"] = {{62}, {
     199}}, $CellContext`sym$229942[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$229942[All], 
      All, $CellContext`i$229950], $CellContext`sym$229942[$CellContext`NO3, 
      "factorized"] = 
    False, $CellContext`sym$229942[$CellContext`NO3, "missing"] = {{62}, {
     199}}, $CellContext`sym$229942[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$229942[All], 
      All, $CellContext`i$229949], $CellContext`sym$229942[$CellContext`oPO4, 
      "factorized"] = 
    False, $CellContext`sym$229942[$CellContext`oPO4, "missing"] = {{62}, {
     199}}, $CellContext`sym$229942[$CellContext`oPO4, "raw"] = Part[
      $CellContext`sym$229942[All], 
      All, $CellContext`i$229951], $CellContext`sym$229942[$CellContext`PO4, 
      "factorized"] = 
    False, $CellContext`sym$229942[$CellContext`PO4, "missing"] = {{28}, {
     199}}, $CellContext`sym$229942[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$229942[All], 
      All, $CellContext`i$229952], \
$CellContext`sym$229942[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$229942[$CellContext`season, "factors"] = 
    Part[{"autumn", "spring", "summer", "winter"}, 
      $CellContext`fordering[$CellContext`sym$229942, $CellContext`season]], \
$CellContext`sym$229942[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$229942[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$229942[All], 
      All, $CellContext`i$229943], $CellContext`sym$229942[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$229942[$CellContext`size, "factors"] = 
    Part[{"large", "medium", "small"}, 
      $CellContext`fordering[$CellContext`sym$229942, $CellContext`size]], \
$CellContext`sym$229942[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$229942[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$229942[All], 
      All, $CellContext`i$229944], $CellContext`sym$229942[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$229942[$CellContext`speed, "factors"] = 
    Part[{"high", "low", "medium"}, 
      $CellContext`fordering[$CellContext`sym$229942, $CellContext`speed]], \
$CellContext`sym$229942[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$229942[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$229942[All], All, $CellContext`i$229945], 
    Attributes[$CellContext`i$229944] = {Temporary}, $CellContext`i$229944 = 
    2, Attributes[$CellContext`i$229956] = {Temporary}, $CellContext`i$229956 = 
    14, Attributes[$CellContext`i$229950] = {
     Temporary}, $CellContext`i$229950 = 8, 
    Attributes[$CellContext`i$229948] = {Temporary}, $CellContext`i$229948 = 
    6, Attributes[$CellContext`i$229955] = {Temporary}, $CellContext`i$229955 = 
    13, Attributes[$CellContext`i$229947] = {
     Temporary}, $CellContext`i$229947 = 5, 
    Attributes[$CellContext`i$229951] = {Temporary}, $CellContext`i$229951 = 
    9, Attributes[$CellContext`i$229957] = {Temporary}, $CellContext`i$229957 = 
    15, Attributes[$CellContext`i$229946] = {
     Temporary}, $CellContext`i$229946 = 4, 
    Attributes[$CellContext`i$229943] = {Temporary}, $CellContext`i$229943 = 
    1, Attributes[$CellContext`i$229958] = {Temporary}, $CellContext`i$229958 = 
    16, Attributes[$CellContext`i$229953] = {
     Temporary}, $CellContext`i$229953 = 11, 
    Attributes[$CellContext`i$229960] = {Temporary}, $CellContext`i$229960 = 
    18, Attributes[$CellContext`i$229949] = {
     Temporary}, $CellContext`i$229949 = 7, 
    Attributes[$CellContext`i$229952] = {Temporary}, $CellContext`i$229952 = 
    10, Attributes[$CellContext`i$229945] = {
     Temporary}, $CellContext`i$229945 = 3, 
    Attributes[$CellContext`i$229959] = {Temporary}, $CellContext`i$229959 = 
    17, Attributes[$CellContext`i$229954] = {
     Temporary}, $CellContext`i$229954 = 12, 
    Attributes[$CellContext`sym$227039] = {
     Temporary}, $CellContext`sym$227039[$CellContext`a1] = Part[
      $CellContext`sym$227039[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227039[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$227039[$CellContext`a2] = Part[
      $CellContext`sym$227039[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227039[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$227039[$CellContext`a3] = Part[
      $CellContext`sym$227039[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227039[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$227039[$CellContext`a4] = Part[
      $CellContext`sym$227039[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227039[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$227039[$CellContext`a5] = Part[
      $CellContext`sym$227039[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227039[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$227039[$CellContext`a6] = Part[
      $CellContext`sym$227039[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227039[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$227039[$CellContext`a7] = Part[
      $CellContext`sym$227039[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227039[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$227039[All] = $CellContext`med[
     All], $CellContext`sym$227039[$CellContext`Chla] = Part[
      $CellContext`sym$227039[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227039[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$227039[$CellContext`Cl] = Part[
      $CellContext`sym$227039[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227039[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$227039[$CellContext`mnO2] = Part[
      $CellContext`sym$227039[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227039[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$227039[$CellContext`mxPH] = Part[
      $CellContext`sym$227039[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227039[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$227039[$CellContext`NH4] = Part[
      $CellContext`sym$227039[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227039[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$227039[$CellContext`NO3] = Part[
      $CellContext`sym$227039[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227039[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$227039[$CellContext`oPO4] = Part[
      $CellContext`sym$227039[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227039[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$227039[$CellContext`PO4] = Part[
      $CellContext`sym$227039[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227039[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$227039[$CellContext`season] = Part[
      $CellContext`sym$227039[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227039[$CellContext`season, 
         "missing"]]]], $CellContext`sym$227039[$CellContext`size] = Part[
      $CellContext`sym$227039[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227039[$CellContext`size, 
         "missing"]]]], $CellContext`sym$227039[$CellContext`speed] = Part[
      $CellContext`sym$227039[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227039[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$227039[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$227039[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227039, $CellContext`a1]], \
$CellContext`sym$227039[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$227039[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$227039[All], 
      All, $CellContext`i$227051], $CellContext`sym$227039[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$227039[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227039, $CellContext`a2]], \
$CellContext`sym$227039[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$227039[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$227039[All], 
      All, $CellContext`i$227052], $CellContext`sym$227039[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$227039[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227039, $CellContext`a3]], \
$CellContext`sym$227039[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$227039[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$227039[All], 
      All, $CellContext`i$227053], $CellContext`sym$227039[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$227039[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227039, $CellContext`a4]], \
$CellContext`sym$227039[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$227039[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$227039[All], 
      All, $CellContext`i$227054], $CellContext`sym$227039[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$227039[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227039, $CellContext`a5]], \
$CellContext`sym$227039[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$227039[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$227039[All], 
      All, $CellContext`i$227055], $CellContext`sym$227039[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$227039[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227039, $CellContext`a6]], \
$CellContext`sym$227039[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$227039[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$227039[All], 
      All, $CellContext`i$227056], $CellContext`sym$227039[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$227039[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227039, $CellContext`a7]], \
$CellContext`sym$227039[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$227039[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$227039[All], 
      All, $CellContext`i$227057], $CellContext`sym$227039[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$227039[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$227039[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$227039[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227039, $CellContext`Chla]], \
$CellContext`sym$227039[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$227039[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$227039[All], 
      All, $CellContext`i$227050], $CellContext`sym$227039[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$227039[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227039, $CellContext`Cl]], \
$CellContext`sym$227039[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$227039[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$227039[All], 
      All, $CellContext`i$227045], $CellContext`sym$227039[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$227039[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227039, $CellContext`mnO2]], \
$CellContext`sym$227039[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$227039[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$227039[All], 
      All, $CellContext`i$227044], $CellContext`sym$227039[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$227039[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227039, $CellContext`mxPH]], \
$CellContext`sym$227039[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$227039[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$227039[All], 
      All, $CellContext`i$227043], $CellContext`sym$227039[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$227039[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227039, $CellContext`NH4]], \
$CellContext`sym$227039[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$227039[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$227039[All], 
      All, $CellContext`i$227047], $CellContext`sym$227039[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$227039[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227039, $CellContext`NO3]], \
$CellContext`sym$227039[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$227039[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$227039[All], 
      All, $CellContext`i$227046], $CellContext`sym$227039[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$227039[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227039, $CellContext`oPO4]], \
$CellContext`sym$227039[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$227039[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$227039[All], 
      All, $CellContext`i$227048], $CellContext`sym$227039[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$227039[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227039, $CellContext`PO4]], \
$CellContext`sym$227039[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$227039[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$227039[All], 
      All, $CellContext`i$227049], \
$CellContext`sym$227039[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$227039[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227039, $CellContext`season]], \
$CellContext`sym$227039[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$227039[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$227039[All], 
      All, $CellContext`i$227040], $CellContext`sym$227039[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$227039[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227039, $CellContext`size]], \
$CellContext`sym$227039[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$227039[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$227039[All], 
      All, $CellContext`i$227041], $CellContext`sym$227039[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$227039[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227039, $CellContext`speed]], \
$CellContext`sym$227039[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$227039[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$227039[All], All, $CellContext`i$227042], 
    Attributes[$CellContext`i$227054] = {Temporary}, $CellContext`i$227054 = 
    15, Attributes[$CellContext`i$227056] = {
     Temporary}, $CellContext`i$227056 = 17, 
    Attributes[$CellContext`i$227050] = {Temporary}, $CellContext`i$227050 = 
    11, Attributes[$CellContext`i$227043] = {
     Temporary}, $CellContext`i$227043 = 4, 
    Attributes[$CellContext`i$227040] = {Temporary}, $CellContext`i$227040 = 
    1, Attributes[$CellContext`i$227048] = {Temporary}, $CellContext`i$227048 = 
    9, Attributes[$CellContext`i$227055] = {Temporary}, $CellContext`i$227055 = 
    16, Attributes[$CellContext`i$227045] = {
     Temporary}, $CellContext`i$227045 = 6, 
    Attributes[$CellContext`i$227042] = {Temporary}, $CellContext`i$227042 = 
    3, Attributes[$CellContext`i$227047] = {Temporary}, $CellContext`i$227047 = 
    8, Attributes[$CellContext`i$227041] = {Temporary}, $CellContext`i$227041 = 
    2, Attributes[$CellContext`i$227044] = {Temporary}, $CellContext`i$227044 = 
    5, Attributes[$CellContext`i$227052] = {Temporary}, $CellContext`i$227052 = 
    13, Attributes[$CellContext`i$227049] = {
     Temporary}, $CellContext`i$227049 = 10, 
    Attributes[$CellContext`i$227057] = {Temporary}, $CellContext`i$227057 = 
    18, Attributes[$CellContext`i$227053] = {
     Temporary}, $CellContext`i$227053 = 14, 
    Attributes[$CellContext`i$227051] = {Temporary}, $CellContext`i$227051 = 
    12, Attributes[$CellContext`i$227046] = {
     Temporary}, $CellContext`i$227046 = 7, 
    Attributes[$CellContext`sym$52667] = {
     Temporary}, $CellContext`sym$52667[$CellContext`a1] = $CellContext`med[
     All], $CellContext`sym$52667[$CellContext`a2] = $CellContext`med[
     All], $CellContext`sym$52667[$CellContext`a3] = $CellContext`med[
     All], $CellContext`sym$52667[$CellContext`a4] = $CellContext`med[
     All], $CellContext`sym$52667[$CellContext`a5] = $CellContext`med[
     All], $CellContext`sym$52667[$CellContext`a6] = $CellContext`med[
     All], $CellContext`sym$52667[$CellContext`a7] = $CellContext`med[
     All], $CellContext`sym$52667[All] = $CellContext`med[
     All], $CellContext`sym$52667[$CellContext`Chla] = $CellContext`med[
     All], $CellContext`sym$52667[$CellContext`Cl] = $CellContext`med[
     All], $CellContext`sym$52667[$CellContext`mnO2] = $CellContext`med[
     All], $CellContext`sym$52667[$CellContext`mxPH] = $CellContext`med[
     All], $CellContext`sym$52667[$CellContext`NH4] = $CellContext`med[
     All], $CellContext`sym$52667[$CellContext`NO3] = $CellContext`med[
     All], $CellContext`sym$52667[$CellContext`oPO4] = $CellContext`med[
     All], $CellContext`sym$52667[$CellContext`PO4] = $CellContext`med[
     All], $CellContext`sym$52667[$CellContext`season] = $CellContext`med[
     All], $CellContext`sym$52667[$CellContext`size] = $CellContext`med[
     All], $CellContext`sym$52667[$CellContext`speed] = $CellContext`med[
     All], $CellContext`sym$52667[$CellContext`a1, "factorized"] = 
    True, $CellContext`sym$52667[$CellContext`a1, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$52667[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$52667[$CellContext`a1, "raw"] = Part[
      $CellContext`med[All], All, 12], $CellContext`sym$52667[$CellContext`a2,
       "factorized"] = 
    True, $CellContext`sym$52667[$CellContext`a2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$52667[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$52667[$CellContext`a2, "raw"] = Part[
      $CellContext`med[All], All, 13], $CellContext`sym$52667[$CellContext`a3,
       "factorized"] = 
    True, $CellContext`sym$52667[$CellContext`a3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$52667[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$52667[$CellContext`a3, "raw"] = Part[
      $CellContext`med[All], All, 14], $CellContext`sym$52667[$CellContext`a4,
       "factorized"] = 
    True, $CellContext`sym$52667[$CellContext`a4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$52667[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$52667[$CellContext`a4, "raw"] = Part[
      $CellContext`med[All], All, 15], $CellContext`sym$52667[$CellContext`a5,
       "factorized"] = 
    True, $CellContext`sym$52667[$CellContext`a5, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$52667[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$52667[$CellContext`a5, "raw"] = Part[
      $CellContext`med[All], All, 16], $CellContext`sym$52667[$CellContext`a6,
       "factorized"] = 
    True, $CellContext`sym$52667[$CellContext`a6, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$52667[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$52667[$CellContext`a6, "raw"] = Part[
      $CellContext`med[All], All, 17], $CellContext`sym$52667[$CellContext`a7,
       "factorized"] = 
    True, $CellContext`sym$52667[$CellContext`a7, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$52667[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$52667[$CellContext`a7, "raw"] = Part[
      $CellContext`med[All], All, 18], $CellContext`sym$52667[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$52667[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$52667[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$52667[$CellContext`Chla, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$52667[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$52667[$CellContext`Chla, "raw"] = Part[
      $CellContext`med[All], All, 11], $CellContext`sym$52667[$CellContext`Cl,
       "factorized"] = 
    True, $CellContext`sym$52667[$CellContext`Cl, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$52667[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$52667[$CellContext`Cl, "raw"] = Part[
      $CellContext`med[All], All, 
      6], $CellContext`sym$52667[$CellContext`mnO2, "factorized"] = 
    True, $CellContext`sym$52667[$CellContext`mnO2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$52667[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$52667[$CellContext`mnO2, "raw"] = Part[
      $CellContext`med[All], All, 
      5], $CellContext`sym$52667[$CellContext`mxPH, "factorized"] = 
    True, $CellContext`sym$52667[$CellContext`mxPH, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$52667[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$52667[$CellContext`mxPH, "raw"] = Part[
      $CellContext`med[All], All, 4], $CellContext`sym$52667[$CellContext`NH4,
       "factorized"] = 
    True, $CellContext`sym$52667[$CellContext`NH4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$52667[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$52667[$CellContext`NH4, "raw"] = Part[
      $CellContext`med[All], All, 8], $CellContext`sym$52667[$CellContext`NO3,
       "factorized"] = 
    True, $CellContext`sym$52667[$CellContext`NO3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$52667[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$52667[$CellContext`NO3, "raw"] = Part[
      $CellContext`med[All], All, 
      7], $CellContext`sym$52667[$CellContext`oPO4, "factorized"] = 
    True, $CellContext`sym$52667[$CellContext`oPO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$52667[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$52667[$CellContext`oPO4, "raw"] = Part[
      $CellContext`med[All], All, 9], $CellContext`sym$52667[$CellContext`PO4,
       "factorized"] = 
    True, $CellContext`sym$52667[$CellContext`PO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$52667[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$52667[$CellContext`PO4, "raw"] = Part[
      $CellContext`med[All], All, 
      10], $CellContext`sym$52667[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$52667[$CellContext`season, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$52667[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$52667[$CellContext`season, "raw"] = 
    Part[
      $CellContext`med[All], All, 
      1], $CellContext`sym$52667[$CellContext`size, "factorized"] = 
    True, $CellContext`sym$52667[$CellContext`size, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$52667[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$52667[$CellContext`size, "raw"] = Part[
      $CellContext`med[All], All, 
      2], $CellContext`sym$52667[$CellContext`speed, "factorized"] = 
    True, $CellContext`sym$52667[$CellContext`speed, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$52667[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$52667[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`med[All], All, 3], 
    Attributes[$CellContext`sym$90706] = {
     Temporary}, $CellContext`sym$90706[$CellContext`a1] = Part[
      $CellContext`sym$90706[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$90706[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$90706[$CellContext`a2] = Part[
      $CellContext`sym$90706[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$90706[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$90706[$CellContext`a3] = Part[
      $CellContext`sym$90706[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$90706[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$90706[$CellContext`a4] = Part[
      $CellContext`sym$90706[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$90706[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$90706[$CellContext`a5] = Part[
      $CellContext`sym$90706[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$90706[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$90706[$CellContext`a6] = Part[
      $CellContext`sym$90706[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$90706[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$90706[$CellContext`a7] = Part[
      $CellContext`sym$90706[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$90706[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$90706[All] = $CellContext`med[
     All], $CellContext`sym$90706[$CellContext`Chla] = Part[
      $CellContext`sym$90706[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$90706[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$90706[$CellContext`Cl] = Part[
      $CellContext`sym$90706[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$90706[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$90706[$CellContext`mnO2] = Part[
      $CellContext`sym$90706[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$90706[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$90706[$CellContext`mxPH] = Part[
      $CellContext`sym$90706[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$90706[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$90706[$CellContext`NH4] = Part[
      $CellContext`sym$90706[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$90706[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$90706[$CellContext`NO3] = Part[
      $CellContext`sym$90706[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$90706[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$90706[$CellContext`oPO4] = Part[
      $CellContext`sym$90706[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$90706[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$90706[$CellContext`PO4] = Part[
      $CellContext`sym$90706[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$90706[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$90706[$CellContext`season] = Part[
      $CellContext`sym$90706[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$90706[$CellContext`season, 
         "missing"]]]], $CellContext`sym$90706[$CellContext`size] = Part[
      $CellContext`sym$90706[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$90706[$CellContext`size, 
         "missing"]]]], $CellContext`sym$90706[$CellContext`speed] = Part[
      $CellContext`sym$90706[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$90706[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$90706[$CellContext`a1, "factorized"] = 
    True, $CellContext`sym$90706[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$90706, $CellContext`a1]], \
$CellContext`sym$90706[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$90706[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$90706[All], 
      All, $CellContext`i$92265], $CellContext`sym$90706[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$90706[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$90706, $CellContext`a2]], \
$CellContext`sym$90706[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$90706[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$90706[All], 
      All, $CellContext`i$92266], $CellContext`sym$90706[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$90706[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$90706, $CellContext`a3]], \
$CellContext`sym$90706[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$90706[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$90706[All], 
      All, $CellContext`i$92267], $CellContext`sym$90706[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$90706[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$90706, $CellContext`a4]], \
$CellContext`sym$90706[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$90706[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$90706[All], 
      All, $CellContext`i$92268], $CellContext`sym$90706[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$90706[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$90706, $CellContext`a5]], \
$CellContext`sym$90706[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$90706[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$90706[All], 
      All, $CellContext`i$92269], $CellContext`sym$90706[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$90706[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$90706, $CellContext`a6]], \
$CellContext`sym$90706[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$90706[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$90706[All], 
      All, $CellContext`i$92270], $CellContext`sym$90706[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$90706[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$90706, $CellContext`a7]], \
$CellContext`sym$90706[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$90706[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$90706[All], 
      All, $CellContext`i$92271], $CellContext`sym$90706[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$90706[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$90706[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$90706[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$90706, $CellContext`Chla]], \
$CellContext`sym$90706[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$90706[$CellContext`Chla, "raw"] = Part[
      $CellContext`sym$90706[All], 
      All, $CellContext`i$92264], $CellContext`sym$90706[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$90706[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$90706, $CellContext`Cl]], \
$CellContext`sym$90706[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$90706[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$90706[All], 
      All, $CellContext`i$92259], $CellContext`sym$90706[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$90706[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$90706, $CellContext`mnO2]], \
$CellContext`sym$90706[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$90706[$CellContext`mnO2, "raw"] = Part[
      $CellContext`sym$90706[All], 
      All, $CellContext`i$92258], $CellContext`sym$90706[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$90706[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$90706, $CellContext`mxPH]], \
$CellContext`sym$90706[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$90706[$CellContext`mxPH, "raw"] = Part[
      $CellContext`sym$90706[All], 
      All, $CellContext`i$92257], $CellContext`sym$90706[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$90706[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$90706, $CellContext`NH4]], \
$CellContext`sym$90706[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$90706[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$90706[All], 
      All, $CellContext`i$92261], $CellContext`sym$90706[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$90706[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$90706, $CellContext`NO3]], \
$CellContext`sym$90706[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$90706[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$90706[All], 
      All, $CellContext`i$92260], $CellContext`sym$90706[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$90706[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$90706, $CellContext`oPO4]], \
$CellContext`sym$90706[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$90706[$CellContext`oPO4, "raw"] = Part[
      $CellContext`sym$90706[All], 
      All, $CellContext`i$92262], $CellContext`sym$90706[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$90706[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$90706, $CellContext`PO4]], \
$CellContext`sym$90706[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$90706[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$90706[All], 
      All, $CellContext`i$92263], $CellContext`sym$90706[$CellContext`season, 
      "factorized"] = 
    True, $CellContext`sym$90706[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$90706, $CellContext`season]], \
$CellContext`sym$90706[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$90706[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$90706[All], 
      All, $CellContext`i$90707], $CellContext`sym$90706[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$90706[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$90706, $CellContext`size]], \
$CellContext`sym$90706[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$90706[$CellContext`size, "raw"] = Part[
      $CellContext`sym$90706[All], 
      All, $CellContext`i$92255], $CellContext`sym$90706[$CellContext`speed, 
      "factorized"] = 
    True, $CellContext`sym$90706[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$90706, $CellContext`speed]], \
$CellContext`sym$90706[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$90706[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$90706[All], All, $CellContext`i$92256], 
    Attributes[$CellContext`i$92262] = {Temporary}, $CellContext`i$92262 = 9, 
    Attributes[$CellContext`i$92268] = {Temporary}, $CellContext`i$92268 = 15,
     Attributes[$CellContext`i$92266] = {Temporary}, $CellContext`i$92266 = 
    13, Attributes[$CellContext`i$92258] = {Temporary}, $CellContext`i$92258 = 
    5, Attributes[$CellContext`i$92257] = {Temporary}, $CellContext`i$92257 = 
    4, Attributes[$CellContext`i$92255] = {Temporary}, $CellContext`i$92255 = 
    2, Attributes[$CellContext`i$92263] = {Temporary}, $CellContext`i$92263 = 
    10, Attributes[$CellContext`i$92265] = {Temporary}, $CellContext`i$92265 = 
    12, Attributes[$CellContext`i$92264] = {Temporary}, $CellContext`i$92264 = 
    11, Attributes[$CellContext`i$92261] = {Temporary}, $CellContext`i$92261 = 
    8, Attributes[$CellContext`i$92260] = {Temporary}, $CellContext`i$92260 = 
    7, Attributes[$CellContext`i$90707] = {Temporary}, $CellContext`i$90707 = 
    1, Attributes[$CellContext`i$92267] = {Temporary}, $CellContext`i$92267 = 
    14, Attributes[$CellContext`i$92259] = {Temporary}, $CellContext`i$92259 = 
    6, Attributes[$CellContext`i$92271] = {Temporary}, $CellContext`i$92271 = 
    18, Attributes[$CellContext`i$92269] = {Temporary}, $CellContext`i$92269 = 
    16, Attributes[$CellContext`i$92270] = {Temporary}, $CellContext`i$92270 = 
    17, Attributes[$CellContext`i$92256] = {Temporary}, $CellContext`i$92256 = 
    3, Attributes[$CellContext`sym$88473] = {
     Temporary}, $CellContext`sym$88473[$CellContext`a1] = Part[
      $CellContext`sym$88473[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$88473[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$88473[$CellContext`a2] = Part[
      $CellContext`sym$88473[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$88473[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$88473[$CellContext`a3] = Part[
      $CellContext`sym$88473[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$88473[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$88473[$CellContext`a4] = Part[
      $CellContext`sym$88473[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$88473[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$88473[$CellContext`a5] = Part[
      $CellContext`sym$88473[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$88473[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$88473[$CellContext`a6] = Part[
      $CellContext`sym$88473[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$88473[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$88473[$CellContext`a7] = Part[
      $CellContext`sym$88473[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$88473[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$88473[All] = $CellContext`med[
     All], $CellContext`sym$88473[$CellContext`Chla] = Part[
      $CellContext`sym$88473[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$88473[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$88473[$CellContext`Cl] = Part[
      $CellContext`sym$88473[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$88473[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$88473[$CellContext`mnO2] = Part[
      $CellContext`sym$88473[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$88473[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$88473[$CellContext`mxPH] = Part[
      $CellContext`sym$88473[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$88473[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$88473[$CellContext`NH4] = Part[
      $CellContext`sym$88473[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$88473[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$88473[$CellContext`NO3] = Part[
      $CellContext`sym$88473[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$88473[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$88473[$CellContext`oPO4] = Part[
      $CellContext`sym$88473[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$88473[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$88473[$CellContext`PO4] = Part[
      $CellContext`sym$88473[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$88473[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$88473[$CellContext`season] = Part[
      $CellContext`sym$88473[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$88473[$CellContext`season, 
         "missing"]]]], $CellContext`sym$88473[$CellContext`size] = Part[
      $CellContext`sym$88473[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$88473[$CellContext`size, 
         "missing"]]]], $CellContext`sym$88473[$CellContext`speed] = Part[
      $CellContext`sym$88473[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$88473[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$88473[$CellContext`a1, "factorized"] = 
    True, $CellContext`sym$88473[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$88473, $CellContext`a1]], \
$CellContext`sym$88473[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$88473[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$88473[All], 
      All, $CellContext`i$90032], $CellContext`sym$88473[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$88473[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$88473, $CellContext`a2]], \
$CellContext`sym$88473[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$88473[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$88473[All], 
      All, $CellContext`i$90033], $CellContext`sym$88473[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$88473[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$88473, $CellContext`a3]], \
$CellContext`sym$88473[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$88473[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$88473[All], 
      All, $CellContext`i$90034], $CellContext`sym$88473[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$88473[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$88473, $CellContext`a4]], \
$CellContext`sym$88473[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$88473[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$88473[All], 
      All, $CellContext`i$90035], $CellContext`sym$88473[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$88473[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$88473, $CellContext`a5]], \
$CellContext`sym$88473[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$88473[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$88473[All], 
      All, $CellContext`i$90036], $CellContext`sym$88473[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$88473[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$88473, $CellContext`a6]], \
$CellContext`sym$88473[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$88473[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$88473[All], 
      All, $CellContext`i$90037], $CellContext`sym$88473[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$88473[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$88473, $CellContext`a7]], \
$CellContext`sym$88473[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$88473[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$88473[All], 
      All, $CellContext`i$90038], $CellContext`sym$88473[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$88473[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$88473[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$88473[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$88473, $CellContext`Chla]], \
$CellContext`sym$88473[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$88473[$CellContext`Chla, "raw"] = Part[
      $CellContext`sym$88473[All], 
      All, $CellContext`i$90031], $CellContext`sym$88473[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$88473[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$88473, $CellContext`Cl]], \
$CellContext`sym$88473[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$88473[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$88473[All], 
      All, $CellContext`i$90026], $CellContext`sym$88473[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$88473[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$88473, $CellContext`mnO2]], \
$CellContext`sym$88473[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$88473[$CellContext`mnO2, "raw"] = Part[
      $CellContext`sym$88473[All], 
      All, $CellContext`i$90025], $CellContext`sym$88473[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$88473[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$88473, $CellContext`mxPH]], \
$CellContext`sym$88473[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$88473[$CellContext`mxPH, "raw"] = Part[
      $CellContext`sym$88473[All], 
      All, $CellContext`i$90024], $CellContext`sym$88473[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$88473[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$88473, $CellContext`NH4]], \
$CellContext`sym$88473[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$88473[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$88473[All], 
      All, $CellContext`i$90028], $CellContext`sym$88473[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$88473[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$88473, $CellContext`NO3]], \
$CellContext`sym$88473[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$88473[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$88473[All], 
      All, $CellContext`i$90027], $CellContext`sym$88473[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$88473[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$88473, $CellContext`oPO4]], \
$CellContext`sym$88473[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$88473[$CellContext`oPO4, "raw"] = Part[
      $CellContext`sym$88473[All], 
      All, $CellContext`i$90029], $CellContext`sym$88473[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$88473[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$88473, $CellContext`PO4]], \
$CellContext`sym$88473[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$88473[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$88473[All], 
      All, $CellContext`i$90030], $CellContext`sym$88473[$CellContext`season, 
      "factorized"] = 
    True, $CellContext`sym$88473[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$88473, $CellContext`season]], \
$CellContext`sym$88473[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$88473[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$88473[All], 
      All, $CellContext`i$88474], $CellContext`sym$88473[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$88473[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$88473, $CellContext`size]], \
$CellContext`sym$88473[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$88473[$CellContext`size, "raw"] = Part[
      $CellContext`sym$88473[All], 
      All, $CellContext`i$90022], $CellContext`sym$88473[$CellContext`speed, 
      "factorized"] = 
    True, $CellContext`sym$88473[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$88473, $CellContext`speed]], \
$CellContext`sym$88473[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$88473[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$88473[All], All, $CellContext`i$90023], 
    Attributes[$CellContext`i$90023] = {Temporary}, $CellContext`i$90023 = 3, 
    Attributes[$CellContext`i$90022] = {Temporary}, $CellContext`i$90022 = 2, 
    Attributes[$CellContext`i$90034] = {Temporary}, $CellContext`i$90034 = 14,
     Attributes[$CellContext`i$90038] = {Temporary}, $CellContext`i$90038 = 
    18, Attributes[$CellContext`i$90030] = {Temporary}, $CellContext`i$90030 = 
    10, Attributes[$CellContext`i$90028] = {Temporary}, $CellContext`i$90028 = 
    8, Attributes[$CellContext`i$90025] = {Temporary}, $CellContext`i$90025 = 
    5, Attributes[$CellContext`i$88474] = {Temporary}, $CellContext`i$88474 = 
    1, Attributes[$CellContext`i$90026] = {Temporary}, $CellContext`i$90026 = 
    6, Attributes[$CellContext`i$90031] = {Temporary}, $CellContext`i$90031 = 
    11, Attributes[$CellContext`i$90037] = {Temporary}, $CellContext`i$90037 = 
    17, Attributes[$CellContext`i$90036] = {Temporary}, $CellContext`i$90036 = 
    16, Attributes[$CellContext`i$90032] = {Temporary}, $CellContext`i$90032 = 
    12, Attributes[$CellContext`i$90024] = {Temporary}, $CellContext`i$90024 = 
    4, Attributes[$CellContext`i$90029] = {Temporary}, $CellContext`i$90029 = 
    9, Attributes[$CellContext`i$90035] = {Temporary}, $CellContext`i$90035 = 
    15, Attributes[$CellContext`i$90027] = {Temporary}, $CellContext`i$90027 = 
    7, Attributes[$CellContext`i$90033] = {Temporary}, $CellContext`i$90033 = 
    13, Attributes[$CellContext`sym$77278] = {
     Temporary}, $CellContext`sym$77278[$CellContext`a1] = Part[
      $CellContext`sym$77278[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$77278[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$77278[$CellContext`a2] = Part[
      $CellContext`sym$77278[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$77278[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$77278[$CellContext`a3] = Part[
      $CellContext`sym$77278[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$77278[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$77278[$CellContext`a4] = Part[
      $CellContext`sym$77278[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$77278[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$77278[$CellContext`a5] = Part[
      $CellContext`sym$77278[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$77278[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$77278[$CellContext`a6] = Part[
      $CellContext`sym$77278[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$77278[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$77278[$CellContext`a7] = Part[
      $CellContext`sym$77278[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$77278[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$77278[All] = $CellContext`med[
     All], $CellContext`sym$77278[$CellContext`Chla] = Part[
      $CellContext`sym$77278[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$77278[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$77278[$CellContext`Cl] = Part[
      $CellContext`sym$77278[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$77278[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$77278[$CellContext`mnO2] = Part[
      $CellContext`sym$77278[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$77278[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$77278[$CellContext`mxPH] = Part[
      $CellContext`sym$77278[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$77278[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$77278[$CellContext`NH4] = Part[
      $CellContext`sym$77278[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$77278[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$77278[$CellContext`NO3] = Part[
      $CellContext`sym$77278[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$77278[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$77278[$CellContext`oPO4] = Part[
      $CellContext`sym$77278[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$77278[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$77278[$CellContext`PO4] = Part[
      $CellContext`sym$77278[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$77278[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$77278[$CellContext`season] = Part[
      $CellContext`sym$77278[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$77278[$CellContext`season, 
         "missing"]]]], $CellContext`sym$77278[$CellContext`size] = Part[
      $CellContext`sym$77278[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$77278[$CellContext`size, 
         "missing"]]]], $CellContext`sym$77278[$CellContext`speed] = Part[
      $CellContext`sym$77278[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$77278[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$77278[$CellContext`a1, "factorized"] = 
    True, $CellContext`sym$77278[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$77278, $CellContext`a1]], \
$CellContext`sym$77278[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$77278[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$77278[All], 
      All, $CellContext`i$78837], $CellContext`sym$77278[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$77278[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$77278, $CellContext`a2]], \
$CellContext`sym$77278[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$77278[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$77278[All], 
      All, $CellContext`i$78838], $CellContext`sym$77278[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$77278[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$77278, $CellContext`a3]], \
$CellContext`sym$77278[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$77278[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$77278[All], 
      All, $CellContext`i$78839], $CellContext`sym$77278[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$77278[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$77278, $CellContext`a4]], \
$CellContext`sym$77278[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$77278[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$77278[All], 
      All, $CellContext`i$78840], $CellContext`sym$77278[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$77278[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$77278, $CellContext`a5]], \
$CellContext`sym$77278[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$77278[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$77278[All], 
      All, $CellContext`i$78841], $CellContext`sym$77278[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$77278[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$77278, $CellContext`a6]], \
$CellContext`sym$77278[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$77278[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$77278[All], 
      All, $CellContext`i$78842], $CellContext`sym$77278[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$77278[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$77278, $CellContext`a7]], \
$CellContext`sym$77278[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$77278[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$77278[All], 
      All, $CellContext`i$78843], $CellContext`sym$77278[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$77278[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$77278[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$77278[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$77278, $CellContext`Chla]], \
$CellContext`sym$77278[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$77278[$CellContext`Chla, "raw"] = Part[
      $CellContext`sym$77278[All], 
      All, $CellContext`i$78836], $CellContext`sym$77278[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$77278[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$77278, $CellContext`Cl]], \
$CellContext`sym$77278[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$77278[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$77278[All], 
      All, $CellContext`i$78831], $CellContext`sym$77278[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$77278[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$77278, $CellContext`mnO2]], \
$CellContext`sym$77278[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$77278[$CellContext`mnO2, "raw"] = Part[
      $CellContext`sym$77278[All], 
      All, $CellContext`i$78830], $CellContext`sym$77278[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$77278[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$77278, $CellContext`mxPH]], \
$CellContext`sym$77278[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$77278[$CellContext`mxPH, "raw"] = Part[
      $CellContext`sym$77278[All], 
      All, $CellContext`i$78829], $CellContext`sym$77278[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$77278[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$77278, $CellContext`NH4]], \
$CellContext`sym$77278[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$77278[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$77278[All], 
      All, $CellContext`i$78833], $CellContext`sym$77278[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$77278[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$77278, $CellContext`NO3]], \
$CellContext`sym$77278[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$77278[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$77278[All], 
      All, $CellContext`i$78832], $CellContext`sym$77278[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$77278[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$77278, $CellContext`oPO4]], \
$CellContext`sym$77278[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$77278[$CellContext`oPO4, "raw"] = Part[
      $CellContext`sym$77278[All], 
      All, $CellContext`i$78834], $CellContext`sym$77278[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$77278[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$77278, $CellContext`PO4]], \
$CellContext`sym$77278[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$77278[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$77278[All], 
      All, $CellContext`i$78835], $CellContext`sym$77278[$CellContext`season, 
      "factorized"] = 
    True, $CellContext`sym$77278[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$77278, $CellContext`season]], \
$CellContext`sym$77278[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$77278[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$77278[All], 
      All, $CellContext`i$77279], $CellContext`sym$77278[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$77278[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$77278, $CellContext`size]], \
$CellContext`sym$77278[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$77278[$CellContext`size, "raw"] = Part[
      $CellContext`sym$77278[All], 
      All, $CellContext`i$78827], $CellContext`sym$77278[$CellContext`speed, 
      "factorized"] = 
    True, $CellContext`sym$77278[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$77278, $CellContext`speed]], \
$CellContext`sym$77278[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$77278[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$77278[All], All, $CellContext`i$78828], 
    Attributes[$CellContext`i$78838] = {Temporary}, $CellContext`i$78838 = 13,
     Attributes[$CellContext`i$78829] = {Temporary}, $CellContext`i$78829 = 4,
     Attributes[$CellContext`i$78843] = {Temporary}, $CellContext`i$78843 = 
    18, Attributes[$CellContext`i$78835] = {Temporary}, $CellContext`i$78835 = 
    10, Attributes[$CellContext`i$78832] = {Temporary}, $CellContext`i$78832 = 
    7, Attributes[$CellContext`i$78840] = {Temporary}, $CellContext`i$78840 = 
    15, Attributes[$CellContext`i$78834] = {Temporary}, $CellContext`i$78834 = 
    9, Attributes[$CellContext`i$78842] = {Temporary}, $CellContext`i$78842 = 
    17, Attributes[$CellContext`i$78833] = {Temporary}, $CellContext`i$78833 = 
    8, Attributes[$CellContext`i$78837] = {Temporary}, $CellContext`i$78837 = 
    12, Attributes[$CellContext`i$78836] = {Temporary}, $CellContext`i$78836 = 
    11, Attributes[$CellContext`i$78841] = {Temporary}, $CellContext`i$78841 = 
    16, Attributes[$CellContext`i$78839] = {Temporary}, $CellContext`i$78839 = 
    14, Attributes[$CellContext`i$78828] = {Temporary}, $CellContext`i$78828 = 
    3, Attributes[$CellContext`i$78830] = {Temporary}, $CellContext`i$78830 = 
    5, Attributes[$CellContext`i$78831] = {Temporary}, $CellContext`i$78831 = 
    6, Attributes[$CellContext`i$77279] = {Temporary}, $CellContext`i$77279 = 
    1, Attributes[$CellContext`i$78827] = {Temporary}, $CellContext`i$78827 = 
    2, Attributes[$CellContext`sym$232973] = {
     Temporary}, $CellContext`sym$232973[$CellContext`a1] = Part[
      $CellContext`sym$232973[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232973[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$232973[$CellContext`a2] = Part[
      $CellContext`sym$232973[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232973[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$232973[$CellContext`a3] = Part[
      $CellContext`sym$232973[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232973[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$232973[$CellContext`a4] = Part[
      $CellContext`sym$232973[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232973[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$232973[$CellContext`a5] = Part[
      $CellContext`sym$232973[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232973[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$232973[$CellContext`a6] = Part[
      $CellContext`sym$232973[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232973[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$232973[$CellContext`a7] = Part[
      $CellContext`sym$232973[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232973[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$232973[
     All] = {{"winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 
       170., 50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
      "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
       558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
      "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 125.667,
        187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
      "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 61.182, 
       138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
      "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222, 
       97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
      "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
       56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
      "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
       111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
      "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 44.667, 
       77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
      "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 71., 
       5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 0.8, 
       17., 0., 0., 2.9, 0., 0., 1.7}, {
      "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 20.75, 
       0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
      "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 19.,
        0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
      "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 41., 
       43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
      "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5, 
       31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
      "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 0.3, 
       52.2, 5., 7.8, 0., 4., 0., 0.}, {
      "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 98.25, 
       1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50., 
       1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
      "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 57.833, 
       0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
      "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 0.8, 
       50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
      "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
       564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
      "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 586.,
        16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
      "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 0.5, 
       15.5, 0., 0., 2.3, 0., 0., 0.}, {
      "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 7.6,
        23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
      "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
       27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
      "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 1.5,
        13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
      "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 44.136, 
       3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
      "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 0.5, 
       29.7, 0., 0., 4.9, 0., 0., 0.}, {
      "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
       Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
      "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 17.1,
        0., 19.6, 0., 0., 0., 2.5}, {
      "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5, 
       33.9, 1., 14.6, 0., 0., 0., 0.}, {
      "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 4.9, 
       3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
      "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 2.8, 
       6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
      "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 130.75, 
       5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
      "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47., 
       2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
      "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23., 
       0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
      "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 58.875, 
       84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
      "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 0.2,
        66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
       Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0., 
       0.}, {
      "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 196.62, 
       253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
      "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
       182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
      "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001, 
       296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
      "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 59.429,
        175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
      "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
       344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
      "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 276.85001, 
       326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
      "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 40.667, 
       3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
      "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 3.3, 
       29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
      "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 0.8, 
       54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
       Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 0., 
       0.}, {"spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121.,
        2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 20.812,
        12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
      "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
       49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
      "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 22.9, 
       4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
      "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 11.8, 
       0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818, 
       0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
      "winter", "small", "high", 6.6, 10.8, 
       Missing[], 3.245, 10., 1., 6.5, 
       Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "medium", 5.6, 11.8, 
       Missing[], 2.22, 5., 1., 1., 
       Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 5.7, 10.8, 
       Missing[], 2.55, 10., 1., 4., 
       Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
      "spring", "small", "high", 6.6, 9.5, 
       Missing[], 1.32, 20., 1., 6., 
       Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
      "summer", "small", "high", 6.6, 10.8, 
       Missing[], 2.64, 10., 2., 11., 
       Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
      "autumn", "small", "medium", 6.6, 11.3, 
       Missing[], 4.17, 10., 1., 6., 
       Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
      "spring", "small", "medium", 6.5, 10.4, 
       Missing[], 5.97, 10., 2., 14., 
       Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
      "summer", "small", "medium", 6.4, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 14., 
       Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
      "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 6.667, 
       Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75, 1.,
        20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
      "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2, 
       0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
      "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 0.6,
        55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
      "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 10.75, 
       2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
      "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 0.5, 
       64.2, 0., 3., 0., 0., 0., 0.}, {
      "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75, 
       351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
      "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
       209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
      "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 151.125,
        279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
      "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
       152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
      "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
       58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
      "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
       249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
      "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 100., 
       233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
      "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 215.5, 
       18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
      "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 25.167, 
       102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
      "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
       105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
      "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
       111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
      "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 1.3, 
       6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
      "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 56.667, 
       2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
      "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 4.3,
        1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
      "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
       104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
      "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 69.93,
        3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
      "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
       214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
      "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
       254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
      "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 57.6,
        169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
      "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
       412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
      "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
       282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
      "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
       197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
      "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 267.75, 
       391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
      "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 191.75, 
       265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
      "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
       232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
      "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 144.66701, 
       244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
      "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 218., 
       6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
      "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 138.5,
        20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
      "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222, 
       239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
      "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
       235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
      "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75, 
       205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
      "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 31.333, 
       211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
      "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625, 
       186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
      "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 12.889, 
       154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
      "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 51.111, 
       183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
      "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
       292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
      "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
       285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
      "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
       201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
      "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
       275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
      "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
       124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
      "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 60.833, 
       141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
      "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71., 
       132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
      "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
       17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
      "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 0.3, 
       46.6, 0., 2.5, 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 8.692, 
       16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
      "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 37.857, 
       102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
      "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
       86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
      "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
       10.111, 
       Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 16.833, 
       18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
      "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545, 
       13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
      "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 261.60001, 
       432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
      "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
       320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
      "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 144., 
       287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
      "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
       166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
      "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
       222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
      "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 36.909, 
       122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
      "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556, 
       127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
      "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
       89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
      "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 55., 
       284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
      "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 102.333, 
       277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
      "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 75.875, 
       177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
      "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
       72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
      "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 48.667, 
       82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
      "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 48.625, 
       66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
      "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 23., 
       173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
      "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 317., 
       5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
      "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 84., 
       4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
      "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 2., 
       10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
      "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 88.5, 
       2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
      "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115., 
       11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
      "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 98.143, 
       2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
      "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
       143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
      "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
       197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
      "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 1., 
       19., 0., 22., 5., 1.1, 5.4, 0.}, {
      "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 10.583, 
       23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
      "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 200.231, 
       19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
      "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 77.333, 
       147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
      "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5, 
       276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
      "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
       123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
      "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 75.207,
        23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
      "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 116.2,
        7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
      "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
       188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
      "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
       72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
      "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 16., 
       0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
      "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 34., 
       53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
      "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 27.5, 
       76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
      "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
       58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
      "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 175.66701, 
       361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
      "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
       22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
      "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 26.8,
        0., 28., 0., 0., 0., 0., 15.1}, {
      "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
       54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
      "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333, 
       34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
      "spring", "large", "low", 9., 5.8, 
       Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 0., 
       0.}, {"spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
       151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
      "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
       269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
      "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 46.438, 
       81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
      "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 85., 
       2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
      "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 66.4, 
       171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
      "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 102.364, 
       232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
      "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 84.3, 
       146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
      "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
       246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
      "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 205.636, 
       219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
      "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 236.39999,
        272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
      "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 1081.66003, 
       346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 5.9, 1.7}, {
      "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 82.222,
        167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
      "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 64.389, 
       137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
      "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 87.333,
        194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
      "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
       159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
      "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 21.3, 
       1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
      "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 0.6,
        37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
      "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
       14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
      "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222, 7.,
        1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 0.8, 
       50.4, 3.8, 0., 0., 0., 0., 0.}, {
      "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 7.654, 
       4., 56.8, 5., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 2.86, 
       17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
      "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 56.091, 
       Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
      "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
       52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
      "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 104.727, 
       228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
      "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 85.4, 
       17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
      "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 87.125,
        14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
      "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 101.455, 
       18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
      "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 50.889, 
       127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
      "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
       81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
      "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 19.727, 
       50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
      "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111, 
       120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
      "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 51.111, 
       91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
      "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 19.111, 
       61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
      "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625, 
       79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
      "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333, 
       75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
      "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333, 
       140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
      "winter", "large", "medium", 8., 7.6, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
      "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
       140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 
       5.8}}, $CellContext`sym$232973[$CellContext`Chla] = Part[
      $CellContext`sym$232973[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232973[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$232973[$CellContext`Cl] = Part[
      $CellContext`sym$232973[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232973[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$232973[$CellContext`mnO2] = Part[
      $CellContext`sym$232973[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232973[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$232973[$CellContext`mxPH] = Part[
      $CellContext`sym$232973[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232973[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$232973[$CellContext`NH4] = Part[
      $CellContext`sym$232973[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232973[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$232973[$CellContext`NO3] = Part[
      $CellContext`sym$232973[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232973[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$232973[$CellContext`oPO4] = Part[
      $CellContext`sym$232973[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232973[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$232973[$CellContext`PO4] = Part[
      $CellContext`sym$232973[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232973[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$232973[$CellContext`season] = Part[
      $CellContext`sym$232973[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232973[$CellContext`season, 
         "missing"]]]], $CellContext`sym$232973[$CellContext`size] = Part[
      $CellContext`sym$232973[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232973[$CellContext`size, 
         "missing"]]]], $CellContext`sym$232973[$CellContext`speed] = Part[
      $CellContext`sym$232973[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232973[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$232973[$CellContext`a1, 
      "factorized"] = 
    False, $CellContext`sym$232973[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$232973[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$232973[All], 
      All, $CellContext`i$232985], $CellContext`sym$232973[$CellContext`a2, 
      "factorized"] = 
    False, $CellContext`sym$232973[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$232973[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$232973[All], 
      All, $CellContext`i$232986], $CellContext`sym$232973[$CellContext`a3, 
      "factorized"] = 
    False, $CellContext`sym$232973[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$232973[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$232973[All], 
      All, $CellContext`i$232987], $CellContext`sym$232973[$CellContext`a4, 
      "factorized"] = 
    False, $CellContext`sym$232973[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$232973[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$232973[All], 
      All, $CellContext`i$232988], $CellContext`sym$232973[$CellContext`a5, 
      "factorized"] = 
    False, $CellContext`sym$232973[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$232973[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$232973[All], 
      All, $CellContext`i$232989], $CellContext`sym$232973[$CellContext`a6, 
      "factorized"] = 
    False, $CellContext`sym$232973[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$232973[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$232973[All], 
      All, $CellContext`i$232990], $CellContext`sym$232973[$CellContext`a7, 
      "factorized"] = 
    False, $CellContext`sym$232973[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$232973[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$232973[All], 
      All, $CellContext`i$232991], $CellContext`sym$232973[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$232973[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed}, $CellContext`sym$232973[$CellContext`Chla, "factorized"] = 
    False, $CellContext`sym$232973[$CellContext`Chla, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {63}, {116}, {184}, {
     199}}, $CellContext`sym$232973[$CellContext`Chla, "raw"] = Part[
      $CellContext`sym$232973[All], 
      All, $CellContext`i$232984], $CellContext`sym$232973[$CellContext`Cl, 
      "factorized"] = 
    False, $CellContext`sym$232973[$CellContext`Cl, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {161}, {
     199}}, $CellContext`sym$232973[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$232973[All], 
      All, $CellContext`i$232979], $CellContext`sym$232973[$CellContext`mnO2, 
      "factorized"] = 
    False, $CellContext`sym$232973[$CellContext`mnO2, "missing"] = {{38}, {
     62}}, $CellContext`sym$232973[$CellContext`mnO2, "raw"] = Part[
      $CellContext`sym$232973[All], 
      All, $CellContext`i$232978], $CellContext`sym$232973[$CellContext`mxPH, 
      "factorized"] = 
    False, $CellContext`sym$232973[$CellContext`mxPH, "missing"] = {{
     48}}, $CellContext`sym$232973[$CellContext`mxPH, "raw"] = Part[
      $CellContext`sym$232973[All], 
      All, $CellContext`i$232977], $CellContext`sym$232973[$CellContext`NH4, 
      "factorized"] = 
    False, $CellContext`sym$232973[$CellContext`NH4, "missing"] = {{62}, {
     199}}, $CellContext`sym$232973[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$232973[All], 
      All, $CellContext`i$232981], $CellContext`sym$232973[$CellContext`NO3, 
      "factorized"] = 
    False, $CellContext`sym$232973[$CellContext`NO3, "missing"] = {{62}, {
     199}}, $CellContext`sym$232973[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$232973[All], 
      All, $CellContext`i$232980], $CellContext`sym$232973[$CellContext`oPO4, 
      "factorized"] = 
    False, $CellContext`sym$232973[$CellContext`oPO4, "missing"] = {{62}, {
     199}}, $CellContext`sym$232973[$CellContext`oPO4, "raw"] = Part[
      $CellContext`sym$232973[All], 
      All, $CellContext`i$232982], $CellContext`sym$232973[$CellContext`PO4, 
      "factorized"] = 
    False, $CellContext`sym$232973[$CellContext`PO4, "missing"] = {{28}, {
     199}}, $CellContext`sym$232973[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$232973[All], 
      All, $CellContext`i$232983], \
$CellContext`sym$232973[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$232973[$CellContext`season, "factors"] = 
    Part[{"autumn", "spring", "summer", "winter"}, 
      $CellContext`fordering[$CellContext`sym$232973, $CellContext`season]], \
$CellContext`sym$232973[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$232973[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$232973[All], 
      All, $CellContext`i$232974], $CellContext`sym$232973[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$232973[$CellContext`size, "factors"] = 
    Part[{"large", "medium", "small"}, 
      $CellContext`fordering[$CellContext`sym$232973, $CellContext`size]], \
$CellContext`sym$232973[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$232973[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$232973[All], 
      All, $CellContext`i$232975], $CellContext`sym$232973[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$232973[$CellContext`speed, "factors"] = 
    Part[{"high", "low", "medium"}, 
      $CellContext`fordering[$CellContext`sym$232973, $CellContext`speed]], \
$CellContext`sym$232973[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$232973[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$232973[All], All, $CellContext`i$232976], 
    Attributes[$CellContext`i$232989] = {Temporary}, $CellContext`i$232989 = 
    16, Attributes[$CellContext`i$232981] = {
     Temporary}, $CellContext`i$232981 = 8, 
    Attributes[$CellContext`i$232976] = {Temporary}, $CellContext`i$232976 = 
    3, Attributes[$CellContext`i$232974] = {Temporary}, $CellContext`i$232974 = 
    1, Attributes[$CellContext`i$232987] = {Temporary}, $CellContext`i$232987 = 
    14, Attributes[$CellContext`i$232977] = {
     Temporary}, $CellContext`i$232977 = 4, 
    Attributes[$CellContext`i$232979] = {Temporary}, $CellContext`i$232979 = 
    6, Attributes[$CellContext`i$232980] = {Temporary}, $CellContext`i$232980 = 
    7, Attributes[$CellContext`i$232985] = {Temporary}, $CellContext`i$232985 = 
    12, Attributes[$CellContext`i$232983] = {
     Temporary}, $CellContext`i$232983 = 10, 
    Attributes[$CellContext`i$232984] = {Temporary}, $CellContext`i$232984 = 
    11, Attributes[$CellContext`i$232988] = {
     Temporary}, $CellContext`i$232988 = 15, 
    Attributes[$CellContext`i$232975] = {Temporary}, $CellContext`i$232975 = 
    2, Attributes[$CellContext`i$232991] = {Temporary}, $CellContext`i$232991 = 
    18, Attributes[$CellContext`i$232990] = {
     Temporary}, $CellContext`i$232990 = 17, 
    Attributes[$CellContext`i$232978] = {Temporary}, $CellContext`i$232978 = 
    5, Attributes[$CellContext`i$232986] = {Temporary}, $CellContext`i$232986 = 
    13, Attributes[$CellContext`i$232982] = {
     Temporary}, $CellContext`i$232982 = 9, 
    Attributes[$CellContext`sym$222453] = {
     Temporary}, $CellContext`sym$222453[$CellContext`a1] = Part[
      $CellContext`sym$222453[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$222453[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$222453[$CellContext`a2] = Part[
      $CellContext`sym$222453[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$222453[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$222453[$CellContext`a3] = Part[
      $CellContext`sym$222453[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$222453[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$222453[$CellContext`a4] = Part[
      $CellContext`sym$222453[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$222453[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$222453[$CellContext`a5] = Part[
      $CellContext`sym$222453[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$222453[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$222453[$CellContext`a6] = Part[
      $CellContext`sym$222453[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$222453[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$222453[$CellContext`a7] = Part[
      $CellContext`sym$222453[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$222453[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$222453[All] = $CellContext`med[
     All], $CellContext`sym$222453[$CellContext`Chla] = Part[
      $CellContext`sym$222453[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$222453[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$222453[$CellContext`Cl] = Part[
      $CellContext`sym$222453[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$222453[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$222453[$CellContext`mnO2] = Part[
      $CellContext`sym$222453[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$222453[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$222453[$CellContext`mxPH] = Part[
      $CellContext`sym$222453[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$222453[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$222453[$CellContext`NH4] = Part[
      $CellContext`sym$222453[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$222453[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$222453[$CellContext`NO3] = Part[
      $CellContext`sym$222453[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$222453[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$222453[$CellContext`oPO4] = Part[
      $CellContext`sym$222453[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$222453[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$222453[$CellContext`PO4] = Part[
      $CellContext`sym$222453[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$222453[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$222453[$CellContext`season] = Part[
      $CellContext`sym$222453[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$222453[$CellContext`season, 
         "missing"]]]], $CellContext`sym$222453[$CellContext`size] = Part[
      $CellContext`sym$222453[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$222453[$CellContext`size, 
         "missing"]]]], $CellContext`sym$222453[$CellContext`speed] = Part[
      $CellContext`sym$222453[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$222453[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$222453[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$222453[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$222453, $CellContext`a1]], \
$CellContext`sym$222453[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$222453[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$222453[All], 
      All, $CellContext`i$224012], $CellContext`sym$222453[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$222453[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$222453, $CellContext`a2]], \
$CellContext`sym$222453[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$222453[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$222453[All], 
      All, $CellContext`i$224013], $CellContext`sym$222453[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$222453[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$222453, $CellContext`a3]], \
$CellContext`sym$222453[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$222453[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$222453[All], 
      All, $CellContext`i$224014], $CellContext`sym$222453[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$222453[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$222453, $CellContext`a4]], \
$CellContext`sym$222453[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$222453[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$222453[All], 
      All, $CellContext`i$224015], $CellContext`sym$222453[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$222453[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$222453, $CellContext`a5]], \
$CellContext`sym$222453[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$222453[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$222453[All], 
      All, $CellContext`i$224016], $CellContext`sym$222453[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$222453[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$222453, $CellContext`a6]], \
$CellContext`sym$222453[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$222453[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$222453[All], 
      All, $CellContext`i$224017], $CellContext`sym$222453[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$222453[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$222453, $CellContext`a7]], \
$CellContext`sym$222453[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$222453[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$222453[All], 
      All, $CellContext`i$224018], $CellContext`sym$222453[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$222453[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$222453[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$222453[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$222453, $CellContext`Chla]], \
$CellContext`sym$222453[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$222453[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$222453[All], 
      All, $CellContext`i$224011], $CellContext`sym$222453[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$222453[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$222453, $CellContext`Cl]], \
$CellContext`sym$222453[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$222453[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$222453[All], 
      All, $CellContext`i$224006], $CellContext`sym$222453[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$222453[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$222453, $CellContext`mnO2]], \
$CellContext`sym$222453[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$222453[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$222453[All], 
      All, $CellContext`i$224005], $CellContext`sym$222453[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$222453[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$222453, $CellContext`mxPH]], \
$CellContext`sym$222453[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$222453[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$222453[All], 
      All, $CellContext`i$224004], $CellContext`sym$222453[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$222453[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$222453, $CellContext`NH4]], \
$CellContext`sym$222453[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$222453[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$222453[All], 
      All, $CellContext`i$224008], $CellContext`sym$222453[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$222453[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$222453, $CellContext`NO3]], \
$CellContext`sym$222453[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$222453[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$222453[All], 
      All, $CellContext`i$224007], $CellContext`sym$222453[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$222453[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$222453, $CellContext`oPO4]], \
$CellContext`sym$222453[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$222453[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$222453[All], 
      All, $CellContext`i$224009], $CellContext`sym$222453[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$222453[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$222453, $CellContext`PO4]], \
$CellContext`sym$222453[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$222453[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$222453[All], 
      All, $CellContext`i$224010], \
$CellContext`sym$222453[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$222453[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$222453, $CellContext`season]], \
$CellContext`sym$222453[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$222453[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$222453[All], 
      All, $CellContext`i$222454], $CellContext`sym$222453[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$222453[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$222453, $CellContext`size]], \
$CellContext`sym$222453[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$222453[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$222453[All], 
      All, $CellContext`i$224002], $CellContext`sym$222453[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$222453[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$222453, $CellContext`speed]], \
$CellContext`sym$222453[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$222453[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$222453[All], All, $CellContext`i$224003], 
    Attributes[$CellContext`i$224006] = {Temporary}, $CellContext`i$224006 = 
    6, Attributes[$CellContext`i$224009] = {Temporary}, $CellContext`i$224009 = 
    9, Attributes[$CellContext`i$224013] = {Temporary}, $CellContext`i$224013 = 
    13, Attributes[$CellContext`i$224012] = {
     Temporary}, $CellContext`i$224012 = 12, 
    Attributes[$CellContext`i$224014] = {Temporary}, $CellContext`i$224014 = 
    14, Attributes[$CellContext`i$224008] = {
     Temporary}, $CellContext`i$224008 = 8, 
    Attributes[$CellContext`i$224017] = {Temporary}, $CellContext`i$224017 = 
    17, Attributes[$CellContext`i$224004] = {
     Temporary}, $CellContext`i$224004 = 4, 
    Attributes[$CellContext`i$224018] = {Temporary}, $CellContext`i$224018 = 
    18, Attributes[$CellContext`i$224015] = {
     Temporary}, $CellContext`i$224015 = 15, 
    Attributes[$CellContext`i$224016] = {Temporary}, $CellContext`i$224016 = 
    16, Attributes[$CellContext`i$224011] = {
     Temporary}, $CellContext`i$224011 = 11, 
    Attributes[$CellContext`i$224003] = {Temporary}, $CellContext`i$224003 = 
    3, Attributes[$CellContext`i$224007] = {Temporary}, $CellContext`i$224007 = 
    7, Attributes[$CellContext`i$224005] = {Temporary}, $CellContext`i$224005 = 
    5, Attributes[$CellContext`i$224002] = {Temporary}, $CellContext`i$224002 = 
    2, Attributes[$CellContext`i$224010] = {Temporary}, $CellContext`i$224010 = 
    10, Attributes[$CellContext`i$222454] = {
     Temporary}, $CellContext`i$222454 = 1, 
    Attributes[$CellContext`sym$23637] = {
     Temporary}, $CellContext`sym$23637[$CellContext`a1] = $CellContext`med[
     All], $CellContext`sym$23637[$CellContext`a2] = $CellContext`med[
     All], $CellContext`sym$23637[$CellContext`a3] = $CellContext`med[
     All], $CellContext`sym$23637[$CellContext`a4] = $CellContext`med[
     All], $CellContext`sym$23637[$CellContext`a5] = $CellContext`med[
     All], $CellContext`sym$23637[$CellContext`a6] = $CellContext`med[
     All], $CellContext`sym$23637[$CellContext`a7] = $CellContext`med[
     All], $CellContext`sym$23637[All] = $CellContext`med[
     All], $CellContext`sym$23637[$CellContext`Chla] = $CellContext`med[
     All], $CellContext`sym$23637[$CellContext`Cl] = $CellContext`med[
     All], $CellContext`sym$23637[$CellContext`mnO2] = $CellContext`med[
     All], $CellContext`sym$23637[$CellContext`mxPH] = $CellContext`med[
     All], $CellContext`sym$23637[$CellContext`NH4] = $CellContext`med[
     All], $CellContext`sym$23637[$CellContext`NO3] = $CellContext`med[
     All], $CellContext`sym$23637[$CellContext`oPO4] = $CellContext`med[
     All], $CellContext`sym$23637[$CellContext`PO4] = $CellContext`med[
     All], $CellContext`sym$23637[$CellContext`season] = $CellContext`med[
     All], $CellContext`sym$23637[$CellContext`size] = $CellContext`med[
     All], $CellContext`sym$23637[$CellContext`speed] = $CellContext`med[
     All], $CellContext`sym$23637[$CellContext`a1, "factorized"] = 
    True, $CellContext`sym$23637[$CellContext`a1, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$23637[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$23637[$CellContext`a1, "raw"] = Part[
      $CellContext`med[All], All, 12], $CellContext`sym$23637[$CellContext`a2,
       "factorized"] = 
    True, $CellContext`sym$23637[$CellContext`a2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$23637[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$23637[$CellContext`a2, "raw"] = Part[
      $CellContext`med[All], All, 13], $CellContext`sym$23637[$CellContext`a3,
       "factorized"] = 
    True, $CellContext`sym$23637[$CellContext`a3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$23637[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$23637[$CellContext`a3, "raw"] = Part[
      $CellContext`med[All], All, 14], $CellContext`sym$23637[$CellContext`a4,
       "factorized"] = 
    True, $CellContext`sym$23637[$CellContext`a4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$23637[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$23637[$CellContext`a4, "raw"] = Part[
      $CellContext`med[All], All, 15], $CellContext`sym$23637[$CellContext`a5,
       "factorized"] = 
    True, $CellContext`sym$23637[$CellContext`a5, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$23637[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$23637[$CellContext`a5, "raw"] = Part[
      $CellContext`med[All], All, 16], $CellContext`sym$23637[$CellContext`a6,
       "factorized"] = 
    True, $CellContext`sym$23637[$CellContext`a6, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$23637[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$23637[$CellContext`a6, "raw"] = Part[
      $CellContext`med[All], All, 17], $CellContext`sym$23637[$CellContext`a7,
       "factorized"] = 
    True, $CellContext`sym$23637[$CellContext`a7, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$23637[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$23637[$CellContext`a7, "raw"] = Part[
      $CellContext`med[All], All, 18], $CellContext`sym$23637[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$23637[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$23637[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$23637[$CellContext`Chla, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$23637[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$23637[$CellContext`Chla, "raw"] = Part[
      $CellContext`med[All], All, 11], $CellContext`sym$23637[$CellContext`Cl,
       "factorized"] = 
    True, $CellContext`sym$23637[$CellContext`Cl, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$23637[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$23637[$CellContext`Cl, "raw"] = Part[
      $CellContext`med[All], All, 
      6], $CellContext`sym$23637[$CellContext`mnO2, "factorized"] = 
    True, $CellContext`sym$23637[$CellContext`mnO2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$23637[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$23637[$CellContext`mnO2, "raw"] = Part[
      $CellContext`med[All], All, 
      5], $CellContext`sym$23637[$CellContext`mxPH, "factorized"] = 
    True, $CellContext`sym$23637[$CellContext`mxPH, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$23637[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$23637[$CellContext`mxPH, "raw"] = Part[
      $CellContext`med[All], All, 4], $CellContext`sym$23637[$CellContext`NH4,
       "factorized"] = 
    True, $CellContext`sym$23637[$CellContext`NH4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$23637[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$23637[$CellContext`NH4, "raw"] = Part[
      $CellContext`med[All], All, 8], $CellContext`sym$23637[$CellContext`NO3,
       "factorized"] = 
    True, $CellContext`sym$23637[$CellContext`NO3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$23637[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$23637[$CellContext`NO3, "raw"] = Part[
      $CellContext`med[All], All, 
      7], $CellContext`sym$23637[$CellContext`oPO4, "factorized"] = 
    True, $CellContext`sym$23637[$CellContext`oPO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$23637[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$23637[$CellContext`oPO4, "raw"] = Part[
      $CellContext`med[All], All, 9], $CellContext`sym$23637[$CellContext`PO4,
       "factorized"] = 
    True, $CellContext`sym$23637[$CellContext`PO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$23637[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$23637[$CellContext`PO4, "raw"] = Part[
      $CellContext`med[All], All, 
      10], $CellContext`sym$23637[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$23637[$CellContext`season, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$23637[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$23637[$CellContext`season, "raw"] = 
    Part[
      $CellContext`med[All], All, 
      1], $CellContext`sym$23637[$CellContext`size, "factorized"] = 
    True, $CellContext`sym$23637[$CellContext`size, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$23637[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$23637[$CellContext`size, "raw"] = Part[
      $CellContext`med[All], All, 
      2], $CellContext`sym$23637[$CellContext`speed, "factorized"] = 
    True, $CellContext`sym$23637[$CellContext`speed, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$23637[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$23637[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`med[All], All, 3], 
    Attributes[$CellContext`sym$104104] = {
     Temporary}, $CellContext`sym$104104[$CellContext`a1] = Part[
      $CellContext`sym$104104[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$104104[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$104104[$CellContext`a2] = Part[
      $CellContext`sym$104104[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$104104[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$104104[$CellContext`a3] = Part[
      $CellContext`sym$104104[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$104104[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$104104[$CellContext`a4] = Part[
      $CellContext`sym$104104[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$104104[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$104104[$CellContext`a5] = Part[
      $CellContext`sym$104104[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$104104[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$104104[$CellContext`a6] = Part[
      $CellContext`sym$104104[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$104104[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$104104[$CellContext`a7] = Part[
      $CellContext`sym$104104[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$104104[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$104104[All] = $CellContext`med[
     All], $CellContext`sym$104104[$CellContext`Chla] = Part[
      $CellContext`sym$104104[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$104104[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$104104[$CellContext`Cl] = Part[
      $CellContext`sym$104104[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$104104[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$104104[$CellContext`mnO2] = Part[
      $CellContext`sym$104104[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$104104[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$104104[$CellContext`mxPH] = Part[
      $CellContext`sym$104104[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$104104[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$104104[$CellContext`NH4] = Part[
      $CellContext`sym$104104[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$104104[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$104104[$CellContext`NO3] = Part[
      $CellContext`sym$104104[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$104104[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$104104[$CellContext`oPO4] = Part[
      $CellContext`sym$104104[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$104104[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$104104[$CellContext`PO4] = Part[
      $CellContext`sym$104104[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$104104[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$104104[$CellContext`season] = Part[
      $CellContext`sym$104104[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$104104[$CellContext`season, 
         "missing"]]]], $CellContext`sym$104104[$CellContext`size] = Part[
      $CellContext`sym$104104[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$104104[$CellContext`size, 
         "missing"]]]], $CellContext`sym$104104[$CellContext`speed] = Part[
      $CellContext`sym$104104[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$104104[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$104104[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$104104[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$104104, $CellContext`a1]], \
$CellContext`sym$104104[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$104104[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$104104[All], 
      All, $CellContext`i$105663], $CellContext`sym$104104[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$104104[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$104104, $CellContext`a2]], \
$CellContext`sym$104104[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$104104[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$104104[All], 
      All, $CellContext`i$105664], $CellContext`sym$104104[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$104104[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$104104, $CellContext`a3]], \
$CellContext`sym$104104[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$104104[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$104104[All], 
      All, $CellContext`i$105665], $CellContext`sym$104104[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$104104[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$104104, $CellContext`a4]], \
$CellContext`sym$104104[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$104104[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$104104[All], 
      All, $CellContext`i$105666], $CellContext`sym$104104[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$104104[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$104104, $CellContext`a5]], \
$CellContext`sym$104104[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$104104[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$104104[All], 
      All, $CellContext`i$105667], $CellContext`sym$104104[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$104104[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$104104, $CellContext`a6]], \
$CellContext`sym$104104[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$104104[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$104104[All], 
      All, $CellContext`i$105668], $CellContext`sym$104104[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$104104[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$104104, $CellContext`a7]], \
$CellContext`sym$104104[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$104104[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$104104[All], 
      All, $CellContext`i$105669], $CellContext`sym$104104[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$104104[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$104104[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$104104[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$104104, $CellContext`Chla]], \
$CellContext`sym$104104[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$104104[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$104104[All], 
      All, $CellContext`i$105662], $CellContext`sym$104104[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$104104[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$104104, $CellContext`Cl]], \
$CellContext`sym$104104[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$104104[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$104104[All], 
      All, $CellContext`i$105657], $CellContext`sym$104104[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$104104[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$104104, $CellContext`mnO2]], \
$CellContext`sym$104104[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$104104[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$104104[All], 
      All, $CellContext`i$105656], $CellContext`sym$104104[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$104104[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$104104, $CellContext`mxPH]], \
$CellContext`sym$104104[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$104104[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$104104[All], 
      All, $CellContext`i$105655], $CellContext`sym$104104[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$104104[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$104104, $CellContext`NH4]], \
$CellContext`sym$104104[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$104104[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$104104[All], 
      All, $CellContext`i$105659], $CellContext`sym$104104[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$104104[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$104104, $CellContext`NO3]], \
$CellContext`sym$104104[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$104104[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$104104[All], 
      All, $CellContext`i$105658], $CellContext`sym$104104[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$104104[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$104104, $CellContext`oPO4]], \
$CellContext`sym$104104[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$104104[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$104104[All], 
      All, $CellContext`i$105660], $CellContext`sym$104104[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$104104[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$104104, $CellContext`PO4]], \
$CellContext`sym$104104[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$104104[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$104104[All], 
      All, $CellContext`i$105661], \
$CellContext`sym$104104[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$104104[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$104104, $CellContext`season]], \
$CellContext`sym$104104[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$104104[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$104104[All], 
      All, $CellContext`i$104105], $CellContext`sym$104104[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$104104[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$104104, $CellContext`size]], \
$CellContext`sym$104104[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$104104[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$104104[All], 
      All, $CellContext`i$105653], $CellContext`sym$104104[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$104104[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$104104, $CellContext`speed]], \
$CellContext`sym$104104[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$104104[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$104104[All], All, $CellContext`i$105654], 
    Attributes[$CellContext`i$105662] = {Temporary}, $CellContext`i$105662 = 
    11, Attributes[$CellContext`i$105667] = {
     Temporary}, $CellContext`i$105667 = 16, 
    Attributes[$CellContext`i$105653] = {Temporary}, $CellContext`i$105653 = 
    2, Attributes[$CellContext`i$105663] = {Temporary}, $CellContext`i$105663 = 
    12, Attributes[$CellContext`i$105661] = {
     Temporary}, $CellContext`i$105661 = 10, 
    Attributes[$CellContext`i$105669] = {Temporary}, $CellContext`i$105669 = 
    18, Attributes[$CellContext`i$105666] = {
     Temporary}, $CellContext`i$105666 = 15, 
    Attributes[$CellContext`i$105657] = {Temporary}, $CellContext`i$105657 = 
    6, Attributes[$CellContext`i$104105] = {Temporary}, $CellContext`i$104105 = 
    1, Attributes[$CellContext`i$105655] = {Temporary}, $CellContext`i$105655 = 
    4, Attributes[$CellContext`i$105659] = {Temporary}, $CellContext`i$105659 = 
    8, Attributes[$CellContext`i$105665] = {Temporary}, $CellContext`i$105665 = 
    14, Attributes[$CellContext`i$105656] = {
     Temporary}, $CellContext`i$105656 = 5, 
    Attributes[$CellContext`i$105668] = {Temporary}, $CellContext`i$105668 = 
    17, Attributes[$CellContext`i$105658] = {
     Temporary}, $CellContext`i$105658 = 7, 
    Attributes[$CellContext`i$105664] = {Temporary}, $CellContext`i$105664 = 
    13, Attributes[$CellContext`i$105654] = {
     Temporary}, $CellContext`i$105654 = 3, 
    Attributes[$CellContext`i$105660] = {Temporary}, $CellContext`i$105660 = 
    9, Attributes[$CellContext`sym$164395] = {
     Temporary}, $CellContext`sym$164395[$CellContext`a1] = Part[
      $CellContext`sym$164395[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$164395[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$164395[$CellContext`a2] = Part[
      $CellContext`sym$164395[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$164395[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$164395[$CellContext`a3] = Part[
      $CellContext`sym$164395[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$164395[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$164395[$CellContext`a4] = Part[
      $CellContext`sym$164395[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$164395[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$164395[$CellContext`a5] = Part[
      $CellContext`sym$164395[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$164395[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$164395[$CellContext`a6] = Part[
      $CellContext`sym$164395[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$164395[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$164395[$CellContext`a7] = Part[
      $CellContext`sym$164395[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$164395[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$164395[All] = $CellContext`med[
     All], $CellContext`sym$164395[$CellContext`Chla] = Part[
      $CellContext`sym$164395[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$164395[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$164395[$CellContext`Cl] = Part[
      $CellContext`sym$164395[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$164395[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$164395[$CellContext`mnO2] = Part[
      $CellContext`sym$164395[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$164395[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$164395[$CellContext`mxPH] = Part[
      $CellContext`sym$164395[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$164395[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$164395[$CellContext`NH4] = Part[
      $CellContext`sym$164395[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$164395[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$164395[$CellContext`NO3] = Part[
      $CellContext`sym$164395[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$164395[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$164395[$CellContext`oPO4] = Part[
      $CellContext`sym$164395[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$164395[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$164395[$CellContext`PO4] = Part[
      $CellContext`sym$164395[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$164395[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$164395[$CellContext`season] = Part[
      $CellContext`sym$164395[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$164395[$CellContext`season, 
         "missing"]]]], $CellContext`sym$164395[$CellContext`size] = Part[
      $CellContext`sym$164395[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$164395[$CellContext`size, 
         "missing"]]]], $CellContext`sym$164395[$CellContext`speed] = Part[
      $CellContext`sym$164395[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$164395[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$164395[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$164395[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$164395, $CellContext`a1]], \
$CellContext`sym$164395[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$164395[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$164395[All], 
      All, $CellContext`i$165954], $CellContext`sym$164395[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$164395[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$164395, $CellContext`a2]], \
$CellContext`sym$164395[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$164395[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$164395[All], 
      All, $CellContext`i$165955], $CellContext`sym$164395[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$164395[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$164395, $CellContext`a3]], \
$CellContext`sym$164395[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$164395[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$164395[All], 
      All, $CellContext`i$165956], $CellContext`sym$164395[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$164395[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$164395, $CellContext`a4]], \
$CellContext`sym$164395[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$164395[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$164395[All], 
      All, $CellContext`i$165957], $CellContext`sym$164395[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$164395[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$164395, $CellContext`a5]], \
$CellContext`sym$164395[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$164395[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$164395[All], 
      All, $CellContext`i$165958], $CellContext`sym$164395[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$164395[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$164395, $CellContext`a6]], \
$CellContext`sym$164395[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$164395[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$164395[All], 
      All, $CellContext`i$165959], $CellContext`sym$164395[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$164395[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$164395, $CellContext`a7]], \
$CellContext`sym$164395[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$164395[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$164395[All], 
      All, $CellContext`i$165960], $CellContext`sym$164395[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$164395[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$164395[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$164395[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$164395, $CellContext`Chla]], \
$CellContext`sym$164395[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$164395[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$164395[All], 
      All, $CellContext`i$165953], $CellContext`sym$164395[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$164395[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$164395, $CellContext`Cl]], \
$CellContext`sym$164395[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$164395[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$164395[All], 
      All, $CellContext`i$165948], $CellContext`sym$164395[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$164395[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$164395, $CellContext`mnO2]], \
$CellContext`sym$164395[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$164395[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$164395[All], 
      All, $CellContext`i$165947], $CellContext`sym$164395[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$164395[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$164395, $CellContext`mxPH]], \
$CellContext`sym$164395[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$164395[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$164395[All], 
      All, $CellContext`i$165946], $CellContext`sym$164395[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$164395[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$164395, $CellContext`NH4]], \
$CellContext`sym$164395[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$164395[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$164395[All], 
      All, $CellContext`i$165950], $CellContext`sym$164395[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$164395[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$164395, $CellContext`NO3]], \
$CellContext`sym$164395[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$164395[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$164395[All], 
      All, $CellContext`i$165949], $CellContext`sym$164395[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$164395[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$164395, $CellContext`oPO4]], \
$CellContext`sym$164395[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$164395[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$164395[All], 
      All, $CellContext`i$165951], $CellContext`sym$164395[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$164395[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$164395, $CellContext`PO4]], \
$CellContext`sym$164395[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$164395[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$164395[All], 
      All, $CellContext`i$165952], \
$CellContext`sym$164395[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$164395[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$164395, $CellContext`season]], \
$CellContext`sym$164395[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$164395[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$164395[All], 
      All, $CellContext`i$164396], $CellContext`sym$164395[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$164395[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$164395, $CellContext`size]], \
$CellContext`sym$164395[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$164395[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$164395[All], 
      All, $CellContext`i$165944], $CellContext`sym$164395[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$164395[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$164395, $CellContext`speed]], \
$CellContext`sym$164395[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$164395[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$164395[All], All, $CellContext`i$165945], 
    Attributes[$CellContext`i$165957] = {Temporary}, $CellContext`i$165957 = 
    15, Attributes[$CellContext`i$165956] = {
     Temporary}, $CellContext`i$165956 = 14, 
    Attributes[$CellContext`i$164396] = {Temporary}, $CellContext`i$164396 = 
    1, Attributes[$CellContext`i$165948] = {Temporary}, $CellContext`i$165948 = 
    6, Attributes[$CellContext`i$165951] = {Temporary}, $CellContext`i$165951 = 
    9, Attributes[$CellContext`i$165952] = {Temporary}, $CellContext`i$165952 = 
    10, Attributes[$CellContext`i$165960] = {
     Temporary}, $CellContext`i$165960 = 18, 
    Attributes[$CellContext`i$165945] = {Temporary}, $CellContext`i$165945 = 
    3, Attributes[$CellContext`i$165954] = {Temporary}, $CellContext`i$165954 = 
    12, Attributes[$CellContext`i$165955] = {
     Temporary}, $CellContext`i$165955 = 13, 
    Attributes[$CellContext`i$165944] = {Temporary}, $CellContext`i$165944 = 
    2, Attributes[$CellContext`i$165949] = {Temporary}, $CellContext`i$165949 = 
    7, Attributes[$CellContext`i$165947] = {Temporary}, $CellContext`i$165947 = 
    5, Attributes[$CellContext`i$165946] = {Temporary}, $CellContext`i$165946 = 
    4, Attributes[$CellContext`i$165953] = {Temporary}, $CellContext`i$165953 = 
    11, Attributes[$CellContext`i$165959] = {
     Temporary}, $CellContext`i$165959 = 17, 
    Attributes[$CellContext`i$165950] = {Temporary}, $CellContext`i$165950 = 
    8, Attributes[$CellContext`i$165958] = {Temporary}, $CellContext`i$165958 = 
    16, Attributes[$CellContext`sym$227110] = {
     Temporary}, $CellContext`sym$227110[$CellContext`a1] = Part[
      $CellContext`sym$227110[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227110[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$227110[$CellContext`a2] = Part[
      $CellContext`sym$227110[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227110[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$227110[$CellContext`a3] = Part[
      $CellContext`sym$227110[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227110[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$227110[$CellContext`a4] = Part[
      $CellContext`sym$227110[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227110[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$227110[$CellContext`a5] = Part[
      $CellContext`sym$227110[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227110[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$227110[$CellContext`a6] = Part[
      $CellContext`sym$227110[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227110[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$227110[$CellContext`a7] = Part[
      $CellContext`sym$227110[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227110[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$227110[All] = $CellContext`med[
     All], $CellContext`sym$227110[$CellContext`Chla] = Part[
      $CellContext`sym$227110[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227110[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$227110[$CellContext`Cl] = Part[
      $CellContext`sym$227110[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227110[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$227110[$CellContext`mnO2] = Part[
      $CellContext`sym$227110[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227110[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$227110[$CellContext`mxPH] = Part[
      $CellContext`sym$227110[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227110[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$227110[$CellContext`NH4] = Part[
      $CellContext`sym$227110[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227110[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$227110[$CellContext`NO3] = Part[
      $CellContext`sym$227110[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227110[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$227110[$CellContext`oPO4] = Part[
      $CellContext`sym$227110[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227110[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$227110[$CellContext`PO4] = Part[
      $CellContext`sym$227110[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227110[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$227110[$CellContext`season] = Part[
      $CellContext`sym$227110[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227110[$CellContext`season, 
         "missing"]]]], $CellContext`sym$227110[$CellContext`size] = Part[
      $CellContext`sym$227110[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227110[$CellContext`size, 
         "missing"]]]], $CellContext`sym$227110[$CellContext`speed] = Part[
      $CellContext`sym$227110[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227110[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$227110[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$227110[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227110, $CellContext`a1]], \
$CellContext`sym$227110[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$227110[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$227110[All], 
      All, $CellContext`i$227122], $CellContext`sym$227110[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$227110[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227110, $CellContext`a2]], \
$CellContext`sym$227110[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$227110[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$227110[All], 
      All, $CellContext`i$227123], $CellContext`sym$227110[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$227110[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227110, $CellContext`a3]], \
$CellContext`sym$227110[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$227110[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$227110[All], 
      All, $CellContext`i$227124], $CellContext`sym$227110[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$227110[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227110, $CellContext`a4]], \
$CellContext`sym$227110[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$227110[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$227110[All], 
      All, $CellContext`i$227125], $CellContext`sym$227110[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$227110[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227110, $CellContext`a5]], \
$CellContext`sym$227110[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$227110[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$227110[All], 
      All, $CellContext`i$227126], $CellContext`sym$227110[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$227110[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227110, $CellContext`a6]], \
$CellContext`sym$227110[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$227110[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$227110[All], 
      All, $CellContext`i$227127], $CellContext`sym$227110[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$227110[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227110, $CellContext`a7]], \
$CellContext`sym$227110[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$227110[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$227110[All], 
      All, $CellContext`i$227128], $CellContext`sym$227110[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$227110[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$227110[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$227110[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227110, $CellContext`Chla]], \
$CellContext`sym$227110[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$227110[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$227110[All], 
      All, $CellContext`i$227121], $CellContext`sym$227110[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$227110[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227110, $CellContext`Cl]], \
$CellContext`sym$227110[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$227110[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$227110[All], 
      All, $CellContext`i$227116], $CellContext`sym$227110[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$227110[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227110, $CellContext`mnO2]], \
$CellContext`sym$227110[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$227110[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$227110[All], 
      All, $CellContext`i$227115], $CellContext`sym$227110[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$227110[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227110, $CellContext`mxPH]], \
$CellContext`sym$227110[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$227110[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$227110[All], 
      All, $CellContext`i$227114], $CellContext`sym$227110[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$227110[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227110, $CellContext`NH4]], \
$CellContext`sym$227110[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$227110[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$227110[All], 
      All, $CellContext`i$227118], $CellContext`sym$227110[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$227110[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227110, $CellContext`NO3]], \
$CellContext`sym$227110[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$227110[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$227110[All], 
      All, $CellContext`i$227117], $CellContext`sym$227110[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$227110[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227110, $CellContext`oPO4]], \
$CellContext`sym$227110[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$227110[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$227110[All], 
      All, $CellContext`i$227119], $CellContext`sym$227110[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$227110[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227110, $CellContext`PO4]], \
$CellContext`sym$227110[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$227110[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$227110[All], 
      All, $CellContext`i$227120], \
$CellContext`sym$227110[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$227110[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227110, $CellContext`season]], \
$CellContext`sym$227110[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$227110[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$227110[All], 
      All, $CellContext`i$227111], $CellContext`sym$227110[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$227110[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227110, $CellContext`size]], \
$CellContext`sym$227110[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$227110[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$227110[All], 
      All, $CellContext`i$227112], $CellContext`sym$227110[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$227110[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227110, $CellContext`speed]], \
$CellContext`sym$227110[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$227110[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$227110[All], All, $CellContext`i$227113], 
    Attributes[$CellContext`i$227119] = {Temporary}, $CellContext`i$227119 = 
    9, Attributes[$CellContext`i$227113] = {Temporary}, $CellContext`i$227113 = 
    3, Attributes[$CellContext`i$227117] = {Temporary}, $CellContext`i$227117 = 
    7, Attributes[$CellContext`i$227112] = {Temporary}, $CellContext`i$227112 = 
    2, Attributes[$CellContext`i$227122] = {Temporary}, $CellContext`i$227122 = 
    12, Attributes[$CellContext`i$227125] = {
     Temporary}, $CellContext`i$227125 = 15, 
    Attributes[$CellContext`i$227118] = {Temporary}, $CellContext`i$227118 = 
    8, Attributes[$CellContext`i$227128] = {Temporary}, $CellContext`i$227128 = 
    18, Attributes[$CellContext`i$227115] = {
     Temporary}, $CellContext`i$227115 = 5, 
    Attributes[$CellContext`i$227120] = {Temporary}, $CellContext`i$227120 = 
    10, Attributes[$CellContext`i$227111] = {
     Temporary}, $CellContext`i$227111 = 1, 
    Attributes[$CellContext`i$227114] = {Temporary}, $CellContext`i$227114 = 
    4, Attributes[$CellContext`i$227116] = {Temporary}, $CellContext`i$227116 = 
    6, Attributes[$CellContext`i$227126] = {Temporary}, $CellContext`i$227126 = 
    16, Attributes[$CellContext`i$227124] = {
     Temporary}, $CellContext`i$227124 = 14, 
    Attributes[$CellContext`i$227123] = {Temporary}, $CellContext`i$227123 = 
    13, Attributes[$CellContext`i$227127] = {
     Temporary}, $CellContext`i$227127 = 17, 
    Attributes[$CellContext`i$227121] = {Temporary}, $CellContext`i$227121 = 
    11, Attributes[$CellContext`sym$7976] = {
     Temporary}, $CellContext`sym$7976[$CellContext`a1] = $CellContext`med[
     All], $CellContext`sym$7976[$CellContext`a2] = $CellContext`med[
     All], $CellContext`sym$7976[$CellContext`a3] = $CellContext`med[
     All], $CellContext`sym$7976[$CellContext`a4] = $CellContext`med[
     All], $CellContext`sym$7976[$CellContext`a5] = $CellContext`med[
     All], $CellContext`sym$7976[$CellContext`a6] = $CellContext`med[
     All], $CellContext`sym$7976[$CellContext`a7] = $CellContext`med[
     All], $CellContext`sym$7976[All] = $CellContext`med[
     All], $CellContext`sym$7976[$CellContext`Chla] = $CellContext`med[
     All], $CellContext`sym$7976[$CellContext`Cl] = $CellContext`med[
     All], $CellContext`sym$7976[$CellContext`mnO2] = $CellContext`med[
     All], $CellContext`sym$7976[$CellContext`mxPH] = $CellContext`med[
     All], $CellContext`sym$7976[$CellContext`NH4] = $CellContext`med[
     All], $CellContext`sym$7976[$CellContext`NO3] = $CellContext`med[
     All], $CellContext`sym$7976[$CellContext`oPO4] = $CellContext`med[
     All], $CellContext`sym$7976[$CellContext`PO4] = $CellContext`med[
     All], $CellContext`sym$7976[$CellContext`season] = $CellContext`med[
     All], $CellContext`sym$7976[$CellContext`size] = $CellContext`med[
     All], $CellContext`sym$7976[$CellContext`speed] = $CellContext`med[
     All], $CellContext`sym$7976[$CellContext`a1, "factorized"] = 
    True, $CellContext`sym$7976[$CellContext`a1, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$7976[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$7976[$CellContext`a1, "raw"] = Part[
      $CellContext`med[All], All, 12], $CellContext`sym$7976[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$7976[$CellContext`a2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$7976[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$7976[$CellContext`a2, "raw"] = Part[
      $CellContext`med[All], All, 13], $CellContext`sym$7976[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$7976[$CellContext`a3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$7976[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$7976[$CellContext`a3, "raw"] = Part[
      $CellContext`med[All], All, 14], $CellContext`sym$7976[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$7976[$CellContext`a4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$7976[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$7976[$CellContext`a4, "raw"] = Part[
      $CellContext`med[All], All, 15], $CellContext`sym$7976[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$7976[$CellContext`a5, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$7976[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$7976[$CellContext`a5, "raw"] = Part[
      $CellContext`med[All], All, 16], $CellContext`sym$7976[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$7976[$CellContext`a6, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$7976[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$7976[$CellContext`a6, "raw"] = Part[
      $CellContext`med[All], All, 17], $CellContext`sym$7976[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$7976[$CellContext`a7, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$7976[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$7976[$CellContext`a7, "raw"] = Part[
      $CellContext`med[All], All, 18], $CellContext`sym$7976[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$7976[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$7976[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$7976[$CellContext`Chla, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$7976[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$7976[$CellContext`Chla, "raw"] = Part[
      $CellContext`med[All], All, 11], $CellContext`sym$7976[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$7976[$CellContext`Cl, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$7976[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$7976[$CellContext`Cl, "raw"] = Part[
      $CellContext`med[All], All, 6], $CellContext`sym$7976[$CellContext`mnO2,
       "factorized"] = 
    True, $CellContext`sym$7976[$CellContext`mnO2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$7976[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$7976[$CellContext`mnO2, "raw"] = Part[
      $CellContext`med[All], All, 5], $CellContext`sym$7976[$CellContext`mxPH,
       "factorized"] = 
    True, $CellContext`sym$7976[$CellContext`mxPH, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$7976[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$7976[$CellContext`mxPH, "raw"] = Part[
      $CellContext`med[All], All, 4], $CellContext`sym$7976[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$7976[$CellContext`NH4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$7976[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$7976[$CellContext`NH4, "raw"] = Part[
      $CellContext`med[All], All, 8], $CellContext`sym$7976[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$7976[$CellContext`NO3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$7976[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$7976[$CellContext`NO3, "raw"] = Part[
      $CellContext`med[All], All, 7], $CellContext`sym$7976[$CellContext`oPO4,
       "factorized"] = 
    True, $CellContext`sym$7976[$CellContext`oPO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$7976[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$7976[$CellContext`oPO4, "raw"] = Part[
      $CellContext`med[All], All, 9], $CellContext`sym$7976[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$7976[$CellContext`PO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$7976[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$7976[$CellContext`PO4, "raw"] = Part[
      $CellContext`med[All], All, 
      10], $CellContext`sym$7976[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$7976[$CellContext`season, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$7976[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$7976[$CellContext`season, "raw"] = 
    Part[
      $CellContext`med[All], All, 1], $CellContext`sym$7976[$CellContext`size,
       "factorized"] = 
    True, $CellContext`sym$7976[$CellContext`size, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$7976[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$7976[$CellContext`size, "raw"] = Part[
      $CellContext`med[All], All, 
      2], $CellContext`sym$7976[$CellContext`speed, "factorized"] = 
    True, $CellContext`sym$7976[$CellContext`speed, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$7976[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$7976[$CellContext`speed, "raw"] = Part[
      $CellContext`med[All], All, 3], 
    Attributes[$CellContext`sym$133133] = {
     Temporary}, $CellContext`sym$133133[$CellContext`a1] = Part[
      $CellContext`sym$133133[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$133133[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$133133[$CellContext`a2] = Part[
      $CellContext`sym$133133[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$133133[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$133133[$CellContext`a3] = Part[
      $CellContext`sym$133133[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$133133[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$133133[$CellContext`a4] = Part[
      $CellContext`sym$133133[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$133133[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$133133[$CellContext`a5] = Part[
      $CellContext`sym$133133[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$133133[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$133133[$CellContext`a6] = Part[
      $CellContext`sym$133133[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$133133[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$133133[$CellContext`a7] = Part[
      $CellContext`sym$133133[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$133133[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$133133[All] = $CellContext`med[
     All], $CellContext`sym$133133[$CellContext`Chla] = Part[
      $CellContext`sym$133133[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$133133[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$133133[$CellContext`Cl] = Part[
      $CellContext`sym$133133[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$133133[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$133133[$CellContext`mnO2] = Part[
      $CellContext`sym$133133[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$133133[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$133133[$CellContext`mxPH] = Part[
      $CellContext`sym$133133[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$133133[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$133133[$CellContext`NH4] = Part[
      $CellContext`sym$133133[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$133133[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$133133[$CellContext`NO3] = Part[
      $CellContext`sym$133133[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$133133[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$133133[$CellContext`oPO4] = Part[
      $CellContext`sym$133133[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$133133[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$133133[$CellContext`PO4] = Part[
      $CellContext`sym$133133[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$133133[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$133133[$CellContext`season] = Part[
      $CellContext`sym$133133[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$133133[$CellContext`season, 
         "missing"]]]], $CellContext`sym$133133[$CellContext`size] = Part[
      $CellContext`sym$133133[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$133133[$CellContext`size, 
         "missing"]]]], $CellContext`sym$133133[$CellContext`speed] = Part[
      $CellContext`sym$133133[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$133133[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$133133[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$133133[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$133133, $CellContext`a1]], \
$CellContext`sym$133133[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$133133[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$133133[All], 
      All, $CellContext`i$134692], $CellContext`sym$133133[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$133133[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$133133, $CellContext`a2]], \
$CellContext`sym$133133[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$133133[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$133133[All], 
      All, $CellContext`i$134693], $CellContext`sym$133133[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$133133[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$133133, $CellContext`a3]], \
$CellContext`sym$133133[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$133133[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$133133[All], 
      All, $CellContext`i$134694], $CellContext`sym$133133[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$133133[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$133133, $CellContext`a4]], \
$CellContext`sym$133133[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$133133[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$133133[All], 
      All, $CellContext`i$134695], $CellContext`sym$133133[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$133133[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$133133, $CellContext`a5]], \
$CellContext`sym$133133[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$133133[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$133133[All], 
      All, $CellContext`i$134696], $CellContext`sym$133133[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$133133[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$133133, $CellContext`a6]], \
$CellContext`sym$133133[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$133133[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$133133[All], 
      All, $CellContext`i$134697], $CellContext`sym$133133[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$133133[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$133133, $CellContext`a7]], \
$CellContext`sym$133133[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$133133[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$133133[All], 
      All, $CellContext`i$134698], $CellContext`sym$133133[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$133133[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$133133[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$133133[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$133133, $CellContext`Chla]], \
$CellContext`sym$133133[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$133133[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$133133[All], 
      All, $CellContext`i$134691], $CellContext`sym$133133[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$133133[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$133133, $CellContext`Cl]], \
$CellContext`sym$133133[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$133133[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$133133[All], 
      All, $CellContext`i$134686], $CellContext`sym$133133[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$133133[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$133133, $CellContext`mnO2]], \
$CellContext`sym$133133[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$133133[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$133133[All], 
      All, $CellContext`i$134685], $CellContext`sym$133133[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$133133[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$133133, $CellContext`mxPH]], \
$CellContext`sym$133133[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$133133[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$133133[All], 
      All, $CellContext`i$134684], $CellContext`sym$133133[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$133133[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$133133, $CellContext`NH4]], \
$CellContext`sym$133133[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$133133[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$133133[All], 
      All, $CellContext`i$134688], $CellContext`sym$133133[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$133133[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$133133, $CellContext`NO3]], \
$CellContext`sym$133133[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$133133[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$133133[All], 
      All, $CellContext`i$134687], $CellContext`sym$133133[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$133133[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$133133, $CellContext`oPO4]], \
$CellContext`sym$133133[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$133133[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$133133[All], 
      All, $CellContext`i$134689], $CellContext`sym$133133[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$133133[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$133133, $CellContext`PO4]], \
$CellContext`sym$133133[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$133133[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$133133[All], 
      All, $CellContext`i$134690], \
$CellContext`sym$133133[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$133133[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$133133, $CellContext`season]], \
$CellContext`sym$133133[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$133133[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$133133[All], 
      All, $CellContext`i$133134], $CellContext`sym$133133[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$133133[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$133133, $CellContext`size]], \
$CellContext`sym$133133[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$133133[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$133133[All], 
      All, $CellContext`i$134682], $CellContext`sym$133133[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$133133[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$133133, $CellContext`speed]], \
$CellContext`sym$133133[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$133133[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$133133[All], All, $CellContext`i$134683], 
    Attributes[$CellContext`i$133134] = {Temporary}, $CellContext`i$133134 = 
    1, Attributes[$CellContext`i$134695] = {Temporary}, $CellContext`i$134695 = 
    15, Attributes[$CellContext`i$134696] = {
     Temporary}, $CellContext`i$134696 = 16, 
    Attributes[$CellContext`i$134682] = {Temporary}, $CellContext`i$134682 = 
    2, Attributes[$CellContext`i$134688] = {Temporary}, $CellContext`i$134688 = 
    8, Attributes[$CellContext`i$134698] = {Temporary}, $CellContext`i$134698 = 
    18, Attributes[$CellContext`i$134691] = {
     Temporary}, $CellContext`i$134691 = 11, 
    Attributes[$CellContext`i$134692] = {Temporary}, $CellContext`i$134692 = 
    12, Attributes[$CellContext`i$134685] = {
     Temporary}, $CellContext`i$134685 = 5, 
    Attributes[$CellContext`i$134693] = {Temporary}, $CellContext`i$134693 = 
    13, Attributes[$CellContext`i$134690] = {
     Temporary}, $CellContext`i$134690 = 10, 
    Attributes[$CellContext`i$134687] = {Temporary}, $CellContext`i$134687 = 
    7, Attributes[$CellContext`i$134697] = {Temporary}, $CellContext`i$134697 = 
    17, Attributes[$CellContext`i$134686] = {
     Temporary}, $CellContext`i$134686 = 6, 
    Attributes[$CellContext`i$134689] = {Temporary}, $CellContext`i$134689 = 
    9, Attributes[$CellContext`i$134683] = {Temporary}, $CellContext`i$134683 = 
    3, Attributes[$CellContext`i$134694] = {Temporary}, $CellContext`i$134694 = 
    14, Attributes[$CellContext`i$134684] = {
     Temporary}, $CellContext`i$134684 = 4, 
    Attributes[$CellContext`sym$66065] = {
     Temporary}, $CellContext`sym$66065[$CellContext`a1] = $CellContext`med[
     All], $CellContext`sym$66065[$CellContext`a2] = $CellContext`med[
     All], $CellContext`sym$66065[$CellContext`a3] = $CellContext`med[
     All], $CellContext`sym$66065[$CellContext`a4] = $CellContext`med[
     All], $CellContext`sym$66065[$CellContext`a5] = $CellContext`med[
     All], $CellContext`sym$66065[$CellContext`a6] = $CellContext`med[
     All], $CellContext`sym$66065[$CellContext`a7] = $CellContext`med[
     All], $CellContext`sym$66065[All] = $CellContext`med[
     All], $CellContext`sym$66065[$CellContext`Chla] = $CellContext`med[
     All], $CellContext`sym$66065[$CellContext`Cl] = $CellContext`med[
     All], $CellContext`sym$66065[$CellContext`mnO2] = $CellContext`med[
     All], $CellContext`sym$66065[$CellContext`mxPH] = $CellContext`med[
     All], $CellContext`sym$66065[$CellContext`NH4] = $CellContext`med[
     All], $CellContext`sym$66065[$CellContext`NO3] = $CellContext`med[
     All], $CellContext`sym$66065[$CellContext`oPO4] = $CellContext`med[
     All], $CellContext`sym$66065[$CellContext`PO4] = $CellContext`med[
     All], $CellContext`sym$66065[$CellContext`season] = $CellContext`med[
     All], $CellContext`sym$66065[$CellContext`size] = $CellContext`med[
     All], $CellContext`sym$66065[$CellContext`speed] = $CellContext`med[
     All], $CellContext`sym$66065[$CellContext`a1, "factorized"] = 
    True, $CellContext`sym$66065[$CellContext`a1, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$66065[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$66065[$CellContext`a1, "raw"] = Part[
      $CellContext`med[All], All, 12], $CellContext`sym$66065[$CellContext`a2,
       "factorized"] = 
    True, $CellContext`sym$66065[$CellContext`a2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$66065[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$66065[$CellContext`a2, "raw"] = Part[
      $CellContext`med[All], All, 13], $CellContext`sym$66065[$CellContext`a3,
       "factorized"] = 
    True, $CellContext`sym$66065[$CellContext`a3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$66065[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$66065[$CellContext`a3, "raw"] = Part[
      $CellContext`med[All], All, 14], $CellContext`sym$66065[$CellContext`a4,
       "factorized"] = 
    True, $CellContext`sym$66065[$CellContext`a4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$66065[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$66065[$CellContext`a4, "raw"] = Part[
      $CellContext`med[All], All, 15], $CellContext`sym$66065[$CellContext`a5,
       "factorized"] = 
    True, $CellContext`sym$66065[$CellContext`a5, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$66065[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$66065[$CellContext`a5, "raw"] = Part[
      $CellContext`med[All], All, 16], $CellContext`sym$66065[$CellContext`a6,
       "factorized"] = 
    True, $CellContext`sym$66065[$CellContext`a6, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$66065[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$66065[$CellContext`a6, "raw"] = Part[
      $CellContext`med[All], All, 17], $CellContext`sym$66065[$CellContext`a7,
       "factorized"] = 
    True, $CellContext`sym$66065[$CellContext`a7, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$66065[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$66065[$CellContext`a7, "raw"] = Part[
      $CellContext`med[All], All, 18], $CellContext`sym$66065[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$66065[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$66065[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$66065[$CellContext`Chla, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$66065[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$66065[$CellContext`Chla, "raw"] = Part[
      $CellContext`med[All], All, 11], $CellContext`sym$66065[$CellContext`Cl,
       "factorized"] = 
    True, $CellContext`sym$66065[$CellContext`Cl, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$66065[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$66065[$CellContext`Cl, "raw"] = Part[
      $CellContext`med[All], All, 
      6], $CellContext`sym$66065[$CellContext`mnO2, "factorized"] = 
    True, $CellContext`sym$66065[$CellContext`mnO2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$66065[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$66065[$CellContext`mnO2, "raw"] = Part[
      $CellContext`med[All], All, 
      5], $CellContext`sym$66065[$CellContext`mxPH, "factorized"] = 
    True, $CellContext`sym$66065[$CellContext`mxPH, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$66065[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$66065[$CellContext`mxPH, "raw"] = Part[
      $CellContext`med[All], All, 4], $CellContext`sym$66065[$CellContext`NH4,
       "factorized"] = 
    True, $CellContext`sym$66065[$CellContext`NH4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$66065[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$66065[$CellContext`NH4, "raw"] = Part[
      $CellContext`med[All], All, 8], $CellContext`sym$66065[$CellContext`NO3,
       "factorized"] = 
    True, $CellContext`sym$66065[$CellContext`NO3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$66065[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$66065[$CellContext`NO3, "raw"] = Part[
      $CellContext`med[All], All, 
      7], $CellContext`sym$66065[$CellContext`oPO4, "factorized"] = 
    True, $CellContext`sym$66065[$CellContext`oPO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$66065[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$66065[$CellContext`oPO4, "raw"] = Part[
      $CellContext`med[All], All, 9], $CellContext`sym$66065[$CellContext`PO4,
       "factorized"] = 
    True, $CellContext`sym$66065[$CellContext`PO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$66065[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$66065[$CellContext`PO4, "raw"] = Part[
      $CellContext`med[All], All, 
      10], $CellContext`sym$66065[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$66065[$CellContext`season, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$66065[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$66065[$CellContext`season, "raw"] = 
    Part[
      $CellContext`med[All], All, 
      1], $CellContext`sym$66065[$CellContext`size, "factorized"] = 
    True, $CellContext`sym$66065[$CellContext`size, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$66065[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$66065[$CellContext`size, "raw"] = Part[
      $CellContext`med[All], All, 
      2], $CellContext`sym$66065[$CellContext`speed, "factorized"] = 
    True, $CellContext`sym$66065[$CellContext`speed, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$66065[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$66065[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`med[All], All, 3], 
    Attributes[$CellContext`sym$227178] = {
     Temporary}, $CellContext`sym$227178[$CellContext`a1] = Part[
      $CellContext`sym$227178[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227178[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$227178[$CellContext`a2] = Part[
      $CellContext`sym$227178[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227178[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$227178[$CellContext`a3] = Part[
      $CellContext`sym$227178[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227178[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$227178[$CellContext`a4] = Part[
      $CellContext`sym$227178[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227178[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$227178[$CellContext`a5] = Part[
      $CellContext`sym$227178[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227178[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$227178[$CellContext`a6] = Part[
      $CellContext`sym$227178[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227178[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$227178[$CellContext`a7] = Part[
      $CellContext`sym$227178[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227178[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$227178[All] = $CellContext`med[
     All], $CellContext`sym$227178[$CellContext`Chla] = Part[
      $CellContext`sym$227178[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227178[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$227178[$CellContext`Cl] = Part[
      $CellContext`sym$227178[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227178[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$227178[$CellContext`mnO2] = Part[
      $CellContext`sym$227178[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227178[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$227178[$CellContext`mxPH] = Part[
      $CellContext`sym$227178[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227178[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$227178[$CellContext`NH4] = Part[
      $CellContext`sym$227178[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227178[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$227178[$CellContext`NO3] = Part[
      $CellContext`sym$227178[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227178[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$227178[$CellContext`oPO4] = Part[
      $CellContext`sym$227178[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227178[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$227178[$CellContext`PO4] = Part[
      $CellContext`sym$227178[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227178[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$227178[$CellContext`season] = Part[
      $CellContext`sym$227178[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227178[$CellContext`season, 
         "missing"]]]], $CellContext`sym$227178[$CellContext`size] = Part[
      $CellContext`sym$227178[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227178[$CellContext`size, 
         "missing"]]]], $CellContext`sym$227178[$CellContext`speed] = Part[
      $CellContext`sym$227178[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227178[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$227178[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$227178[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227178, $CellContext`a1]], \
$CellContext`sym$227178[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$227178[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$227178[All], 
      All, $CellContext`i$227190], $CellContext`sym$227178[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$227178[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227178, $CellContext`a2]], \
$CellContext`sym$227178[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$227178[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$227178[All], 
      All, $CellContext`i$227191], $CellContext`sym$227178[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$227178[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227178, $CellContext`a3]], \
$CellContext`sym$227178[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$227178[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$227178[All], 
      All, $CellContext`i$227192], $CellContext`sym$227178[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$227178[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227178, $CellContext`a4]], \
$CellContext`sym$227178[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$227178[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$227178[All], 
      All, $CellContext`i$227193], $CellContext`sym$227178[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$227178[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227178, $CellContext`a5]], \
$CellContext`sym$227178[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$227178[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$227178[All], 
      All, $CellContext`i$227194], $CellContext`sym$227178[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$227178[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227178, $CellContext`a6]], \
$CellContext`sym$227178[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$227178[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$227178[All], 
      All, $CellContext`i$227195], $CellContext`sym$227178[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$227178[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227178, $CellContext`a7]], \
$CellContext`sym$227178[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$227178[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$227178[All], 
      All, $CellContext`i$227196], $CellContext`sym$227178[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$227178[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$227178[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$227178[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227178, $CellContext`Chla]], \
$CellContext`sym$227178[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$227178[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$227178[All], 
      All, $CellContext`i$227189], $CellContext`sym$227178[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$227178[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227178, $CellContext`Cl]], \
$CellContext`sym$227178[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$227178[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$227178[All], 
      All, $CellContext`i$227184], $CellContext`sym$227178[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$227178[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227178, $CellContext`mnO2]], \
$CellContext`sym$227178[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$227178[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$227178[All], 
      All, $CellContext`i$227183], $CellContext`sym$227178[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$227178[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227178, $CellContext`mxPH]], \
$CellContext`sym$227178[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$227178[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$227178[All], 
      All, $CellContext`i$227182], $CellContext`sym$227178[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$227178[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227178, $CellContext`NH4]], \
$CellContext`sym$227178[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$227178[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$227178[All], 
      All, $CellContext`i$227186], $CellContext`sym$227178[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$227178[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227178, $CellContext`NO3]], \
$CellContext`sym$227178[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$227178[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$227178[All], 
      All, $CellContext`i$227185], $CellContext`sym$227178[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$227178[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227178, $CellContext`oPO4]], \
$CellContext`sym$227178[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$227178[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$227178[All], 
      All, $CellContext`i$227187], $CellContext`sym$227178[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$227178[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227178, $CellContext`PO4]], \
$CellContext`sym$227178[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$227178[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$227178[All], 
      All, $CellContext`i$227188], \
$CellContext`sym$227178[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$227178[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227178, $CellContext`season]], \
$CellContext`sym$227178[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$227178[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$227178[All], 
      All, $CellContext`i$227179], $CellContext`sym$227178[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$227178[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227178, $CellContext`size]], \
$CellContext`sym$227178[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$227178[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$227178[All], 
      All, $CellContext`i$227180], $CellContext`sym$227178[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$227178[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227178, $CellContext`speed]], \
$CellContext`sym$227178[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$227178[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$227178[All], All, $CellContext`i$227181], 
    Attributes[$CellContext`i$227182] = {Temporary}, $CellContext`i$227182 = 
    4, Attributes[$CellContext`i$227186] = {Temporary}, $CellContext`i$227186 = 
    8, Attributes[$CellContext`i$227185] = {Temporary}, $CellContext`i$227185 = 
    7, Attributes[$CellContext`i$227179] = {Temporary}, $CellContext`i$227179 = 
    1, Attributes[$CellContext`i$227187] = {Temporary}, $CellContext`i$227187 = 
    9, Attributes[$CellContext`i$227189] = {Temporary}, $CellContext`i$227189 = 
    11, Attributes[$CellContext`i$227184] = {
     Temporary}, $CellContext`i$227184 = 6, 
    Attributes[$CellContext`i$227193] = {Temporary}, $CellContext`i$227193 = 
    15, Attributes[$CellContext`i$227196] = {
     Temporary}, $CellContext`i$227196 = 18, 
    Attributes[$CellContext`i$227195] = {Temporary}, $CellContext`i$227195 = 
    17, Attributes[$CellContext`i$227181] = {
     Temporary}, $CellContext`i$227181 = 3, 
    Attributes[$CellContext`i$227180] = {Temporary}, $CellContext`i$227180 = 
    2, Attributes[$CellContext`i$227191] = {Temporary}, $CellContext`i$227191 = 
    13, Attributes[$CellContext`i$227194] = {
     Temporary}, $CellContext`i$227194 = 16, 
    Attributes[$CellContext`i$227190] = {Temporary}, $CellContext`i$227190 = 
    12, Attributes[$CellContext`i$227192] = {
     Temporary}, $CellContext`i$227192 = 14, 
    Attributes[$CellContext`i$227188] = {Temporary}, $CellContext`i$227188 = 
    10, Attributes[$CellContext`i$227183] = {
     Temporary}, $CellContext`i$227183 = 5, 
    Attributes[$CellContext`sym$95172] = {
     Temporary}, $CellContext`sym$95172[$CellContext`a1] = Part[
      $CellContext`sym$95172[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$95172[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$95172[$CellContext`a2] = Part[
      $CellContext`sym$95172[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$95172[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$95172[$CellContext`a3] = Part[
      $CellContext`sym$95172[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$95172[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$95172[$CellContext`a4] = Part[
      $CellContext`sym$95172[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$95172[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$95172[$CellContext`a5] = Part[
      $CellContext`sym$95172[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$95172[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$95172[$CellContext`a6] = Part[
      $CellContext`sym$95172[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$95172[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$95172[$CellContext`a7] = Part[
      $CellContext`sym$95172[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$95172[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$95172[All] = $CellContext`med[
     All], $CellContext`sym$95172[$CellContext`Chla] = Part[
      $CellContext`sym$95172[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$95172[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$95172[$CellContext`Cl] = Part[
      $CellContext`sym$95172[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$95172[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$95172[$CellContext`mnO2] = Part[
      $CellContext`sym$95172[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$95172[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$95172[$CellContext`mxPH] = Part[
      $CellContext`sym$95172[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$95172[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$95172[$CellContext`NH4] = Part[
      $CellContext`sym$95172[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$95172[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$95172[$CellContext`NO3] = Part[
      $CellContext`sym$95172[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$95172[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$95172[$CellContext`oPO4] = Part[
      $CellContext`sym$95172[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$95172[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$95172[$CellContext`PO4] = Part[
      $CellContext`sym$95172[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$95172[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$95172[$CellContext`season] = Part[
      $CellContext`sym$95172[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$95172[$CellContext`season, 
         "missing"]]]], $CellContext`sym$95172[$CellContext`size] = Part[
      $CellContext`sym$95172[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$95172[$CellContext`size, 
         "missing"]]]], $CellContext`sym$95172[$CellContext`speed] = Part[
      $CellContext`sym$95172[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$95172[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$95172[$CellContext`a1, "factorized"] = 
    True, $CellContext`sym$95172[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$95172, $CellContext`a1]], \
$CellContext`sym$95172[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$95172[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$95172[All], 
      All, $CellContext`i$96731], $CellContext`sym$95172[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$95172[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$95172, $CellContext`a2]], \
$CellContext`sym$95172[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$95172[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$95172[All], 
      All, $CellContext`i$96732], $CellContext`sym$95172[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$95172[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$95172, $CellContext`a3]], \
$CellContext`sym$95172[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$95172[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$95172[All], 
      All, $CellContext`i$96733], $CellContext`sym$95172[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$95172[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$95172, $CellContext`a4]], \
$CellContext`sym$95172[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$95172[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$95172[All], 
      All, $CellContext`i$96734], $CellContext`sym$95172[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$95172[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$95172, $CellContext`a5]], \
$CellContext`sym$95172[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$95172[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$95172[All], 
      All, $CellContext`i$96735], $CellContext`sym$95172[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$95172[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$95172, $CellContext`a6]], \
$CellContext`sym$95172[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$95172[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$95172[All], 
      All, $CellContext`i$96736], $CellContext`sym$95172[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$95172[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$95172, $CellContext`a7]], \
$CellContext`sym$95172[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$95172[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$95172[All], 
      All, $CellContext`i$96737], $CellContext`sym$95172[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$95172[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$95172[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$95172[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$95172, $CellContext`Chla]], \
$CellContext`sym$95172[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$95172[$CellContext`Chla, "raw"] = Part[
      $CellContext`sym$95172[All], 
      All, $CellContext`i$96730], $CellContext`sym$95172[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$95172[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$95172, $CellContext`Cl]], \
$CellContext`sym$95172[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$95172[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$95172[All], 
      All, $CellContext`i$96725], $CellContext`sym$95172[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$95172[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$95172, $CellContext`mnO2]], \
$CellContext`sym$95172[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$95172[$CellContext`mnO2, "raw"] = Part[
      $CellContext`sym$95172[All], 
      All, $CellContext`i$96724], $CellContext`sym$95172[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$95172[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$95172, $CellContext`mxPH]], \
$CellContext`sym$95172[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$95172[$CellContext`mxPH, "raw"] = Part[
      $CellContext`sym$95172[All], 
      All, $CellContext`i$96723], $CellContext`sym$95172[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$95172[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$95172, $CellContext`NH4]], \
$CellContext`sym$95172[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$95172[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$95172[All], 
      All, $CellContext`i$96727], $CellContext`sym$95172[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$95172[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$95172, $CellContext`NO3]], \
$CellContext`sym$95172[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$95172[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$95172[All], 
      All, $CellContext`i$96726], $CellContext`sym$95172[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$95172[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$95172, $CellContext`oPO4]], \
$CellContext`sym$95172[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$95172[$CellContext`oPO4, "raw"] = Part[
      $CellContext`sym$95172[All], 
      All, $CellContext`i$96728], $CellContext`sym$95172[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$95172[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$95172, $CellContext`PO4]], \
$CellContext`sym$95172[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$95172[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$95172[All], 
      All, $CellContext`i$96729], $CellContext`sym$95172[$CellContext`season, 
      "factorized"] = 
    True, $CellContext`sym$95172[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$95172, $CellContext`season]], \
$CellContext`sym$95172[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$95172[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$95172[All], 
      All, $CellContext`i$95173], $CellContext`sym$95172[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$95172[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$95172, $CellContext`size]], \
$CellContext`sym$95172[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$95172[$CellContext`size, "raw"] = Part[
      $CellContext`sym$95172[All], 
      All, $CellContext`i$96721], $CellContext`sym$95172[$CellContext`speed, 
      "factorized"] = 
    True, $CellContext`sym$95172[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$95172, $CellContext`speed]], \
$CellContext`sym$95172[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$95172[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$95172[All], All, $CellContext`i$96722], 
    Attributes[$CellContext`i$96723] = {Temporary}, $CellContext`i$96723 = 4, 
    Attributes[$CellContext`i$96721] = {Temporary}, $CellContext`i$96721 = 2, 
    Attributes[$CellContext`i$96732] = {Temporary}, $CellContext`i$96732 = 13,
     Attributes[$CellContext`i$96737] = {Temporary}, $CellContext`i$96737 = 
    18, Attributes[$CellContext`i$96730] = {Temporary}, $CellContext`i$96730 = 
    11, Attributes[$CellContext`i$96725] = {Temporary}, $CellContext`i$96725 = 
    6, Attributes[$CellContext`i$95173] = {Temporary}, $CellContext`i$95173 = 
    1, Attributes[$CellContext`i$96731] = {Temporary}, $CellContext`i$96731 = 
    12, Attributes[$CellContext`i$96722] = {Temporary}, $CellContext`i$96722 = 
    3, Attributes[$CellContext`i$96726] = {Temporary}, $CellContext`i$96726 = 
    7, Attributes[$CellContext`i$96735] = {Temporary}, $CellContext`i$96735 = 
    16, Attributes[$CellContext`i$96736] = {Temporary}, $CellContext`i$96736 = 
    17, Attributes[$CellContext`i$96729] = {Temporary}, $CellContext`i$96729 = 
    10, Attributes[$CellContext`i$96724] = {Temporary}, $CellContext`i$96724 = 
    5, Attributes[$CellContext`i$96728] = {Temporary}, $CellContext`i$96728 = 
    9, Attributes[$CellContext`i$96733] = {Temporary}, $CellContext`i$96733 = 
    14, Attributes[$CellContext`i$96727] = {Temporary}, $CellContext`i$96727 = 
    8, Attributes[$CellContext`i$96734] = {Temporary}, $CellContext`i$96734 = 
    15, Attributes[$CellContext`sym$175560] = {
     Temporary}, $CellContext`sym$175560[$CellContext`a1] = Part[
      $CellContext`sym$175560[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$175560[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$175560[$CellContext`a2] = Part[
      $CellContext`sym$175560[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$175560[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$175560[$CellContext`a3] = Part[
      $CellContext`sym$175560[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$175560[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$175560[$CellContext`a4] = Part[
      $CellContext`sym$175560[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$175560[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$175560[$CellContext`a5] = Part[
      $CellContext`sym$175560[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$175560[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$175560[$CellContext`a6] = Part[
      $CellContext`sym$175560[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$175560[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$175560[$CellContext`a7] = Part[
      $CellContext`sym$175560[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$175560[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$175560[All] = $CellContext`med[
     All], $CellContext`sym$175560[$CellContext`Chla] = Part[
      $CellContext`sym$175560[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$175560[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$175560[$CellContext`Cl] = Part[
      $CellContext`sym$175560[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$175560[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$175560[$CellContext`mnO2] = Part[
      $CellContext`sym$175560[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$175560[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$175560[$CellContext`mxPH] = Part[
      $CellContext`sym$175560[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$175560[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$175560[$CellContext`NH4] = Part[
      $CellContext`sym$175560[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$175560[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$175560[$CellContext`NO3] = Part[
      $CellContext`sym$175560[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$175560[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$175560[$CellContext`oPO4] = Part[
      $CellContext`sym$175560[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$175560[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$175560[$CellContext`PO4] = Part[
      $CellContext`sym$175560[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$175560[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$175560[$CellContext`season] = Part[
      $CellContext`sym$175560[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$175560[$CellContext`season, 
         "missing"]]]], $CellContext`sym$175560[$CellContext`size] = Part[
      $CellContext`sym$175560[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$175560[$CellContext`size, 
         "missing"]]]], $CellContext`sym$175560[$CellContext`speed] = Part[
      $CellContext`sym$175560[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$175560[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$175560[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$175560[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$175560, $CellContext`a1]], \
$CellContext`sym$175560[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$175560[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$175560[All], 
      All, $CellContext`i$177119], $CellContext`sym$175560[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$175560[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$175560, $CellContext`a2]], \
$CellContext`sym$175560[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$175560[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$175560[All], 
      All, $CellContext`i$177120], $CellContext`sym$175560[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$175560[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$175560, $CellContext`a3]], \
$CellContext`sym$175560[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$175560[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$175560[All], 
      All, $CellContext`i$177121], $CellContext`sym$175560[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$175560[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$175560, $CellContext`a4]], \
$CellContext`sym$175560[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$175560[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$175560[All], 
      All, $CellContext`i$177122], $CellContext`sym$175560[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$175560[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$175560, $CellContext`a5]], \
$CellContext`sym$175560[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$175560[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$175560[All], 
      All, $CellContext`i$177123], $CellContext`sym$175560[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$175560[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$175560, $CellContext`a6]], \
$CellContext`sym$175560[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$175560[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$175560[All], 
      All, $CellContext`i$177124], $CellContext`sym$175560[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$175560[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$175560, $CellContext`a7]], \
$CellContext`sym$175560[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$175560[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$175560[All], 
      All, $CellContext`i$177125], $CellContext`sym$175560[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$175560[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$175560[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$175560[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$175560, $CellContext`Chla]], \
$CellContext`sym$175560[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$175560[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$175560[All], 
      All, $CellContext`i$177118], $CellContext`sym$175560[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$175560[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$175560, $CellContext`Cl]], \
$CellContext`sym$175560[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$175560[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$175560[All], 
      All, $CellContext`i$177113], $CellContext`sym$175560[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$175560[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$175560, $CellContext`mnO2]], \
$CellContext`sym$175560[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$175560[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$175560[All], 
      All, $CellContext`i$177112], $CellContext`sym$175560[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$175560[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$175560, $CellContext`mxPH]], \
$CellContext`sym$175560[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$175560[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$175560[All], 
      All, $CellContext`i$177111], $CellContext`sym$175560[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$175560[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$175560, $CellContext`NH4]], \
$CellContext`sym$175560[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$175560[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$175560[All], 
      All, $CellContext`i$177115], $CellContext`sym$175560[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$175560[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$175560, $CellContext`NO3]], \
$CellContext`sym$175560[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$175560[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$175560[All], 
      All, $CellContext`i$177114], $CellContext`sym$175560[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$175560[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$175560, $CellContext`oPO4]], \
$CellContext`sym$175560[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$175560[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$175560[All], 
      All, $CellContext`i$177116], $CellContext`sym$175560[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$175560[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$175560, $CellContext`PO4]], \
$CellContext`sym$175560[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$175560[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$175560[All], 
      All, $CellContext`i$177117], \
$CellContext`sym$175560[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$175560[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$175560, $CellContext`season]], \
$CellContext`sym$175560[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$175560[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$175560[All], 
      All, $CellContext`i$175561], $CellContext`sym$175560[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$175560[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$175560, $CellContext`size]], \
$CellContext`sym$175560[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$175560[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$175560[All], 
      All, $CellContext`i$177109], $CellContext`sym$175560[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$175560[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$175560, $CellContext`speed]], \
$CellContext`sym$175560[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$175560[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$175560[All], All, $CellContext`i$177110], 
    Attributes[$CellContext`i$177115] = {Temporary}, $CellContext`i$177115 = 
    8, Attributes[$CellContext`i$177118] = {Temporary}, $CellContext`i$177118 = 
    11, Attributes[$CellContext`i$175561] = {
     Temporary}, $CellContext`i$175561 = 1, 
    Attributes[$CellContext`i$177110] = {Temporary}, $CellContext`i$177110 = 
    3, Attributes[$CellContext`i$177119] = {Temporary}, $CellContext`i$177119 = 
    12, Attributes[$CellContext`i$177116] = {
     Temporary}, $CellContext`i$177116 = 9, 
    Attributes[$CellContext`i$177121] = {Temporary}, $CellContext`i$177121 = 
    14, Attributes[$CellContext`i$177113] = {
     Temporary}, $CellContext`i$177113 = 6, 
    Attributes[$CellContext`i$177109] = {Temporary}, $CellContext`i$177109 = 
    2, Attributes[$CellContext`i$177124] = {Temporary}, $CellContext`i$177124 = 
    17, Attributes[$CellContext`i$177120] = {
     Temporary}, $CellContext`i$177120 = 13, 
    Attributes[$CellContext`i$177111] = {Temporary}, $CellContext`i$177111 = 
    4, Attributes[$CellContext`i$177123] = {Temporary}, $CellContext`i$177123 = 
    16, Attributes[$CellContext`i$177122] = {
     Temporary}, $CellContext`i$177122 = 15, 
    Attributes[$CellContext`i$177125] = {Temporary}, $CellContext`i$177125 = 
    18, Attributes[$CellContext`i$177117] = {
     Temporary}, $CellContext`i$177117 = 10, 
    Attributes[$CellContext`i$177112] = {Temporary}, $CellContext`i$177112 = 
    5, Attributes[$CellContext`i$177114] = {Temporary}, $CellContext`i$177114 = 
    7, Attributes[$CellContext`sym$195657] = {
     Temporary}, $CellContext`sym$195657[$CellContext`a1] = Part[
      $CellContext`sym$195657[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$195657[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$195657[$CellContext`a2] = Part[
      $CellContext`sym$195657[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$195657[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$195657[$CellContext`a3] = Part[
      $CellContext`sym$195657[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$195657[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$195657[$CellContext`a4] = Part[
      $CellContext`sym$195657[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$195657[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$195657[$CellContext`a5] = Part[
      $CellContext`sym$195657[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$195657[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$195657[$CellContext`a6] = Part[
      $CellContext`sym$195657[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$195657[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$195657[$CellContext`a7] = Part[
      $CellContext`sym$195657[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$195657[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$195657[All] = $CellContext`med[
     All], $CellContext`sym$195657[$CellContext`Chla] = Part[
      $CellContext`sym$195657[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$195657[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$195657[$CellContext`Cl] = Part[
      $CellContext`sym$195657[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$195657[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$195657[$CellContext`mnO2] = Part[
      $CellContext`sym$195657[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$195657[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$195657[$CellContext`mxPH] = Part[
      $CellContext`sym$195657[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$195657[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$195657[$CellContext`NH4] = Part[
      $CellContext`sym$195657[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$195657[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$195657[$CellContext`NO3] = Part[
      $CellContext`sym$195657[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$195657[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$195657[$CellContext`oPO4] = Part[
      $CellContext`sym$195657[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$195657[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$195657[$CellContext`PO4] = Part[
      $CellContext`sym$195657[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$195657[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$195657[$CellContext`season] = Part[
      $CellContext`sym$195657[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$195657[$CellContext`season, 
         "missing"]]]], $CellContext`sym$195657[$CellContext`size] = Part[
      $CellContext`sym$195657[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$195657[$CellContext`size, 
         "missing"]]]], $CellContext`sym$195657[$CellContext`speed] = Part[
      $CellContext`sym$195657[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$195657[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$195657[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$195657[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$195657, $CellContext`a1]], \
$CellContext`sym$195657[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$195657[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$195657[All], 
      All, $CellContext`i$197216], $CellContext`sym$195657[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$195657[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$195657, $CellContext`a2]], \
$CellContext`sym$195657[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$195657[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$195657[All], 
      All, $CellContext`i$197217], $CellContext`sym$195657[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$195657[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$195657, $CellContext`a3]], \
$CellContext`sym$195657[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$195657[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$195657[All], 
      All, $CellContext`i$197218], $CellContext`sym$195657[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$195657[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$195657, $CellContext`a4]], \
$CellContext`sym$195657[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$195657[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$195657[All], 
      All, $CellContext`i$197219], $CellContext`sym$195657[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$195657[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$195657, $CellContext`a5]], \
$CellContext`sym$195657[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$195657[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$195657[All], 
      All, $CellContext`i$197220], $CellContext`sym$195657[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$195657[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$195657, $CellContext`a6]], \
$CellContext`sym$195657[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$195657[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$195657[All], 
      All, $CellContext`i$197221], $CellContext`sym$195657[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$195657[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$195657, $CellContext`a7]], \
$CellContext`sym$195657[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$195657[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$195657[All], 
      All, $CellContext`i$197222], $CellContext`sym$195657[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$195657[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$195657[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$195657[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$195657, $CellContext`Chla]], \
$CellContext`sym$195657[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$195657[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$195657[All], 
      All, $CellContext`i$197215], $CellContext`sym$195657[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$195657[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$195657, $CellContext`Cl]], \
$CellContext`sym$195657[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$195657[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$195657[All], 
      All, $CellContext`i$197210], $CellContext`sym$195657[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$195657[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$195657, $CellContext`mnO2]], \
$CellContext`sym$195657[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$195657[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$195657[All], 
      All, $CellContext`i$197209], $CellContext`sym$195657[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$195657[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$195657, $CellContext`mxPH]], \
$CellContext`sym$195657[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$195657[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$195657[All], 
      All, $CellContext`i$197208], $CellContext`sym$195657[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$195657[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$195657, $CellContext`NH4]], \
$CellContext`sym$195657[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$195657[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$195657[All], 
      All, $CellContext`i$197212], $CellContext`sym$195657[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$195657[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$195657, $CellContext`NO3]], \
$CellContext`sym$195657[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$195657[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$195657[All], 
      All, $CellContext`i$197211], $CellContext`sym$195657[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$195657[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$195657, $CellContext`oPO4]], \
$CellContext`sym$195657[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$195657[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$195657[All], 
      All, $CellContext`i$197213], $CellContext`sym$195657[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$195657[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$195657, $CellContext`PO4]], \
$CellContext`sym$195657[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$195657[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$195657[All], 
      All, $CellContext`i$197214], \
$CellContext`sym$195657[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$195657[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$195657, $CellContext`season]], \
$CellContext`sym$195657[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$195657[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$195657[All], 
      All, $CellContext`i$195658], $CellContext`sym$195657[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$195657[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$195657, $CellContext`size]], \
$CellContext`sym$195657[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$195657[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$195657[All], 
      All, $CellContext`i$197206], $CellContext`sym$195657[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$195657[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$195657, $CellContext`speed]], \
$CellContext`sym$195657[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$195657[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$195657[All], All, $CellContext`i$197207], 
    Attributes[$CellContext`i$197222] = {Temporary}, $CellContext`i$197222 = 
    18, Attributes[$CellContext`i$197220] = {
     Temporary}, $CellContext`i$197220 = 16, 
    Attributes[$CellContext`i$197219] = {Temporary}, $CellContext`i$197219 = 
    15, Attributes[$CellContext`i$197213] = {
     Temporary}, $CellContext`i$197213 = 9, 
    Attributes[$CellContext`i$197221] = {Temporary}, $CellContext`i$197221 = 
    17, Attributes[$CellContext`i$197211] = {
     Temporary}, $CellContext`i$197211 = 7, 
    Attributes[$CellContext`i$197208] = {Temporary}, $CellContext`i$197208 = 
    4, Attributes[$CellContext`i$197210] = {Temporary}, $CellContext`i$197210 = 
    6, Attributes[$CellContext`i$197216] = {Temporary}, $CellContext`i$197216 = 
    12, Attributes[$CellContext`i$195658] = {
     Temporary}, $CellContext`i$195658 = 1, 
    Attributes[$CellContext`i$197207] = {Temporary}, $CellContext`i$197207 = 
    3, Attributes[$CellContext`i$197209] = {Temporary}, $CellContext`i$197209 = 
    5, Attributes[$CellContext`i$197212] = {Temporary}, $CellContext`i$197212 = 
    8, Attributes[$CellContext`i$197218] = {Temporary}, $CellContext`i$197218 = 
    14, Attributes[$CellContext`i$197217] = {
     Temporary}, $CellContext`i$197217 = 13, 
    Attributes[$CellContext`i$197215] = {Temporary}, $CellContext`i$197215 = 
    11, Attributes[$CellContext`i$197206] = {
     Temporary}, $CellContext`i$197206 = 2, 
    Attributes[$CellContext`i$197214] = {Temporary}, $CellContext`i$197214 = 
    10, Attributes[$CellContext`sym$79541] = {
     Temporary}, $CellContext`sym$79541[$CellContext`a1] = Part[
      $CellContext`sym$79541[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$79541[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$79541[$CellContext`a2] = Part[
      $CellContext`sym$79541[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$79541[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$79541[$CellContext`a3] = Part[
      $CellContext`sym$79541[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$79541[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$79541[$CellContext`a4] = Part[
      $CellContext`sym$79541[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$79541[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$79541[$CellContext`a5] = Part[
      $CellContext`sym$79541[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$79541[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$79541[$CellContext`a6] = Part[
      $CellContext`sym$79541[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$79541[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$79541[$CellContext`a7] = Part[
      $CellContext`sym$79541[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$79541[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$79541[All] = $CellContext`med[
     All], $CellContext`sym$79541[$CellContext`Chla] = Part[
      $CellContext`sym$79541[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$79541[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$79541[$CellContext`Cl] = Part[
      $CellContext`sym$79541[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$79541[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$79541[$CellContext`mnO2] = Part[
      $CellContext`sym$79541[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$79541[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$79541[$CellContext`mxPH] = Part[
      $CellContext`sym$79541[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$79541[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$79541[$CellContext`NH4] = Part[
      $CellContext`sym$79541[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$79541[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$79541[$CellContext`NO3] = Part[
      $CellContext`sym$79541[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$79541[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$79541[$CellContext`oPO4] = Part[
      $CellContext`sym$79541[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$79541[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$79541[$CellContext`PO4] = Part[
      $CellContext`sym$79541[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$79541[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$79541[$CellContext`season] = Part[
      $CellContext`sym$79541[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$79541[$CellContext`season, 
         "missing"]]]], $CellContext`sym$79541[$CellContext`size] = Part[
      $CellContext`sym$79541[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$79541[$CellContext`size, 
         "missing"]]]], $CellContext`sym$79541[$CellContext`speed] = Part[
      $CellContext`sym$79541[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$79541[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$79541[$CellContext`a1, "factorized"] = 
    True, $CellContext`sym$79541[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$79541, $CellContext`a1]], \
$CellContext`sym$79541[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$79541[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$79541[All], 
      All, $CellContext`i$81100], $CellContext`sym$79541[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$79541[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$79541, $CellContext`a2]], \
$CellContext`sym$79541[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$79541[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$79541[All], 
      All, $CellContext`i$81101], $CellContext`sym$79541[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$79541[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$79541, $CellContext`a3]], \
$CellContext`sym$79541[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$79541[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$79541[All], 
      All, $CellContext`i$81102], $CellContext`sym$79541[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$79541[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$79541, $CellContext`a4]], \
$CellContext`sym$79541[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$79541[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$79541[All], 
      All, $CellContext`i$81103], $CellContext`sym$79541[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$79541[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$79541, $CellContext`a5]], \
$CellContext`sym$79541[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$79541[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$79541[All], 
      All, $CellContext`i$81104], $CellContext`sym$79541[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$79541[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$79541, $CellContext`a6]], \
$CellContext`sym$79541[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$79541[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$79541[All], 
      All, $CellContext`i$81105], $CellContext`sym$79541[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$79541[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$79541, $CellContext`a7]], \
$CellContext`sym$79541[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$79541[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$79541[All], 
      All, $CellContext`i$81106], $CellContext`sym$79541[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$79541[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$79541[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$79541[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$79541, $CellContext`Chla]], \
$CellContext`sym$79541[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$79541[$CellContext`Chla, "raw"] = Part[
      $CellContext`sym$79541[All], 
      All, $CellContext`i$81099], $CellContext`sym$79541[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$79541[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$79541, $CellContext`Cl]], \
$CellContext`sym$79541[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$79541[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$79541[All], 
      All, $CellContext`i$81094], $CellContext`sym$79541[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$79541[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$79541, $CellContext`mnO2]], \
$CellContext`sym$79541[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$79541[$CellContext`mnO2, "raw"] = Part[
      $CellContext`sym$79541[All], 
      All, $CellContext`i$81093], $CellContext`sym$79541[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$79541[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$79541, $CellContext`mxPH]], \
$CellContext`sym$79541[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$79541[$CellContext`mxPH, "raw"] = Part[
      $CellContext`sym$79541[All], 
      All, $CellContext`i$81092], $CellContext`sym$79541[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$79541[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$79541, $CellContext`NH4]], \
$CellContext`sym$79541[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$79541[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$79541[All], 
      All, $CellContext`i$81096], $CellContext`sym$79541[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$79541[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$79541, $CellContext`NO3]], \
$CellContext`sym$79541[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$79541[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$79541[All], 
      All, $CellContext`i$81095], $CellContext`sym$79541[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$79541[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$79541, $CellContext`oPO4]], \
$CellContext`sym$79541[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$79541[$CellContext`oPO4, "raw"] = Part[
      $CellContext`sym$79541[All], 
      All, $CellContext`i$81097], $CellContext`sym$79541[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$79541[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$79541, $CellContext`PO4]], \
$CellContext`sym$79541[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$79541[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$79541[All], 
      All, $CellContext`i$81098], $CellContext`sym$79541[$CellContext`season, 
      "factorized"] = 
    True, $CellContext`sym$79541[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$79541, $CellContext`season]], \
$CellContext`sym$79541[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$79541[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$79541[All], 
      All, $CellContext`i$79542], $CellContext`sym$79541[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$79541[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$79541, $CellContext`size]], \
$CellContext`sym$79541[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$79541[$CellContext`size, "raw"] = Part[
      $CellContext`sym$79541[All], 
      All, $CellContext`i$81090], $CellContext`sym$79541[$CellContext`speed, 
      "factorized"] = 
    True, $CellContext`sym$79541[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$79541, $CellContext`speed]], \
$CellContext`sym$79541[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$79541[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$79541[All], All, $CellContext`i$81091], 
    Attributes[$CellContext`i$81094] = {Temporary}, $CellContext`i$81094 = 6, 
    Attributes[$CellContext`i$81102] = {Temporary}, $CellContext`i$81102 = 14,
     Attributes[$CellContext`i$81098] = {Temporary}, $CellContext`i$81098 = 
    10, Attributes[$CellContext`i$81095] = {Temporary}, $CellContext`i$81095 = 
    7, Attributes[$CellContext`i$81097] = {Temporary}, $CellContext`i$81097 = 
    9, Attributes[$CellContext`i$81093] = {Temporary}, $CellContext`i$81093 = 
    5, Attributes[$CellContext`i$79542] = {Temporary}, $CellContext`i$79542 = 
    1, Attributes[$CellContext`i$81101] = {Temporary}, $CellContext`i$81101 = 
    13, Attributes[$CellContext`i$81106] = {Temporary}, $CellContext`i$81106 = 
    18, Attributes[$CellContext`i$81103] = {Temporary}, $CellContext`i$81103 = 
    15, Attributes[$CellContext`i$81091] = {Temporary}, $CellContext`i$81091 = 
    3, Attributes[$CellContext`i$81105] = {Temporary}, $CellContext`i$81105 = 
    17, Attributes[$CellContext`i$81092] = {Temporary}, $CellContext`i$81092 = 
    4, Attributes[$CellContext`i$81104] = {Temporary}, $CellContext`i$81104 = 
    16, Attributes[$CellContext`i$81099] = {Temporary}, $CellContext`i$81099 = 
    11, Attributes[$CellContext`i$81096] = {Temporary}, $CellContext`i$81096 = 
    8, Attributes[$CellContext`i$81090] = {Temporary}, $CellContext`i$81090 = 
    2, Attributes[$CellContext`i$81100] = {Temporary}, $CellContext`i$81100 = 
    12, Attributes[$CellContext`sym$186725] = {
     Temporary}, $CellContext`sym$186725[$CellContext`a1] = Part[
      $CellContext`sym$186725[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$186725[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$186725[$CellContext`a2] = Part[
      $CellContext`sym$186725[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$186725[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$186725[$CellContext`a3] = Part[
      $CellContext`sym$186725[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$186725[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$186725[$CellContext`a4] = Part[
      $CellContext`sym$186725[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$186725[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$186725[$CellContext`a5] = Part[
      $CellContext`sym$186725[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$186725[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$186725[$CellContext`a6] = Part[
      $CellContext`sym$186725[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$186725[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$186725[$CellContext`a7] = Part[
      $CellContext`sym$186725[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$186725[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$186725[All] = $CellContext`med[
     All], $CellContext`sym$186725[$CellContext`Chla] = Part[
      $CellContext`sym$186725[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$186725[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$186725[$CellContext`Cl] = Part[
      $CellContext`sym$186725[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$186725[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$186725[$CellContext`mnO2] = Part[
      $CellContext`sym$186725[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$186725[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$186725[$CellContext`mxPH] = Part[
      $CellContext`sym$186725[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$186725[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$186725[$CellContext`NH4] = Part[
      $CellContext`sym$186725[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$186725[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$186725[$CellContext`NO3] = Part[
      $CellContext`sym$186725[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$186725[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$186725[$CellContext`oPO4] = Part[
      $CellContext`sym$186725[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$186725[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$186725[$CellContext`PO4] = Part[
      $CellContext`sym$186725[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$186725[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$186725[$CellContext`season] = Part[
      $CellContext`sym$186725[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$186725[$CellContext`season, 
         "missing"]]]], $CellContext`sym$186725[$CellContext`size] = Part[
      $CellContext`sym$186725[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$186725[$CellContext`size, 
         "missing"]]]], $CellContext`sym$186725[$CellContext`speed] = Part[
      $CellContext`sym$186725[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$186725[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$186725[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$186725[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$186725, $CellContext`a1]], \
$CellContext`sym$186725[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$186725[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$186725[All], 
      All, $CellContext`i$188284], $CellContext`sym$186725[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$186725[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$186725, $CellContext`a2]], \
$CellContext`sym$186725[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$186725[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$186725[All], 
      All, $CellContext`i$188285], $CellContext`sym$186725[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$186725[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$186725, $CellContext`a3]], \
$CellContext`sym$186725[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$186725[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$186725[All], 
      All, $CellContext`i$188286], $CellContext`sym$186725[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$186725[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$186725, $CellContext`a4]], \
$CellContext`sym$186725[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$186725[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$186725[All], 
      All, $CellContext`i$188287], $CellContext`sym$186725[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$186725[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$186725, $CellContext`a5]], \
$CellContext`sym$186725[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$186725[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$186725[All], 
      All, $CellContext`i$188288], $CellContext`sym$186725[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$186725[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$186725, $CellContext`a6]], \
$CellContext`sym$186725[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$186725[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$186725[All], 
      All, $CellContext`i$188289], $CellContext`sym$186725[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$186725[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$186725, $CellContext`a7]], \
$CellContext`sym$186725[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$186725[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$186725[All], 
      All, $CellContext`i$188290], $CellContext`sym$186725[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$186725[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$186725[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$186725[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$186725, $CellContext`Chla]], \
$CellContext`sym$186725[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$186725[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$186725[All], 
      All, $CellContext`i$188283], $CellContext`sym$186725[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$186725[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$186725, $CellContext`Cl]], \
$CellContext`sym$186725[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$186725[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$186725[All], 
      All, $CellContext`i$188278], $CellContext`sym$186725[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$186725[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$186725, $CellContext`mnO2]], \
$CellContext`sym$186725[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$186725[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$186725[All], 
      All, $CellContext`i$188277], $CellContext`sym$186725[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$186725[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$186725, $CellContext`mxPH]], \
$CellContext`sym$186725[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$186725[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$186725[All], 
      All, $CellContext`i$188276], $CellContext`sym$186725[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$186725[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$186725, $CellContext`NH4]], \
$CellContext`sym$186725[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$186725[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$186725[All], 
      All, $CellContext`i$188280], $CellContext`sym$186725[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$186725[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$186725, $CellContext`NO3]], \
$CellContext`sym$186725[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$186725[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$186725[All], 
      All, $CellContext`i$188279], $CellContext`sym$186725[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$186725[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$186725, $CellContext`oPO4]], \
$CellContext`sym$186725[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$186725[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$186725[All], 
      All, $CellContext`i$188281], $CellContext`sym$186725[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$186725[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$186725, $CellContext`PO4]], \
$CellContext`sym$186725[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$186725[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$186725[All], 
      All, $CellContext`i$188282], \
$CellContext`sym$186725[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$186725[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$186725, $CellContext`season]], \
$CellContext`sym$186725[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$186725[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$186725[All], 
      All, $CellContext`i$186726], $CellContext`sym$186725[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$186725[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$186725, $CellContext`size]], \
$CellContext`sym$186725[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$186725[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$186725[All], 
      All, $CellContext`i$188274], $CellContext`sym$186725[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$186725[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$186725, $CellContext`speed]], \
$CellContext`sym$186725[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$186725[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$186725[All], All, $CellContext`i$188275], 
    Attributes[$CellContext`i$188280] = {Temporary}, $CellContext`i$188280 = 
    8, Attributes[$CellContext`i$188287] = {Temporary}, $CellContext`i$188287 = 
    15, Attributes[$CellContext`i$188274] = {
     Temporary}, $CellContext`i$188274 = 2, 
    Attributes[$CellContext`i$188281] = {Temporary}, $CellContext`i$188281 = 
    9, Attributes[$CellContext`i$188284] = {Temporary}, $CellContext`i$188284 = 
    12, Attributes[$CellContext`i$188282] = {
     Temporary}, $CellContext`i$188282 = 10, 
    Attributes[$CellContext`i$188278] = {Temporary}, $CellContext`i$188278 = 
    6, Attributes[$CellContext`i$188286] = {Temporary}, $CellContext`i$188286 = 
    14, Attributes[$CellContext`i$188285] = {
     Temporary}, $CellContext`i$188285 = 13, 
    Attributes[$CellContext`i$188283] = {Temporary}, $CellContext`i$188283 = 
    11, Attributes[$CellContext`i$188276] = {
     Temporary}, $CellContext`i$188276 = 4, 
    Attributes[$CellContext`i$188289] = {Temporary}, $CellContext`i$188289 = 
    17, Attributes[$CellContext`i$188290] = {
     Temporary}, $CellContext`i$188290 = 18, 
    Attributes[$CellContext`i$188275] = {Temporary}, $CellContext`i$188275 = 
    3, Attributes[$CellContext`i$188279] = {Temporary}, $CellContext`i$188279 = 
    7, Attributes[$CellContext`i$186726] = {Temporary}, $CellContext`i$186726 = 
    1, Attributes[$CellContext`i$188288] = {Temporary}, $CellContext`i$188288 = 
    16, Attributes[$CellContext`i$188277] = {
     Temporary}, $CellContext`i$188277 = 5, 
    Attributes[$CellContext`sym$43735] = {
     Temporary}, $CellContext`sym$43735[$CellContext`a1] = $CellContext`med[
     All], $CellContext`sym$43735[$CellContext`a2] = $CellContext`med[
     All], $CellContext`sym$43735[$CellContext`a3] = $CellContext`med[
     All], $CellContext`sym$43735[$CellContext`a4] = $CellContext`med[
     All], $CellContext`sym$43735[$CellContext`a5] = $CellContext`med[
     All], $CellContext`sym$43735[$CellContext`a6] = $CellContext`med[
     All], $CellContext`sym$43735[$CellContext`a7] = $CellContext`med[
     All], $CellContext`sym$43735[All] = $CellContext`med[
     All], $CellContext`sym$43735[$CellContext`Chla] = $CellContext`med[
     All], $CellContext`sym$43735[$CellContext`Cl] = $CellContext`med[
     All], $CellContext`sym$43735[$CellContext`mnO2] = $CellContext`med[
     All], $CellContext`sym$43735[$CellContext`mxPH] = $CellContext`med[
     All], $CellContext`sym$43735[$CellContext`NH4] = $CellContext`med[
     All], $CellContext`sym$43735[$CellContext`NO3] = $CellContext`med[
     All], $CellContext`sym$43735[$CellContext`oPO4] = $CellContext`med[
     All], $CellContext`sym$43735[$CellContext`PO4] = $CellContext`med[
     All], $CellContext`sym$43735[$CellContext`season] = $CellContext`med[
     All], $CellContext`sym$43735[$CellContext`size] = $CellContext`med[
     All], $CellContext`sym$43735[$CellContext`speed] = $CellContext`med[
     All], $CellContext`sym$43735[$CellContext`a1, "factorized"] = 
    True, $CellContext`sym$43735[$CellContext`a1, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$43735[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$43735[$CellContext`a1, "raw"] = Part[
      $CellContext`med[All], All, 12], $CellContext`sym$43735[$CellContext`a2,
       "factorized"] = 
    True, $CellContext`sym$43735[$CellContext`a2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$43735[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$43735[$CellContext`a2, "raw"] = Part[
      $CellContext`med[All], All, 13], $CellContext`sym$43735[$CellContext`a3,
       "factorized"] = 
    True, $CellContext`sym$43735[$CellContext`a3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$43735[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$43735[$CellContext`a3, "raw"] = Part[
      $CellContext`med[All], All, 14], $CellContext`sym$43735[$CellContext`a4,
       "factorized"] = 
    True, $CellContext`sym$43735[$CellContext`a4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$43735[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$43735[$CellContext`a4, "raw"] = Part[
      $CellContext`med[All], All, 15], $CellContext`sym$43735[$CellContext`a5,
       "factorized"] = 
    True, $CellContext`sym$43735[$CellContext`a5, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$43735[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$43735[$CellContext`a5, "raw"] = Part[
      $CellContext`med[All], All, 16], $CellContext`sym$43735[$CellContext`a6,
       "factorized"] = 
    True, $CellContext`sym$43735[$CellContext`a6, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$43735[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$43735[$CellContext`a6, "raw"] = Part[
      $CellContext`med[All], All, 17], $CellContext`sym$43735[$CellContext`a7,
       "factorized"] = 
    True, $CellContext`sym$43735[$CellContext`a7, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$43735[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$43735[$CellContext`a7, "raw"] = Part[
      $CellContext`med[All], All, 18], $CellContext`sym$43735[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$43735[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$43735[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$43735[$CellContext`Chla, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$43735[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$43735[$CellContext`Chla, "raw"] = Part[
      $CellContext`med[All], All, 11], $CellContext`sym$43735[$CellContext`Cl,
       "factorized"] = 
    True, $CellContext`sym$43735[$CellContext`Cl, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$43735[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$43735[$CellContext`Cl, "raw"] = Part[
      $CellContext`med[All], All, 
      6], $CellContext`sym$43735[$CellContext`mnO2, "factorized"] = 
    True, $CellContext`sym$43735[$CellContext`mnO2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$43735[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$43735[$CellContext`mnO2, "raw"] = Part[
      $CellContext`med[All], All, 
      5], $CellContext`sym$43735[$CellContext`mxPH, "factorized"] = 
    True, $CellContext`sym$43735[$CellContext`mxPH, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$43735[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$43735[$CellContext`mxPH, "raw"] = Part[
      $CellContext`med[All], All, 4], $CellContext`sym$43735[$CellContext`NH4,
       "factorized"] = 
    True, $CellContext`sym$43735[$CellContext`NH4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$43735[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$43735[$CellContext`NH4, "raw"] = Part[
      $CellContext`med[All], All, 8], $CellContext`sym$43735[$CellContext`NO3,
       "factorized"] = 
    True, $CellContext`sym$43735[$CellContext`NO3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$43735[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$43735[$CellContext`NO3, "raw"] = Part[
      $CellContext`med[All], All, 
      7], $CellContext`sym$43735[$CellContext`oPO4, "factorized"] = 
    True, $CellContext`sym$43735[$CellContext`oPO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$43735[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$43735[$CellContext`oPO4, "raw"] = Part[
      $CellContext`med[All], All, 9], $CellContext`sym$43735[$CellContext`PO4,
       "factorized"] = 
    True, $CellContext`sym$43735[$CellContext`PO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$43735[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$43735[$CellContext`PO4, "raw"] = Part[
      $CellContext`med[All], All, 
      10], $CellContext`sym$43735[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$43735[$CellContext`season, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$43735[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$43735[$CellContext`season, "raw"] = 
    Part[
      $CellContext`med[All], All, 
      1], $CellContext`sym$43735[$CellContext`size, "factorized"] = 
    True, $CellContext`sym$43735[$CellContext`size, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$43735[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$43735[$CellContext`size, "raw"] = Part[
      $CellContext`med[All], All, 
      2], $CellContext`sym$43735[$CellContext`speed, "factorized"] = 
    True, $CellContext`sym$43735[$CellContext`speed, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$43735[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$43735[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`med[All], All, 3], 
    Attributes[$CellContext`sym$193424] = {
     Temporary}, $CellContext`sym$193424[$CellContext`a1] = Part[
      $CellContext`sym$193424[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$193424[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$193424[$CellContext`a2] = Part[
      $CellContext`sym$193424[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$193424[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$193424[$CellContext`a3] = Part[
      $CellContext`sym$193424[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$193424[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$193424[$CellContext`a4] = Part[
      $CellContext`sym$193424[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$193424[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$193424[$CellContext`a5] = Part[
      $CellContext`sym$193424[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$193424[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$193424[$CellContext`a6] = Part[
      $CellContext`sym$193424[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$193424[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$193424[$CellContext`a7] = Part[
      $CellContext`sym$193424[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$193424[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$193424[All] = $CellContext`med[
     All], $CellContext`sym$193424[$CellContext`Chla] = Part[
      $CellContext`sym$193424[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$193424[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$193424[$CellContext`Cl] = Part[
      $CellContext`sym$193424[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$193424[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$193424[$CellContext`mnO2] = Part[
      $CellContext`sym$193424[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$193424[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$193424[$CellContext`mxPH] = Part[
      $CellContext`sym$193424[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$193424[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$193424[$CellContext`NH4] = Part[
      $CellContext`sym$193424[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$193424[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$193424[$CellContext`NO3] = Part[
      $CellContext`sym$193424[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$193424[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$193424[$CellContext`oPO4] = Part[
      $CellContext`sym$193424[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$193424[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$193424[$CellContext`PO4] = Part[
      $CellContext`sym$193424[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$193424[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$193424[$CellContext`season] = Part[
      $CellContext`sym$193424[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$193424[$CellContext`season, 
         "missing"]]]], $CellContext`sym$193424[$CellContext`size] = Part[
      $CellContext`sym$193424[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$193424[$CellContext`size, 
         "missing"]]]], $CellContext`sym$193424[$CellContext`speed] = Part[
      $CellContext`sym$193424[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$193424[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$193424[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$193424[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$193424, $CellContext`a1]], \
$CellContext`sym$193424[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$193424[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$193424[All], 
      All, $CellContext`i$194983], $CellContext`sym$193424[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$193424[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$193424, $CellContext`a2]], \
$CellContext`sym$193424[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$193424[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$193424[All], 
      All, $CellContext`i$194984], $CellContext`sym$193424[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$193424[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$193424, $CellContext`a3]], \
$CellContext`sym$193424[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$193424[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$193424[All], 
      All, $CellContext`i$194985], $CellContext`sym$193424[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$193424[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$193424, $CellContext`a4]], \
$CellContext`sym$193424[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$193424[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$193424[All], 
      All, $CellContext`i$194986], $CellContext`sym$193424[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$193424[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$193424, $CellContext`a5]], \
$CellContext`sym$193424[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$193424[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$193424[All], 
      All, $CellContext`i$194987], $CellContext`sym$193424[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$193424[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$193424, $CellContext`a6]], \
$CellContext`sym$193424[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$193424[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$193424[All], 
      All, $CellContext`i$194988], $CellContext`sym$193424[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$193424[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$193424, $CellContext`a7]], \
$CellContext`sym$193424[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$193424[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$193424[All], 
      All, $CellContext`i$194989], $CellContext`sym$193424[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$193424[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$193424[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$193424[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$193424, $CellContext`Chla]], \
$CellContext`sym$193424[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$193424[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$193424[All], 
      All, $CellContext`i$194982], $CellContext`sym$193424[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$193424[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$193424, $CellContext`Cl]], \
$CellContext`sym$193424[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$193424[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$193424[All], 
      All, $CellContext`i$194977], $CellContext`sym$193424[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$193424[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$193424, $CellContext`mnO2]], \
$CellContext`sym$193424[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$193424[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$193424[All], 
      All, $CellContext`i$194976], $CellContext`sym$193424[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$193424[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$193424, $CellContext`mxPH]], \
$CellContext`sym$193424[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$193424[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$193424[All], 
      All, $CellContext`i$194975], $CellContext`sym$193424[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$193424[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$193424, $CellContext`NH4]], \
$CellContext`sym$193424[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$193424[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$193424[All], 
      All, $CellContext`i$194979], $CellContext`sym$193424[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$193424[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$193424, $CellContext`NO3]], \
$CellContext`sym$193424[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$193424[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$193424[All], 
      All, $CellContext`i$194978], $CellContext`sym$193424[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$193424[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$193424, $CellContext`oPO4]], \
$CellContext`sym$193424[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$193424[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$193424[All], 
      All, $CellContext`i$194980], $CellContext`sym$193424[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$193424[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$193424, $CellContext`PO4]], \
$CellContext`sym$193424[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$193424[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$193424[All], 
      All, $CellContext`i$194981], \
$CellContext`sym$193424[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$193424[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$193424, $CellContext`season]], \
$CellContext`sym$193424[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$193424[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$193424[All], 
      All, $CellContext`i$193425], $CellContext`sym$193424[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$193424[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$193424, $CellContext`size]], \
$CellContext`sym$193424[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$193424[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$193424[All], 
      All, $CellContext`i$194973], $CellContext`sym$193424[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$193424[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$193424, $CellContext`speed]], \
$CellContext`sym$193424[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$193424[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$193424[All], All, $CellContext`i$194974], 
    Attributes[$CellContext`i$194987] = {Temporary}, $CellContext`i$194987 = 
    16, Attributes[$CellContext`i$194975] = {
     Temporary}, $CellContext`i$194975 = 4, 
    Attributes[$CellContext`i$194977] = {Temporary}, $CellContext`i$194977 = 
    6, Attributes[$CellContext`i$194973] = {Temporary}, $CellContext`i$194973 = 
    2, Attributes[$CellContext`i$194979] = {Temporary}, $CellContext`i$194979 = 
    8, Attributes[$CellContext`i$194989] = {Temporary}, $CellContext`i$194989 = 
    18, Attributes[$CellContext`i$194981] = {
     Temporary}, $CellContext`i$194981 = 10, 
    Attributes[$CellContext`i$194974] = {Temporary}, $CellContext`i$194974 = 
    3, Attributes[$CellContext`i$194976] = {Temporary}, $CellContext`i$194976 = 
    5, Attributes[$CellContext`i$193425] = {Temporary}, $CellContext`i$193425 = 
    1, Attributes[$CellContext`i$194985] = {Temporary}, $CellContext`i$194985 = 
    14, Attributes[$CellContext`i$194978] = {
     Temporary}, $CellContext`i$194978 = 7, 
    Attributes[$CellContext`i$194986] = {Temporary}, $CellContext`i$194986 = 
    15, Attributes[$CellContext`i$194988] = {
     Temporary}, $CellContext`i$194988 = 17, 
    Attributes[$CellContext`i$194980] = {Temporary}, $CellContext`i$194980 = 
    9, Attributes[$CellContext`i$194983] = {Temporary}, $CellContext`i$194983 = 
    12, Attributes[$CellContext`i$194982] = {
     Temporary}, $CellContext`i$194982 = 11, 
    Attributes[$CellContext`i$194984] = {Temporary}, $CellContext`i$194984 = 
    13, Attributes[$CellContext`sym$162162] = {
     Temporary}, $CellContext`sym$162162[$CellContext`a1] = Part[
      $CellContext`sym$162162[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$162162[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$162162[$CellContext`a2] = Part[
      $CellContext`sym$162162[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$162162[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$162162[$CellContext`a3] = Part[
      $CellContext`sym$162162[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$162162[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$162162[$CellContext`a4] = Part[
      $CellContext`sym$162162[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$162162[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$162162[$CellContext`a5] = Part[
      $CellContext`sym$162162[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$162162[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$162162[$CellContext`a6] = Part[
      $CellContext`sym$162162[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$162162[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$162162[$CellContext`a7] = Part[
      $CellContext`sym$162162[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$162162[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$162162[All] = $CellContext`med[
     All], $CellContext`sym$162162[$CellContext`Chla] = Part[
      $CellContext`sym$162162[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$162162[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$162162[$CellContext`Cl] = Part[
      $CellContext`sym$162162[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$162162[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$162162[$CellContext`mnO2] = Part[
      $CellContext`sym$162162[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$162162[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$162162[$CellContext`mxPH] = Part[
      $CellContext`sym$162162[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$162162[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$162162[$CellContext`NH4] = Part[
      $CellContext`sym$162162[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$162162[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$162162[$CellContext`NO3] = Part[
      $CellContext`sym$162162[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$162162[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$162162[$CellContext`oPO4] = Part[
      $CellContext`sym$162162[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$162162[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$162162[$CellContext`PO4] = Part[
      $CellContext`sym$162162[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$162162[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$162162[$CellContext`season] = Part[
      $CellContext`sym$162162[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$162162[$CellContext`season, 
         "missing"]]]], $CellContext`sym$162162[$CellContext`size] = Part[
      $CellContext`sym$162162[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$162162[$CellContext`size, 
         "missing"]]]], $CellContext`sym$162162[$CellContext`speed] = Part[
      $CellContext`sym$162162[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$162162[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$162162[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$162162[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$162162, $CellContext`a1]], \
$CellContext`sym$162162[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$162162[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$162162[All], 
      All, $CellContext`i$163721], $CellContext`sym$162162[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$162162[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$162162, $CellContext`a2]], \
$CellContext`sym$162162[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$162162[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$162162[All], 
      All, $CellContext`i$163722], $CellContext`sym$162162[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$162162[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$162162, $CellContext`a3]], \
$CellContext`sym$162162[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$162162[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$162162[All], 
      All, $CellContext`i$163723], $CellContext`sym$162162[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$162162[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$162162, $CellContext`a4]], \
$CellContext`sym$162162[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$162162[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$162162[All], 
      All, $CellContext`i$163724], $CellContext`sym$162162[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$162162[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$162162, $CellContext`a5]], \
$CellContext`sym$162162[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$162162[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$162162[All], 
      All, $CellContext`i$163725], $CellContext`sym$162162[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$162162[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$162162, $CellContext`a6]], \
$CellContext`sym$162162[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$162162[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$162162[All], 
      All, $CellContext`i$163726], $CellContext`sym$162162[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$162162[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$162162, $CellContext`a7]], \
$CellContext`sym$162162[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$162162[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$162162[All], 
      All, $CellContext`i$163727], $CellContext`sym$162162[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$162162[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$162162[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$162162[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$162162, $CellContext`Chla]], \
$CellContext`sym$162162[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$162162[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$162162[All], 
      All, $CellContext`i$163720], $CellContext`sym$162162[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$162162[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$162162, $CellContext`Cl]], \
$CellContext`sym$162162[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$162162[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$162162[All], 
      All, $CellContext`i$163715], $CellContext`sym$162162[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$162162[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$162162, $CellContext`mnO2]], \
$CellContext`sym$162162[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$162162[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$162162[All], 
      All, $CellContext`i$163714], $CellContext`sym$162162[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$162162[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$162162, $CellContext`mxPH]], \
$CellContext`sym$162162[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$162162[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$162162[All], 
      All, $CellContext`i$163713], $CellContext`sym$162162[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$162162[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$162162, $CellContext`NH4]], \
$CellContext`sym$162162[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$162162[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$162162[All], 
      All, $CellContext`i$163717], $CellContext`sym$162162[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$162162[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$162162, $CellContext`NO3]], \
$CellContext`sym$162162[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$162162[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$162162[All], 
      All, $CellContext`i$163716], $CellContext`sym$162162[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$162162[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$162162, $CellContext`oPO4]], \
$CellContext`sym$162162[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$162162[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$162162[All], 
      All, $CellContext`i$163718], $CellContext`sym$162162[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$162162[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$162162, $CellContext`PO4]], \
$CellContext`sym$162162[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$162162[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$162162[All], 
      All, $CellContext`i$163719], \
$CellContext`sym$162162[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$162162[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$162162, $CellContext`season]], \
$CellContext`sym$162162[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$162162[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$162162[All], 
      All, $CellContext`i$162163], $CellContext`sym$162162[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$162162[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$162162, $CellContext`size]], \
$CellContext`sym$162162[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$162162[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$162162[All], 
      All, $CellContext`i$163711], $CellContext`sym$162162[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$162162[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$162162, $CellContext`speed]], \
$CellContext`sym$162162[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$162162[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$162162[All], All, $CellContext`i$163712], 
    Attributes[$CellContext`i$163717] = {Temporary}, $CellContext`i$163717 = 
    8, Attributes[$CellContext`i$163714] = {Temporary}, $CellContext`i$163714 = 
    5, Attributes[$CellContext`i$163721] = {Temporary}, $CellContext`i$163721 = 
    12, Attributes[$CellContext`i$163719] = {
     Temporary}, $CellContext`i$163719 = 10, 
    Attributes[$CellContext`i$163718] = {Temporary}, $CellContext`i$163718 = 
    9, Attributes[$CellContext`i$163720] = {Temporary}, $CellContext`i$163720 = 
    11, Attributes[$CellContext`i$163712] = {
     Temporary}, $CellContext`i$163712 = 3, 
    Attributes[$CellContext`i$163726] = {Temporary}, $CellContext`i$163726 = 
    17, Attributes[$CellContext`i$163724] = {
     Temporary}, $CellContext`i$163724 = 15, 
    Attributes[$CellContext`i$163711] = {Temporary}, $CellContext`i$163711 = 
    2, Attributes[$CellContext`i$163725] = {Temporary}, $CellContext`i$163725 = 
    16, Attributes[$CellContext`i$162163] = {
     Temporary}, $CellContext`i$162163 = 1, 
    Attributes[$CellContext`i$163716] = {Temporary}, $CellContext`i$163716 = 
    7, Attributes[$CellContext`i$163713] = {Temporary}, $CellContext`i$163713 = 
    4, Attributes[$CellContext`i$163722] = {Temporary}, $CellContext`i$163722 = 
    13, Attributes[$CellContext`i$163727] = {
     Temporary}, $CellContext`i$163727 = 18, 
    Attributes[$CellContext`i$163723] = {Temporary}, $CellContext`i$163723 = 
    14, Attributes[$CellContext`i$163715] = {
     Temporary}, $CellContext`i$163715 = 6, 
    Attributes[$CellContext`sym$19171] = {
     Temporary}, $CellContext`sym$19171[$CellContext`a1] = $CellContext`med[
     All], $CellContext`sym$19171[$CellContext`a2] = $CellContext`med[
     All], $CellContext`sym$19171[$CellContext`a3] = $CellContext`med[
     All], $CellContext`sym$19171[$CellContext`a4] = $CellContext`med[
     All], $CellContext`sym$19171[$CellContext`a5] = $CellContext`med[
     All], $CellContext`sym$19171[$CellContext`a6] = $CellContext`med[
     All], $CellContext`sym$19171[$CellContext`a7] = $CellContext`med[
     All], $CellContext`sym$19171[All] = $CellContext`med[
     All], $CellContext`sym$19171[$CellContext`Chla] = $CellContext`med[
     All], $CellContext`sym$19171[$CellContext`Cl] = $CellContext`med[
     All], $CellContext`sym$19171[$CellContext`mnO2] = $CellContext`med[
     All], $CellContext`sym$19171[$CellContext`mxPH] = $CellContext`med[
     All], $CellContext`sym$19171[$CellContext`NH4] = $CellContext`med[
     All], $CellContext`sym$19171[$CellContext`NO3] = $CellContext`med[
     All], $CellContext`sym$19171[$CellContext`oPO4] = $CellContext`med[
     All], $CellContext`sym$19171[$CellContext`PO4] = $CellContext`med[
     All], $CellContext`sym$19171[$CellContext`season] = $CellContext`med[
     All], $CellContext`sym$19171[$CellContext`size] = $CellContext`med[
     All], $CellContext`sym$19171[$CellContext`speed] = $CellContext`med[
     All], $CellContext`sym$19171[$CellContext`a1, "factorized"] = 
    True, $CellContext`sym$19171[$CellContext`a1, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$19171[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$19171[$CellContext`a1, "raw"] = Part[
      $CellContext`med[All], All, 12], $CellContext`sym$19171[$CellContext`a2,
       "factorized"] = 
    True, $CellContext`sym$19171[$CellContext`a2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$19171[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$19171[$CellContext`a2, "raw"] = Part[
      $CellContext`med[All], All, 13], $CellContext`sym$19171[$CellContext`a3,
       "factorized"] = 
    True, $CellContext`sym$19171[$CellContext`a3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$19171[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$19171[$CellContext`a3, "raw"] = Part[
      $CellContext`med[All], All, 14], $CellContext`sym$19171[$CellContext`a4,
       "factorized"] = 
    True, $CellContext`sym$19171[$CellContext`a4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$19171[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$19171[$CellContext`a4, "raw"] = Part[
      $CellContext`med[All], All, 15], $CellContext`sym$19171[$CellContext`a5,
       "factorized"] = 
    True, $CellContext`sym$19171[$CellContext`a5, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$19171[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$19171[$CellContext`a5, "raw"] = Part[
      $CellContext`med[All], All, 16], $CellContext`sym$19171[$CellContext`a6,
       "factorized"] = 
    True, $CellContext`sym$19171[$CellContext`a6, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$19171[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$19171[$CellContext`a6, "raw"] = Part[
      $CellContext`med[All], All, 17], $CellContext`sym$19171[$CellContext`a7,
       "factorized"] = 
    True, $CellContext`sym$19171[$CellContext`a7, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$19171[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$19171[$CellContext`a7, "raw"] = Part[
      $CellContext`med[All], All, 18], $CellContext`sym$19171[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$19171[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$19171[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$19171[$CellContext`Chla, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$19171[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$19171[$CellContext`Chla, "raw"] = Part[
      $CellContext`med[All], All, 11], $CellContext`sym$19171[$CellContext`Cl,
       "factorized"] = 
    True, $CellContext`sym$19171[$CellContext`Cl, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$19171[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$19171[$CellContext`Cl, "raw"] = Part[
      $CellContext`med[All], All, 
      6], $CellContext`sym$19171[$CellContext`mnO2, "factorized"] = 
    True, $CellContext`sym$19171[$CellContext`mnO2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$19171[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$19171[$CellContext`mnO2, "raw"] = Part[
      $CellContext`med[All], All, 
      5], $CellContext`sym$19171[$CellContext`mxPH, "factorized"] = 
    True, $CellContext`sym$19171[$CellContext`mxPH, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$19171[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$19171[$CellContext`mxPH, "raw"] = Part[
      $CellContext`med[All], All, 4], $CellContext`sym$19171[$CellContext`NH4,
       "factorized"] = 
    True, $CellContext`sym$19171[$CellContext`NH4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$19171[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$19171[$CellContext`NH4, "raw"] = Part[
      $CellContext`med[All], All, 8], $CellContext`sym$19171[$CellContext`NO3,
       "factorized"] = 
    True, $CellContext`sym$19171[$CellContext`NO3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$19171[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$19171[$CellContext`NO3, "raw"] = Part[
      $CellContext`med[All], All, 
      7], $CellContext`sym$19171[$CellContext`oPO4, "factorized"] = 
    True, $CellContext`sym$19171[$CellContext`oPO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$19171[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$19171[$CellContext`oPO4, "raw"] = Part[
      $CellContext`med[All], All, 9], $CellContext`sym$19171[$CellContext`PO4,
       "factorized"] = 
    True, $CellContext`sym$19171[$CellContext`PO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$19171[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$19171[$CellContext`PO4, "raw"] = Part[
      $CellContext`med[All], All, 
      10], $CellContext`sym$19171[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$19171[$CellContext`season, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$19171[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$19171[$CellContext`season, "raw"] = 
    Part[
      $CellContext`med[All], All, 
      1], $CellContext`sym$19171[$CellContext`size, "factorized"] = 
    True, $CellContext`sym$19171[$CellContext`size, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$19171[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$19171[$CellContext`size, "raw"] = Part[
      $CellContext`med[All], All, 
      2], $CellContext`sym$19171[$CellContext`speed, "factorized"] = 
    True, $CellContext`sym$19171[$CellContext`speed, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$19171[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$19171[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`med[All], All, 3], 
    Attributes[$CellContext`sym$200123] = {
     Temporary}, $CellContext`sym$200123[$CellContext`a1] = Part[
      $CellContext`sym$200123[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$200123[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$200123[$CellContext`a2] = Part[
      $CellContext`sym$200123[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$200123[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$200123[$CellContext`a3] = Part[
      $CellContext`sym$200123[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$200123[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$200123[$CellContext`a4] = Part[
      $CellContext`sym$200123[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$200123[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$200123[$CellContext`a5] = Part[
      $CellContext`sym$200123[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$200123[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$200123[$CellContext`a6] = Part[
      $CellContext`sym$200123[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$200123[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$200123[$CellContext`a7] = Part[
      $CellContext`sym$200123[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$200123[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$200123[All] = $CellContext`med[
     All], $CellContext`sym$200123[$CellContext`Chla] = Part[
      $CellContext`sym$200123[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$200123[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$200123[$CellContext`Cl] = Part[
      $CellContext`sym$200123[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$200123[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$200123[$CellContext`mnO2] = Part[
      $CellContext`sym$200123[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$200123[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$200123[$CellContext`mxPH] = Part[
      $CellContext`sym$200123[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$200123[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$200123[$CellContext`NH4] = Part[
      $CellContext`sym$200123[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$200123[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$200123[$CellContext`NO3] = Part[
      $CellContext`sym$200123[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$200123[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$200123[$CellContext`oPO4] = Part[
      $CellContext`sym$200123[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$200123[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$200123[$CellContext`PO4] = Part[
      $CellContext`sym$200123[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$200123[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$200123[$CellContext`season] = Part[
      $CellContext`sym$200123[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$200123[$CellContext`season, 
         "missing"]]]], $CellContext`sym$200123[$CellContext`size] = Part[
      $CellContext`sym$200123[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$200123[$CellContext`size, 
         "missing"]]]], $CellContext`sym$200123[$CellContext`speed] = Part[
      $CellContext`sym$200123[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$200123[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$200123[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$200123[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$200123, $CellContext`a1]], \
$CellContext`sym$200123[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$200123[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$200123[All], 
      All, $CellContext`i$201682], $CellContext`sym$200123[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$200123[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$200123, $CellContext`a2]], \
$CellContext`sym$200123[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$200123[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$200123[All], 
      All, $CellContext`i$201683], $CellContext`sym$200123[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$200123[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$200123, $CellContext`a3]], \
$CellContext`sym$200123[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$200123[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$200123[All], 
      All, $CellContext`i$201684], $CellContext`sym$200123[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$200123[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$200123, $CellContext`a4]], \
$CellContext`sym$200123[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$200123[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$200123[All], 
      All, $CellContext`i$201685], $CellContext`sym$200123[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$200123[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$200123, $CellContext`a5]], \
$CellContext`sym$200123[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$200123[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$200123[All], 
      All, $CellContext`i$201686], $CellContext`sym$200123[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$200123[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$200123, $CellContext`a6]], \
$CellContext`sym$200123[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$200123[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$200123[All], 
      All, $CellContext`i$201687], $CellContext`sym$200123[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$200123[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$200123, $CellContext`a7]], \
$CellContext`sym$200123[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$200123[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$200123[All], 
      All, $CellContext`i$201688], $CellContext`sym$200123[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$200123[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$200123[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$200123[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$200123, $CellContext`Chla]], \
$CellContext`sym$200123[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$200123[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$200123[All], 
      All, $CellContext`i$201681], $CellContext`sym$200123[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$200123[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$200123, $CellContext`Cl]], \
$CellContext`sym$200123[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$200123[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$200123[All], 
      All, $CellContext`i$201676], $CellContext`sym$200123[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$200123[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$200123, $CellContext`mnO2]], \
$CellContext`sym$200123[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$200123[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$200123[All], 
      All, $CellContext`i$201675], $CellContext`sym$200123[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$200123[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$200123, $CellContext`mxPH]], \
$CellContext`sym$200123[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$200123[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$200123[All], 
      All, $CellContext`i$201674], $CellContext`sym$200123[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$200123[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$200123, $CellContext`NH4]], \
$CellContext`sym$200123[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$200123[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$200123[All], 
      All, $CellContext`i$201678], $CellContext`sym$200123[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$200123[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$200123, $CellContext`NO3]], \
$CellContext`sym$200123[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$200123[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$200123[All], 
      All, $CellContext`i$201677], $CellContext`sym$200123[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$200123[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$200123, $CellContext`oPO4]], \
$CellContext`sym$200123[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$200123[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$200123[All], 
      All, $CellContext`i$201679], $CellContext`sym$200123[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$200123[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$200123, $CellContext`PO4]], \
$CellContext`sym$200123[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$200123[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$200123[All], 
      All, $CellContext`i$201680], \
$CellContext`sym$200123[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$200123[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$200123, $CellContext`season]], \
$CellContext`sym$200123[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$200123[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$200123[All], 
      All, $CellContext`i$200124], $CellContext`sym$200123[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$200123[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$200123, $CellContext`size]], \
$CellContext`sym$200123[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$200123[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$200123[All], 
      All, $CellContext`i$201672], $CellContext`sym$200123[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$200123[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$200123, $CellContext`speed]], \
$CellContext`sym$200123[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$200123[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$200123[All], All, $CellContext`i$201673], 
    Attributes[$CellContext`i$201683] = {Temporary}, $CellContext`i$201683 = 
    13, Attributes[$CellContext`i$201685] = {
     Temporary}, $CellContext`i$201685 = 15, 
    Attributes[$CellContext`i$201676] = {Temporary}, $CellContext`i$201676 = 
    6, Attributes[$CellContext`i$200124] = {Temporary}, $CellContext`i$200124 = 
    1, Attributes[$CellContext`i$201687] = {Temporary}, $CellContext`i$201687 = 
    17, Attributes[$CellContext`i$201679] = {
     Temporary}, $CellContext`i$201679 = 9, 
    Attributes[$CellContext`i$201681] = {Temporary}, $CellContext`i$201681 = 
    11, Attributes[$CellContext`i$201678] = {
     Temporary}, $CellContext`i$201678 = 8, 
    Attributes[$CellContext`i$201686] = {Temporary}, $CellContext`i$201686 = 
    16, Attributes[$CellContext`i$201675] = {
     Temporary}, $CellContext`i$201675 = 5, 
    Attributes[$CellContext`i$201682] = {Temporary}, $CellContext`i$201682 = 
    12, Attributes[$CellContext`i$201673] = {
     Temporary}, $CellContext`i$201673 = 3, 
    Attributes[$CellContext`i$201674] = {Temporary}, $CellContext`i$201674 = 
    4, Attributes[$CellContext`i$201677] = {Temporary}, $CellContext`i$201677 = 
    7, Attributes[$CellContext`i$201688] = {Temporary}, $CellContext`i$201688 = 
    18, Attributes[$CellContext`i$201672] = {
     Temporary}, $CellContext`i$201672 = 2, 
    Attributes[$CellContext`i$201684] = {Temporary}, $CellContext`i$201684 = 
    14, Attributes[$CellContext`i$201680] = {
     Temporary}, $CellContext`i$201680 = 10, 
    Attributes[$CellContext`sym$166628] = {
     Temporary}, $CellContext`sym$166628[$CellContext`a1] = Part[
      $CellContext`sym$166628[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$166628[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$166628[$CellContext`a2] = Part[
      $CellContext`sym$166628[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$166628[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$166628[$CellContext`a3] = Part[
      $CellContext`sym$166628[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$166628[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$166628[$CellContext`a4] = Part[
      $CellContext`sym$166628[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$166628[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$166628[$CellContext`a5] = Part[
      $CellContext`sym$166628[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$166628[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$166628[$CellContext`a6] = Part[
      $CellContext`sym$166628[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$166628[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$166628[$CellContext`a7] = Part[
      $CellContext`sym$166628[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$166628[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$166628[All] = $CellContext`med[
     All], $CellContext`sym$166628[$CellContext`Chla] = Part[
      $CellContext`sym$166628[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$166628[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$166628[$CellContext`Cl] = Part[
      $CellContext`sym$166628[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$166628[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$166628[$CellContext`mnO2] = Part[
      $CellContext`sym$166628[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$166628[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$166628[$CellContext`mxPH] = Part[
      $CellContext`sym$166628[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$166628[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$166628[$CellContext`NH4] = Part[
      $CellContext`sym$166628[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$166628[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$166628[$CellContext`NO3] = Part[
      $CellContext`sym$166628[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$166628[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$166628[$CellContext`oPO4] = Part[
      $CellContext`sym$166628[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$166628[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$166628[$CellContext`PO4] = Part[
      $CellContext`sym$166628[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$166628[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$166628[$CellContext`season] = Part[
      $CellContext`sym$166628[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$166628[$CellContext`season, 
         "missing"]]]], $CellContext`sym$166628[$CellContext`size] = Part[
      $CellContext`sym$166628[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$166628[$CellContext`size, 
         "missing"]]]], $CellContext`sym$166628[$CellContext`speed] = Part[
      $CellContext`sym$166628[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$166628[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$166628[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$166628[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$166628, $CellContext`a1]], \
$CellContext`sym$166628[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$166628[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$166628[All], 
      All, $CellContext`i$168187], $CellContext`sym$166628[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$166628[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$166628, $CellContext`a2]], \
$CellContext`sym$166628[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$166628[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$166628[All], 
      All, $CellContext`i$168188], $CellContext`sym$166628[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$166628[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$166628, $CellContext`a3]], \
$CellContext`sym$166628[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$166628[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$166628[All], 
      All, $CellContext`i$168189], $CellContext`sym$166628[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$166628[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$166628, $CellContext`a4]], \
$CellContext`sym$166628[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$166628[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$166628[All], 
      All, $CellContext`i$168190], $CellContext`sym$166628[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$166628[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$166628, $CellContext`a5]], \
$CellContext`sym$166628[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$166628[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$166628[All], 
      All, $CellContext`i$168191], $CellContext`sym$166628[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$166628[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$166628, $CellContext`a6]], \
$CellContext`sym$166628[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$166628[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$166628[All], 
      All, $CellContext`i$168192], $CellContext`sym$166628[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$166628[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$166628, $CellContext`a7]], \
$CellContext`sym$166628[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$166628[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$166628[All], 
      All, $CellContext`i$168193], $CellContext`sym$166628[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$166628[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$166628[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$166628[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$166628, $CellContext`Chla]], \
$CellContext`sym$166628[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$166628[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$166628[All], 
      All, $CellContext`i$168186], $CellContext`sym$166628[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$166628[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$166628, $CellContext`Cl]], \
$CellContext`sym$166628[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$166628[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$166628[All], 
      All, $CellContext`i$168181], $CellContext`sym$166628[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$166628[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$166628, $CellContext`mnO2]], \
$CellContext`sym$166628[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$166628[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$166628[All], 
      All, $CellContext`i$168180], $CellContext`sym$166628[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$166628[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$166628, $CellContext`mxPH]], \
$CellContext`sym$166628[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$166628[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$166628[All], 
      All, $CellContext`i$168179], $CellContext`sym$166628[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$166628[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$166628, $CellContext`NH4]], \
$CellContext`sym$166628[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$166628[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$166628[All], 
      All, $CellContext`i$168183], $CellContext`sym$166628[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$166628[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$166628, $CellContext`NO3]], \
$CellContext`sym$166628[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$166628[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$166628[All], 
      All, $CellContext`i$168182], $CellContext`sym$166628[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$166628[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$166628, $CellContext`oPO4]], \
$CellContext`sym$166628[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$166628[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$166628[All], 
      All, $CellContext`i$168184], $CellContext`sym$166628[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$166628[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$166628, $CellContext`PO4]], \
$CellContext`sym$166628[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$166628[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$166628[All], 
      All, $CellContext`i$168185], \
$CellContext`sym$166628[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$166628[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$166628, $CellContext`season]], \
$CellContext`sym$166628[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$166628[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$166628[All], 
      All, $CellContext`i$166629], $CellContext`sym$166628[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$166628[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$166628, $CellContext`size]], \
$CellContext`sym$166628[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$166628[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$166628[All], 
      All, $CellContext`i$168177], $CellContext`sym$166628[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$166628[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$166628, $CellContext`speed]], \
$CellContext`sym$166628[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$166628[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$166628[All], All, $CellContext`i$168178], 
    Attributes[$CellContext`i$168184] = {Temporary}, $CellContext`i$168184 = 
    9, Attributes[$CellContext`i$168183] = {Temporary}, $CellContext`i$168183 = 
    8, Attributes[$CellContext`i$166629] = {Temporary}, $CellContext`i$166629 = 
    1, Attributes[$CellContext`i$168180] = {Temporary}, $CellContext`i$168180 = 
    5, Attributes[$CellContext`i$168193] = {Temporary}, $CellContext`i$168193 = 
    18, Attributes[$CellContext`i$168177] = {
     Temporary}, $CellContext`i$168177 = 2, 
    Attributes[$CellContext`i$168182] = {Temporary}, $CellContext`i$168182 = 
    7, Attributes[$CellContext`i$168190] = {Temporary}, $CellContext`i$168190 = 
    15, Attributes[$CellContext`i$168189] = {
     Temporary}, $CellContext`i$168189 = 14, 
    Attributes[$CellContext`i$168178] = {Temporary}, $CellContext`i$168178 = 
    3, Attributes[$CellContext`i$168192] = {Temporary}, $CellContext`i$168192 = 
    17, Attributes[$CellContext`i$168191] = {
     Temporary}, $CellContext`i$168191 = 16, 
    Attributes[$CellContext`i$168179] = {Temporary}, $CellContext`i$168179 = 
    4, Attributes[$CellContext`i$168187] = {Temporary}, $CellContext`i$168187 = 
    12, Attributes[$CellContext`i$168186] = {
     Temporary}, $CellContext`i$168186 = 11, 
    Attributes[$CellContext`i$168181] = {Temporary}, $CellContext`i$168181 = 
    6, Attributes[$CellContext`i$168185] = {Temporary}, $CellContext`i$168185 = 
    10, Attributes[$CellContext`i$168188] = {
     Temporary}, $CellContext`i$168188 = 13, 
    Attributes[$CellContext`sym$230375] = {
     Temporary}, $CellContext`sym$230375[$CellContext`a1] = Part[
      $CellContext`sym$230375[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$230375[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$230375[$CellContext`a2] = Part[
      $CellContext`sym$230375[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$230375[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$230375[$CellContext`a3] = Part[
      $CellContext`sym$230375[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$230375[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$230375[$CellContext`a4] = Part[
      $CellContext`sym$230375[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$230375[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$230375[$CellContext`a5] = Part[
      $CellContext`sym$230375[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$230375[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$230375[$CellContext`a6] = Part[
      $CellContext`sym$230375[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$230375[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$230375[$CellContext`a7] = Part[
      $CellContext`sym$230375[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$230375[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$230375[
     All] = {{"winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 
       170., 50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
      "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
       558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
      "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 125.667,
        187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
      "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 61.182, 
       138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
      "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222, 
       97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
      "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
       56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
      "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
       111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
      "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 44.667, 
       77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
      "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 71., 
       5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 0.8, 
       17., 0., 0., 2.9, 0., 0., 1.7}, {
      "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 20.75, 
       0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
      "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 19.,
        0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
      "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 41., 
       43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
      "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5, 
       31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
      "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 0.3, 
       52.2, 5., 7.8, 0., 4., 0., 0.}, {
      "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 98.25, 
       1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50., 
       1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
      "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 57.833, 
       0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
      "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 0.8, 
       50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
      "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
       564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
      "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 586.,
        16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
      "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 0.5, 
       15.5, 0., 0., 2.3, 0., 0., 0.}, {
      "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 7.6,
        23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
      "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
       27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
      "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 1.5,
        13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
      "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 44.136, 
       3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
      "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 0.5, 
       29.7, 0., 0., 4.9, 0., 0., 0.}, {
      "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
       Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
      "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 17.1,
        0., 19.6, 0., 0., 0., 2.5}, {
      "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5, 
       33.9, 1., 14.6, 0., 0., 0., 0.}, {
      "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 4.9, 
       3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
      "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 2.8, 
       6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
      "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 130.75, 
       5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
      "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47., 
       2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
      "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23., 
       0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
      "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 58.875, 
       84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
      "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 0.2,
        66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
       Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0., 
       0.}, {
      "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 196.62, 
       253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
      "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
       182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
      "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001, 
       296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
      "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 59.429,
        175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
      "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
       344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
      "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 276.85001, 
       326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
      "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 40.667, 
       3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
      "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 3.3, 
       29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
      "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 0.8, 
       54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
       Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 0., 
       0.}, {"spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121.,
        2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 20.812,
        12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
      "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
       49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
      "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 22.9, 
       4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
      "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 11.8, 
       0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818, 
       0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
      "winter", "small", "high", 6.6, 10.8, 
       Missing[], 3.245, 10., 1., 6.5, 
       Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "medium", 5.6, 11.8, 
       Missing[], 2.22, 5., 1., 1., 
       Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 5.7, 10.8, 
       Missing[], 2.55, 10., 1., 4., 
       Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
      "spring", "small", "high", 6.6, 9.5, 
       Missing[], 1.32, 20., 1., 6., 
       Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
      "summer", "small", "high", 6.6, 10.8, 
       Missing[], 2.64, 10., 2., 11., 
       Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
      "autumn", "small", "medium", 6.6, 11.3, 
       Missing[], 4.17, 10., 1., 6., 
       Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
      "spring", "small", "medium", 6.5, 10.4, 
       Missing[], 5.97, 10., 2., 14., 
       Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
      "summer", "small", "medium", 6.4, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 14., 
       Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
      "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 6.667, 
       Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75, 1.,
        20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
      "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2, 
       0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
      "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 0.6,
        55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
      "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 10.75, 
       2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
      "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 0.5, 
       64.2, 0., 3., 0., 0., 0., 0.}, {
      "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75, 
       351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
      "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
       209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
      "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 151.125,
        279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
      "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
       152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
      "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
       58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
      "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
       249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
      "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 100., 
       233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
      "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 215.5, 
       18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
      "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 25.167, 
       102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
      "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
       105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
      "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
       111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
      "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 1.3, 
       6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
      "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 56.667, 
       2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
      "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 4.3,
        1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
      "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
       104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
      "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 69.93,
        3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
      "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
       214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
      "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
       254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
      "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 57.6,
        169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
      "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
       412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
      "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
       282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
      "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
       197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
      "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 267.75, 
       391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
      "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 191.75, 
       265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
      "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
       232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
      "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 144.66701, 
       244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
      "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 218., 
       6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
      "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 138.5,
        20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
      "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222, 
       239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
      "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
       235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
      "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75, 
       205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
      "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 31.333, 
       211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
      "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625, 
       186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
      "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 12.889, 
       154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
      "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 51.111, 
       183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
      "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
       292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
      "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
       285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
      "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
       201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
      "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
       275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
      "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
       124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
      "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 60.833, 
       141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
      "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71., 
       132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
      "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
       17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
      "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 0.3, 
       46.6, 0., 2.5, 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 8.692, 
       16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
      "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 37.857, 
       102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
      "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
       86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
      "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
       10.111, 
       Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 16.833, 
       18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
      "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545, 
       13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
      "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 261.60001, 
       432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
      "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
       320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
      "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 144., 
       287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
      "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
       166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
      "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
       222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
      "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 36.909, 
       122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
      "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556, 
       127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
      "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
       89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
      "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 55., 
       284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
      "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 102.333, 
       277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
      "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 75.875, 
       177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
      "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
       72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
      "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 48.667, 
       82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
      "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 48.625, 
       66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
      "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 23., 
       173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
      "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 317., 
       5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
      "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 84., 
       4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
      "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 2., 
       10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
      "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 88.5, 
       2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
      "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115., 
       11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
      "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 98.143, 
       2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
      "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
       143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
      "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
       197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
      "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 1., 
       19., 0., 22., 5., 1.1, 5.4, 0.}, {
      "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 10.583, 
       23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
      "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 200.231, 
       19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
      "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 77.333, 
       147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
      "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5, 
       276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
      "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
       123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
      "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 75.207,
        23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
      "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 116.2,
        7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
      "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
       188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
      "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
       72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
      "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 16., 
       0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
      "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 34., 
       53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
      "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 27.5, 
       76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
      "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
       58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
      "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 175.66701, 
       361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
      "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
       22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
      "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 26.8,
        0., 28., 0., 0., 0., 0., 15.1}, {
      "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
       54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
      "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333, 
       34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
      "spring", "large", "low", 9., 5.8, 
       Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 0., 
       0.}, {"spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
       151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
      "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
       269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
      "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 46.438, 
       81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
      "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 85., 
       2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
      "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 66.4, 
       171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
      "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 102.364, 
       232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
      "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 84.3, 
       146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
      "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
       246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
      "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 205.636, 
       219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
      "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 236.39999,
        272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
      "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 1081.66003, 
       346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 5.9, 1.7}, {
      "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 82.222,
        167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
      "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 64.389, 
       137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
      "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 87.333,
        194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
      "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
       159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
      "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 21.3, 
       1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
      "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 0.6,
        37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
      "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
       14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
      "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222, 7.,
        1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 0.8, 
       50.4, 3.8, 0., 0., 0., 0., 0.}, {
      "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 7.654, 
       4., 56.8, 5., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 2.86, 
       17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
      "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 56.091, 
       Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
      "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
       52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
      "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 104.727, 
       228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
      "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 85.4, 
       17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
      "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 87.125,
        14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
      "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 101.455, 
       18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
      "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 50.889, 
       127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
      "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
       81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
      "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 19.727, 
       50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
      "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111, 
       120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
      "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 51.111, 
       91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
      "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 19.111, 
       61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
      "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625, 
       79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
      "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333, 
       75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
      "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333, 
       140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
      "winter", "large", "medium", 8., 7.6, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
      "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
       140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 
       5.8}}, $CellContext`sym$230375[$CellContext`Chla] = Part[
      $CellContext`sym$230375[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$230375[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$230375[$CellContext`Cl] = Part[
      $CellContext`sym$230375[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$230375[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$230375[$CellContext`mnO2] = Part[
      $CellContext`sym$230375[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$230375[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$230375[$CellContext`mxPH] = Part[
      $CellContext`sym$230375[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$230375[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$230375[$CellContext`NH4] = Part[
      $CellContext`sym$230375[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$230375[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$230375[$CellContext`NO3] = Part[
      $CellContext`sym$230375[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$230375[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$230375[$CellContext`oPO4] = Part[
      $CellContext`sym$230375[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$230375[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$230375[$CellContext`PO4] = Part[
      $CellContext`sym$230375[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$230375[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$230375[$CellContext`season] = Part[
      $CellContext`sym$230375[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$230375[$CellContext`season, 
         "missing"]]]], $CellContext`sym$230375[$CellContext`size] = Part[
      $CellContext`sym$230375[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$230375[$CellContext`size, 
         "missing"]]]], $CellContext`sym$230375[$CellContext`speed] = Part[
      $CellContext`sym$230375[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$230375[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$230375[$CellContext`a1, 
      "factorized"] = 
    False, $CellContext`sym$230375[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$230375[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$230375[All], 
      All, $CellContext`i$230387], $CellContext`sym$230375[$CellContext`a2, 
      "factorized"] = 
    False, $CellContext`sym$230375[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$230375[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$230375[All], 
      All, $CellContext`i$230388], $CellContext`sym$230375[$CellContext`a3, 
      "factorized"] = 
    False, $CellContext`sym$230375[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$230375[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$230375[All], 
      All, $CellContext`i$230389], $CellContext`sym$230375[$CellContext`a4, 
      "factorized"] = 
    False, $CellContext`sym$230375[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$230375[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$230375[All], 
      All, $CellContext`i$230390], $CellContext`sym$230375[$CellContext`a5, 
      "factorized"] = 
    False, $CellContext`sym$230375[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$230375[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$230375[All], 
      All, $CellContext`i$230391], $CellContext`sym$230375[$CellContext`a6, 
      "factorized"] = 
    False, $CellContext`sym$230375[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$230375[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$230375[All], 
      All, $CellContext`i$230392], $CellContext`sym$230375[$CellContext`a7, 
      "factorized"] = 
    False, $CellContext`sym$230375[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$230375[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$230375[All], 
      All, $CellContext`i$230393], $CellContext`sym$230375[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$230375[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed}, $CellContext`sym$230375[$CellContext`Chla, "factorized"] = 
    False, $CellContext`sym$230375[$CellContext`Chla, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {63}, {116}, {184}, {
     199}}, $CellContext`sym$230375[$CellContext`Chla, "raw"] = Part[
      $CellContext`sym$230375[All], 
      All, $CellContext`i$230386], $CellContext`sym$230375[$CellContext`Cl, 
      "factorized"] = 
    False, $CellContext`sym$230375[$CellContext`Cl, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {161}, {
     199}}, $CellContext`sym$230375[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$230375[All], 
      All, $CellContext`i$230381], $CellContext`sym$230375[$CellContext`mnO2, 
      "factorized"] = 
    False, $CellContext`sym$230375[$CellContext`mnO2, "missing"] = {{38}, {
     62}}, $CellContext`sym$230375[$CellContext`mnO2, "raw"] = Part[
      $CellContext`sym$230375[All], 
      All, $CellContext`i$230380], $CellContext`sym$230375[$CellContext`mxPH, 
      "factorized"] = 
    False, $CellContext`sym$230375[$CellContext`mxPH, "missing"] = {{
     48}}, $CellContext`sym$230375[$CellContext`mxPH, "raw"] = Part[
      $CellContext`sym$230375[All], 
      All, $CellContext`i$230379], $CellContext`sym$230375[$CellContext`NH4, 
      "factorized"] = 
    False, $CellContext`sym$230375[$CellContext`NH4, "missing"] = {{62}, {
     199}}, $CellContext`sym$230375[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$230375[All], 
      All, $CellContext`i$230383], $CellContext`sym$230375[$CellContext`NO3, 
      "factorized"] = 
    False, $CellContext`sym$230375[$CellContext`NO3, "missing"] = {{62}, {
     199}}, $CellContext`sym$230375[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$230375[All], 
      All, $CellContext`i$230382], $CellContext`sym$230375[$CellContext`oPO4, 
      "factorized"] = 
    False, $CellContext`sym$230375[$CellContext`oPO4, "missing"] = {{62}, {
     199}}, $CellContext`sym$230375[$CellContext`oPO4, "raw"] = Part[
      $CellContext`sym$230375[All], 
      All, $CellContext`i$230384], $CellContext`sym$230375[$CellContext`PO4, 
      "factorized"] = 
    False, $CellContext`sym$230375[$CellContext`PO4, "missing"] = {{28}, {
     199}}, $CellContext`sym$230375[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$230375[All], 
      All, $CellContext`i$230385], \
$CellContext`sym$230375[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$230375[$CellContext`season, "factors"] = 
    Part[{"autumn", "spring", "summer", "winter"}, 
      $CellContext`fordering[$CellContext`sym$230375, $CellContext`season]], \
$CellContext`sym$230375[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$230375[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$230375[All], 
      All, $CellContext`i$230376], $CellContext`sym$230375[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$230375[$CellContext`size, "factors"] = 
    Part[{"large", "medium", "small"}, 
      $CellContext`fordering[$CellContext`sym$230375, $CellContext`size]], \
$CellContext`sym$230375[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$230375[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$230375[All], 
      All, $CellContext`i$230377], $CellContext`sym$230375[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$230375[$CellContext`speed, "factors"] = 
    Part[{"high", "low", "medium"}, 
      $CellContext`fordering[$CellContext`sym$230375, $CellContext`speed]], \
$CellContext`sym$230375[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$230375[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$230375[All], All, $CellContext`i$230378], 
    Attributes[$CellContext`i$230383] = {Temporary}, $CellContext`i$230383 = 
    8, Attributes[$CellContext`i$230382] = {Temporary}, $CellContext`i$230382 = 
    7, Attributes[$CellContext`i$230393] = {Temporary}, $CellContext`i$230393 = 
    18, Attributes[$CellContext`i$230388] = {
     Temporary}, $CellContext`i$230388 = 13, 
    Attributes[$CellContext`i$230379] = {Temporary}, $CellContext`i$230379 = 
    4, Attributes[$CellContext`i$230390] = {Temporary}, $CellContext`i$230390 = 
    15, Attributes[$CellContext`i$230385] = {
     Temporary}, $CellContext`i$230385 = 10, 
    Attributes[$CellContext`i$230387] = {Temporary}, $CellContext`i$230387 = 
    12, Attributes[$CellContext`i$230391] = {
     Temporary}, $CellContext`i$230391 = 16, 
    Attributes[$CellContext`i$230377] = {Temporary}, $CellContext`i$230377 = 
    2, Attributes[$CellContext`i$230376] = {Temporary}, $CellContext`i$230376 = 
    1, Attributes[$CellContext`i$230389] = {Temporary}, $CellContext`i$230389 = 
    14, Attributes[$CellContext`i$230378] = {
     Temporary}, $CellContext`i$230378 = 3, 
    Attributes[$CellContext`i$230381] = {Temporary}, $CellContext`i$230381 = 
    6, Attributes[$CellContext`i$230392] = {Temporary}, $CellContext`i$230392 = 
    17, Attributes[$CellContext`i$230380] = {
     Temporary}, $CellContext`i$230380 = 5, 
    Attributes[$CellContext`i$230384] = {Temporary}, $CellContext`i$230384 = 
    9, Attributes[$CellContext`i$230386] = {Temporary}, $CellContext`i$230386 = 
    11, Attributes[$CellContext`sym$211288] = {
     Temporary}, $CellContext`sym$211288[$CellContext`a1] = Part[
      $CellContext`sym$211288[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$211288[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$211288[$CellContext`a2] = Part[
      $CellContext`sym$211288[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$211288[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$211288[$CellContext`a3] = Part[
      $CellContext`sym$211288[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$211288[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$211288[$CellContext`a4] = Part[
      $CellContext`sym$211288[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$211288[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$211288[$CellContext`a5] = Part[
      $CellContext`sym$211288[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$211288[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$211288[$CellContext`a6] = Part[
      $CellContext`sym$211288[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$211288[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$211288[$CellContext`a7] = Part[
      $CellContext`sym$211288[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$211288[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$211288[All] = $CellContext`med[
     All], $CellContext`sym$211288[$CellContext`Chla] = Part[
      $CellContext`sym$211288[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$211288[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$211288[$CellContext`Cl] = Part[
      $CellContext`sym$211288[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$211288[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$211288[$CellContext`mnO2] = Part[
      $CellContext`sym$211288[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$211288[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$211288[$CellContext`mxPH] = Part[
      $CellContext`sym$211288[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$211288[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$211288[$CellContext`NH4] = Part[
      $CellContext`sym$211288[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$211288[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$211288[$CellContext`NO3] = Part[
      $CellContext`sym$211288[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$211288[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$211288[$CellContext`oPO4] = Part[
      $CellContext`sym$211288[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$211288[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$211288[$CellContext`PO4] = Part[
      $CellContext`sym$211288[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$211288[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$211288[$CellContext`season] = Part[
      $CellContext`sym$211288[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$211288[$CellContext`season, 
         "missing"]]]], $CellContext`sym$211288[$CellContext`size] = Part[
      $CellContext`sym$211288[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$211288[$CellContext`size, 
         "missing"]]]], $CellContext`sym$211288[$CellContext`speed] = Part[
      $CellContext`sym$211288[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$211288[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$211288[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$211288[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$211288, $CellContext`a1]], \
$CellContext`sym$211288[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$211288[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$211288[All], 
      All, $CellContext`i$212847], $CellContext`sym$211288[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$211288[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$211288, $CellContext`a2]], \
$CellContext`sym$211288[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$211288[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$211288[All], 
      All, $CellContext`i$212848], $CellContext`sym$211288[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$211288[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$211288, $CellContext`a3]], \
$CellContext`sym$211288[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$211288[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$211288[All], 
      All, $CellContext`i$212849], $CellContext`sym$211288[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$211288[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$211288, $CellContext`a4]], \
$CellContext`sym$211288[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$211288[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$211288[All], 
      All, $CellContext`i$212850], $CellContext`sym$211288[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$211288[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$211288, $CellContext`a5]], \
$CellContext`sym$211288[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$211288[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$211288[All], 
      All, $CellContext`i$212851], $CellContext`sym$211288[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$211288[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$211288, $CellContext`a6]], \
$CellContext`sym$211288[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$211288[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$211288[All], 
      All, $CellContext`i$212852], $CellContext`sym$211288[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$211288[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$211288, $CellContext`a7]], \
$CellContext`sym$211288[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$211288[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$211288[All], 
      All, $CellContext`i$212853], $CellContext`sym$211288[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$211288[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$211288[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$211288[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$211288, $CellContext`Chla]], \
$CellContext`sym$211288[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$211288[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$211288[All], 
      All, $CellContext`i$212846], $CellContext`sym$211288[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$211288[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$211288, $CellContext`Cl]], \
$CellContext`sym$211288[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$211288[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$211288[All], 
      All, $CellContext`i$212841], $CellContext`sym$211288[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$211288[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$211288, $CellContext`mnO2]], \
$CellContext`sym$211288[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$211288[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$211288[All], 
      All, $CellContext`i$212840], $CellContext`sym$211288[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$211288[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$211288, $CellContext`mxPH]], \
$CellContext`sym$211288[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$211288[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$211288[All], 
      All, $CellContext`i$212839], $CellContext`sym$211288[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$211288[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$211288, $CellContext`NH4]], \
$CellContext`sym$211288[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$211288[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$211288[All], 
      All, $CellContext`i$212843], $CellContext`sym$211288[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$211288[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$211288, $CellContext`NO3]], \
$CellContext`sym$211288[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$211288[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$211288[All], 
      All, $CellContext`i$212842], $CellContext`sym$211288[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$211288[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$211288, $CellContext`oPO4]], \
$CellContext`sym$211288[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$211288[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$211288[All], 
      All, $CellContext`i$212844], $CellContext`sym$211288[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$211288[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$211288, $CellContext`PO4]], \
$CellContext`sym$211288[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$211288[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$211288[All], 
      All, $CellContext`i$212845], \
$CellContext`sym$211288[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$211288[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$211288, $CellContext`season]], \
$CellContext`sym$211288[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$211288[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$211288[All], 
      All, $CellContext`i$211289], $CellContext`sym$211288[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$211288[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$211288, $CellContext`size]], \
$CellContext`sym$211288[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$211288[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$211288[All], 
      All, $CellContext`i$212837], $CellContext`sym$211288[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$211288[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$211288, $CellContext`speed]], \
$CellContext`sym$211288[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$211288[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$211288[All], All, $CellContext`i$212838], 
    Attributes[$CellContext`i$212849] = {Temporary}, $CellContext`i$212849 = 
    14, Attributes[$CellContext`i$212839] = {
     Temporary}, $CellContext`i$212839 = 4, 
    Attributes[$CellContext`i$212853] = {Temporary}, $CellContext`i$212853 = 
    18, Attributes[$CellContext`i$212837] = {
     Temporary}, $CellContext`i$212837 = 2, 
    Attributes[$CellContext`i$212838] = {Temporary}, $CellContext`i$212838 = 
    3, Attributes[$CellContext`i$212850] = {Temporary}, $CellContext`i$212850 = 
    15, Attributes[$CellContext`i$212847] = {
     Temporary}, $CellContext`i$212847 = 12, 
    Attributes[$CellContext`i$212846] = {Temporary}, $CellContext`i$212846 = 
    11, Attributes[$CellContext`i$212843] = {
     Temporary}, $CellContext`i$212843 = 8, 
    Attributes[$CellContext`i$212841] = {Temporary}, $CellContext`i$212841 = 
    6, Attributes[$CellContext`i$212844] = {Temporary}, $CellContext`i$212844 = 
    9, Attributes[$CellContext`i$212851] = {Temporary}, $CellContext`i$212851 = 
    16, Attributes[$CellContext`i$212840] = {
     Temporary}, $CellContext`i$212840 = 5, 
    Attributes[$CellContext`i$212842] = {Temporary}, $CellContext`i$212842 = 
    7, Attributes[$CellContext`i$211289] = {Temporary}, $CellContext`i$211289 = 
    1, Attributes[$CellContext`i$212848] = {Temporary}, $CellContext`i$212848 = 
    13, Attributes[$CellContext`i$212852] = {
     Temporary}, $CellContext`i$212852 = 17, 
    Attributes[$CellContext`i$212845] = {Temporary}, $CellContext`i$212845 = 
    10, Attributes[$CellContext`sym$227670] = {
     Temporary}, $CellContext`sym$227670[$CellContext`a1] = Part[
      $CellContext`sym$227670[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227670[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$227670[$CellContext`a2] = Part[
      $CellContext`sym$227670[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227670[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$227670[$CellContext`a3] = Part[
      $CellContext`sym$227670[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227670[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$227670[$CellContext`a4] = Part[
      $CellContext`sym$227670[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227670[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$227670[$CellContext`a5] = Part[
      $CellContext`sym$227670[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227670[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$227670[$CellContext`a6] = Part[
      $CellContext`sym$227670[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227670[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$227670[$CellContext`a7] = Part[
      $CellContext`sym$227670[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227670[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$227670[All] = $CellContext`med[
     All], $CellContext`sym$227670[$CellContext`Chla] = Part[
      $CellContext`sym$227670[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227670[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$227670[$CellContext`Cl] = Part[
      $CellContext`sym$227670[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227670[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$227670[$CellContext`mnO2] = Part[
      $CellContext`sym$227670[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227670[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$227670[$CellContext`mxPH] = Part[
      $CellContext`sym$227670[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227670[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$227670[$CellContext`NH4] = Part[
      $CellContext`sym$227670[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227670[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$227670[$CellContext`NO3] = Part[
      $CellContext`sym$227670[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227670[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$227670[$CellContext`oPO4] = Part[
      $CellContext`sym$227670[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227670[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$227670[$CellContext`PO4] = Part[
      $CellContext`sym$227670[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227670[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$227670[$CellContext`season] = Part[
      $CellContext`sym$227670[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227670[$CellContext`season, 
         "missing"]]]], $CellContext`sym$227670[$CellContext`size] = Part[
      $CellContext`sym$227670[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227670[$CellContext`size, 
         "missing"]]]], $CellContext`sym$227670[$CellContext`speed] = Part[
      $CellContext`sym$227670[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227670[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$227670[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$227670[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227670, $CellContext`a1]], \
$CellContext`sym$227670[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$227670[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$227670[All], 
      All, $CellContext`i$227682], $CellContext`sym$227670[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$227670[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227670, $CellContext`a2]], \
$CellContext`sym$227670[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$227670[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$227670[All], 
      All, $CellContext`i$227683], $CellContext`sym$227670[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$227670[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227670, $CellContext`a3]], \
$CellContext`sym$227670[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$227670[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$227670[All], 
      All, $CellContext`i$227684], $CellContext`sym$227670[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$227670[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227670, $CellContext`a4]], \
$CellContext`sym$227670[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$227670[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$227670[All], 
      All, $CellContext`i$227685], $CellContext`sym$227670[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$227670[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227670, $CellContext`a5]], \
$CellContext`sym$227670[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$227670[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$227670[All], 
      All, $CellContext`i$227686], $CellContext`sym$227670[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$227670[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227670, $CellContext`a6]], \
$CellContext`sym$227670[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$227670[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$227670[All], 
      All, $CellContext`i$227687], $CellContext`sym$227670[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$227670[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227670, $CellContext`a7]], \
$CellContext`sym$227670[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$227670[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$227670[All], 
      All, $CellContext`i$227688], $CellContext`sym$227670[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$227670[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$227670[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$227670[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227670, $CellContext`Chla]], \
$CellContext`sym$227670[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$227670[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$227670[All], 
      All, $CellContext`i$227681], $CellContext`sym$227670[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$227670[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227670, $CellContext`Cl]], \
$CellContext`sym$227670[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$227670[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$227670[All], 
      All, $CellContext`i$227676], $CellContext`sym$227670[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$227670[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227670, $CellContext`mnO2]], \
$CellContext`sym$227670[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$227670[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$227670[All], 
      All, $CellContext`i$227675], $CellContext`sym$227670[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$227670[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227670, $CellContext`mxPH]], \
$CellContext`sym$227670[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$227670[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$227670[All], 
      All, $CellContext`i$227674], $CellContext`sym$227670[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$227670[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227670, $CellContext`NH4]], \
$CellContext`sym$227670[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$227670[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$227670[All], 
      All, $CellContext`i$227678], $CellContext`sym$227670[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$227670[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227670, $CellContext`NO3]], \
$CellContext`sym$227670[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$227670[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$227670[All], 
      All, $CellContext`i$227677], $CellContext`sym$227670[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$227670[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227670, $CellContext`oPO4]], \
$CellContext`sym$227670[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$227670[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$227670[All], 
      All, $CellContext`i$227679], $CellContext`sym$227670[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$227670[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227670, $CellContext`PO4]], \
$CellContext`sym$227670[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$227670[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$227670[All], 
      All, $CellContext`i$227680], \
$CellContext`sym$227670[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$227670[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227670, $CellContext`season]], \
$CellContext`sym$227670[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$227670[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$227670[All], 
      All, $CellContext`i$227671], $CellContext`sym$227670[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$227670[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227670, $CellContext`size]], \
$CellContext`sym$227670[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$227670[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$227670[All], 
      All, $CellContext`i$227672], $CellContext`sym$227670[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$227670[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227670, $CellContext`speed]], \
$CellContext`sym$227670[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$227670[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$227670[All], All, $CellContext`i$227673], 
    Attributes[$CellContext`i$227678] = {Temporary}, $CellContext`i$227678 = 
    8, Attributes[$CellContext`i$227685] = {Temporary}, $CellContext`i$227685 = 
    15, Attributes[$CellContext`i$227688] = {
     Temporary}, $CellContext`i$227688 = 18, 
    Attributes[$CellContext`i$227677] = {Temporary}, $CellContext`i$227677 = 
    7, Attributes[$CellContext`i$227683] = {Temporary}, $CellContext`i$227683 = 
    13, Attributes[$CellContext`i$227687] = {
     Temporary}, $CellContext`i$227687 = 17, 
    Attributes[$CellContext`i$227676] = {Temporary}, $CellContext`i$227676 = 
    6, Attributes[$CellContext`i$227674] = {Temporary}, $CellContext`i$227674 = 
    4, Attributes[$CellContext`i$227671] = {Temporary}, $CellContext`i$227671 = 
    1, Attributes[$CellContext`i$227681] = {Temporary}, $CellContext`i$227681 = 
    11, Attributes[$CellContext`i$227672] = {
     Temporary}, $CellContext`i$227672 = 2, 
    Attributes[$CellContext`i$227680] = {Temporary}, $CellContext`i$227680 = 
    10, Attributes[$CellContext`i$227673] = {
     Temporary}, $CellContext`i$227673 = 3, 
    Attributes[$CellContext`i$227684] = {Temporary}, $CellContext`i$227684 = 
    14, Attributes[$CellContext`i$227675] = {
     Temporary}, $CellContext`i$227675 = 5, 
    Attributes[$CellContext`i$227686] = {Temporary}, $CellContext`i$227686 = 
    16, Attributes[$CellContext`i$227682] = {
     Temporary}, $CellContext`i$227682 = 12, 
    Attributes[$CellContext`i$227679] = {Temporary}, $CellContext`i$227679 = 
    9, Attributes[$CellContext`sym$226954] = {
     Temporary}, $CellContext`sym$226954[$CellContext`a1] = Part[
      $CellContext`sym$226954[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$226954[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$226954[$CellContext`a2] = Part[
      $CellContext`sym$226954[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$226954[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$226954[$CellContext`a3] = Part[
      $CellContext`sym$226954[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$226954[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$226954[$CellContext`a4] = Part[
      $CellContext`sym$226954[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$226954[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$226954[$CellContext`a5] = Part[
      $CellContext`sym$226954[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$226954[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$226954[$CellContext`a6] = Part[
      $CellContext`sym$226954[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$226954[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$226954[$CellContext`a7] = Part[
      $CellContext`sym$226954[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$226954[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$226954[All] = $CellContext`med[
     All], $CellContext`sym$226954[$CellContext`Chla] = Part[
      $CellContext`sym$226954[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$226954[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$226954[$CellContext`Cl] = Part[
      $CellContext`sym$226954[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$226954[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$226954[$CellContext`mnO2] = Part[
      $CellContext`sym$226954[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$226954[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$226954[$CellContext`mxPH] = Part[
      $CellContext`sym$226954[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$226954[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$226954[$CellContext`NH4] = Part[
      $CellContext`sym$226954[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$226954[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$226954[$CellContext`NO3] = Part[
      $CellContext`sym$226954[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$226954[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$226954[$CellContext`oPO4] = Part[
      $CellContext`sym$226954[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$226954[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$226954[$CellContext`PO4] = Part[
      $CellContext`sym$226954[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$226954[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$226954[$CellContext`season] = Part[
      $CellContext`sym$226954[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$226954[$CellContext`season, 
         "missing"]]]], $CellContext`sym$226954[$CellContext`size] = Part[
      $CellContext`sym$226954[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$226954[$CellContext`size, 
         "missing"]]]], $CellContext`sym$226954[$CellContext`speed] = Part[
      $CellContext`sym$226954[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$226954[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$226954[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$226954[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$226954, $CellContext`a1]], \
$CellContext`sym$226954[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$226954[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$226954[All], 
      All, $CellContext`i$226966], $CellContext`sym$226954[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$226954[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$226954, $CellContext`a2]], \
$CellContext`sym$226954[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$226954[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$226954[All], 
      All, $CellContext`i$226967], $CellContext`sym$226954[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$226954[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$226954, $CellContext`a3]], \
$CellContext`sym$226954[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$226954[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$226954[All], 
      All, $CellContext`i$226968], $CellContext`sym$226954[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$226954[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$226954, $CellContext`a4]], \
$CellContext`sym$226954[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$226954[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$226954[All], 
      All, $CellContext`i$226969], $CellContext`sym$226954[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$226954[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$226954, $CellContext`a5]], \
$CellContext`sym$226954[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$226954[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$226954[All], 
      All, $CellContext`i$226970], $CellContext`sym$226954[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$226954[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$226954, $CellContext`a6]], \
$CellContext`sym$226954[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$226954[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$226954[All], 
      All, $CellContext`i$226971], $CellContext`sym$226954[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$226954[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$226954, $CellContext`a7]], \
$CellContext`sym$226954[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$226954[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$226954[All], 
      All, $CellContext`i$226972], $CellContext`sym$226954[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$226954[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$226954[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$226954[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$226954, $CellContext`Chla]], \
$CellContext`sym$226954[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$226954[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$226954[All], 
      All, $CellContext`i$226965], $CellContext`sym$226954[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$226954[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$226954, $CellContext`Cl]], \
$CellContext`sym$226954[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$226954[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$226954[All], 
      All, $CellContext`i$226960], $CellContext`sym$226954[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$226954[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$226954, $CellContext`mnO2]], \
$CellContext`sym$226954[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$226954[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$226954[All], 
      All, $CellContext`i$226959], $CellContext`sym$226954[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$226954[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$226954, $CellContext`mxPH]], \
$CellContext`sym$226954[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$226954[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$226954[All], 
      All, $CellContext`i$226958], $CellContext`sym$226954[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$226954[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$226954, $CellContext`NH4]], \
$CellContext`sym$226954[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$226954[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$226954[All], 
      All, $CellContext`i$226962], $CellContext`sym$226954[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$226954[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$226954, $CellContext`NO3]], \
$CellContext`sym$226954[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$226954[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$226954[All], 
      All, $CellContext`i$226961], $CellContext`sym$226954[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$226954[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$226954, $CellContext`oPO4]], \
$CellContext`sym$226954[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$226954[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$226954[All], 
      All, $CellContext`i$226963], $CellContext`sym$226954[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$226954[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$226954, $CellContext`PO4]], \
$CellContext`sym$226954[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$226954[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$226954[All], 
      All, $CellContext`i$226964], \
$CellContext`sym$226954[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$226954[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$226954, $CellContext`season]], \
$CellContext`sym$226954[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$226954[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$226954[All], 
      All, $CellContext`i$226955], $CellContext`sym$226954[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$226954[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$226954, $CellContext`size]], \
$CellContext`sym$226954[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$226954[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$226954[All], 
      All, $CellContext`i$226956], $CellContext`sym$226954[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$226954[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$226954, $CellContext`speed]], \
$CellContext`sym$226954[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$226954[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$226954[All], All, $CellContext`i$226957], 
    Attributes[$CellContext`i$226967] = {Temporary}, $CellContext`i$226967 = 
    13, Attributes[$CellContext`i$226959] = {
     Temporary}, $CellContext`i$226959 = 5, 
    Attributes[$CellContext`i$226963] = {Temporary}, $CellContext`i$226963 = 
    9, Attributes[$CellContext`i$226961] = {Temporary}, $CellContext`i$226961 = 
    7, Attributes[$CellContext`i$226957] = {Temporary}, $CellContext`i$226957 = 
    3, Attributes[$CellContext`i$226956] = {Temporary}, $CellContext`i$226956 = 
    2, Attributes[$CellContext`i$226960] = {Temporary}, $CellContext`i$226960 = 
    6, Attributes[$CellContext`i$226962] = {Temporary}, $CellContext`i$226962 = 
    8, Attributes[$CellContext`i$226955] = {Temporary}, $CellContext`i$226955 = 
    1, Attributes[$CellContext`i$226969] = {Temporary}, $CellContext`i$226969 = 
    15, Attributes[$CellContext`i$226968] = {
     Temporary}, $CellContext`i$226968 = 14, 
    Attributes[$CellContext`i$226972] = {Temporary}, $CellContext`i$226972 = 
    18, Attributes[$CellContext`i$226971] = {
     Temporary}, $CellContext`i$226971 = 17, 
    Attributes[$CellContext`i$226970] = {Temporary}, $CellContext`i$226970 = 
    16, Attributes[$CellContext`i$226966] = {
     Temporary}, $CellContext`i$226966 = 12, 
    Attributes[$CellContext`i$226965] = {Temporary}, $CellContext`i$226965 = 
    11, Attributes[$CellContext`i$226964] = {
     Temporary}, $CellContext`i$226964 = 10, 
    Attributes[$CellContext`i$226958] = {Temporary}, $CellContext`i$226958 = 
    4, Attributes[$CellContext`sym$227370] = {
     Temporary}, $CellContext`sym$227370[$CellContext`a1] = Part[
      $CellContext`sym$227370[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227370[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$227370[$CellContext`a2] = Part[
      $CellContext`sym$227370[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227370[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$227370[$CellContext`a3] = Part[
      $CellContext`sym$227370[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227370[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$227370[$CellContext`a4] = Part[
      $CellContext`sym$227370[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227370[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$227370[$CellContext`a5] = Part[
      $CellContext`sym$227370[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227370[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$227370[$CellContext`a6] = Part[
      $CellContext`sym$227370[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227370[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$227370[$CellContext`a7] = Part[
      $CellContext`sym$227370[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227370[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$227370[All] = $CellContext`med[
     All], $CellContext`sym$227370[$CellContext`Chla] = Part[
      $CellContext`sym$227370[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227370[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$227370[$CellContext`Cl] = Part[
      $CellContext`sym$227370[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227370[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$227370[$CellContext`mnO2] = Part[
      $CellContext`sym$227370[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227370[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$227370[$CellContext`mxPH] = Part[
      $CellContext`sym$227370[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227370[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$227370[$CellContext`NH4] = Part[
      $CellContext`sym$227370[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227370[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$227370[$CellContext`NO3] = Part[
      $CellContext`sym$227370[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227370[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$227370[$CellContext`oPO4] = Part[
      $CellContext`sym$227370[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227370[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$227370[$CellContext`PO4] = Part[
      $CellContext`sym$227370[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227370[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$227370[$CellContext`season] = Part[
      $CellContext`sym$227370[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227370[$CellContext`season, 
         "missing"]]]], $CellContext`sym$227370[$CellContext`size] = Part[
      $CellContext`sym$227370[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227370[$CellContext`size, 
         "missing"]]]], $CellContext`sym$227370[$CellContext`speed] = Part[
      $CellContext`sym$227370[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227370[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$227370[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$227370[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227370, $CellContext`a1]], \
$CellContext`sym$227370[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$227370[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$227370[All], 
      All, $CellContext`i$227382], $CellContext`sym$227370[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$227370[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227370, $CellContext`a2]], \
$CellContext`sym$227370[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$227370[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$227370[All], 
      All, $CellContext`i$227383], $CellContext`sym$227370[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$227370[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227370, $CellContext`a3]], \
$CellContext`sym$227370[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$227370[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$227370[All], 
      All, $CellContext`i$227384], $CellContext`sym$227370[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$227370[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227370, $CellContext`a4]], \
$CellContext`sym$227370[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$227370[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$227370[All], 
      All, $CellContext`i$227385], $CellContext`sym$227370[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$227370[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227370, $CellContext`a5]], \
$CellContext`sym$227370[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$227370[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$227370[All], 
      All, $CellContext`i$227386], $CellContext`sym$227370[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$227370[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227370, $CellContext`a6]], \
$CellContext`sym$227370[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$227370[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$227370[All], 
      All, $CellContext`i$227387], $CellContext`sym$227370[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$227370[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227370, $CellContext`a7]], \
$CellContext`sym$227370[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$227370[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$227370[All], 
      All, $CellContext`i$227388], $CellContext`sym$227370[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$227370[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$227370[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$227370[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227370, $CellContext`Chla]], \
$CellContext`sym$227370[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$227370[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$227370[All], 
      All, $CellContext`i$227381], $CellContext`sym$227370[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$227370[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227370, $CellContext`Cl]], \
$CellContext`sym$227370[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$227370[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$227370[All], 
      All, $CellContext`i$227376], $CellContext`sym$227370[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$227370[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227370, $CellContext`mnO2]], \
$CellContext`sym$227370[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$227370[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$227370[All], 
      All, $CellContext`i$227375], $CellContext`sym$227370[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$227370[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227370, $CellContext`mxPH]], \
$CellContext`sym$227370[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$227370[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$227370[All], 
      All, $CellContext`i$227374], $CellContext`sym$227370[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$227370[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227370, $CellContext`NH4]], \
$CellContext`sym$227370[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$227370[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$227370[All], 
      All, $CellContext`i$227378], $CellContext`sym$227370[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$227370[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227370, $CellContext`NO3]], \
$CellContext`sym$227370[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$227370[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$227370[All], 
      All, $CellContext`i$227377], $CellContext`sym$227370[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$227370[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227370, $CellContext`oPO4]], \
$CellContext`sym$227370[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$227370[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$227370[All], 
      All, $CellContext`i$227379], $CellContext`sym$227370[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$227370[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227370, $CellContext`PO4]], \
$CellContext`sym$227370[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$227370[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$227370[All], 
      All, $CellContext`i$227380], \
$CellContext`sym$227370[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$227370[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227370, $CellContext`season]], \
$CellContext`sym$227370[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$227370[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$227370[All], 
      All, $CellContext`i$227371], $CellContext`sym$227370[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$227370[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227370, $CellContext`size]], \
$CellContext`sym$227370[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$227370[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$227370[All], 
      All, $CellContext`i$227372], $CellContext`sym$227370[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$227370[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227370, $CellContext`speed]], \
$CellContext`sym$227370[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$227370[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$227370[All], All, $CellContext`i$227373], 
    Attributes[$CellContext`i$227380] = {Temporary}, $CellContext`i$227380 = 
    10, Attributes[$CellContext`i$227371] = {
     Temporary}, $CellContext`i$227371 = 1, 
    Attributes[$CellContext`i$227377] = {Temporary}, $CellContext`i$227377 = 
    7, Attributes[$CellContext`i$227376] = {Temporary}, $CellContext`i$227376 = 
    6, Attributes[$CellContext`i$227385] = {Temporary}, $CellContext`i$227385 = 
    15, Attributes[$CellContext`i$227374] = {
     Temporary}, $CellContext`i$227374 = 4, 
    Attributes[$CellContext`i$227383] = {Temporary}, $CellContext`i$227383 = 
    13, Attributes[$CellContext`i$227382] = {
     Temporary}, $CellContext`i$227382 = 12, 
    Attributes[$CellContext`i$227373] = {Temporary}, $CellContext`i$227373 = 
    3, Attributes[$CellContext`i$227381] = {Temporary}, $CellContext`i$227381 = 
    11, Attributes[$CellContext`i$227386] = {
     Temporary}, $CellContext`i$227386 = 16, 
    Attributes[$CellContext`i$227375] = {Temporary}, $CellContext`i$227375 = 
    5, Attributes[$CellContext`i$227384] = {Temporary}, $CellContext`i$227384 = 
    14, Attributes[$CellContext`i$227378] = {
     Temporary}, $CellContext`i$227378 = 8, 
    Attributes[$CellContext`i$227387] = {Temporary}, $CellContext`i$227387 = 
    17, Attributes[$CellContext`i$227388] = {
     Temporary}, $CellContext`i$227388 = 18, 
    Attributes[$CellContext`i$227372] = {Temporary}, $CellContext`i$227372 = 
    2, Attributes[$CellContext`i$227379] = {Temporary}, $CellContext`i$227379 = 
    9, Attributes[$CellContext`sym$72812] = {
     Temporary}, $CellContext`sym$72812[$CellContext`a1] = Part[
      $CellContext`sym$72812[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$72812[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$72812[$CellContext`a2] = Part[
      $CellContext`sym$72812[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$72812[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$72812[$CellContext`a3] = Part[
      $CellContext`sym$72812[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$72812[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$72812[$CellContext`a4] = Part[
      $CellContext`sym$72812[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$72812[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$72812[$CellContext`a5] = Part[
      $CellContext`sym$72812[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$72812[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$72812[$CellContext`a6] = Part[
      $CellContext`sym$72812[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$72812[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$72812[$CellContext`a7] = Part[
      $CellContext`sym$72812[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$72812[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$72812[All] = $CellContext`med[
     All], $CellContext`sym$72812[$CellContext`Chla] = Part[
      $CellContext`sym$72812[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$72812[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$72812[$CellContext`Cl] = Part[
      $CellContext`sym$72812[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$72812[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$72812[$CellContext`mnO2] = Part[
      $CellContext`sym$72812[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$72812[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$72812[$CellContext`mxPH] = Part[
      $CellContext`sym$72812[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$72812[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$72812[$CellContext`NH4] = Part[
      $CellContext`sym$72812[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$72812[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$72812[$CellContext`NO3] = Part[
      $CellContext`sym$72812[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$72812[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$72812[$CellContext`oPO4] = Part[
      $CellContext`sym$72812[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$72812[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$72812[$CellContext`PO4] = Part[
      $CellContext`sym$72812[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$72812[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$72812[$CellContext`season] = Part[
      $CellContext`sym$72812[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$72812[$CellContext`season, 
         "missing"]]]], $CellContext`sym$72812[$CellContext`size] = Part[
      $CellContext`sym$72812[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$72812[$CellContext`size, 
         "missing"]]]], $CellContext`sym$72812[$CellContext`speed] = Part[
      $CellContext`sym$72812[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$72812[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$72812[$CellContext`a1, "factorized"] = 
    True, $CellContext`sym$72812[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$72812, $CellContext`a1]], \
$CellContext`sym$72812[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$72812[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$72812[All], 
      All, $CellContext`i$74371], $CellContext`sym$72812[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$72812[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$72812, $CellContext`a2]], \
$CellContext`sym$72812[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$72812[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$72812[All], 
      All, $CellContext`i$74372], $CellContext`sym$72812[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$72812[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$72812, $CellContext`a3]], \
$CellContext`sym$72812[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$72812[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$72812[All], 
      All, $CellContext`i$74373], $CellContext`sym$72812[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$72812[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$72812, $CellContext`a4]], \
$CellContext`sym$72812[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$72812[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$72812[All], 
      All, $CellContext`i$74374], $CellContext`sym$72812[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$72812[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$72812, $CellContext`a5]], \
$CellContext`sym$72812[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$72812[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$72812[All], 
      All, $CellContext`i$74375], $CellContext`sym$72812[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$72812[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$72812, $CellContext`a6]], \
$CellContext`sym$72812[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$72812[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$72812[All], 
      All, $CellContext`i$74376], $CellContext`sym$72812[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$72812[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$72812, $CellContext`a7]], \
$CellContext`sym$72812[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$72812[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$72812[All], 
      All, $CellContext`i$74377], $CellContext`sym$72812[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$72812[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$72812[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$72812[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$72812, $CellContext`Chla]], \
$CellContext`sym$72812[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$72812[$CellContext`Chla, "raw"] = Part[
      $CellContext`sym$72812[All], 
      All, $CellContext`i$74370], $CellContext`sym$72812[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$72812[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$72812, $CellContext`Cl]], \
$CellContext`sym$72812[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$72812[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$72812[All], 
      All, $CellContext`i$74365], $CellContext`sym$72812[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$72812[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$72812, $CellContext`mnO2]], \
$CellContext`sym$72812[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$72812[$CellContext`mnO2, "raw"] = Part[
      $CellContext`sym$72812[All], 
      All, $CellContext`i$74364], $CellContext`sym$72812[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$72812[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$72812, $CellContext`mxPH]], \
$CellContext`sym$72812[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$72812[$CellContext`mxPH, "raw"] = Part[
      $CellContext`sym$72812[All], 
      All, $CellContext`i$74363], $CellContext`sym$72812[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$72812[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$72812, $CellContext`NH4]], \
$CellContext`sym$72812[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$72812[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$72812[All], 
      All, $CellContext`i$74367], $CellContext`sym$72812[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$72812[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$72812, $CellContext`NO3]], \
$CellContext`sym$72812[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$72812[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$72812[All], 
      All, $CellContext`i$74366], $CellContext`sym$72812[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$72812[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$72812, $CellContext`oPO4]], \
$CellContext`sym$72812[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$72812[$CellContext`oPO4, "raw"] = Part[
      $CellContext`sym$72812[All], 
      All, $CellContext`i$74368], $CellContext`sym$72812[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$72812[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$72812, $CellContext`PO4]], \
$CellContext`sym$72812[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$72812[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$72812[All], 
      All, $CellContext`i$74369], $CellContext`sym$72812[$CellContext`season, 
      "factorized"] = 
    True, $CellContext`sym$72812[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$72812, $CellContext`season]], \
$CellContext`sym$72812[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$72812[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$72812[All], 
      All, $CellContext`i$72813], $CellContext`sym$72812[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$72812[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$72812, $CellContext`size]], \
$CellContext`sym$72812[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$72812[$CellContext`size, "raw"] = Part[
      $CellContext`sym$72812[All], 
      All, $CellContext`i$74361], $CellContext`sym$72812[$CellContext`speed, 
      "factorized"] = 
    True, $CellContext`sym$72812[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$72812, $CellContext`speed]], \
$CellContext`sym$72812[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$72812[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$72812[All], All, $CellContext`i$74362], 
    Attributes[$CellContext`i$74375] = {Temporary}, $CellContext`i$74375 = 16,
     Attributes[$CellContext`i$74372] = {Temporary}, $CellContext`i$74372 = 
    13, Attributes[$CellContext`i$74376] = {Temporary}, $CellContext`i$74376 = 
    17, Attributes[$CellContext`i$74363] = {Temporary}, $CellContext`i$74363 = 
    4, Attributes[$CellContext`i$74374] = {Temporary}, $CellContext`i$74374 = 
    15, Attributes[$CellContext`i$74365] = {Temporary}, $CellContext`i$74365 = 
    6, Attributes[$CellContext`i$74377] = {Temporary}, $CellContext`i$74377 = 
    18, Attributes[$CellContext`i$74364] = {Temporary}, $CellContext`i$74364 = 
    5, Attributes[$CellContext`i$74373] = {Temporary}, $CellContext`i$74373 = 
    14, Attributes[$CellContext`i$72813] = {Temporary}, $CellContext`i$72813 = 
    1, Attributes[$CellContext`i$74371] = {Temporary}, $CellContext`i$74371 = 
    12, Attributes[$CellContext`i$74369] = {Temporary}, $CellContext`i$74369 = 
    10, Attributes[$CellContext`i$74366] = {Temporary}, $CellContext`i$74366 = 
    7, Attributes[$CellContext`i$74368] = {Temporary}, $CellContext`i$74368 = 
    9, Attributes[$CellContext`i$74362] = {Temporary}, $CellContext`i$74362 = 
    3, Attributes[$CellContext`i$74367] = {Temporary}, $CellContext`i$74367 = 
    8, Attributes[$CellContext`i$74361] = {Temporary}, $CellContext`i$74361 = 
    2, Attributes[$CellContext`i$74370] = {Temporary}, $CellContext`i$74370 = 
    11, Attributes[$CellContext`sym$220220] = {
     Temporary}, $CellContext`sym$220220[$CellContext`a1] = Part[
      $CellContext`sym$220220[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$220220[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$220220[$CellContext`a2] = Part[
      $CellContext`sym$220220[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$220220[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$220220[$CellContext`a3] = Part[
      $CellContext`sym$220220[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$220220[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$220220[$CellContext`a4] = Part[
      $CellContext`sym$220220[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$220220[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$220220[$CellContext`a5] = Part[
      $CellContext`sym$220220[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$220220[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$220220[$CellContext`a6] = Part[
      $CellContext`sym$220220[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$220220[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$220220[$CellContext`a7] = Part[
      $CellContext`sym$220220[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$220220[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$220220[All] = $CellContext`med[
     All], $CellContext`sym$220220[$CellContext`Chla] = Part[
      $CellContext`sym$220220[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$220220[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$220220[$CellContext`Cl] = Part[
      $CellContext`sym$220220[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$220220[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$220220[$CellContext`mnO2] = Part[
      $CellContext`sym$220220[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$220220[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$220220[$CellContext`mxPH] = Part[
      $CellContext`sym$220220[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$220220[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$220220[$CellContext`NH4] = Part[
      $CellContext`sym$220220[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$220220[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$220220[$CellContext`NO3] = Part[
      $CellContext`sym$220220[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$220220[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$220220[$CellContext`oPO4] = Part[
      $CellContext`sym$220220[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$220220[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$220220[$CellContext`PO4] = Part[
      $CellContext`sym$220220[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$220220[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$220220[$CellContext`season] = Part[
      $CellContext`sym$220220[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$220220[$CellContext`season, 
         "missing"]]]], $CellContext`sym$220220[$CellContext`size] = Part[
      $CellContext`sym$220220[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$220220[$CellContext`size, 
         "missing"]]]], $CellContext`sym$220220[$CellContext`speed] = Part[
      $CellContext`sym$220220[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$220220[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$220220[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$220220[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$220220, $CellContext`a1]], \
$CellContext`sym$220220[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$220220[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$220220[All], 
      All, $CellContext`i$221779], $CellContext`sym$220220[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$220220[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$220220, $CellContext`a2]], \
$CellContext`sym$220220[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$220220[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$220220[All], 
      All, $CellContext`i$221780], $CellContext`sym$220220[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$220220[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$220220, $CellContext`a3]], \
$CellContext`sym$220220[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$220220[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$220220[All], 
      All, $CellContext`i$221781], $CellContext`sym$220220[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$220220[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$220220, $CellContext`a4]], \
$CellContext`sym$220220[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$220220[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$220220[All], 
      All, $CellContext`i$221782], $CellContext`sym$220220[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$220220[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$220220, $CellContext`a5]], \
$CellContext`sym$220220[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$220220[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$220220[All], 
      All, $CellContext`i$221783], $CellContext`sym$220220[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$220220[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$220220, $CellContext`a6]], \
$CellContext`sym$220220[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$220220[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$220220[All], 
      All, $CellContext`i$221784], $CellContext`sym$220220[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$220220[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$220220, $CellContext`a7]], \
$CellContext`sym$220220[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$220220[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$220220[All], 
      All, $CellContext`i$221785], $CellContext`sym$220220[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$220220[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$220220[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$220220[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$220220, $CellContext`Chla]], \
$CellContext`sym$220220[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$220220[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$220220[All], 
      All, $CellContext`i$221778], $CellContext`sym$220220[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$220220[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$220220, $CellContext`Cl]], \
$CellContext`sym$220220[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$220220[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$220220[All], 
      All, $CellContext`i$221773], $CellContext`sym$220220[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$220220[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$220220, $CellContext`mnO2]], \
$CellContext`sym$220220[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$220220[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$220220[All], 
      All, $CellContext`i$221772], $CellContext`sym$220220[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$220220[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$220220, $CellContext`mxPH]], \
$CellContext`sym$220220[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$220220[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$220220[All], 
      All, $CellContext`i$221771], $CellContext`sym$220220[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$220220[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$220220, $CellContext`NH4]], \
$CellContext`sym$220220[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$220220[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$220220[All], 
      All, $CellContext`i$221775], $CellContext`sym$220220[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$220220[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$220220, $CellContext`NO3]], \
$CellContext`sym$220220[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$220220[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$220220[All], 
      All, $CellContext`i$221774], $CellContext`sym$220220[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$220220[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$220220, $CellContext`oPO4]], \
$CellContext`sym$220220[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$220220[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$220220[All], 
      All, $CellContext`i$221776], $CellContext`sym$220220[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$220220[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$220220, $CellContext`PO4]], \
$CellContext`sym$220220[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$220220[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$220220[All], 
      All, $CellContext`i$221777], \
$CellContext`sym$220220[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$220220[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$220220, $CellContext`season]], \
$CellContext`sym$220220[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$220220[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$220220[All], 
      All, $CellContext`i$220221], $CellContext`sym$220220[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$220220[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$220220, $CellContext`size]], \
$CellContext`sym$220220[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$220220[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$220220[All], 
      All, $CellContext`i$221769], $CellContext`sym$220220[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$220220[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$220220, $CellContext`speed]], \
$CellContext`sym$220220[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$220220[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$220220[All], All, $CellContext`i$221770], 
    Attributes[$CellContext`i$221774] = {Temporary}, $CellContext`i$221774 = 
    7, Attributes[$CellContext`i$221779] = {Temporary}, $CellContext`i$221779 = 
    12, Attributes[$CellContext`i$221771] = {
     Temporary}, $CellContext`i$221771 = 4, 
    Attributes[$CellContext`i$221776] = {Temporary}, $CellContext`i$221776 = 
    9, Attributes[$CellContext`i$221782] = {Temporary}, $CellContext`i$221782 = 
    15, Attributes[$CellContext`i$221770] = {
     Temporary}, $CellContext`i$221770 = 3, 
    Attributes[$CellContext`i$220221] = {Temporary}, $CellContext`i$220221 = 
    1, Attributes[$CellContext`i$221775] = {Temporary}, $CellContext`i$221775 = 
    8, Attributes[$CellContext`i$221773] = {Temporary}, $CellContext`i$221773 = 
    6, Attributes[$CellContext`i$221778] = {Temporary}, $CellContext`i$221778 = 
    11, Attributes[$CellContext`i$221785] = {
     Temporary}, $CellContext`i$221785 = 18, 
    Attributes[$CellContext`i$221783] = {Temporary}, $CellContext`i$221783 = 
    16, Attributes[$CellContext`i$221769] = {
     Temporary}, $CellContext`i$221769 = 2, 
    Attributes[$CellContext`i$221777] = {Temporary}, $CellContext`i$221777 = 
    10, Attributes[$CellContext`i$221784] = {
     Temporary}, $CellContext`i$221784 = 17, 
    Attributes[$CellContext`i$221780] = {Temporary}, $CellContext`i$221780 = 
    13, Attributes[$CellContext`i$221781] = {
     Temporary}, $CellContext`i$221781 = 14, 
    Attributes[$CellContext`i$221772] = {Temporary}, $CellContext`i$221772 = 
    5, Attributes[$CellContext`sym$97405] = {
     Temporary}, $CellContext`sym$97405[$CellContext`a1] = Part[
      $CellContext`sym$97405[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$97405[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$97405[$CellContext`a2] = Part[
      $CellContext`sym$97405[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$97405[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$97405[$CellContext`a3] = Part[
      $CellContext`sym$97405[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$97405[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$97405[$CellContext`a4] = Part[
      $CellContext`sym$97405[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$97405[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$97405[$CellContext`a5] = Part[
      $CellContext`sym$97405[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$97405[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$97405[$CellContext`a6] = Part[
      $CellContext`sym$97405[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$97405[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$97405[$CellContext`a7] = Part[
      $CellContext`sym$97405[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$97405[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$97405[All] = $CellContext`med[
     All], $CellContext`sym$97405[$CellContext`Chla] = Part[
      $CellContext`sym$97405[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$97405[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$97405[$CellContext`Cl] = Part[
      $CellContext`sym$97405[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$97405[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$97405[$CellContext`mnO2] = Part[
      $CellContext`sym$97405[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$97405[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$97405[$CellContext`mxPH] = Part[
      $CellContext`sym$97405[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$97405[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$97405[$CellContext`NH4] = Part[
      $CellContext`sym$97405[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$97405[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$97405[$CellContext`NO3] = Part[
      $CellContext`sym$97405[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$97405[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$97405[$CellContext`oPO4] = Part[
      $CellContext`sym$97405[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$97405[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$97405[$CellContext`PO4] = Part[
      $CellContext`sym$97405[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$97405[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$97405[$CellContext`season] = Part[
      $CellContext`sym$97405[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$97405[$CellContext`season, 
         "missing"]]]], $CellContext`sym$97405[$CellContext`size] = Part[
      $CellContext`sym$97405[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$97405[$CellContext`size, 
         "missing"]]]], $CellContext`sym$97405[$CellContext`speed] = Part[
      $CellContext`sym$97405[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$97405[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$97405[$CellContext`a1, "factorized"] = 
    True, $CellContext`sym$97405[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$97405, $CellContext`a1]], \
$CellContext`sym$97405[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$97405[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$97405[All], 
      All, $CellContext`i$98964], $CellContext`sym$97405[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$97405[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$97405, $CellContext`a2]], \
$CellContext`sym$97405[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$97405[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$97405[All], 
      All, $CellContext`i$98965], $CellContext`sym$97405[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$97405[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$97405, $CellContext`a3]], \
$CellContext`sym$97405[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$97405[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$97405[All], 
      All, $CellContext`i$98966], $CellContext`sym$97405[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$97405[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$97405, $CellContext`a4]], \
$CellContext`sym$97405[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$97405[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$97405[All], 
      All, $CellContext`i$98967], $CellContext`sym$97405[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$97405[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$97405, $CellContext`a5]], \
$CellContext`sym$97405[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$97405[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$97405[All], 
      All, $CellContext`i$98968], $CellContext`sym$97405[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$97405[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$97405, $CellContext`a6]], \
$CellContext`sym$97405[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$97405[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$97405[All], 
      All, $CellContext`i$98969], $CellContext`sym$97405[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$97405[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$97405, $CellContext`a7]], \
$CellContext`sym$97405[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$97405[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$97405[All], 
      All, $CellContext`i$98970], $CellContext`sym$97405[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$97405[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$97405[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$97405[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$97405, $CellContext`Chla]], \
$CellContext`sym$97405[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$97405[$CellContext`Chla, "raw"] = Part[
      $CellContext`sym$97405[All], 
      All, $CellContext`i$98963], $CellContext`sym$97405[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$97405[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$97405, $CellContext`Cl]], \
$CellContext`sym$97405[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$97405[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$97405[All], 
      All, $CellContext`i$98958], $CellContext`sym$97405[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$97405[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$97405, $CellContext`mnO2]], \
$CellContext`sym$97405[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$97405[$CellContext`mnO2, "raw"] = Part[
      $CellContext`sym$97405[All], 
      All, $CellContext`i$98957], $CellContext`sym$97405[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$97405[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$97405, $CellContext`mxPH]], \
$CellContext`sym$97405[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$97405[$CellContext`mxPH, "raw"] = Part[
      $CellContext`sym$97405[All], 
      All, $CellContext`i$98956], $CellContext`sym$97405[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$97405[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$97405, $CellContext`NH4]], \
$CellContext`sym$97405[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$97405[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$97405[All], 
      All, $CellContext`i$98960], $CellContext`sym$97405[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$97405[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$97405, $CellContext`NO3]], \
$CellContext`sym$97405[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$97405[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$97405[All], 
      All, $CellContext`i$98959], $CellContext`sym$97405[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$97405[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$97405, $CellContext`oPO4]], \
$CellContext`sym$97405[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$97405[$CellContext`oPO4, "raw"] = Part[
      $CellContext`sym$97405[All], 
      All, $CellContext`i$98961], $CellContext`sym$97405[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$97405[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$97405, $CellContext`PO4]], \
$CellContext`sym$97405[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$97405[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$97405[All], 
      All, $CellContext`i$98962], $CellContext`sym$97405[$CellContext`season, 
      "factorized"] = 
    True, $CellContext`sym$97405[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$97405, $CellContext`season]], \
$CellContext`sym$97405[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$97405[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$97405[All], 
      All, $CellContext`i$97406], $CellContext`sym$97405[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$97405[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$97405, $CellContext`size]], \
$CellContext`sym$97405[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$97405[$CellContext`size, "raw"] = Part[
      $CellContext`sym$97405[All], 
      All, $CellContext`i$98954], $CellContext`sym$97405[$CellContext`speed, 
      "factorized"] = 
    True, $CellContext`sym$97405[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$97405, $CellContext`speed]], \
$CellContext`sym$97405[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$97405[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$97405[All], All, $CellContext`i$98955], 
    Attributes[$CellContext`i$98955] = {Temporary}, $CellContext`i$98955 = 3, 
    Attributes[$CellContext`i$98954] = {Temporary}, $CellContext`i$98954 = 2, 
    Attributes[$CellContext`i$98968] = {Temporary}, $CellContext`i$98968 = 16,
     Attributes[$CellContext`i$98957] = {Temporary}, $CellContext`i$98957 = 5,
     Attributes[$CellContext`i$97406] = {Temporary}, $CellContext`i$97406 = 1,
     Attributes[$CellContext`i$98961] = {Temporary}, $CellContext`i$98961 = 9,
     Attributes[$CellContext`i$98958] = {Temporary}, $CellContext`i$98958 = 6,
     Attributes[$CellContext`i$98956] = {Temporary}, $CellContext`i$98956 = 4,
     Attributes[$CellContext`i$98963] = {Temporary}, $CellContext`i$98963 = 
    11, Attributes[$CellContext`i$98966] = {Temporary}, $CellContext`i$98966 = 
    14, Attributes[$CellContext`i$98959] = {Temporary}, $CellContext`i$98959 = 
    7, Attributes[$CellContext`i$98960] = {Temporary}, $CellContext`i$98960 = 
    8, Attributes[$CellContext`i$98970] = {Temporary}, $CellContext`i$98970 = 
    18, Attributes[$CellContext`i$98965] = {Temporary}, $CellContext`i$98965 = 
    13, Attributes[$CellContext`i$98967] = {Temporary}, $CellContext`i$98967 = 
    15, Attributes[$CellContext`i$98962] = {Temporary}, $CellContext`i$98962 = 
    10, Attributes[$CellContext`i$98964] = {Temporary}, $CellContext`i$98964 = 
    12, Attributes[$CellContext`i$98969] = {Temporary}, $CellContext`i$98969 = 
    17, Attributes[$CellContext`sym$5743] = {
     Temporary}, $CellContext`sym$5743[$CellContext`a1] = $CellContext`med[
     All], $CellContext`sym$5743[$CellContext`a2] = $CellContext`med[
     All], $CellContext`sym$5743[$CellContext`a3] = $CellContext`med[
     All], $CellContext`sym$5743[$CellContext`a4] = $CellContext`med[
     All], $CellContext`sym$5743[$CellContext`a5] = $CellContext`med[
     All], $CellContext`sym$5743[$CellContext`a6] = $CellContext`med[
     All], $CellContext`sym$5743[$CellContext`a7] = $CellContext`med[
     All], $CellContext`sym$5743[All] = $CellContext`med[
     All], $CellContext`sym$5743[$CellContext`Chla] = $CellContext`med[
     All], $CellContext`sym$5743[$CellContext`Cl] = $CellContext`med[
     All], $CellContext`sym$5743[$CellContext`mnO2] = $CellContext`med[
     All], $CellContext`sym$5743[$CellContext`mxPH] = $CellContext`med[
     All], $CellContext`sym$5743[$CellContext`NH4] = $CellContext`med[
     All], $CellContext`sym$5743[$CellContext`NO3] = $CellContext`med[
     All], $CellContext`sym$5743[$CellContext`oPO4] = $CellContext`med[
     All], $CellContext`sym$5743[$CellContext`PO4] = $CellContext`med[
     All], $CellContext`sym$5743[$CellContext`season] = $CellContext`med[
     All], $CellContext`sym$5743[$CellContext`size] = $CellContext`med[
     All], $CellContext`sym$5743[$CellContext`speed] = $CellContext`med[
     All], $CellContext`sym$5743[$CellContext`a1, "factorized"] = 
    True, $CellContext`sym$5743[$CellContext`a1, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$5743[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$5743[$CellContext`a1, "raw"] = Part[
      $CellContext`med[All], All, 12], $CellContext`sym$5743[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$5743[$CellContext`a2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$5743[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$5743[$CellContext`a2, "raw"] = Part[
      $CellContext`med[All], All, 13], $CellContext`sym$5743[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$5743[$CellContext`a3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$5743[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$5743[$CellContext`a3, "raw"] = Part[
      $CellContext`med[All], All, 14], $CellContext`sym$5743[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$5743[$CellContext`a4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$5743[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$5743[$CellContext`a4, "raw"] = Part[
      $CellContext`med[All], All, 15], $CellContext`sym$5743[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$5743[$CellContext`a5, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$5743[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$5743[$CellContext`a5, "raw"] = Part[
      $CellContext`med[All], All, 16], $CellContext`sym$5743[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$5743[$CellContext`a6, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$5743[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$5743[$CellContext`a6, "raw"] = Part[
      $CellContext`med[All], All, 17], $CellContext`sym$5743[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$5743[$CellContext`a7, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$5743[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$5743[$CellContext`a7, "raw"] = Part[
      $CellContext`med[All], All, 18], $CellContext`sym$5743[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$5743[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$5743[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$5743[$CellContext`Chla, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$5743[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$5743[$CellContext`Chla, "raw"] = Part[
      $CellContext`med[All], All, 11], $CellContext`sym$5743[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$5743[$CellContext`Cl, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$5743[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$5743[$CellContext`Cl, "raw"] = Part[
      $CellContext`med[All], All, 6], $CellContext`sym$5743[$CellContext`mnO2,
       "factorized"] = 
    True, $CellContext`sym$5743[$CellContext`mnO2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$5743[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$5743[$CellContext`mnO2, "raw"] = Part[
      $CellContext`med[All], All, 5], $CellContext`sym$5743[$CellContext`mxPH,
       "factorized"] = 
    True, $CellContext`sym$5743[$CellContext`mxPH, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$5743[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$5743[$CellContext`mxPH, "raw"] = Part[
      $CellContext`med[All], All, 4], $CellContext`sym$5743[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$5743[$CellContext`NH4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$5743[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$5743[$CellContext`NH4, "raw"] = Part[
      $CellContext`med[All], All, 8], $CellContext`sym$5743[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$5743[$CellContext`NO3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$5743[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$5743[$CellContext`NO3, "raw"] = Part[
      $CellContext`med[All], All, 7], $CellContext`sym$5743[$CellContext`oPO4,
       "factorized"] = 
    True, $CellContext`sym$5743[$CellContext`oPO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$5743[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$5743[$CellContext`oPO4, "raw"] = Part[
      $CellContext`med[All], All, 9], $CellContext`sym$5743[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$5743[$CellContext`PO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$5743[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$5743[$CellContext`PO4, "raw"] = Part[
      $CellContext`med[All], All, 
      10], $CellContext`sym$5743[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$5743[$CellContext`season, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$5743[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$5743[$CellContext`season, "raw"] = 
    Part[
      $CellContext`med[All], All, 1], $CellContext`sym$5743[$CellContext`size,
       "factorized"] = 
    True, $CellContext`sym$5743[$CellContext`size, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$5743[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$5743[$CellContext`size, "raw"] = Part[
      $CellContext`med[All], All, 
      2], $CellContext`sym$5743[$CellContext`speed, "factorized"] = 
    True, $CellContext`sym$5743[$CellContext`speed, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$5743[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$5743[$CellContext`speed, "raw"] = Part[
      $CellContext`med[All], All, 3], 
    Attributes[$CellContext`sym$202356] = {
     Temporary}, $CellContext`sym$202356[$CellContext`a1] = Part[
      $CellContext`sym$202356[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$202356[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$202356[$CellContext`a2] = Part[
      $CellContext`sym$202356[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$202356[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$202356[$CellContext`a3] = Part[
      $CellContext`sym$202356[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$202356[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$202356[$CellContext`a4] = Part[
      $CellContext`sym$202356[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$202356[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$202356[$CellContext`a5] = Part[
      $CellContext`sym$202356[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$202356[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$202356[$CellContext`a6] = Part[
      $CellContext`sym$202356[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$202356[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$202356[$CellContext`a7] = Part[
      $CellContext`sym$202356[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$202356[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$202356[All] = $CellContext`med[
     All], $CellContext`sym$202356[$CellContext`Chla] = Part[
      $CellContext`sym$202356[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$202356[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$202356[$CellContext`Cl] = Part[
      $CellContext`sym$202356[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$202356[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$202356[$CellContext`mnO2] = Part[
      $CellContext`sym$202356[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$202356[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$202356[$CellContext`mxPH] = Part[
      $CellContext`sym$202356[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$202356[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$202356[$CellContext`NH4] = Part[
      $CellContext`sym$202356[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$202356[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$202356[$CellContext`NO3] = Part[
      $CellContext`sym$202356[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$202356[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$202356[$CellContext`oPO4] = Part[
      $CellContext`sym$202356[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$202356[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$202356[$CellContext`PO4] = Part[
      $CellContext`sym$202356[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$202356[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$202356[$CellContext`season] = Part[
      $CellContext`sym$202356[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$202356[$CellContext`season, 
         "missing"]]]], $CellContext`sym$202356[$CellContext`size] = Part[
      $CellContext`sym$202356[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$202356[$CellContext`size, 
         "missing"]]]], $CellContext`sym$202356[$CellContext`speed] = Part[
      $CellContext`sym$202356[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$202356[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$202356[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$202356[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$202356, $CellContext`a1]], \
$CellContext`sym$202356[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$202356[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$202356[All], 
      All, $CellContext`i$203915], $CellContext`sym$202356[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$202356[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$202356, $CellContext`a2]], \
$CellContext`sym$202356[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$202356[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$202356[All], 
      All, $CellContext`i$203916], $CellContext`sym$202356[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$202356[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$202356, $CellContext`a3]], \
$CellContext`sym$202356[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$202356[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$202356[All], 
      All, $CellContext`i$203917], $CellContext`sym$202356[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$202356[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$202356, $CellContext`a4]], \
$CellContext`sym$202356[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$202356[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$202356[All], 
      All, $CellContext`i$203918], $CellContext`sym$202356[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$202356[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$202356, $CellContext`a5]], \
$CellContext`sym$202356[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$202356[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$202356[All], 
      All, $CellContext`i$203919], $CellContext`sym$202356[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$202356[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$202356, $CellContext`a6]], \
$CellContext`sym$202356[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$202356[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$202356[All], 
      All, $CellContext`i$203920], $CellContext`sym$202356[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$202356[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$202356, $CellContext`a7]], \
$CellContext`sym$202356[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$202356[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$202356[All], 
      All, $CellContext`i$203921], $CellContext`sym$202356[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$202356[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$202356[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$202356[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$202356, $CellContext`Chla]], \
$CellContext`sym$202356[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$202356[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$202356[All], 
      All, $CellContext`i$203914], $CellContext`sym$202356[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$202356[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$202356, $CellContext`Cl]], \
$CellContext`sym$202356[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$202356[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$202356[All], 
      All, $CellContext`i$203909], $CellContext`sym$202356[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$202356[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$202356, $CellContext`mnO2]], \
$CellContext`sym$202356[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$202356[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$202356[All], 
      All, $CellContext`i$203908], $CellContext`sym$202356[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$202356[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$202356, $CellContext`mxPH]], \
$CellContext`sym$202356[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$202356[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$202356[All], 
      All, $CellContext`i$203907], $CellContext`sym$202356[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$202356[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$202356, $CellContext`NH4]], \
$CellContext`sym$202356[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$202356[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$202356[All], 
      All, $CellContext`i$203911], $CellContext`sym$202356[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$202356[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$202356, $CellContext`NO3]], \
$CellContext`sym$202356[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$202356[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$202356[All], 
      All, $CellContext`i$203910], $CellContext`sym$202356[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$202356[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$202356, $CellContext`oPO4]], \
$CellContext`sym$202356[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$202356[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$202356[All], 
      All, $CellContext`i$203912], $CellContext`sym$202356[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$202356[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$202356, $CellContext`PO4]], \
$CellContext`sym$202356[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$202356[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$202356[All], 
      All, $CellContext`i$203913], \
$CellContext`sym$202356[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$202356[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$202356, $CellContext`season]], \
$CellContext`sym$202356[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$202356[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$202356[All], 
      All, $CellContext`i$202357], $CellContext`sym$202356[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$202356[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$202356, $CellContext`size]], \
$CellContext`sym$202356[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$202356[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$202356[All], 
      All, $CellContext`i$203905], $CellContext`sym$202356[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$202356[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$202356, $CellContext`speed]], \
$CellContext`sym$202356[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$202356[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$202356[All], All, $CellContext`i$203906], 
    Attributes[$CellContext`i$203913] = {Temporary}, $CellContext`i$203913 = 
    10, Attributes[$CellContext`i$203916] = {
     Temporary}, $CellContext`i$203916 = 13, 
    Attributes[$CellContext`i$203906] = {Temporary}, $CellContext`i$203906 = 
    3, Attributes[$CellContext`i$203905] = {Temporary}, $CellContext`i$203905 = 
    2, Attributes[$CellContext`i$203907] = {Temporary}, $CellContext`i$203907 = 
    4, Attributes[$CellContext`i$203919] = {Temporary}, $CellContext`i$203919 = 
    16, Attributes[$CellContext`i$203914] = {
     Temporary}, $CellContext`i$203914 = 11, 
    Attributes[$CellContext`i$203921] = {Temporary}, $CellContext`i$203921 = 
    18, Attributes[$CellContext`i$203920] = {
     Temporary}, $CellContext`i$203920 = 17, 
    Attributes[$CellContext`i$203912] = {Temporary}, $CellContext`i$203912 = 
    9, Attributes[$CellContext`i$202357] = {Temporary}, $CellContext`i$202357 = 
    1, Attributes[$CellContext`i$203915] = {Temporary}, $CellContext`i$203915 = 
    12, Attributes[$CellContext`i$203908] = {
     Temporary}, $CellContext`i$203908 = 5, 
    Attributes[$CellContext`i$203917] = {Temporary}, $CellContext`i$203917 = 
    14, Attributes[$CellContext`i$203911] = {
     Temporary}, $CellContext`i$203911 = 8, 
    Attributes[$CellContext`i$203918] = {Temporary}, $CellContext`i$203918 = 
    15, Attributes[$CellContext`i$203910] = {
     Temporary}, $CellContext`i$203910 = 7, 
    Attributes[$CellContext`i$203909] = {Temporary}, $CellContext`i$203909 = 
    6, Attributes[$CellContext`sym$101871] = {
     Temporary}, $CellContext`sym$101871[$CellContext`a1] = Part[
      $CellContext`sym$101871[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$101871[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$101871[$CellContext`a2] = Part[
      $CellContext`sym$101871[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$101871[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$101871[$CellContext`a3] = Part[
      $CellContext`sym$101871[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$101871[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$101871[$CellContext`a4] = Part[
      $CellContext`sym$101871[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$101871[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$101871[$CellContext`a5] = Part[
      $CellContext`sym$101871[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$101871[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$101871[$CellContext`a6] = Part[
      $CellContext`sym$101871[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$101871[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$101871[$CellContext`a7] = Part[
      $CellContext`sym$101871[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$101871[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$101871[All] = $CellContext`med[
     All], $CellContext`sym$101871[$CellContext`Chla] = Part[
      $CellContext`sym$101871[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$101871[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$101871[$CellContext`Cl] = Part[
      $CellContext`sym$101871[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$101871[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$101871[$CellContext`mnO2] = Part[
      $CellContext`sym$101871[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$101871[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$101871[$CellContext`mxPH] = Part[
      $CellContext`sym$101871[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$101871[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$101871[$CellContext`NH4] = Part[
      $CellContext`sym$101871[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$101871[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$101871[$CellContext`NO3] = Part[
      $CellContext`sym$101871[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$101871[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$101871[$CellContext`oPO4] = Part[
      $CellContext`sym$101871[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$101871[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$101871[$CellContext`PO4] = Part[
      $CellContext`sym$101871[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$101871[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$101871[$CellContext`season] = Part[
      $CellContext`sym$101871[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$101871[$CellContext`season, 
         "missing"]]]], $CellContext`sym$101871[$CellContext`size] = Part[
      $CellContext`sym$101871[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$101871[$CellContext`size, 
         "missing"]]]], $CellContext`sym$101871[$CellContext`speed] = Part[
      $CellContext`sym$101871[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$101871[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$101871[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$101871[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$101871, $CellContext`a1]], \
$CellContext`sym$101871[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$101871[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$101871[All], 
      All, $CellContext`i$103430], $CellContext`sym$101871[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$101871[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$101871, $CellContext`a2]], \
$CellContext`sym$101871[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$101871[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$101871[All], 
      All, $CellContext`i$103431], $CellContext`sym$101871[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$101871[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$101871, $CellContext`a3]], \
$CellContext`sym$101871[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$101871[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$101871[All], 
      All, $CellContext`i$103432], $CellContext`sym$101871[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$101871[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$101871, $CellContext`a4]], \
$CellContext`sym$101871[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$101871[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$101871[All], 
      All, $CellContext`i$103433], $CellContext`sym$101871[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$101871[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$101871, $CellContext`a5]], \
$CellContext`sym$101871[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$101871[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$101871[All], 
      All, $CellContext`i$103434], $CellContext`sym$101871[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$101871[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$101871, $CellContext`a6]], \
$CellContext`sym$101871[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$101871[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$101871[All], 
      All, $CellContext`i$103435], $CellContext`sym$101871[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$101871[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$101871, $CellContext`a7]], \
$CellContext`sym$101871[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$101871[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$101871[All], 
      All, $CellContext`i$103436], $CellContext`sym$101871[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$101871[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$101871[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$101871[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$101871, $CellContext`Chla]], \
$CellContext`sym$101871[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$101871[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$101871[All], 
      All, $CellContext`i$103429], $CellContext`sym$101871[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$101871[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$101871, $CellContext`Cl]], \
$CellContext`sym$101871[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$101871[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$101871[All], 
      All, $CellContext`i$103424], $CellContext`sym$101871[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$101871[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$101871, $CellContext`mnO2]], \
$CellContext`sym$101871[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$101871[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$101871[All], 
      All, $CellContext`i$103423], $CellContext`sym$101871[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$101871[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$101871, $CellContext`mxPH]], \
$CellContext`sym$101871[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$101871[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$101871[All], 
      All, $CellContext`i$103422], $CellContext`sym$101871[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$101871[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$101871, $CellContext`NH4]], \
$CellContext`sym$101871[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$101871[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$101871[All], 
      All, $CellContext`i$103426], $CellContext`sym$101871[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$101871[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$101871, $CellContext`NO3]], \
$CellContext`sym$101871[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$101871[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$101871[All], 
      All, $CellContext`i$103425], $CellContext`sym$101871[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$101871[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$101871, $CellContext`oPO4]], \
$CellContext`sym$101871[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$101871[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$101871[All], 
      All, $CellContext`i$103427], $CellContext`sym$101871[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$101871[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$101871, $CellContext`PO4]], \
$CellContext`sym$101871[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$101871[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$101871[All], 
      All, $CellContext`i$103428], \
$CellContext`sym$101871[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$101871[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$101871, $CellContext`season]], \
$CellContext`sym$101871[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$101871[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$101871[All], 
      All, $CellContext`i$101872], $CellContext`sym$101871[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$101871[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$101871, $CellContext`size]], \
$CellContext`sym$101871[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$101871[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$101871[All], 
      All, $CellContext`i$103420], $CellContext`sym$101871[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$101871[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$101871, $CellContext`speed]], \
$CellContext`sym$101871[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$101871[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$101871[All], All, $CellContext`i$103421], 
    Attributes[$CellContext`i$103433] = {Temporary}, $CellContext`i$103433 = 
    15, Attributes[$CellContext`i$103428] = {
     Temporary}, $CellContext`i$103428 = 10, 
    Attributes[$CellContext`i$103432] = {Temporary}, $CellContext`i$103432 = 
    14, Attributes[$CellContext`i$103431] = {
     Temporary}, $CellContext`i$103431 = 13, 
    Attributes[$CellContext`i$103427] = {Temporary}, $CellContext`i$103427 = 
    9, Attributes[$CellContext`i$103429] = {Temporary}, $CellContext`i$103429 = 
    11, Attributes[$CellContext`i$103423] = {
     Temporary}, $CellContext`i$103423 = 5, 
    Attributes[$CellContext`i$103426] = {Temporary}, $CellContext`i$103426 = 
    8, Attributes[$CellContext`i$103425] = {Temporary}, $CellContext`i$103425 = 
    7, Attributes[$CellContext`i$103420] = {Temporary}, $CellContext`i$103420 = 
    2, Attributes[$CellContext`i$101872] = {Temporary}, $CellContext`i$101872 = 
    1, Attributes[$CellContext`i$103435] = {Temporary}, $CellContext`i$103435 = 
    17, Attributes[$CellContext`i$103422] = {
     Temporary}, $CellContext`i$103422 = 4, 
    Attributes[$CellContext`i$103430] = {Temporary}, $CellContext`i$103430 = 
    12, Attributes[$CellContext`i$103434] = {
     Temporary}, $CellContext`i$103434 = 16, 
    Attributes[$CellContext`i$103424] = {Temporary}, $CellContext`i$103424 = 
    6, Attributes[$CellContext`i$103421] = {Temporary}, $CellContext`i$103421 = 
    3, Attributes[$CellContext`i$103436] = {Temporary}, $CellContext`i$103436 = 
    18, Attributes[$CellContext`sym$228168] = {
     Temporary}, $CellContext`sym$228168[$CellContext`a1] = Part[
      $CellContext`sym$228168[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228168[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$228168[$CellContext`a2] = Part[
      $CellContext`sym$228168[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228168[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$228168[$CellContext`a3] = Part[
      $CellContext`sym$228168[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228168[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$228168[$CellContext`a4] = Part[
      $CellContext`sym$228168[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228168[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$228168[$CellContext`a5] = Part[
      $CellContext`sym$228168[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228168[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$228168[$CellContext`a6] = Part[
      $CellContext`sym$228168[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228168[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$228168[$CellContext`a7] = Part[
      $CellContext`sym$228168[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228168[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$228168[
     All] = {{"winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 
       170., 50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
      "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
       558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
      "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 125.667,
        187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
      "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 61.182, 
       138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
      "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222, 
       97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
      "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
       56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
      "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
       111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
      "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 44.667, 
       77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
      "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 71., 
       5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 0.8, 
       17., 0., 0., 2.9, 0., 0., 1.7}, {
      "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 20.75, 
       0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
      "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 19.,
        0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
      "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 41., 
       43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
      "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5, 
       31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
      "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 0.3, 
       52.2, 5., 7.8, 0., 4., 0., 0.}, {
      "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 98.25, 
       1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50., 
       1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
      "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 57.833, 
       0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
      "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 0.8, 
       50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
      "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
       564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
      "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 586.,
        16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
      "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 0.5, 
       15.5, 0., 0., 2.3, 0., 0., 0.}, {
      "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 7.6,
        23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
      "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
       27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
      "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 1.5,
        13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
      "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 44.136, 
       3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
      "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 0.5, 
       29.7, 0., 0., 4.9, 0., 0., 0.}, {
      "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
       Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
      "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 17.1,
        0., 19.6, 0., 0., 0., 2.5}, {
      "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5, 
       33.9, 1., 14.6, 0., 0., 0., 0.}, {
      "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 4.9, 
       3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
      "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 2.8, 
       6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
      "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 130.75, 
       5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
      "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47., 
       2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
      "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23., 
       0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
      "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 58.875, 
       84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
      "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 0.2,
        66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
       Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0., 
       0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
       196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
      "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
       182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
      "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001, 
       296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
      "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 59.429,
        175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
      "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
       344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
      "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 276.85001, 
       326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
      "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 40.667, 
       3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
      "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 3.3, 
       29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
      "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 0.8, 
       54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
       Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 0., 
       0.}, {"spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121.,
        2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 20.812,
        12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
      "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
       49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
      "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 22.9, 
       4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
      "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 11.8, 
       0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818, 
       0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
      "winter", "small", "high", 6.6, 10.8, 
       Missing[], 3.245, 10., 1., 6.5, 
       Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "medium", 5.6, 11.8, 
       Missing[], 2.22, 5., 1., 1., 
       Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 5.7, 10.8, 
       Missing[], 2.55, 10., 1., 4., 
       Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
      "spring", "small", "high", 6.6, 9.5, 
       Missing[], 1.32, 20., 1., 6., 
       Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
      "summer", "small", "high", 6.6, 10.8, 
       Missing[], 2.64, 10., 2., 11., 
       Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
      "autumn", "small", "medium", 6.6, 11.3, 
       Missing[], 4.17, 10., 1., 6., 
       Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
      "spring", "small", "medium", 6.5, 10.4, 
       Missing[], 5.97, 10., 2., 14., 
       Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 6.667, 
       Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75, 1.,
        20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
      "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2, 
       0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
      "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 0.6,
        55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
      "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 10.75, 
       2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
      "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 0.5, 
       64.2, 0., 3., 0., 0., 0., 0.}, {
      "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75, 
       351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
      "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
       209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
      "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 151.125,
        279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
      "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
       152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
      "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
       58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
      "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
       249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
      "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 100., 
       233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
      "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 215.5, 
       18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
      "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 25.167, 
       102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
      "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
       105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
      "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
       111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
      "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 1.3, 
       6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
      "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 56.667, 
       2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
      "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 4.3,
        1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
      "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
       104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
      "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 69.93,
        3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
      "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
       214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
      "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
       254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
      "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 57.6,
        169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
      "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
       412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
      "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
       282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
      "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
       197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
      "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 267.75, 
       391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
      "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 191.75, 
       265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
      "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
       232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
      "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 144.66701, 
       244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
      "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 218., 
       6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
      "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 138.5,
        20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
      "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222, 
       239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
      "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
       235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
      "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75, 
       205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
      "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 31.333, 
       211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
      "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625, 
       186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
      "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 12.889, 
       154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
      "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 51.111, 
       183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
      "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
       292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
      "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
       285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
      "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
       201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
      "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
       275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
      "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
       124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
      "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 60.833, 
       141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
      "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71., 
       132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
      "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
       17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
      "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 0.3, 
       46.6, 0., 2.5, 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 8.692, 
       16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
      "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 37.857, 
       102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
      "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
       86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
      "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
       10.111, 
       Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 16.833, 
       18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
      "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545, 
       13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
      "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 261.60001, 
       432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
      "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
       320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
      "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 144., 
       287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
      "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
       166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
      "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
       222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
      "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 36.909, 
       122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
      "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556, 
       127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
      "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
       89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
      "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 55., 
       284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
      "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 102.333, 
       277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
      "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 75.875, 
       177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
      "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
       72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
      "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 48.667, 
       82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
      "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 48.625, 
       66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
      "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 23., 
       173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
      "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 317., 
       5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
      "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 84., 
       4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
      "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 2., 
       10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
      "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 88.5, 
       2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
      "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115., 
       11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
      "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 98.143, 
       2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
      "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
       143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
      "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
       197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
      "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 1., 
       19., 0., 22., 5., 1.1, 5.4, 0.}, {
      "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 10.583, 
       23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
      "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 200.231, 
       19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
      "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 77.333, 
       147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
      "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5, 
       276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
      "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
       123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
      "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 75.207,
        23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
      "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 116.2,
        7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
      "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
       188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
      "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
       72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
      "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 16., 
       0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
      "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 34., 
       53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
      "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 27.5, 
       76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
      "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
       58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
      "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 175.66701, 
       361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
      "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
       22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
      "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 26.8,
        0., 28., 0., 0., 0., 0., 15.1}, {
      "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
       54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
      "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333, 
       34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
      "spring", "large", "low", 9., 5.8, 
       Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 0., 
       0.}, {"spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
       151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
      "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
       269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
      "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 46.438, 
       81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
      "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 85., 
       2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
      "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 66.4, 
       171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
      "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 102.364, 
       232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
      "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 84.3, 
       146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
      "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
       246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
      "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 205.636, 
       219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
      "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 236.39999,
        272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
      "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 1081.66003, 
       346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 5.9, 1.7}, {
      "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 82.222,
        167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
      "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 64.389, 
       137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
      "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 87.333,
        194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
      "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
       159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
      "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 21.3, 
       1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
      "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 0.6,
        37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
      "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
       14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
      "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222, 7.,
        1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 0.8, 
       50.4, 3.8, 0., 0., 0., 0., 0.}, {
      "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 7.654, 
       4., 56.8, 5., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 2.86, 
       17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
      "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 56.091, 
       Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
      "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
       52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
      "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 104.727, 
       228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
      "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 85.4, 
       17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
      "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 87.125,
        14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
      "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 101.455, 
       18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
      "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 50.889, 
       127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
      "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
       81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
      "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 19.727, 
       50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
      "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111, 
       120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
      "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 51.111, 
       91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
      "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 19.111, 
       61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
      "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625, 
       79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
      "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333, 
       75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
      "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333, 
       140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
      "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
       140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 
       5.8}}, $CellContext`sym$228168[$CellContext`Chla] = Part[
      $CellContext`sym$228168[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {
          "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
           196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228168[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$228168[$CellContext`Cl] = Part[
      $CellContext`sym$228168[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228168[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$228168[$CellContext`mnO2] = Part[
      $CellContext`sym$228168[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228168[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$228168[$CellContext`mxPH] = Part[
      $CellContext`sym$228168[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228168[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$228168[$CellContext`NH4] = Part[
      $CellContext`sym$228168[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228168[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$228168[$CellContext`NO3] = Part[
      $CellContext`sym$228168[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {
          "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
           196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228168[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$228168[$CellContext`oPO4] = Part[
      $CellContext`sym$228168[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228168[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$228168[$CellContext`PO4] = Part[
      $CellContext`sym$228168[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228168[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$228168[$CellContext`season] = Part[
      $CellContext`sym$228168[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228168[$CellContext`season, 
         "missing"]]]], $CellContext`sym$228168[$CellContext`size] = Part[
      $CellContext`sym$228168[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228168[$CellContext`size, 
         "missing"]]]], $CellContext`sym$228168[$CellContext`speed] = Part[
      $CellContext`sym$228168[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {
          "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
           196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228168[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$228168[$CellContext`a1, 
      "factorized"] = 
    False, $CellContext`sym$228168[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$228168[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$228168[All], 
      All, $CellContext`i$228180], $CellContext`sym$228168[$CellContext`a2, 
      "factorized"] = 
    False, $CellContext`sym$228168[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$228168[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$228168[All], 
      All, $CellContext`i$228181], $CellContext`sym$228168[$CellContext`a3, 
      "factorized"] = 
    False, $CellContext`sym$228168[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$228168[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$228168[All], 
      All, $CellContext`i$228182], $CellContext`sym$228168[$CellContext`a4, 
      "factorized"] = 
    False, $CellContext`sym$228168[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$228168[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$228168[All], 
      All, $CellContext`i$228183], $CellContext`sym$228168[$CellContext`a5, 
      "factorized"] = 
    False, $CellContext`sym$228168[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$228168[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$228168[All], 
      All, $CellContext`i$228184], $CellContext`sym$228168[$CellContext`a6, 
      "factorized"] = 
    False, $CellContext`sym$228168[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$228168[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$228168[All], 
      All, $CellContext`i$228185], $CellContext`sym$228168[$CellContext`a7, 
      "factorized"] = 
    False, $CellContext`sym$228168[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$228168[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$228168[All], 
      All, $CellContext`i$228186], $CellContext`sym$228168[
     All, 
      "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$228168[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed}, $CellContext`sym$228168[$CellContext`Chla, "factorized"] = 
    False, $CellContext`sym$228168[$CellContext`Chla, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {115}, {
     183}}, $CellContext`sym$228168[$CellContext`Chla, "raw"] = Part[
      $CellContext`sym$228168[All], 
      All, $CellContext`i$228179], $CellContext`sym$228168[$CellContext`Cl, 
      "factorized"] = 
    False, $CellContext`sym$228168[$CellContext`Cl, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {
     160}}, $CellContext`sym$228168[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$228168[All], 
      All, $CellContext`i$228174], $CellContext`sym$228168[$CellContext`mnO2, 
      "factorized"] = 
    False, $CellContext`sym$228168[$CellContext`mnO2, "missing"] = {{
     38}}, $CellContext`sym$228168[$CellContext`mnO2, "raw"] = Part[
      $CellContext`sym$228168[All], 
      All, $CellContext`i$228173], $CellContext`sym$228168[$CellContext`mxPH, 
      "factorized"] = 
    False, $CellContext`sym$228168[$CellContext`mxPH, "missing"] = {{
     48}}, $CellContext`sym$228168[$CellContext`mxPH, "raw"] = Part[
      $CellContext`sym$228168[All], 
      All, $CellContext`i$228172], $CellContext`sym$228168[$CellContext`NH4, 
      "factorized"] = 
    False, $CellContext`sym$228168[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$228168[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$228168[All], 
      All, $CellContext`i$228176], $CellContext`sym$228168[$CellContext`NO3, 
      "factorized"] = 
    False, $CellContext`sym$228168[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$228168[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$228168[All], 
      All, $CellContext`i$228175], $CellContext`sym$228168[$CellContext`oPO4, 
      "factorized"] = 
    False, $CellContext`sym$228168[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$228168[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$228168[All], 
      All, $CellContext`i$228177], $CellContext`sym$228168[$CellContext`PO4, 
      "factorized"] = 
    False, $CellContext`sym$228168[$CellContext`PO4, "missing"] = {{
     28}}, $CellContext`sym$228168[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$228168[All], 
      All, $CellContext`i$228178], \
$CellContext`sym$228168[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$228168[$CellContext`season, "factors"] = 
    Part[{"autumn", "spring", "summer", "winter"}, 
      $CellContext`fordering[$CellContext`sym$228168, $CellContext`season]], \
$CellContext`sym$228168[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$228168[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$228168[All], 
      All, $CellContext`i$228169], $CellContext`sym$228168[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$228168[$CellContext`size, "factors"] = 
    Part[{"large", "medium", "small"}, 
      $CellContext`fordering[$CellContext`sym$228168, $CellContext`size]], \
$CellContext`sym$228168[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$228168[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$228168[All], 
      All, $CellContext`i$228170], $CellContext`sym$228168[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$228168[$CellContext`speed, "factors"] = 
    Part[{"high", "low", "medium"}, 
      $CellContext`fordering[$CellContext`sym$228168, $CellContext`speed]], \
$CellContext`sym$228168[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$228168[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$228168[All], All, $CellContext`i$228171], 
    Attributes[$CellContext`i$228183] = {Temporary}, $CellContext`i$228183 = 
    15, Attributes[$CellContext`i$228177] = {
     Temporary}, $CellContext`i$228177 = 9, 
    Attributes[$CellContext`i$228172] = {Temporary}, $CellContext`i$228172 = 
    4, Attributes[$CellContext`i$228169] = {Temporary}, $CellContext`i$228169 = 
    1, Attributes[$CellContext`i$228180] = {Temporary}, $CellContext`i$228180 = 
    12, Attributes[$CellContext`i$228175] = {
     Temporary}, $CellContext`i$228175 = 7, 
    Attributes[$CellContext`i$228184] = {Temporary}, $CellContext`i$228184 = 
    16, Attributes[$CellContext`i$228171] = {
     Temporary}, $CellContext`i$228171 = 3, 
    Attributes[$CellContext`i$228178] = {Temporary}, $CellContext`i$228178 = 
    10, Attributes[$CellContext`i$228170] = {
     Temporary}, $CellContext`i$228170 = 2, 
    Attributes[$CellContext`i$228186] = {Temporary}, $CellContext`i$228186 = 
    18, Attributes[$CellContext`i$228173] = {
     Temporary}, $CellContext`i$228173 = 5, 
    Attributes[$CellContext`i$228185] = {Temporary}, $CellContext`i$228185 = 
    17, Attributes[$CellContext`i$228179] = {
     Temporary}, $CellContext`i$228179 = 11, 
    Attributes[$CellContext`i$228182] = {Temporary}, $CellContext`i$228182 = 
    14, Attributes[$CellContext`i$228174] = {
     Temporary}, $CellContext`i$228174 = 6, 
    Attributes[$CellContext`i$228176] = {Temporary}, $CellContext`i$228176 = 
    8, Attributes[$CellContext`i$228181] = {Temporary}, $CellContext`i$228181 = 
    13, Attributes[$CellContext`sym$99638] = {
     Temporary}, $CellContext`sym$99638[$CellContext`a1] = Part[
      $CellContext`sym$99638[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$99638[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$99638[$CellContext`a2] = Part[
      $CellContext`sym$99638[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$99638[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$99638[$CellContext`a3] = Part[
      $CellContext`sym$99638[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$99638[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$99638[$CellContext`a4] = Part[
      $CellContext`sym$99638[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$99638[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$99638[$CellContext`a5] = Part[
      $CellContext`sym$99638[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$99638[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$99638[$CellContext`a6] = Part[
      $CellContext`sym$99638[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$99638[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$99638[$CellContext`a7] = Part[
      $CellContext`sym$99638[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$99638[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$99638[All] = $CellContext`med[
     All], $CellContext`sym$99638[$CellContext`Chla] = Part[
      $CellContext`sym$99638[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$99638[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$99638[$CellContext`Cl] = Part[
      $CellContext`sym$99638[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$99638[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$99638[$CellContext`mnO2] = Part[
      $CellContext`sym$99638[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$99638[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$99638[$CellContext`mxPH] = Part[
      $CellContext`sym$99638[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$99638[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$99638[$CellContext`NH4] = Part[
      $CellContext`sym$99638[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$99638[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$99638[$CellContext`NO3] = Part[
      $CellContext`sym$99638[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$99638[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$99638[$CellContext`oPO4] = Part[
      $CellContext`sym$99638[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$99638[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$99638[$CellContext`PO4] = Part[
      $CellContext`sym$99638[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$99638[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$99638[$CellContext`season] = Part[
      $CellContext`sym$99638[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$99638[$CellContext`season, 
         "missing"]]]], $CellContext`sym$99638[$CellContext`size] = Part[
      $CellContext`sym$99638[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$99638[$CellContext`size, 
         "missing"]]]], $CellContext`sym$99638[$CellContext`speed] = Part[
      $CellContext`sym$99638[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$99638[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$99638[$CellContext`a1, "factorized"] = 
    True, $CellContext`sym$99638[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$99638, $CellContext`a1]], \
$CellContext`sym$99638[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$99638[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$99638[All], 
      All, $CellContext`i$101197], $CellContext`sym$99638[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$99638[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$99638, $CellContext`a2]], \
$CellContext`sym$99638[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$99638[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$99638[All], 
      All, $CellContext`i$101198], $CellContext`sym$99638[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$99638[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$99638, $CellContext`a3]], \
$CellContext`sym$99638[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$99638[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$99638[All], 
      All, $CellContext`i$101199], $CellContext`sym$99638[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$99638[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$99638, $CellContext`a4]], \
$CellContext`sym$99638[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$99638[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$99638[All], 
      All, $CellContext`i$101200], $CellContext`sym$99638[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$99638[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$99638, $CellContext`a5]], \
$CellContext`sym$99638[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$99638[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$99638[All], 
      All, $CellContext`i$101201], $CellContext`sym$99638[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$99638[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$99638, $CellContext`a6]], \
$CellContext`sym$99638[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$99638[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$99638[All], 
      All, $CellContext`i$101202], $CellContext`sym$99638[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$99638[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$99638, $CellContext`a7]], \
$CellContext`sym$99638[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$99638[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$99638[All], 
      All, $CellContext`i$101203], $CellContext`sym$99638[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$99638[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$99638[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$99638[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$99638, $CellContext`Chla]], \
$CellContext`sym$99638[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$99638[$CellContext`Chla, "raw"] = Part[
      $CellContext`sym$99638[All], 
      All, $CellContext`i$101196], $CellContext`sym$99638[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$99638[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$99638, $CellContext`Cl]], \
$CellContext`sym$99638[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$99638[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$99638[All], 
      All, $CellContext`i$101191], $CellContext`sym$99638[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$99638[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$99638, $CellContext`mnO2]], \
$CellContext`sym$99638[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$99638[$CellContext`mnO2, "raw"] = Part[
      $CellContext`sym$99638[All], 
      All, $CellContext`i$101190], $CellContext`sym$99638[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$99638[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$99638, $CellContext`mxPH]], \
$CellContext`sym$99638[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$99638[$CellContext`mxPH, "raw"] = Part[
      $CellContext`sym$99638[All], 
      All, $CellContext`i$101189], $CellContext`sym$99638[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$99638[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$99638, $CellContext`NH4]], \
$CellContext`sym$99638[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$99638[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$99638[All], 
      All, $CellContext`i$101193], $CellContext`sym$99638[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$99638[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$99638, $CellContext`NO3]], \
$CellContext`sym$99638[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$99638[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$99638[All], 
      All, $CellContext`i$101192], $CellContext`sym$99638[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$99638[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$99638, $CellContext`oPO4]], \
$CellContext`sym$99638[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$99638[$CellContext`oPO4, "raw"] = Part[
      $CellContext`sym$99638[All], 
      All, $CellContext`i$101194], $CellContext`sym$99638[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$99638[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$99638, $CellContext`PO4]], \
$CellContext`sym$99638[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$99638[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$99638[All], 
      All, $CellContext`i$101195], $CellContext`sym$99638[$CellContext`season,
       "factorized"] = 
    True, $CellContext`sym$99638[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$99638, $CellContext`season]], \
$CellContext`sym$99638[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$99638[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$99638[All], 
      All, $CellContext`i$99639], $CellContext`sym$99638[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$99638[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$99638, $CellContext`size]], \
$CellContext`sym$99638[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$99638[$CellContext`size, "raw"] = Part[
      $CellContext`sym$99638[All], 
      All, $CellContext`i$101187], $CellContext`sym$99638[$CellContext`speed, 
      "factorized"] = 
    True, $CellContext`sym$99638[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$99638, $CellContext`speed]], \
$CellContext`sym$99638[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$99638[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$99638[All], All, $CellContext`i$101188], 
    Attributes[$CellContext`i$101195] = {Temporary}, $CellContext`i$101195 = 
    10, Attributes[$CellContext`i$101196] = {
     Temporary}, $CellContext`i$101196 = 11, 
    Attributes[$CellContext`i$101197] = {Temporary}, $CellContext`i$101197 = 
    12, Attributes[$CellContext`i$101203] = {
     Temporary}, $CellContext`i$101203 = 18, 
    Attributes[$CellContext`i$101201] = {Temporary}, $CellContext`i$101201 = 
    16, Attributes[$CellContext`i$101191] = {
     Temporary}, $CellContext`i$101191 = 6, Attributes[$CellContext`i$99639] = 
    {Temporary}, $CellContext`i$99639 = 1, 
    Attributes[$CellContext`i$101202] = {Temporary}, $CellContext`i$101202 = 
    17, Attributes[$CellContext`i$101190] = {
     Temporary}, $CellContext`i$101190 = 5, 
    Attributes[$CellContext`i$101192] = {Temporary}, $CellContext`i$101192 = 
    7, Attributes[$CellContext`i$101194] = {Temporary}, $CellContext`i$101194 = 
    9, Attributes[$CellContext`i$101199] = {Temporary}, $CellContext`i$101199 = 
    14, Attributes[$CellContext`i$101198] = {
     Temporary}, $CellContext`i$101198 = 13, 
    Attributes[$CellContext`i$101193] = {Temporary}, $CellContext`i$101193 = 
    8, Attributes[$CellContext`i$101189] = {Temporary}, $CellContext`i$101189 = 
    4, Attributes[$CellContext`i$101200] = {Temporary}, $CellContext`i$101200 = 
    15, Attributes[$CellContext`i$101187] = {
     Temporary}, $CellContext`i$101187 = 2, 
    Attributes[$CellContext`i$101188] = {Temporary}, $CellContext`i$101188 = 
    3, Attributes[$CellContext`sym$68298] = {
     Temporary}, $CellContext`sym$68298[$CellContext`a1] = $CellContext`med[
     All], $CellContext`sym$68298[$CellContext`a2] = $CellContext`med[
     All], $CellContext`sym$68298[$CellContext`a3] = $CellContext`med[
     All], $CellContext`sym$68298[$CellContext`a4] = $CellContext`med[
     All], $CellContext`sym$68298[$CellContext`a5] = $CellContext`med[
     All], $CellContext`sym$68298[$CellContext`a6] = $CellContext`med[
     All], $CellContext`sym$68298[$CellContext`a7] = $CellContext`med[
     All], $CellContext`sym$68298[All] = $CellContext`med[
     All], $CellContext`sym$68298[$CellContext`Chla] = $CellContext`med[
     All], $CellContext`sym$68298[$CellContext`Cl] = $CellContext`med[
     All], $CellContext`sym$68298[$CellContext`mnO2] = $CellContext`med[
     All], $CellContext`sym$68298[$CellContext`mxPH] = $CellContext`med[
     All], $CellContext`sym$68298[$CellContext`NH4] = $CellContext`med[
     All], $CellContext`sym$68298[$CellContext`NO3] = $CellContext`med[
     All], $CellContext`sym$68298[$CellContext`oPO4] = $CellContext`med[
     All], $CellContext`sym$68298[$CellContext`PO4] = $CellContext`med[
     All], $CellContext`sym$68298[$CellContext`season] = $CellContext`med[
     All], $CellContext`sym$68298[$CellContext`size] = $CellContext`med[
     All], $CellContext`sym$68298[$CellContext`speed] = $CellContext`med[
     All], $CellContext`sym$68298[$CellContext`a1, "factorized"] = 
    True, $CellContext`sym$68298[$CellContext`a1, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$68298[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$68298[$CellContext`a1, "raw"] = Part[
      $CellContext`med[All], All, 12], $CellContext`sym$68298[$CellContext`a2,
       "factorized"] = 
    True, $CellContext`sym$68298[$CellContext`a2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$68298[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$68298[$CellContext`a2, "raw"] = Part[
      $CellContext`med[All], All, 13], $CellContext`sym$68298[$CellContext`a3,
       "factorized"] = 
    True, $CellContext`sym$68298[$CellContext`a3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$68298[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$68298[$CellContext`a3, "raw"] = Part[
      $CellContext`med[All], All, 14], $CellContext`sym$68298[$CellContext`a4,
       "factorized"] = 
    True, $CellContext`sym$68298[$CellContext`a4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$68298[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$68298[$CellContext`a4, "raw"] = Part[
      $CellContext`med[All], All, 15], $CellContext`sym$68298[$CellContext`a5,
       "factorized"] = 
    True, $CellContext`sym$68298[$CellContext`a5, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$68298[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$68298[$CellContext`a5, "raw"] = Part[
      $CellContext`med[All], All, 16], $CellContext`sym$68298[$CellContext`a6,
       "factorized"] = 
    True, $CellContext`sym$68298[$CellContext`a6, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$68298[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$68298[$CellContext`a6, "raw"] = Part[
      $CellContext`med[All], All, 17], $CellContext`sym$68298[$CellContext`a7,
       "factorized"] = 
    True, $CellContext`sym$68298[$CellContext`a7, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$68298[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$68298[$CellContext`a7, "raw"] = Part[
      $CellContext`med[All], All, 18], $CellContext`sym$68298[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$68298[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$68298[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$68298[$CellContext`Chla, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$68298[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$68298[$CellContext`Chla, "raw"] = Part[
      $CellContext`med[All], All, 11], $CellContext`sym$68298[$CellContext`Cl,
       "factorized"] = 
    True, $CellContext`sym$68298[$CellContext`Cl, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$68298[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$68298[$CellContext`Cl, "raw"] = Part[
      $CellContext`med[All], All, 
      6], $CellContext`sym$68298[$CellContext`mnO2, "factorized"] = 
    True, $CellContext`sym$68298[$CellContext`mnO2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$68298[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$68298[$CellContext`mnO2, "raw"] = Part[
      $CellContext`med[All], All, 
      5], $CellContext`sym$68298[$CellContext`mxPH, "factorized"] = 
    True, $CellContext`sym$68298[$CellContext`mxPH, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$68298[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$68298[$CellContext`mxPH, "raw"] = Part[
      $CellContext`med[All], All, 4], $CellContext`sym$68298[$CellContext`NH4,
       "factorized"] = 
    True, $CellContext`sym$68298[$CellContext`NH4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$68298[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$68298[$CellContext`NH4, "raw"] = Part[
      $CellContext`med[All], All, 8], $CellContext`sym$68298[$CellContext`NO3,
       "factorized"] = 
    True, $CellContext`sym$68298[$CellContext`NO3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$68298[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$68298[$CellContext`NO3, "raw"] = Part[
      $CellContext`med[All], All, 
      7], $CellContext`sym$68298[$CellContext`oPO4, "factorized"] = 
    True, $CellContext`sym$68298[$CellContext`oPO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$68298[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$68298[$CellContext`oPO4, "raw"] = Part[
      $CellContext`med[All], All, 9], $CellContext`sym$68298[$CellContext`PO4,
       "factorized"] = 
    True, $CellContext`sym$68298[$CellContext`PO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$68298[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$68298[$CellContext`PO4, "raw"] = Part[
      $CellContext`med[All], All, 
      10], $CellContext`sym$68298[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$68298[$CellContext`season, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$68298[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$68298[$CellContext`season, "raw"] = 
    Part[
      $CellContext`med[All], All, 
      1], $CellContext`sym$68298[$CellContext`size, "factorized"] = 
    True, $CellContext`sym$68298[$CellContext`size, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$68298[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$68298[$CellContext`size, "raw"] = Part[
      $CellContext`med[All], All, 
      2], $CellContext`sym$68298[$CellContext`speed, "factorized"] = 
    True, $CellContext`sym$68298[$CellContext`speed, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$68298[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$68298[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`med[All], All, 3], 
    Attributes[$CellContext`sym$180026] = {
     Temporary}, $CellContext`sym$180026[$CellContext`a1] = Part[
      $CellContext`sym$180026[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$180026[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$180026[$CellContext`a2] = Part[
      $CellContext`sym$180026[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$180026[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$180026[$CellContext`a3] = Part[
      $CellContext`sym$180026[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$180026[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$180026[$CellContext`a4] = Part[
      $CellContext`sym$180026[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$180026[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$180026[$CellContext`a5] = Part[
      $CellContext`sym$180026[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$180026[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$180026[$CellContext`a6] = Part[
      $CellContext`sym$180026[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$180026[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$180026[$CellContext`a7] = Part[
      $CellContext`sym$180026[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$180026[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$180026[All] = $CellContext`med[
     All], $CellContext`sym$180026[$CellContext`Chla] = Part[
      $CellContext`sym$180026[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$180026[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$180026[$CellContext`Cl] = Part[
      $CellContext`sym$180026[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$180026[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$180026[$CellContext`mnO2] = Part[
      $CellContext`sym$180026[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$180026[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$180026[$CellContext`mxPH] = Part[
      $CellContext`sym$180026[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$180026[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$180026[$CellContext`NH4] = Part[
      $CellContext`sym$180026[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$180026[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$180026[$CellContext`NO3] = Part[
      $CellContext`sym$180026[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$180026[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$180026[$CellContext`oPO4] = Part[
      $CellContext`sym$180026[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$180026[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$180026[$CellContext`PO4] = Part[
      $CellContext`sym$180026[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$180026[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$180026[$CellContext`season] = Part[
      $CellContext`sym$180026[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$180026[$CellContext`season, 
         "missing"]]]], $CellContext`sym$180026[$CellContext`size] = Part[
      $CellContext`sym$180026[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$180026[$CellContext`size, 
         "missing"]]]], $CellContext`sym$180026[$CellContext`speed] = Part[
      $CellContext`sym$180026[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$180026[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$180026[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$180026[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$180026, $CellContext`a1]], \
$CellContext`sym$180026[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$180026[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$180026[All], 
      All, $CellContext`i$181585], $CellContext`sym$180026[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$180026[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$180026, $CellContext`a2]], \
$CellContext`sym$180026[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$180026[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$180026[All], 
      All, $CellContext`i$181586], $CellContext`sym$180026[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$180026[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$180026, $CellContext`a3]], \
$CellContext`sym$180026[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$180026[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$180026[All], 
      All, $CellContext`i$181587], $CellContext`sym$180026[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$180026[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$180026, $CellContext`a4]], \
$CellContext`sym$180026[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$180026[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$180026[All], 
      All, $CellContext`i$181588], $CellContext`sym$180026[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$180026[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$180026, $CellContext`a5]], \
$CellContext`sym$180026[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$180026[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$180026[All], 
      All, $CellContext`i$181589], $CellContext`sym$180026[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$180026[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$180026, $CellContext`a6]], \
$CellContext`sym$180026[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$180026[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$180026[All], 
      All, $CellContext`i$181590], $CellContext`sym$180026[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$180026[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$180026, $CellContext`a7]], \
$CellContext`sym$180026[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$180026[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$180026[All], 
      All, $CellContext`i$181591], $CellContext`sym$180026[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$180026[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$180026[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$180026[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$180026, $CellContext`Chla]], \
$CellContext`sym$180026[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$180026[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$180026[All], 
      All, $CellContext`i$181584], $CellContext`sym$180026[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$180026[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$180026, $CellContext`Cl]], \
$CellContext`sym$180026[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$180026[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$180026[All], 
      All, $CellContext`i$181579], $CellContext`sym$180026[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$180026[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$180026, $CellContext`mnO2]], \
$CellContext`sym$180026[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$180026[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$180026[All], 
      All, $CellContext`i$181578], $CellContext`sym$180026[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$180026[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$180026, $CellContext`mxPH]], \
$CellContext`sym$180026[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$180026[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$180026[All], 
      All, $CellContext`i$181577], $CellContext`sym$180026[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$180026[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$180026, $CellContext`NH4]], \
$CellContext`sym$180026[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$180026[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$180026[All], 
      All, $CellContext`i$181581], $CellContext`sym$180026[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$180026[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$180026, $CellContext`NO3]], \
$CellContext`sym$180026[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$180026[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$180026[All], 
      All, $CellContext`i$181580], $CellContext`sym$180026[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$180026[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$180026, $CellContext`oPO4]], \
$CellContext`sym$180026[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$180026[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$180026[All], 
      All, $CellContext`i$181582], $CellContext`sym$180026[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$180026[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$180026, $CellContext`PO4]], \
$CellContext`sym$180026[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$180026[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$180026[All], 
      All, $CellContext`i$181583], \
$CellContext`sym$180026[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$180026[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$180026, $CellContext`season]], \
$CellContext`sym$180026[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$180026[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$180026[All], 
      All, $CellContext`i$180027], $CellContext`sym$180026[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$180026[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$180026, $CellContext`size]], \
$CellContext`sym$180026[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$180026[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$180026[All], 
      All, $CellContext`i$181575], $CellContext`sym$180026[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$180026[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$180026, $CellContext`speed]], \
$CellContext`sym$180026[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$180026[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$180026[All], All, $CellContext`i$181576], 
    Attributes[$CellContext`i$181576] = {Temporary}, $CellContext`i$181576 = 
    3, Attributes[$CellContext`i$181579] = {Temporary}, $CellContext`i$181579 = 
    6, Attributes[$CellContext`i$181583] = {Temporary}, $CellContext`i$181583 = 
    10, Attributes[$CellContext`i$181584] = {
     Temporary}, $CellContext`i$181584 = 11, 
    Attributes[$CellContext`i$181582] = {Temporary}, $CellContext`i$181582 = 
    9, Attributes[$CellContext`i$181591] = {Temporary}, $CellContext`i$181591 = 
    18, Attributes[$CellContext`i$180027] = {
     Temporary}, $CellContext`i$180027 = 1, 
    Attributes[$CellContext`i$181577] = {Temporary}, $CellContext`i$181577 = 
    4, Attributes[$CellContext`i$181586] = {Temporary}, $CellContext`i$181586 = 
    13, Attributes[$CellContext`i$181581] = {
     Temporary}, $CellContext`i$181581 = 8, 
    Attributes[$CellContext`i$181575] = {Temporary}, $CellContext`i$181575 = 
    2, Attributes[$CellContext`i$181585] = {Temporary}, $CellContext`i$181585 = 
    12, Attributes[$CellContext`i$181588] = {
     Temporary}, $CellContext`i$181588 = 15, 
    Attributes[$CellContext`i$181590] = {Temporary}, $CellContext`i$181590 = 
    17, Attributes[$CellContext`i$181578] = {
     Temporary}, $CellContext`i$181578 = 5, 
    Attributes[$CellContext`i$181589] = {Temporary}, $CellContext`i$181589 = 
    16, Attributes[$CellContext`i$181587] = {
     Temporary}, $CellContext`i$181587 = 14, 
    Attributes[$CellContext`i$181580] = {Temporary}, $CellContext`i$181580 = 
    7, Attributes[$CellContext`sym$213521] = {
     Temporary}, $CellContext`sym$213521[$CellContext`a1] = Part[
      $CellContext`sym$213521[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$213521[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$213521[$CellContext`a2] = Part[
      $CellContext`sym$213521[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$213521[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$213521[$CellContext`a3] = Part[
      $CellContext`sym$213521[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$213521[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$213521[$CellContext`a4] = Part[
      $CellContext`sym$213521[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$213521[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$213521[$CellContext`a5] = Part[
      $CellContext`sym$213521[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$213521[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$213521[$CellContext`a6] = Part[
      $CellContext`sym$213521[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$213521[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$213521[$CellContext`a7] = Part[
      $CellContext`sym$213521[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$213521[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$213521[All] = $CellContext`med[
     All], $CellContext`sym$213521[$CellContext`Chla] = Part[
      $CellContext`sym$213521[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$213521[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$213521[$CellContext`Cl] = Part[
      $CellContext`sym$213521[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$213521[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$213521[$CellContext`mnO2] = Part[
      $CellContext`sym$213521[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$213521[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$213521[$CellContext`mxPH] = Part[
      $CellContext`sym$213521[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$213521[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$213521[$CellContext`NH4] = Part[
      $CellContext`sym$213521[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$213521[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$213521[$CellContext`NO3] = Part[
      $CellContext`sym$213521[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$213521[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$213521[$CellContext`oPO4] = Part[
      $CellContext`sym$213521[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$213521[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$213521[$CellContext`PO4] = Part[
      $CellContext`sym$213521[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$213521[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$213521[$CellContext`season] = Part[
      $CellContext`sym$213521[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$213521[$CellContext`season, 
         "missing"]]]], $CellContext`sym$213521[$CellContext`size] = Part[
      $CellContext`sym$213521[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$213521[$CellContext`size, 
         "missing"]]]], $CellContext`sym$213521[$CellContext`speed] = Part[
      $CellContext`sym$213521[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$213521[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$213521[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$213521[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$213521, $CellContext`a1]], \
$CellContext`sym$213521[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$213521[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$213521[All], 
      All, $CellContext`i$215080], $CellContext`sym$213521[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$213521[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$213521, $CellContext`a2]], \
$CellContext`sym$213521[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$213521[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$213521[All], 
      All, $CellContext`i$215081], $CellContext`sym$213521[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$213521[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$213521, $CellContext`a3]], \
$CellContext`sym$213521[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$213521[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$213521[All], 
      All, $CellContext`i$215082], $CellContext`sym$213521[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$213521[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$213521, $CellContext`a4]], \
$CellContext`sym$213521[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$213521[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$213521[All], 
      All, $CellContext`i$215083], $CellContext`sym$213521[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$213521[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$213521, $CellContext`a5]], \
$CellContext`sym$213521[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$213521[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$213521[All], 
      All, $CellContext`i$215084], $CellContext`sym$213521[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$213521[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$213521, $CellContext`a6]], \
$CellContext`sym$213521[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$213521[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$213521[All], 
      All, $CellContext`i$215085], $CellContext`sym$213521[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$213521[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$213521, $CellContext`a7]], \
$CellContext`sym$213521[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$213521[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$213521[All], 
      All, $CellContext`i$215086], $CellContext`sym$213521[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$213521[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$213521[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$213521[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$213521, $CellContext`Chla]], \
$CellContext`sym$213521[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$213521[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$213521[All], 
      All, $CellContext`i$215079], $CellContext`sym$213521[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$213521[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$213521, $CellContext`Cl]], \
$CellContext`sym$213521[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$213521[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$213521[All], 
      All, $CellContext`i$215074], $CellContext`sym$213521[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$213521[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$213521, $CellContext`mnO2]], \
$CellContext`sym$213521[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$213521[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$213521[All], 
      All, $CellContext`i$215073], $CellContext`sym$213521[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$213521[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$213521, $CellContext`mxPH]], \
$CellContext`sym$213521[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$213521[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$213521[All], 
      All, $CellContext`i$215072], $CellContext`sym$213521[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$213521[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$213521, $CellContext`NH4]], \
$CellContext`sym$213521[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$213521[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$213521[All], 
      All, $CellContext`i$215076], $CellContext`sym$213521[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$213521[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$213521, $CellContext`NO3]], \
$CellContext`sym$213521[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$213521[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$213521[All], 
      All, $CellContext`i$215075], $CellContext`sym$213521[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$213521[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$213521, $CellContext`oPO4]], \
$CellContext`sym$213521[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$213521[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$213521[All], 
      All, $CellContext`i$215077], $CellContext`sym$213521[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$213521[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$213521, $CellContext`PO4]], \
$CellContext`sym$213521[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$213521[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$213521[All], 
      All, $CellContext`i$215078], \
$CellContext`sym$213521[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$213521[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$213521, $CellContext`season]], \
$CellContext`sym$213521[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$213521[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$213521[All], 
      All, $CellContext`i$213522], $CellContext`sym$213521[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$213521[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$213521, $CellContext`size]], \
$CellContext`sym$213521[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$213521[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$213521[All], 
      All, $CellContext`i$215070], $CellContext`sym$213521[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$213521[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$213521, $CellContext`speed]], \
$CellContext`sym$213521[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$213521[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$213521[All], All, $CellContext`i$215071], 
    Attributes[$CellContext`i$215071] = {Temporary}, $CellContext`i$215071 = 
    3, Attributes[$CellContext`i$215081] = {Temporary}, $CellContext`i$215081 = 
    13, Attributes[$CellContext`i$215076] = {
     Temporary}, $CellContext`i$215076 = 8, 
    Attributes[$CellContext`i$215074] = {Temporary}, $CellContext`i$215074 = 
    6, Attributes[$CellContext`i$215077] = {Temporary}, $CellContext`i$215077 = 
    9, Attributes[$CellContext`i$215073] = {Temporary}, $CellContext`i$215073 = 
    5, Attributes[$CellContext`i$215083] = {Temporary}, $CellContext`i$215083 = 
    15, Attributes[$CellContext`i$213522] = {
     Temporary}, $CellContext`i$213522 = 1, 
    Attributes[$CellContext`i$215082] = {Temporary}, $CellContext`i$215082 = 
    14, Attributes[$CellContext`i$215080] = {
     Temporary}, $CellContext`i$215080 = 12, 
    Attributes[$CellContext`i$215072] = {Temporary}, $CellContext`i$215072 = 
    4, Attributes[$CellContext`i$215075] = {Temporary}, $CellContext`i$215075 = 
    7, Attributes[$CellContext`i$215078] = {Temporary}, $CellContext`i$215078 = 
    10, Attributes[$CellContext`i$215070] = {
     Temporary}, $CellContext`i$215070 = 2, 
    Attributes[$CellContext`i$215084] = {Temporary}, $CellContext`i$215084 = 
    16, Attributes[$CellContext`i$215079] = {
     Temporary}, $CellContext`i$215079 = 11, 
    Attributes[$CellContext`i$215086] = {Temporary}, $CellContext`i$215086 = 
    18, Attributes[$CellContext`i$215085] = {
     Temporary}, $CellContext`i$215085 = 17, 
    Attributes[$CellContext`sym$41502] = {
     Temporary}, $CellContext`sym$41502[$CellContext`a1] = $CellContext`med[
     All], $CellContext`sym$41502[$CellContext`a2] = $CellContext`med[
     All], $CellContext`sym$41502[$CellContext`a3] = $CellContext`med[
     All], $CellContext`sym$41502[$CellContext`a4] = $CellContext`med[
     All], $CellContext`sym$41502[$CellContext`a5] = $CellContext`med[
     All], $CellContext`sym$41502[$CellContext`a6] = $CellContext`med[
     All], $CellContext`sym$41502[$CellContext`a7] = $CellContext`med[
     All], $CellContext`sym$41502[All] = $CellContext`med[
     All], $CellContext`sym$41502[$CellContext`Chla] = $CellContext`med[
     All], $CellContext`sym$41502[$CellContext`Cl] = $CellContext`med[
     All], $CellContext`sym$41502[$CellContext`mnO2] = $CellContext`med[
     All], $CellContext`sym$41502[$CellContext`mxPH] = $CellContext`med[
     All], $CellContext`sym$41502[$CellContext`NH4] = $CellContext`med[
     All], $CellContext`sym$41502[$CellContext`NO3] = $CellContext`med[
     All], $CellContext`sym$41502[$CellContext`oPO4] = $CellContext`med[
     All], $CellContext`sym$41502[$CellContext`PO4] = $CellContext`med[
     All], $CellContext`sym$41502[$CellContext`season] = $CellContext`med[
     All], $CellContext`sym$41502[$CellContext`size] = $CellContext`med[
     All], $CellContext`sym$41502[$CellContext`speed] = $CellContext`med[
     All], $CellContext`sym$41502[$CellContext`a1, "factorized"] = 
    True, $CellContext`sym$41502[$CellContext`a1, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$41502[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$41502[$CellContext`a1, "raw"] = Part[
      $CellContext`med[All], All, 12], $CellContext`sym$41502[$CellContext`a2,
       "factorized"] = 
    True, $CellContext`sym$41502[$CellContext`a2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$41502[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$41502[$CellContext`a2, "raw"] = Part[
      $CellContext`med[All], All, 13], $CellContext`sym$41502[$CellContext`a3,
       "factorized"] = 
    True, $CellContext`sym$41502[$CellContext`a3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$41502[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$41502[$CellContext`a3, "raw"] = Part[
      $CellContext`med[All], All, 14], $CellContext`sym$41502[$CellContext`a4,
       "factorized"] = 
    True, $CellContext`sym$41502[$CellContext`a4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$41502[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$41502[$CellContext`a4, "raw"] = Part[
      $CellContext`med[All], All, 15], $CellContext`sym$41502[$CellContext`a5,
       "factorized"] = 
    True, $CellContext`sym$41502[$CellContext`a5, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$41502[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$41502[$CellContext`a5, "raw"] = Part[
      $CellContext`med[All], All, 16], $CellContext`sym$41502[$CellContext`a6,
       "factorized"] = 
    True, $CellContext`sym$41502[$CellContext`a6, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$41502[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$41502[$CellContext`a6, "raw"] = Part[
      $CellContext`med[All], All, 17], $CellContext`sym$41502[$CellContext`a7,
       "factorized"] = 
    True, $CellContext`sym$41502[$CellContext`a7, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$41502[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$41502[$CellContext`a7, "raw"] = Part[
      $CellContext`med[All], All, 18], $CellContext`sym$41502[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$41502[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$41502[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$41502[$CellContext`Chla, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$41502[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$41502[$CellContext`Chla, "raw"] = Part[
      $CellContext`med[All], All, 11], $CellContext`sym$41502[$CellContext`Cl,
       "factorized"] = 
    True, $CellContext`sym$41502[$CellContext`Cl, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$41502[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$41502[$CellContext`Cl, "raw"] = Part[
      $CellContext`med[All], All, 
      6], $CellContext`sym$41502[$CellContext`mnO2, "factorized"] = 
    True, $CellContext`sym$41502[$CellContext`mnO2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$41502[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$41502[$CellContext`mnO2, "raw"] = Part[
      $CellContext`med[All], All, 
      5], $CellContext`sym$41502[$CellContext`mxPH, "factorized"] = 
    True, $CellContext`sym$41502[$CellContext`mxPH, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$41502[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$41502[$CellContext`mxPH, "raw"] = Part[
      $CellContext`med[All], All, 4], $CellContext`sym$41502[$CellContext`NH4,
       "factorized"] = 
    True, $CellContext`sym$41502[$CellContext`NH4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$41502[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$41502[$CellContext`NH4, "raw"] = Part[
      $CellContext`med[All], All, 8], $CellContext`sym$41502[$CellContext`NO3,
       "factorized"] = 
    True, $CellContext`sym$41502[$CellContext`NO3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$41502[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$41502[$CellContext`NO3, "raw"] = Part[
      $CellContext`med[All], All, 
      7], $CellContext`sym$41502[$CellContext`oPO4, "factorized"] = 
    True, $CellContext`sym$41502[$CellContext`oPO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$41502[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$41502[$CellContext`oPO4, "raw"] = Part[
      $CellContext`med[All], All, 9], $CellContext`sym$41502[$CellContext`PO4,
       "factorized"] = 
    True, $CellContext`sym$41502[$CellContext`PO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$41502[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$41502[$CellContext`PO4, "raw"] = Part[
      $CellContext`med[All], All, 
      10], $CellContext`sym$41502[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$41502[$CellContext`season, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$41502[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$41502[$CellContext`season, "raw"] = 
    Part[
      $CellContext`med[All], All, 
      1], $CellContext`sym$41502[$CellContext`size, "factorized"] = 
    True, $CellContext`sym$41502[$CellContext`size, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$41502[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$41502[$CellContext`size, "raw"] = Part[
      $CellContext`med[All], All, 
      2], $CellContext`sym$41502[$CellContext`speed, "factorized"] = 
    True, $CellContext`sym$41502[$CellContext`speed, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$41502[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$41502[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`med[All], All, 3], 
    Attributes[$CellContext`sym$130900] = {
     Temporary}, $CellContext`sym$130900[$CellContext`a1] = Part[
      $CellContext`sym$130900[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$130900[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$130900[$CellContext`a2] = Part[
      $CellContext`sym$130900[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$130900[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$130900[$CellContext`a3] = Part[
      $CellContext`sym$130900[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$130900[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$130900[$CellContext`a4] = Part[
      $CellContext`sym$130900[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$130900[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$130900[$CellContext`a5] = Part[
      $CellContext`sym$130900[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$130900[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$130900[$CellContext`a6] = Part[
      $CellContext`sym$130900[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$130900[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$130900[$CellContext`a7] = Part[
      $CellContext`sym$130900[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$130900[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$130900[All] = $CellContext`med[
     All], $CellContext`sym$130900[$CellContext`Chla] = Part[
      $CellContext`sym$130900[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$130900[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$130900[$CellContext`Cl] = Part[
      $CellContext`sym$130900[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$130900[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$130900[$CellContext`mnO2] = Part[
      $CellContext`sym$130900[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$130900[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$130900[$CellContext`mxPH] = Part[
      $CellContext`sym$130900[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$130900[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$130900[$CellContext`NH4] = Part[
      $CellContext`sym$130900[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$130900[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$130900[$CellContext`NO3] = Part[
      $CellContext`sym$130900[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$130900[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$130900[$CellContext`oPO4] = Part[
      $CellContext`sym$130900[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$130900[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$130900[$CellContext`PO4] = Part[
      $CellContext`sym$130900[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$130900[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$130900[$CellContext`season] = Part[
      $CellContext`sym$130900[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$130900[$CellContext`season, 
         "missing"]]]], $CellContext`sym$130900[$CellContext`size] = Part[
      $CellContext`sym$130900[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$130900[$CellContext`size, 
         "missing"]]]], $CellContext`sym$130900[$CellContext`speed] = Part[
      $CellContext`sym$130900[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$130900[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$130900[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$130900[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$130900, $CellContext`a1]], \
$CellContext`sym$130900[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$130900[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$130900[All], 
      All, $CellContext`i$132459], $CellContext`sym$130900[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$130900[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$130900, $CellContext`a2]], \
$CellContext`sym$130900[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$130900[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$130900[All], 
      All, $CellContext`i$132460], $CellContext`sym$130900[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$130900[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$130900, $CellContext`a3]], \
$CellContext`sym$130900[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$130900[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$130900[All], 
      All, $CellContext`i$132461], $CellContext`sym$130900[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$130900[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$130900, $CellContext`a4]], \
$CellContext`sym$130900[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$130900[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$130900[All], 
      All, $CellContext`i$132462], $CellContext`sym$130900[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$130900[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$130900, $CellContext`a5]], \
$CellContext`sym$130900[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$130900[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$130900[All], 
      All, $CellContext`i$132463], $CellContext`sym$130900[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$130900[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$130900, $CellContext`a6]], \
$CellContext`sym$130900[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$130900[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$130900[All], 
      All, $CellContext`i$132464], $CellContext`sym$130900[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$130900[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$130900, $CellContext`a7]], \
$CellContext`sym$130900[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$130900[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$130900[All], 
      All, $CellContext`i$132465], $CellContext`sym$130900[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$130900[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$130900[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$130900[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$130900, $CellContext`Chla]], \
$CellContext`sym$130900[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$130900[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$130900[All], 
      All, $CellContext`i$132458], $CellContext`sym$130900[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$130900[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$130900, $CellContext`Cl]], \
$CellContext`sym$130900[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$130900[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$130900[All], 
      All, $CellContext`i$132453], $CellContext`sym$130900[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$130900[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$130900, $CellContext`mnO2]], \
$CellContext`sym$130900[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$130900[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$130900[All], 
      All, $CellContext`i$132452], $CellContext`sym$130900[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$130900[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$130900, $CellContext`mxPH]], \
$CellContext`sym$130900[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$130900[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$130900[All], 
      All, $CellContext`i$132451], $CellContext`sym$130900[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$130900[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$130900, $CellContext`NH4]], \
$CellContext`sym$130900[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$130900[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$130900[All], 
      All, $CellContext`i$132455], $CellContext`sym$130900[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$130900[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$130900, $CellContext`NO3]], \
$CellContext`sym$130900[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$130900[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$130900[All], 
      All, $CellContext`i$132454], $CellContext`sym$130900[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$130900[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$130900, $CellContext`oPO4]], \
$CellContext`sym$130900[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$130900[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$130900[All], 
      All, $CellContext`i$132456], $CellContext`sym$130900[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$130900[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$130900, $CellContext`PO4]], \
$CellContext`sym$130900[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$130900[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$130900[All], 
      All, $CellContext`i$132457], \
$CellContext`sym$130900[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$130900[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$130900, $CellContext`season]], \
$CellContext`sym$130900[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$130900[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$130900[All], 
      All, $CellContext`i$130901], $CellContext`sym$130900[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$130900[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$130900, $CellContext`size]], \
$CellContext`sym$130900[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$130900[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$130900[All], 
      All, $CellContext`i$132449], $CellContext`sym$130900[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$130900[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$130900, $CellContext`speed]], \
$CellContext`sym$130900[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$130900[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$130900[All], All, $CellContext`i$132450], 
    Attributes[$CellContext`i$132455] = {Temporary}, $CellContext`i$132455 = 
    8, Attributes[$CellContext`i$132463] = {Temporary}, $CellContext`i$132463 = 
    16, Attributes[$CellContext`i$132454] = {
     Temporary}, $CellContext`i$132454 = 7, 
    Attributes[$CellContext`i$132462] = {Temporary}, $CellContext`i$132462 = 
    15, Attributes[$CellContext`i$132453] = {
     Temporary}, $CellContext`i$132453 = 6, 
    Attributes[$CellContext`i$132452] = {Temporary}, $CellContext`i$132452 = 
    5, Attributes[$CellContext`i$132457] = {Temporary}, $CellContext`i$132457 = 
    10, Attributes[$CellContext`i$132465] = {
     Temporary}, $CellContext`i$132465 = 18, 
    Attributes[$CellContext`i$132449] = {Temporary}, $CellContext`i$132449 = 
    2, Attributes[$CellContext`i$132464] = {Temporary}, $CellContext`i$132464 = 
    17, Attributes[$CellContext`i$132451] = {
     Temporary}, $CellContext`i$132451 = 4, 
    Attributes[$CellContext`i$132458] = {Temporary}, $CellContext`i$132458 = 
    11, Attributes[$CellContext`i$132456] = {
     Temporary}, $CellContext`i$132456 = 9, 
    Attributes[$CellContext`i$132461] = {Temporary}, $CellContext`i$132461 = 
    14, Attributes[$CellContext`i$132460] = {
     Temporary}, $CellContext`i$132460 = 13, 
    Attributes[$CellContext`i$132459] = {Temporary}, $CellContext`i$132459 = 
    12, Attributes[$CellContext`i$130901] = {
     Temporary}, $CellContext`i$130901 = 1, 
    Attributes[$CellContext`i$132450] = {Temporary}, $CellContext`i$132450 = 
    3, Attributes[$CellContext`sym$37036] = {
     Temporary}, $CellContext`sym$37036[$CellContext`a1] = $CellContext`med[
     All], $CellContext`sym$37036[$CellContext`a2] = $CellContext`med[
     All], $CellContext`sym$37036[$CellContext`a3] = $CellContext`med[
     All], $CellContext`sym$37036[$CellContext`a4] = $CellContext`med[
     All], $CellContext`sym$37036[$CellContext`a5] = $CellContext`med[
     All], $CellContext`sym$37036[$CellContext`a6] = $CellContext`med[
     All], $CellContext`sym$37036[$CellContext`a7] = $CellContext`med[
     All], $CellContext`sym$37036[All] = $CellContext`med[
     All], $CellContext`sym$37036[$CellContext`Chla] = $CellContext`med[
     All], $CellContext`sym$37036[$CellContext`Cl] = $CellContext`med[
     All], $CellContext`sym$37036[$CellContext`mnO2] = $CellContext`med[
     All], $CellContext`sym$37036[$CellContext`mxPH] = $CellContext`med[
     All], $CellContext`sym$37036[$CellContext`NH4] = $CellContext`med[
     All], $CellContext`sym$37036[$CellContext`NO3] = $CellContext`med[
     All], $CellContext`sym$37036[$CellContext`oPO4] = $CellContext`med[
     All], $CellContext`sym$37036[$CellContext`PO4] = $CellContext`med[
     All], $CellContext`sym$37036[$CellContext`season] = $CellContext`med[
     All], $CellContext`sym$37036[$CellContext`size] = $CellContext`med[
     All], $CellContext`sym$37036[$CellContext`speed] = $CellContext`med[
     All], $CellContext`sym$37036[$CellContext`a1, "factorized"] = 
    True, $CellContext`sym$37036[$CellContext`a1, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$37036[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$37036[$CellContext`a1, "raw"] = Part[
      $CellContext`med[All], All, 12], $CellContext`sym$37036[$CellContext`a2,
       "factorized"] = 
    True, $CellContext`sym$37036[$CellContext`a2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$37036[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$37036[$CellContext`a2, "raw"] = Part[
      $CellContext`med[All], All, 13], $CellContext`sym$37036[$CellContext`a3,
       "factorized"] = 
    True, $CellContext`sym$37036[$CellContext`a3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$37036[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$37036[$CellContext`a3, "raw"] = Part[
      $CellContext`med[All], All, 14], $CellContext`sym$37036[$CellContext`a4,
       "factorized"] = 
    True, $CellContext`sym$37036[$CellContext`a4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$37036[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$37036[$CellContext`a4, "raw"] = Part[
      $CellContext`med[All], All, 15], $CellContext`sym$37036[$CellContext`a5,
       "factorized"] = 
    True, $CellContext`sym$37036[$CellContext`a5, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$37036[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$37036[$CellContext`a5, "raw"] = Part[
      $CellContext`med[All], All, 16], $CellContext`sym$37036[$CellContext`a6,
       "factorized"] = 
    True, $CellContext`sym$37036[$CellContext`a6, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$37036[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$37036[$CellContext`a6, "raw"] = Part[
      $CellContext`med[All], All, 17], $CellContext`sym$37036[$CellContext`a7,
       "factorized"] = 
    True, $CellContext`sym$37036[$CellContext`a7, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$37036[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$37036[$CellContext`a7, "raw"] = Part[
      $CellContext`med[All], All, 18], $CellContext`sym$37036[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$37036[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$37036[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$37036[$CellContext`Chla, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$37036[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$37036[$CellContext`Chla, "raw"] = Part[
      $CellContext`med[All], All, 11], $CellContext`sym$37036[$CellContext`Cl,
       "factorized"] = 
    True, $CellContext`sym$37036[$CellContext`Cl, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$37036[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$37036[$CellContext`Cl, "raw"] = Part[
      $CellContext`med[All], All, 
      6], $CellContext`sym$37036[$CellContext`mnO2, "factorized"] = 
    True, $CellContext`sym$37036[$CellContext`mnO2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$37036[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$37036[$CellContext`mnO2, "raw"] = Part[
      $CellContext`med[All], All, 
      5], $CellContext`sym$37036[$CellContext`mxPH, "factorized"] = 
    True, $CellContext`sym$37036[$CellContext`mxPH, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$37036[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$37036[$CellContext`mxPH, "raw"] = Part[
      $CellContext`med[All], All, 4], $CellContext`sym$37036[$CellContext`NH4,
       "factorized"] = 
    True, $CellContext`sym$37036[$CellContext`NH4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$37036[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$37036[$CellContext`NH4, "raw"] = Part[
      $CellContext`med[All], All, 8], $CellContext`sym$37036[$CellContext`NO3,
       "factorized"] = 
    True, $CellContext`sym$37036[$CellContext`NO3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$37036[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$37036[$CellContext`NO3, "raw"] = Part[
      $CellContext`med[All], All, 
      7], $CellContext`sym$37036[$CellContext`oPO4, "factorized"] = 
    True, $CellContext`sym$37036[$CellContext`oPO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$37036[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$37036[$CellContext`oPO4, "raw"] = Part[
      $CellContext`med[All], All, 9], $CellContext`sym$37036[$CellContext`PO4,
       "factorized"] = 
    True, $CellContext`sym$37036[$CellContext`PO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$37036[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$37036[$CellContext`PO4, "raw"] = Part[
      $CellContext`med[All], All, 
      10], $CellContext`sym$37036[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$37036[$CellContext`season, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$37036[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$37036[$CellContext`season, "raw"] = 
    Part[
      $CellContext`med[All], All, 
      1], $CellContext`sym$37036[$CellContext`size, "factorized"] = 
    True, $CellContext`sym$37036[$CellContext`size, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$37036[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$37036[$CellContext`size, "raw"] = Part[
      $CellContext`med[All], All, 
      2], $CellContext`sym$37036[$CellContext`speed, "factorized"] = 
    True, $CellContext`sym$37036[$CellContext`speed, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$37036[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$37036[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`med[All], All, 3], 
    Attributes[$CellContext`sym$235571] = {
     Temporary}, $CellContext`sym$235571[$CellContext`a1] = Part[
      $CellContext`sym$235571[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$235571[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$235571[$CellContext`a2] = Part[
      $CellContext`sym$235571[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$235571[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$235571[$CellContext`a3] = Part[
      $CellContext`sym$235571[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$235571[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$235571[$CellContext`a4] = Part[
      $CellContext`sym$235571[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$235571[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$235571[$CellContext`a5] = Part[
      $CellContext`sym$235571[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$235571[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$235571[$CellContext`a6] = Part[
      $CellContext`sym$235571[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$235571[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$235571[$CellContext`a7] = Part[
      $CellContext`sym$235571[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$235571[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$235571[
     All] = {{"winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 
       170., 50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
      "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
       558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
      "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 125.667,
        187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
      "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 61.182, 
       138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
      "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222, 
       97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
      "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
       56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
      "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
       111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
      "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 44.667, 
       77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
      "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 71., 
       5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 0.8, 
       17., 0., 0., 2.9, 0., 0., 1.7}, {
      "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 20.75, 
       0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
      "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 19.,
        0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
      "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 41., 
       43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
      "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5, 
       31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
      "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 0.3, 
       52.2, 5., 7.8, 0., 4., 0., 0.}, {
      "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 98.25, 
       1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50., 
       1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
      "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 57.833, 
       0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
      "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 0.8, 
       50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
      "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
       564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
      "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 586.,
        16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
      "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 0.5, 
       15.5, 0., 0., 2.3, 0., 0., 0.}, {
      "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 7.6,
        23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
      "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
       27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
      "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 1.5,
        13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
      "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 44.136, 
       3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
      "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 0.5, 
       29.7, 0., 0., 4.9, 0., 0., 0.}, {
      "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
       Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
      "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 17.1,
        0., 19.6, 0., 0., 0., 2.5}, {
      "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5, 
       33.9, 1., 14.6, 0., 0., 0., 0.}, {
      "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 4.9, 
       3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
      "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 2.8, 
       6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
      "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 130.75, 
       5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
      "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47., 
       2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
      "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23., 
       0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
      "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 58.875, 
       84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
      "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 0.2,
        66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
       Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0., 
       0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
       196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
      "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
       182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
      "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001, 
       296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
      "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 59.429,
        175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
      "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
       344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
      "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 276.85001, 
       326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
      "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 40.667, 
       3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
      "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 3.3, 
       29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
      "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 0.8, 
       54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
       Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 0., 
       0.}, {"spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121.,
        2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 20.812,
        12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
      "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
       49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
      "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 22.9, 
       4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
      "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 11.8, 
       0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818, 
       0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
      "winter", "small", "high", 6.6, 10.8, 
       Missing[], 3.245, 10., 1., 6.5, 
       Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "medium", 5.6, 11.8, 
       Missing[], 2.22, 5., 1., 1., 
       Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 5.7, 10.8, 
       Missing[], 2.55, 10., 1., 4., 
       Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
      "spring", "small", "high", 6.6, 9.5, 
       Missing[], 1.32, 20., 1., 6., 
       Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
      "summer", "small", "high", 6.6, 10.8, 
       Missing[], 2.64, 10., 2., 11., 
       Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
      "autumn", "small", "medium", 6.6, 11.3, 
       Missing[], 4.17, 10., 1., 6., 
       Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
      "spring", "small", "medium", 6.5, 10.4, 
       Missing[], 5.97, 10., 2., 14., 
       Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
      "summer", "small", "medium", 6.4, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 14., 
       Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
      "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 6.667, 
       Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75, 1.,
        20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
      "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2, 
       0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
      "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 0.6,
        55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
      "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 10.75, 
       2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
      "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 0.5, 
       64.2, 0., 3., 0., 0., 0., 0.}, {
      "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75, 
       351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
      "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
       209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
      "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 151.125,
        279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
      "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
       152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
      "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
       58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
      "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
       249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
      "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 100., 
       233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
      "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 215.5, 
       18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
      "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 25.167, 
       102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
      "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
       105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
      "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
       111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
      "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 1.3, 
       6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
      "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 56.667, 
       2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
      "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 4.3,
        1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
      "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
       104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
      "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 69.93,
        3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
      "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
       214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
      "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
       254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
      "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 57.6,
        169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
      "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
       412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
      "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
       282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
      "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
       197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
      "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 267.75, 
       391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
      "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 191.75, 
       265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
      "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
       232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
      "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 144.66701, 
       244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
      "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 218., 
       6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
      "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 138.5,
        20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
      "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222, 
       239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
      "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
       235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
      "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75, 
       205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
      "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 31.333, 
       211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
      "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625, 
       186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
      "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 12.889, 
       154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
      "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 51.111, 
       183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
      "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
       292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
      "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
       285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
      "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
       201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
      "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
       275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
      "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
       124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
      "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 60.833, 
       141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
      "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71., 
       132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
      "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
       17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
      "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 0.3, 
       46.6, 0., 2.5, 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 8.692, 
       16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
      "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 37.857, 
       102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
      "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
       86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
      "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
       10.111, 
       Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 16.833, 
       18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
      "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545, 
       13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
      "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 261.60001, 
       432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
      "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
       320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
      "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 144., 
       287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
      "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
       166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
      "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
       222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
      "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 36.909, 
       122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
      "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556, 
       127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
      "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
       89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
      "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 55., 
       284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
      "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 102.333, 
       277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
      "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 75.875, 
       177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
      "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
       72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
      "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 48.667, 
       82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
      "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 48.625, 
       66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
      "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 23., 
       173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
      "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 317., 
       5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
      "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 84., 
       4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
      "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 2., 
       10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
      "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 88.5, 
       2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
      "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115., 
       11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
      "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 98.143, 
       2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
      "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
       143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
      "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
       197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
      "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 1., 
       19., 0., 22., 5., 1.1, 5.4, 0.}, {
      "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 10.583, 
       23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
      "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 200.231, 
       19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
      "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 77.333, 
       147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
      "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5, 
       276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
      "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
       123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
      "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 75.207,
        23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
      "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 116.2,
        7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
      "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
       188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
      "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
       72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
      "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 16., 
       0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
      "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 34., 
       53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
      "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 27.5, 
       76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
      "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
       58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
      "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 175.66701, 
       361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
      "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
       22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
      "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 26.8,
        0., 28., 0., 0., 0., 0., 15.1}, {
      "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
       54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
      "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333, 
       34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
      "spring", "large", "low", 9., 5.8, 
       Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 0., 
       0.}, {"spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
       151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
      "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
       269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
      "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 46.438, 
       81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
      "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 85., 
       2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
      "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 66.4, 
       171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
      "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 102.364, 
       232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
      "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 84.3, 
       146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
      "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
       246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
      "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 205.636, 
       219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
      "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 236.39999,
        272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
      "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 1081.66003, 
       346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 5.9, 1.7}, {
      "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 82.222,
        167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
      "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 64.389, 
       137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
      "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 87.333,
        194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
      "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
       159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
      "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 21.3, 
       1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
      "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 0.6,
        37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
      "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
       14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
      "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222, 7.,
        1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 0.8, 
       50.4, 3.8, 0., 0., 0., 0., 0.}, {
      "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 7.654, 
       4., 56.8, 5., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 2.86, 
       17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
      "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 56.091, 
       Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
      "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
       52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
      "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 104.727, 
       228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
      "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 85.4, 
       17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
      "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 87.125,
        14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
      "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 101.455, 
       18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
      "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 50.889, 
       127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
      "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
       81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
      "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 19.727, 
       50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
      "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111, 
       120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
      "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 51.111, 
       91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
      "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 19.111, 
       61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
      "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625, 
       79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
      "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333, 
       75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
      "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333, 
       140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
      "winter", "large", "medium", 8., 7.6, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
      "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
       140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 
       5.8}}, $CellContext`sym$235571[$CellContext`Chla] = Part[
      $CellContext`sym$235571[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {
          "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
           196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$235571[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$235571[$CellContext`Cl] = Part[
      $CellContext`sym$235571[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$235571[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$235571[$CellContext`mnO2] = Part[
      $CellContext`sym$235571[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$235571[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$235571[$CellContext`mxPH] = Part[
      $CellContext`sym$235571[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$235571[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$235571[$CellContext`NH4] = Part[
      $CellContext`sym$235571[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$235571[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$235571[$CellContext`NO3] = Part[
      $CellContext`sym$235571[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$235571[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$235571[$CellContext`oPO4] = Part[
      $CellContext`sym$235571[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$235571[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$235571[$CellContext`PO4] = Part[
      $CellContext`sym$235571[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$235571[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$235571[$CellContext`season] = Part[
      $CellContext`sym$235571[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$235571[$CellContext`season, 
         "missing"]]]], $CellContext`sym$235571[$CellContext`size] = Part[
      $CellContext`sym$235571[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$235571[$CellContext`size, 
         "missing"]]]], $CellContext`sym$235571[$CellContext`speed] = Part[
      $CellContext`sym$235571[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$235571[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$235571[$CellContext`a1, 
      "factorized"] = 
    False, $CellContext`sym$235571[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$235571[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$235571[All], 
      All, $CellContext`i$235583], $CellContext`sym$235571[$CellContext`a2, 
      "factorized"] = 
    False, $CellContext`sym$235571[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$235571[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$235571[All], 
      All, $CellContext`i$235584], $CellContext`sym$235571[$CellContext`a3, 
      "factorized"] = 
    False, $CellContext`sym$235571[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$235571[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$235571[All], 
      All, $CellContext`i$235585], $CellContext`sym$235571[$CellContext`a4, 
      "factorized"] = 
    False, $CellContext`sym$235571[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$235571[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$235571[All], 
      All, $CellContext`i$235586], $CellContext`sym$235571[$CellContext`a5, 
      "factorized"] = 
    False, $CellContext`sym$235571[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$235571[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$235571[All], 
      All, $CellContext`i$235587], $CellContext`sym$235571[$CellContext`a6, 
      "factorized"] = 
    False, $CellContext`sym$235571[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$235571[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$235571[All], 
      All, $CellContext`i$235588], $CellContext`sym$235571[$CellContext`a7, 
      "factorized"] = 
    False, $CellContext`sym$235571[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$235571[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$235571[All], 
      All, $CellContext`i$235589], $CellContext`sym$235571[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$235571[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed}, $CellContext`sym$235571[$CellContext`Chla, "factorized"] = 
    False, $CellContext`sym$235571[$CellContext`Chla, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {63}, {116}, {184}, {
     199}}, $CellContext`sym$235571[$CellContext`Chla, "raw"] = Part[
      $CellContext`sym$235571[All], 
      All, $CellContext`i$235582], $CellContext`sym$235571[$CellContext`Cl, 
      "factorized"] = 
    False, $CellContext`sym$235571[$CellContext`Cl, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {161}, {
     199}}, $CellContext`sym$235571[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$235571[All], 
      All, $CellContext`i$235577], $CellContext`sym$235571[$CellContext`mnO2, 
      "factorized"] = 
    False, $CellContext`sym$235571[$CellContext`mnO2, "missing"] = {{38}, {
     62}}, $CellContext`sym$235571[$CellContext`mnO2, "raw"] = Part[
      $CellContext`sym$235571[All], 
      All, $CellContext`i$235576], $CellContext`sym$235571[$CellContext`mxPH, 
      "factorized"] = 
    False, $CellContext`sym$235571[$CellContext`mxPH, "missing"] = {{
     48}}, $CellContext`sym$235571[$CellContext`mxPH, "raw"] = Part[
      $CellContext`sym$235571[All], 
      All, $CellContext`i$235575], $CellContext`sym$235571[$CellContext`NH4, 
      "factorized"] = 
    False, $CellContext`sym$235571[$CellContext`NH4, "missing"] = {{62}, {
     199}}, $CellContext`sym$235571[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$235571[All], 
      All, $CellContext`i$235579], $CellContext`sym$235571[$CellContext`NO3, 
      "factorized"] = 
    False, $CellContext`sym$235571[$CellContext`NO3, "missing"] = {{62}, {
     199}}, $CellContext`sym$235571[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$235571[All], 
      All, $CellContext`i$235578], $CellContext`sym$235571[$CellContext`oPO4, 
      "factorized"] = 
    False, $CellContext`sym$235571[$CellContext`oPO4, "missing"] = {{62}, {
     199}}, $CellContext`sym$235571[$CellContext`oPO4, "raw"] = Part[
      $CellContext`sym$235571[All], 
      All, $CellContext`i$235580], $CellContext`sym$235571[$CellContext`PO4, 
      "factorized"] = 
    False, $CellContext`sym$235571[$CellContext`PO4, "missing"] = {{28}, {
     199}}, $CellContext`sym$235571[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$235571[All], 
      All, $CellContext`i$235581], \
$CellContext`sym$235571[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$235571[$CellContext`season, "factors"] = 
    Part[{"autumn", "spring", "summer", "winter"}, 
      $CellContext`fordering[$CellContext`sym$235571, $CellContext`season]], \
$CellContext`sym$235571[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$235571[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$235571[All], 
      All, $CellContext`i$235572], $CellContext`sym$235571[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$235571[$CellContext`size, "factors"] = 
    Part[{"large", "medium", "small"}, 
      $CellContext`fordering[$CellContext`sym$235571, $CellContext`size]], \
$CellContext`sym$235571[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$235571[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$235571[All], 
      All, $CellContext`i$235573], $CellContext`sym$235571[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$235571[$CellContext`speed, "factors"] = 
    Part[{"high", "low", "medium"}, 
      $CellContext`fordering[$CellContext`sym$235571, $CellContext`speed]], \
$CellContext`sym$235571[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$235571[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$235571[All], All, $CellContext`i$235574], 
    Attributes[$CellContext`i$235576] = {Temporary}, $CellContext`i$235576 = 
    5, Attributes[$CellContext`i$235582] = {Temporary}, $CellContext`i$235582 = 
    11, Attributes[$CellContext`i$235589] = {
     Temporary}, $CellContext`i$235589 = 18, 
    Attributes[$CellContext`i$235572] = {Temporary}, $CellContext`i$235572 = 
    1, Attributes[$CellContext`i$235587] = {Temporary}, $CellContext`i$235587 = 
    16, Attributes[$CellContext`i$235577] = {
     Temporary}, $CellContext`i$235577 = 6, 
    Attributes[$CellContext`i$235584] = {Temporary}, $CellContext`i$235584 = 
    13, Attributes[$CellContext`i$235575] = {
     Temporary}, $CellContext`i$235575 = 4, 
    Attributes[$CellContext`i$235579] = {Temporary}, $CellContext`i$235579 = 
    8, Attributes[$CellContext`i$235586] = {Temporary}, $CellContext`i$235586 = 
    15, Attributes[$CellContext`i$235573] = {
     Temporary}, $CellContext`i$235573 = 2, 
    Attributes[$CellContext`i$235583] = {Temporary}, $CellContext`i$235583 = 
    12, Attributes[$CellContext`i$235578] = {
     Temporary}, $CellContext`i$235578 = 7, 
    Attributes[$CellContext`i$235585] = {Temporary}, $CellContext`i$235585 = 
    14, Attributes[$CellContext`i$235588] = {
     Temporary}, $CellContext`i$235588 = 17, 
    Attributes[$CellContext`i$235580] = {Temporary}, $CellContext`i$235580 = 
    9, Attributes[$CellContext`i$235581] = {Temporary}, $CellContext`i$235581 = 
    10, Attributes[$CellContext`i$235574] = {
     Temporary}, $CellContext`i$235574 = 3, 
    Attributes[$CellContext`sym$228188] = {
     Temporary}, $CellContext`sym$228188[$CellContext`a1] = Part[
      $CellContext`sym$228188[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 104., 2.7, 
           30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 8., 9.8, 1.45, 0.81, 10., 2.5, 3., 0.3, 
           75.8, 0., 0., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
           196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {
          "winter", "small", "low", 8.06, 12.6, 9., 0.23, 10., 5., 6., 1.1, 
           35.5, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 32.730000000000004`, 3.245, 
           10., 1., 6.5, 5.475, 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 32.730000000000004`, 2.22, 
           5., 1., 1., 5.475, 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 32.730000000000004`, 2.55, 
           10., 1., 4., 5.475, 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 32.730000000000004`, 1.32, 20.,
            1., 6., 5.475, 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 32.730000000000004`, 2.64, 
           10., 2., 11., 5.475, 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 32.730000000000004`, 4.17, 
           10., 1., 6., 5.475, 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 32.730000000000004`, 5.97, 
           10., 2., 14., 5.475, 66.9, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 5.475, 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 5.475, 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 32.730000000000004`, 0.9, 142., 
           102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 5.475, 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228188[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$228188[$CellContext`a2] = Part[
      $CellContext`sym$228188[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 104., 2.7, 
           30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 8., 9.8, 1.45, 0.81, 10., 2.5, 3., 0.3, 
           75.8, 0., 0., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
           196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {
          "winter", "small", "low", 8.06, 12.6, 9., 0.23, 10., 5., 6., 1.1, 
           35.5, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 32.730000000000004`, 3.245, 
           10., 1., 6.5, 5.475, 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 32.730000000000004`, 2.22, 
           5., 1., 1., 5.475, 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 32.730000000000004`, 2.55, 
           10., 1., 4., 5.475, 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 32.730000000000004`, 1.32, 20.,
            1., 6., 5.475, 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 32.730000000000004`, 2.64, 
           10., 2., 11., 5.475, 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 32.730000000000004`, 4.17, 
           10., 1., 6., 5.475, 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 32.730000000000004`, 5.97, 
           10., 2., 14., 5.475, 66.9, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 5.475, 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 5.475, 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 32.730000000000004`, 0.9, 142., 
           102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 5.475, 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228188[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$228188[$CellContext`a3] = Part[
      $CellContext`sym$228188[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 104., 2.7, 
           30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 8., 9.8, 1.45, 0.81, 10., 2.5, 3., 0.3, 
           75.8, 0., 0., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
           196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {
          "winter", "small", "low", 8.06, 12.6, 9., 0.23, 10., 5., 6., 1.1, 
           35.5, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 32.730000000000004`, 3.245, 
           10., 1., 6.5, 5.475, 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 32.730000000000004`, 2.22, 
           5., 1., 1., 5.475, 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 32.730000000000004`, 2.55, 
           10., 1., 4., 5.475, 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 32.730000000000004`, 1.32, 20.,
            1., 6., 5.475, 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 32.730000000000004`, 2.64, 
           10., 2., 11., 5.475, 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 32.730000000000004`, 4.17, 
           10., 1., 6., 5.475, 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 32.730000000000004`, 5.97, 
           10., 2., 14., 5.475, 66.9, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 5.475, 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 5.475, 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 32.730000000000004`, 0.9, 142., 
           102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 5.475, 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228188[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$228188[$CellContext`a4] = Part[
      $CellContext`sym$228188[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 104., 2.7, 
           30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 8., 9.8, 1.45, 0.81, 10., 2.5, 3., 0.3, 
           75.8, 0., 0., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
           196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {
          "winter", "small", "low", 8.06, 12.6, 9., 0.23, 10., 5., 6., 1.1, 
           35.5, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 32.730000000000004`, 3.245, 
           10., 1., 6.5, 5.475, 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 32.730000000000004`, 2.22, 
           5., 1., 1., 5.475, 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 32.730000000000004`, 2.55, 
           10., 1., 4., 5.475, 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 32.730000000000004`, 1.32, 20.,
            1., 6., 5.475, 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 32.730000000000004`, 2.64, 
           10., 2., 11., 5.475, 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 32.730000000000004`, 4.17, 
           10., 1., 6., 5.475, 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 32.730000000000004`, 5.97, 
           10., 2., 14., 5.475, 66.9, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 5.475, 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 5.475, 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 32.730000000000004`, 0.9, 142., 
           102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 5.475, 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228188[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$228188[$CellContext`a5] = Part[
      $CellContext`sym$228188[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 104., 2.7, 
           30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 8., 9.8, 1.45, 0.81, 10., 2.5, 3., 0.3, 
           75.8, 0., 0., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
           196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {
          "winter", "small", "low", 8.06, 12.6, 9., 0.23, 10., 5., 6., 1.1, 
           35.5, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 32.730000000000004`, 3.245, 
           10., 1., 6.5, 5.475, 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 32.730000000000004`, 2.22, 
           5., 1., 1., 5.475, 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 32.730000000000004`, 2.55, 
           10., 1., 4., 5.475, 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 32.730000000000004`, 1.32, 20.,
            1., 6., 5.475, 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 32.730000000000004`, 2.64, 
           10., 2., 11., 5.475, 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 32.730000000000004`, 4.17, 
           10., 1., 6., 5.475, 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 32.730000000000004`, 5.97, 
           10., 2., 14., 5.475, 66.9, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 5.475, 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 5.475, 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 32.730000000000004`, 0.9, 142., 
           102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 5.475, 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228188[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$228188[$CellContext`a6] = Part[
      $CellContext`sym$228188[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 104., 2.7, 
           30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 8., 9.8, 1.45, 0.81, 10., 2.5, 3., 0.3, 
           75.8, 0., 0., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
           196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {
          "winter", "small", "low", 8.06, 12.6, 9., 0.23, 10., 5., 6., 1.1, 
           35.5, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 32.730000000000004`, 3.245, 
           10., 1., 6.5, 5.475, 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 32.730000000000004`, 2.22, 
           5., 1., 1., 5.475, 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 32.730000000000004`, 2.55, 
           10., 1., 4., 5.475, 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 32.730000000000004`, 1.32, 20.,
            1., 6., 5.475, 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 32.730000000000004`, 2.64, 
           10., 2., 11., 5.475, 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 32.730000000000004`, 4.17, 
           10., 1., 6., 5.475, 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 32.730000000000004`, 5.97, 
           10., 2., 14., 5.475, 66.9, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 5.475, 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 5.475, 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 32.730000000000004`, 0.9, 142., 
           102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 5.475, 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228188[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$228188[$CellContext`a7] = Part[
      $CellContext`sym$228188[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 104., 2.7, 
           30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 8., 9.8, 1.45, 0.81, 10., 2.5, 3., 0.3, 
           75.8, 0., 0., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
           196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {
          "winter", "small", "low", 8.06, 12.6, 9., 0.23, 10., 5., 6., 1.1, 
           35.5, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 32.730000000000004`, 3.245, 
           10., 1., 6.5, 5.475, 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 32.730000000000004`, 2.22, 
           5., 1., 1., 5.475, 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 32.730000000000004`, 2.55, 
           10., 1., 4., 5.475, 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 32.730000000000004`, 1.32, 20.,
            1., 6., 5.475, 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 32.730000000000004`, 2.64, 
           10., 2., 11., 5.475, 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 32.730000000000004`, 4.17, 
           10., 1., 6., 5.475, 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 32.730000000000004`, 5.97, 
           10., 2., 14., 5.475, 66.9, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 5.475, 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 5.475, 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 32.730000000000004`, 0.9, 142., 
           102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 5.475, 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228188[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$228188[
     All] = {{"winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 
       170., 50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
      "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
       558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
      "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 125.667,
        187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
      "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 61.182, 
       138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
      "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222, 
       97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
      "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
       56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
      "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
       111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
      "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 44.667, 
       77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
      "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 71., 
       5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 0.8, 
       17., 0., 0., 2.9, 0., 0., 1.7}, {
      "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 20.75, 
       0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
      "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 19.,
        0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
      "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 41., 
       43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
      "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5, 
       31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
      "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 0.3, 
       52.2, 5., 7.8, 0., 4., 0., 0.}, {
      "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 98.25, 
       1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50., 
       1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
      "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 57.833, 
       0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
      "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 0.8, 
       50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
      "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
       564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
      "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 586.,
        16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
      "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 0.5, 
       15.5, 0., 0., 2.3, 0., 0., 0.}, {
      "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 7.6,
        23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
      "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
       27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
      "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 1.5,
        13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
      "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 44.136, 
       3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
      "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 0.5, 
       29.7, 0., 0., 4.9, 0., 0., 0.}, {
      "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 104., 2.7, 
       30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
      "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 17.1,
        0., 19.6, 0., 0., 0., 2.5}, {
      "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5, 
       33.9, 1., 14.6, 0., 0., 0., 0.}, {
      "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 4.9, 
       3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
      "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 2.8, 
       6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
      "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 130.75, 
       5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
      "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47., 
       2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
      "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23., 
       0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
      "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 58.875, 
       84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
      "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 0.2,
        66., 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 8., 9.8, 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8,
        0., 0., 0., 0., 0., 0.}, {
      "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 196.62, 
       253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
      "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
       182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
      "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001, 
       296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
      "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 59.429,
        175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
      "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
       344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
      "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 276.85001, 
       326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
      "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 40.667, 
       3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
      "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 3.3, 
       29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
      "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 0.8, 
       54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {
      "winter", "small", "low", 8.06, 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 
       0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 2.8, 
       89.8, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 20.812,
        12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
      "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
       49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
      "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 22.9, 
       4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
      "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 11.8, 
       0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818, 
       0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
      "winter", "small", "high", 6.6, 10.8, 32.730000000000004`, 3.245, 10., 
       1., 6.5, 5.475, 24.3, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "medium", 5.6, 11.8, 32.730000000000004`, 2.22, 5., 
       1., 1., 5.475, 82.7, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 5.7, 10.8, 32.730000000000004`, 2.55, 10., 
       1., 4., 5.475, 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
      "spring", "small", "high", 6.6, 9.5, 32.730000000000004`, 1.32, 20., 1.,
        6., 5.475, 46.8, 0., 0., 28.8, 0., 0., 0.}, {
      "summer", "small", "high", 6.6, 10.8, 32.730000000000004`, 2.64, 10., 
       2., 11., 5.475, 46.9, 0., 0., 13.4, 0., 0., 0.}, {
      "autumn", "small", "medium", 6.6, 11.3, 32.730000000000004`, 4.17, 10., 
       1., 6., 5.475, 47.1, 0., 0., 0., 0., 1.2, 0.}, {
      "spring", "small", "medium", 6.5, 10.4, 32.730000000000004`, 5.97, 10., 
       2., 14., 5.475, 66.9, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 6.667, 
       5.475, 14.4, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75, 1.,
        20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
      "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2, 
       0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
      "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 0.6,
        55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
      "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 10.75, 
       2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
      "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 0.5, 
       64.2, 0., 3., 0., 0., 0., 0.}, {
      "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75, 
       351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
      "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
       209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
      "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 151.125,
        279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
      "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
       152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
      "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
       58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
      "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
       249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
      "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 100., 
       233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
      "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 215.5, 
       18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
      "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 25.167, 
       102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
      "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
       105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
      "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
       111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
      "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 1.3, 
       6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
      "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 56.667, 
       2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
      "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 4.3,
        1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
      "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
       104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
      "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 69.93,
        3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
      "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
       214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
      "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
       254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
      "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 57.6,
        169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
      "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
       412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
      "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
       282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
      "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
       197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
      "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 267.75, 
       391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
      "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 191.75, 
       265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
      "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
       232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
      "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 144.66701, 
       244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
      "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 218., 
       6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
      "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 138.5,
        20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
      "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222, 
       239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
      "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
       235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
      "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75, 
       205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
      "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 31.333, 
       211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
      "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625, 
       186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
      "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 12.889, 
       154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
      "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 51.111, 
       183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
      "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
       292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
      "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
       285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
      "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
       201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
      "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
       275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
      "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
       124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
      "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 60.833, 
       141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
      "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71., 
       132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
      "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
       17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
      "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 0.3, 
       46.6, 0., 2.5, 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 8.692, 
       16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
      "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 37.857, 
       102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
      "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
       86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
      "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
       10.111, 5.475, 41., 1.5, 0., 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 16.833, 
       18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
      "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545, 
       13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
      "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 261.60001, 
       432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
      "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
       320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
      "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 144., 
       287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
      "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
       166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
      "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
       222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
      "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 36.909, 
       122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
      "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556, 
       127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
      "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
       89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
      "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 55., 
       284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
      "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 102.333, 
       277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
      "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 75.875, 
       177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
      "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
       72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
      "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 48.667, 
       82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
      "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 48.625, 
       66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
      "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 23., 
       173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
      "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 317., 
       5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
      "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 84., 
       4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
      "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 2., 
       10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
      "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 88.5, 
       2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
      "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115., 
       11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
      "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 98.143, 
       2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
      "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
       143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
      "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
       197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
      "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 1., 
       19., 0., 22., 5., 1.1, 5.4, 0.}, {
      "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 10.583, 
       23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
      "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 200.231, 
       19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
      "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 77.333, 
       147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
      "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5, 
       276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
      "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
       123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
      "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 75.207,
        23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
      "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 116.2,
        7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
      "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
       188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
      "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
       72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
      "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 16., 
       0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
      "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 34., 
       53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
      "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 27.5, 
       76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
      "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
       58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
      "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 175.66701, 
       361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
      "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
       22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
      "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 26.8,
        0., 28., 0., 0., 0., 0., 15.1}, {
      "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
       54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
      "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333, 
       34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
      "spring", "large", "low", 9., 5.8, 32.730000000000004`, 0.9, 142., 102.,
        186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 0., 0.}, {
      "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 151.33299, 
       252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
      "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
       269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
      "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 46.438, 
       81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
      "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 85., 
       2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
      "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 66.4, 
       171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
      "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 102.364, 
       232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
      "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 84.3, 
       146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
      "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
       246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
      "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 205.636, 
       219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
      "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 236.39999,
        272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
      "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 1081.66003, 
       346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 5.9, 1.7}, {
      "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 82.222,
        167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
      "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 64.389, 
       137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
      "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 87.333,
        194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
      "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
       159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
      "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 21.3, 
       1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
      "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 0.6,
        37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
      "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
       14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
      "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222, 7.,
        1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 0.8, 
       50.4, 3.8, 0., 0., 0., 0., 0.}, {
      "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 7.654, 
       4., 56.8, 5., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 2.86, 
       17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
      "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 56.091, 
       5.475, 16.8, 19.6, 4., 0., 0., 0., 0.}, {
      "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
       52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
      "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 104.727, 
       228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
      "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 85.4, 
       17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
      "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 87.125,
        14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
      "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 101.455, 
       18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
      "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 50.889, 
       127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
      "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
       81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
      "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 19.727, 
       50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
      "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111, 
       120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
      "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 51.111, 
       91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
      "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 19.111, 
       61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
      "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625, 
       79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
      "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333, 
       75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
      "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333, 
       140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
      "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
       140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 
       5.8}}, $CellContext`sym$228188[$CellContext`Chla] = Part[
      $CellContext`sym$228188[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 104., 2.7, 
           30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 8., 9.8, 1.45, 0.81, 10., 2.5, 3., 0.3, 
           75.8, 0., 0., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
           196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {
          "winter", "small", "low", 8.06, 12.6, 9., 0.23, 10., 5., 6., 1.1, 
           35.5, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 32.730000000000004`, 3.245, 
           10., 1., 6.5, 5.475, 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 32.730000000000004`, 2.22, 
           5., 1., 1., 5.475, 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 32.730000000000004`, 2.55, 
           10., 1., 4., 5.475, 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 32.730000000000004`, 1.32, 20.,
            1., 6., 5.475, 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 32.730000000000004`, 2.64, 
           10., 2., 11., 5.475, 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 32.730000000000004`, 4.17, 
           10., 1., 6., 5.475, 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 32.730000000000004`, 5.97, 
           10., 2., 14., 5.475, 66.9, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 5.475, 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 5.475, 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 32.730000000000004`, 0.9, 142., 
           102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 5.475, 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228188[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$228188[$CellContext`Cl] = Part[
      $CellContext`sym$228188[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 104., 2.7, 
           30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 8., 9.8, 1.45, 0.81, 10., 2.5, 3., 0.3, 
           75.8, 0., 0., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
           196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {
          "winter", "small", "low", 8.06, 12.6, 9., 0.23, 10., 5., 6., 1.1, 
           35.5, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 32.730000000000004`, 3.245, 
           10., 1., 6.5, 5.475, 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 32.730000000000004`, 2.22, 
           5., 1., 1., 5.475, 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 32.730000000000004`, 2.55, 
           10., 1., 4., 5.475, 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 32.730000000000004`, 1.32, 20.,
            1., 6., 5.475, 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 32.730000000000004`, 2.64, 
           10., 2., 11., 5.475, 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 32.730000000000004`, 4.17, 
           10., 1., 6., 5.475, 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 32.730000000000004`, 5.97, 
           10., 2., 14., 5.475, 66.9, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 5.475, 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 5.475, 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 32.730000000000004`, 0.9, 142., 
           102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 5.475, 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228188[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$228188[$CellContext`mnO2] = Part[
      $CellContext`sym$228188[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 104., 2.7, 
           30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 8., 9.8, 1.45, 0.81, 10., 2.5, 3., 0.3, 
           75.8, 0., 0., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
           196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {
          "winter", "small", "low", 8.06, 12.6, 9., 0.23, 10., 5., 6., 1.1, 
           35.5, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 32.730000000000004`, 3.245, 
           10., 1., 6.5, 5.475, 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 32.730000000000004`, 2.22, 
           5., 1., 1., 5.475, 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 32.730000000000004`, 2.55, 
           10., 1., 4., 5.475, 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 32.730000000000004`, 1.32, 20.,
            1., 6., 5.475, 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 32.730000000000004`, 2.64, 
           10., 2., 11., 5.475, 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 32.730000000000004`, 4.17, 
           10., 1., 6., 5.475, 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 32.730000000000004`, 5.97, 
           10., 2., 14., 5.475, 66.9, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 5.475, 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 5.475, 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 32.730000000000004`, 0.9, 142., 
           102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 5.475, 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228188[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$228188[$CellContext`mxPH] = Part[
      $CellContext`sym$228188[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 104., 2.7, 
           30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 8., 9.8, 1.45, 0.81, 10., 2.5, 3., 0.3, 
           75.8, 0., 0., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
           196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {
          "winter", "small", "low", 8.06, 12.6, 9., 0.23, 10., 5., 6., 1.1, 
           35.5, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 32.730000000000004`, 3.245, 
           10., 1., 6.5, 5.475, 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 32.730000000000004`, 2.22, 
           5., 1., 1., 5.475, 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 32.730000000000004`, 2.55, 
           10., 1., 4., 5.475, 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 32.730000000000004`, 1.32, 20.,
            1., 6., 5.475, 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 32.730000000000004`, 2.64, 
           10., 2., 11., 5.475, 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 32.730000000000004`, 4.17, 
           10., 1., 6., 5.475, 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 32.730000000000004`, 5.97, 
           10., 2., 14., 5.475, 66.9, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 5.475, 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 5.475, 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 32.730000000000004`, 0.9, 142., 
           102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 5.475, 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228188[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$228188[$CellContext`NH4] = Part[
      $CellContext`sym$228188[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 104., 2.7, 
           30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 8., 9.8, 1.45, 0.81, 10., 2.5, 3., 0.3, 
           75.8, 0., 0., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
           196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {
          "winter", "small", "low", 8.06, 12.6, 9., 0.23, 10., 5., 6., 1.1, 
           35.5, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 32.730000000000004`, 3.245, 
           10., 1., 6.5, 5.475, 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 32.730000000000004`, 2.22, 
           5., 1., 1., 5.475, 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 32.730000000000004`, 2.55, 
           10., 1., 4., 5.475, 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 32.730000000000004`, 1.32, 20.,
            1., 6., 5.475, 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 32.730000000000004`, 2.64, 
           10., 2., 11., 5.475, 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 32.730000000000004`, 4.17, 
           10., 1., 6., 5.475, 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 32.730000000000004`, 5.97, 
           10., 2., 14., 5.475, 66.9, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 5.475, 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 5.475, 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 32.730000000000004`, 0.9, 142., 
           102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 5.475, 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228188[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$228188[$CellContext`NO3] = Part[
      $CellContext`sym$228188[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 104., 2.7, 
           30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 8., 9.8, 1.45, 0.81, 10., 2.5, 3., 0.3, 
           75.8, 0., 0., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
           196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {
          "winter", "small", "low", 8.06, 12.6, 9., 0.23, 10., 5., 6., 1.1, 
           35.5, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 32.730000000000004`, 3.245, 
           10., 1., 6.5, 5.475, 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 32.730000000000004`, 2.22, 
           5., 1., 1., 5.475, 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 32.730000000000004`, 2.55, 
           10., 1., 4., 5.475, 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 32.730000000000004`, 1.32, 20.,
            1., 6., 5.475, 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 32.730000000000004`, 2.64, 
           10., 2., 11., 5.475, 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 32.730000000000004`, 4.17, 
           10., 1., 6., 5.475, 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 32.730000000000004`, 5.97, 
           10., 2., 14., 5.475, 66.9, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 5.475, 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 5.475, 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 32.730000000000004`, 0.9, 142., 
           102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 5.475, 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228188[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$228188[$CellContext`oPO4] = Part[
      $CellContext`sym$228188[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 104., 2.7, 
           30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 8., 9.8, 1.45, 0.81, 10., 2.5, 3., 0.3, 
           75.8, 0., 0., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
           196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {
          "winter", "small", "low", 8.06, 12.6, 9., 0.23, 10., 5., 6., 1.1, 
           35.5, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 32.730000000000004`, 3.245, 
           10., 1., 6.5, 5.475, 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 32.730000000000004`, 2.22, 
           5., 1., 1., 5.475, 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 32.730000000000004`, 2.55, 
           10., 1., 4., 5.475, 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 32.730000000000004`, 1.32, 20.,
            1., 6., 5.475, 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 32.730000000000004`, 2.64, 
           10., 2., 11., 5.475, 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 32.730000000000004`, 4.17, 
           10., 1., 6., 5.475, 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 32.730000000000004`, 5.97, 
           10., 2., 14., 5.475, 66.9, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 5.475, 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 5.475, 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 32.730000000000004`, 0.9, 142., 
           102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 5.475, 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228188[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$228188[$CellContext`PO4] = Part[
      $CellContext`sym$228188[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 104., 2.7, 
           30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 8., 9.8, 1.45, 0.81, 10., 2.5, 3., 0.3, 
           75.8, 0., 0., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
           196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {
          "winter", "small", "low", 8.06, 12.6, 9., 0.23, 10., 5., 6., 1.1, 
           35.5, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 32.730000000000004`, 3.245, 
           10., 1., 6.5, 5.475, 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 32.730000000000004`, 2.22, 
           5., 1., 1., 5.475, 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 32.730000000000004`, 2.55, 
           10., 1., 4., 5.475, 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 32.730000000000004`, 1.32, 20.,
            1., 6., 5.475, 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 32.730000000000004`, 2.64, 
           10., 2., 11., 5.475, 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 32.730000000000004`, 4.17, 
           10., 1., 6., 5.475, 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 32.730000000000004`, 5.97, 
           10., 2., 14., 5.475, 66.9, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 5.475, 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 5.475, 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 32.730000000000004`, 0.9, 142., 
           102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 5.475, 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228188[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$228188[$CellContext`season] = Part[
      $CellContext`sym$228188[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 104., 2.7, 
           30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 8., 9.8, 1.45, 0.81, 10., 2.5, 3., 0.3, 
           75.8, 0., 0., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
           196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {
          "winter", "small", "low", 8.06, 12.6, 9., 0.23, 10., 5., 6., 1.1, 
           35.5, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 32.730000000000004`, 3.245, 
           10., 1., 6.5, 5.475, 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 32.730000000000004`, 2.22, 
           5., 1., 1., 5.475, 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 32.730000000000004`, 2.55, 
           10., 1., 4., 5.475, 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 32.730000000000004`, 1.32, 20.,
            1., 6., 5.475, 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 32.730000000000004`, 2.64, 
           10., 2., 11., 5.475, 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 32.730000000000004`, 4.17, 
           10., 1., 6., 5.475, 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 32.730000000000004`, 5.97, 
           10., 2., 14., 5.475, 66.9, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 5.475, 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 5.475, 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 32.730000000000004`, 0.9, 142., 
           102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 5.475, 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228188[$CellContext`season, 
         "missing"]]]], $CellContext`sym$228188[$CellContext`size] = Part[
      $CellContext`sym$228188[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 104., 2.7, 
           30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 8., 9.8, 1.45, 0.81, 10., 2.5, 3., 0.3, 
           75.8, 0., 0., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
           196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {
          "winter", "small", "low", 8.06, 12.6, 9., 0.23, 10., 5., 6., 1.1, 
           35.5, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 32.730000000000004`, 3.245, 
           10., 1., 6.5, 5.475, 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 32.730000000000004`, 2.22, 
           5., 1., 1., 5.475, 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 32.730000000000004`, 2.55, 
           10., 1., 4., 5.475, 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 32.730000000000004`, 1.32, 20.,
            1., 6., 5.475, 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 32.730000000000004`, 2.64, 
           10., 2., 11., 5.475, 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 32.730000000000004`, 4.17, 
           10., 1., 6., 5.475, 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 32.730000000000004`, 5.97, 
           10., 2., 14., 5.475, 66.9, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 5.475, 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 5.475, 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 32.730000000000004`, 0.9, 142., 
           102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 5.475, 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228188[$CellContext`size, 
         "missing"]]]], $CellContext`sym$228188[$CellContext`speed] = Part[
      $CellContext`sym$228188[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 104., 2.7, 
           30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 8., 9.8, 1.45, 0.81, 10., 2.5, 3., 0.3, 
           75.8, 0., 0., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
           196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {
          "winter", "small", "low", 8.06, 12.6, 9., 0.23, 10., 5., 6., 1.1, 
           35.5, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 32.730000000000004`, 3.245, 
           10., 1., 6.5, 5.475, 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 32.730000000000004`, 2.22, 
           5., 1., 1., 5.475, 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 32.730000000000004`, 2.55, 
           10., 1., 4., 5.475, 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 32.730000000000004`, 1.32, 20.,
            1., 6., 5.475, 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 32.730000000000004`, 2.64, 
           10., 2., 11., 5.475, 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 32.730000000000004`, 4.17, 
           10., 1., 6., 5.475, 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 32.730000000000004`, 5.97, 
           10., 2., 14., 5.475, 66.9, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 5.475, 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 5.475, 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 32.730000000000004`, 0.9, 142., 
           102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 5.475, 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228188[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$228188[$CellContext`a1, 
      "factorized"] = 
    False, $CellContext`sym$228188[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$228188[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$228188[All], 
      All, $CellContext`i$228200], $CellContext`sym$228188[$CellContext`a2, 
      "factorized"] = 
    False, $CellContext`sym$228188[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$228188[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$228188[All], 
      All, $CellContext`i$228201], $CellContext`sym$228188[$CellContext`a3, 
      "factorized"] = 
    False, $CellContext`sym$228188[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$228188[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$228188[All], 
      All, $CellContext`i$228202], $CellContext`sym$228188[$CellContext`a4, 
      "factorized"] = 
    False, $CellContext`sym$228188[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$228188[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$228188[All], 
      All, $CellContext`i$228203], $CellContext`sym$228188[$CellContext`a5, 
      "factorized"] = 
    False, $CellContext`sym$228188[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$228188[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$228188[All], 
      All, $CellContext`i$228204], $CellContext`sym$228188[$CellContext`a6, 
      "factorized"] = 
    False, $CellContext`sym$228188[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$228188[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$228188[All], 
      All, $CellContext`i$228205], $CellContext`sym$228188[$CellContext`a7, 
      "factorized"] = 
    False, $CellContext`sym$228188[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$228188[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$228188[All], 
      All, $CellContext`i$228206], $CellContext`sym$228188[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$228188[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed}, $CellContext`sym$228188[$CellContext`Chla, "factorized"] = 
    False, $CellContext`sym$228188[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$228188[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$228188[All], 
      All, $CellContext`i$228199], $CellContext`sym$228188[$CellContext`Cl, 
      "factorized"] = 
    False, $CellContext`sym$228188[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$228188[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$228188[All], 
      All, $CellContext`i$228194], $CellContext`sym$228188[$CellContext`mnO2, 
      "factorized"] = 
    False, $CellContext`sym$228188[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$228188[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$228188[All], 
      All, $CellContext`i$228193], $CellContext`sym$228188[$CellContext`mxPH, 
      "factorized"] = 
    False, $CellContext`sym$228188[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$228188[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$228188[All], 
      All, $CellContext`i$228192], $CellContext`sym$228188[$CellContext`NH4, 
      "factorized"] = 
    False, $CellContext`sym$228188[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$228188[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$228188[All], 
      All, $CellContext`i$228196], $CellContext`sym$228188[$CellContext`NO3, 
      "factorized"] = 
    False, $CellContext`sym$228188[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$228188[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$228188[All], 
      All, $CellContext`i$228195], $CellContext`sym$228188[$CellContext`oPO4, 
      "factorized"] = 
    False, $CellContext`sym$228188[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$228188[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$228188[All], 
      All, $CellContext`i$228197], $CellContext`sym$228188[$CellContext`PO4, 
      "factorized"] = 
    False, $CellContext`sym$228188[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$228188[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$228188[All], 
      All, $CellContext`i$228198], \
$CellContext`sym$228188[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$228188[$CellContext`season, "factors"] = 
    Part[{"autumn", "spring", "summer", "winter"}, 
      $CellContext`fordering[$CellContext`sym$228188, $CellContext`season]], \
$CellContext`sym$228188[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$228188[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$228188[All], 
      All, $CellContext`i$228189], $CellContext`sym$228188[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$228188[$CellContext`size, "factors"] = 
    Part[{"large", "medium", "small"}, 
      $CellContext`fordering[$CellContext`sym$228188, $CellContext`size]], \
$CellContext`sym$228188[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$228188[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$228188[All], 
      All, $CellContext`i$228190], $CellContext`sym$228188[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$228188[$CellContext`speed, "factors"] = 
    Part[{"high", "low", "medium"}, 
      $CellContext`fordering[$CellContext`sym$228188, $CellContext`speed]], \
$CellContext`sym$228188[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$228188[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$228188[All], All, $CellContext`i$228191], 
    Attributes[$CellContext`i$228198] = {Temporary}, $CellContext`i$228198 = 
    10, Attributes[$CellContext`i$228193] = {
     Temporary}, $CellContext`i$228193 = 5, 
    Attributes[$CellContext`i$228190] = {Temporary}, $CellContext`i$228190 = 
    2, Attributes[$CellContext`i$228199] = {Temporary}, $CellContext`i$228199 = 
    11, Attributes[$CellContext`i$228196] = {
     Temporary}, $CellContext`i$228196 = 8, 
    Attributes[$CellContext`i$228201] = {Temporary}, $CellContext`i$228201 = 
    13, Attributes[$CellContext`i$228204] = {
     Temporary}, $CellContext`i$228204 = 16, 
    Attributes[$CellContext`i$228206] = {Temporary}, $CellContext`i$228206 = 
    18, Attributes[$CellContext`i$228194] = {
     Temporary}, $CellContext`i$228194 = 6, 
    Attributes[$CellContext`i$228192] = {Temporary}, $CellContext`i$228192 = 
    4, Attributes[$CellContext`i$228202] = {Temporary}, $CellContext`i$228202 = 
    14, Attributes[$CellContext`i$228203] = {
     Temporary}, $CellContext`i$228203 = 15, 
    Attributes[$CellContext`i$228191] = {Temporary}, $CellContext`i$228191 = 
    3, Attributes[$CellContext`i$228200] = {Temporary}, $CellContext`i$228200 = 
    12, Attributes[$CellContext`i$228189] = {
     Temporary}, $CellContext`i$228189 = 1, 
    Attributes[$CellContext`i$228195] = {Temporary}, $CellContext`i$228195 = 
    7, Attributes[$CellContext`i$228197] = {Temporary}, $CellContext`i$228197 = 
    9, Attributes[$CellContext`i$228205] = {Temporary}, $CellContext`i$228205 = 
    17, Attributes[$CellContext`sym$227310] = {
     Temporary}, $CellContext`sym$227310[$CellContext`a1] = Part[
      $CellContext`sym$227310[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227310[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$227310[$CellContext`a2] = Part[
      $CellContext`sym$227310[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227310[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$227310[$CellContext`a3] = Part[
      $CellContext`sym$227310[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227310[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$227310[$CellContext`a4] = Part[
      $CellContext`sym$227310[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227310[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$227310[$CellContext`a5] = Part[
      $CellContext`sym$227310[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227310[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$227310[$CellContext`a6] = Part[
      $CellContext`sym$227310[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227310[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$227310[$CellContext`a7] = Part[
      $CellContext`sym$227310[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227310[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$227310[All] = $CellContext`med[
     All], $CellContext`sym$227310[$CellContext`Chla] = Part[
      $CellContext`sym$227310[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227310[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$227310[$CellContext`Cl] = Part[
      $CellContext`sym$227310[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227310[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$227310[$CellContext`mnO2] = Part[
      $CellContext`sym$227310[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227310[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$227310[$CellContext`mxPH] = Part[
      $CellContext`sym$227310[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227310[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$227310[$CellContext`NH4] = Part[
      $CellContext`sym$227310[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227310[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$227310[$CellContext`NO3] = Part[
      $CellContext`sym$227310[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227310[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$227310[$CellContext`oPO4] = Part[
      $CellContext`sym$227310[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227310[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$227310[$CellContext`PO4] = Part[
      $CellContext`sym$227310[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227310[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$227310[$CellContext`season] = Part[
      $CellContext`sym$227310[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227310[$CellContext`season, 
         "missing"]]]], $CellContext`sym$227310[$CellContext`size] = Part[
      $CellContext`sym$227310[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227310[$CellContext`size, 
         "missing"]]]], $CellContext`sym$227310[$CellContext`speed] = Part[
      $CellContext`sym$227310[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$227310[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$227310[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$227310[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227310, $CellContext`a1]], \
$CellContext`sym$227310[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$227310[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$227310[All], 
      All, $CellContext`i$227322], $CellContext`sym$227310[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$227310[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227310, $CellContext`a2]], \
$CellContext`sym$227310[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$227310[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$227310[All], 
      All, $CellContext`i$227323], $CellContext`sym$227310[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$227310[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227310, $CellContext`a3]], \
$CellContext`sym$227310[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$227310[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$227310[All], 
      All, $CellContext`i$227324], $CellContext`sym$227310[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$227310[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227310, $CellContext`a4]], \
$CellContext`sym$227310[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$227310[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$227310[All], 
      All, $CellContext`i$227325], $CellContext`sym$227310[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$227310[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227310, $CellContext`a5]], \
$CellContext`sym$227310[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$227310[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$227310[All], 
      All, $CellContext`i$227326], $CellContext`sym$227310[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$227310[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227310, $CellContext`a6]], \
$CellContext`sym$227310[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$227310[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$227310[All], 
      All, $CellContext`i$227327], $CellContext`sym$227310[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$227310[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227310, $CellContext`a7]], \
$CellContext`sym$227310[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$227310[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$227310[All], 
      All, $CellContext`i$227328], $CellContext`sym$227310[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$227310[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$227310[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$227310[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227310, $CellContext`Chla]], \
$CellContext`sym$227310[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$227310[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$227310[All], 
      All, $CellContext`i$227321], $CellContext`sym$227310[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$227310[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227310, $CellContext`Cl]], \
$CellContext`sym$227310[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$227310[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$227310[All], 
      All, $CellContext`i$227316], $CellContext`sym$227310[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$227310[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227310, $CellContext`mnO2]], \
$CellContext`sym$227310[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$227310[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$227310[All], 
      All, $CellContext`i$227315], $CellContext`sym$227310[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$227310[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227310, $CellContext`mxPH]], \
$CellContext`sym$227310[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$227310[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$227310[All], 
      All, $CellContext`i$227314], $CellContext`sym$227310[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$227310[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227310, $CellContext`NH4]], \
$CellContext`sym$227310[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$227310[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$227310[All], 
      All, $CellContext`i$227318], $CellContext`sym$227310[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$227310[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227310, $CellContext`NO3]], \
$CellContext`sym$227310[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$227310[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$227310[All], 
      All, $CellContext`i$227317], $CellContext`sym$227310[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$227310[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227310, $CellContext`oPO4]], \
$CellContext`sym$227310[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$227310[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$227310[All], 
      All, $CellContext`i$227319], $CellContext`sym$227310[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$227310[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227310, $CellContext`PO4]], \
$CellContext`sym$227310[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$227310[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$227310[All], 
      All, $CellContext`i$227320], \
$CellContext`sym$227310[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$227310[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227310, $CellContext`season]], \
$CellContext`sym$227310[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$227310[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$227310[All], 
      All, $CellContext`i$227311], $CellContext`sym$227310[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$227310[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227310, $CellContext`size]], \
$CellContext`sym$227310[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$227310[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$227310[All], 
      All, $CellContext`i$227312], $CellContext`sym$227310[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$227310[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$227310, $CellContext`speed]], \
$CellContext`sym$227310[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$227310[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$227310[All], All, $CellContext`i$227313], 
    Attributes[$CellContext`i$227328] = {Temporary}, $CellContext`i$227328 = 
    18, Attributes[$CellContext`i$227325] = {
     Temporary}, $CellContext`i$227325 = 15, 
    Attributes[$CellContext`i$227314] = {Temporary}, $CellContext`i$227314 = 
    4, Attributes[$CellContext`i$227326] = {Temporary}, $CellContext`i$227326 = 
    16, Attributes[$CellContext`i$227321] = {
     Temporary}, $CellContext`i$227321 = 11, 
    Attributes[$CellContext`i$227313] = {Temporary}, $CellContext`i$227313 = 
    3, Attributes[$CellContext`i$227317] = {Temporary}, $CellContext`i$227317 = 
    7, Attributes[$CellContext`i$227322] = {Temporary}, $CellContext`i$227322 = 
    12, Attributes[$CellContext`i$227320] = {
     Temporary}, $CellContext`i$227320 = 10, 
    Attributes[$CellContext`i$227319] = {Temporary}, $CellContext`i$227319 = 
    9, Attributes[$CellContext`i$227315] = {Temporary}, $CellContext`i$227315 = 
    5, Attributes[$CellContext`i$227324] = {Temporary}, $CellContext`i$227324 = 
    14, Attributes[$CellContext`i$227323] = {
     Temporary}, $CellContext`i$227323 = 13, 
    Attributes[$CellContext`i$227327] = {Temporary}, $CellContext`i$227327 = 
    17, Attributes[$CellContext`i$227311] = {
     Temporary}, $CellContext`i$227311 = 1, 
    Attributes[$CellContext`i$227316] = {Temporary}, $CellContext`i$227316 = 
    6, Attributes[$CellContext`i$227318] = {Temporary}, $CellContext`i$227318 = 
    8, Attributes[$CellContext`i$227312] = {Temporary}, $CellContext`i$227312 = 
    2, Attributes[$CellContext`sym$188958] = {
     Temporary}, $CellContext`sym$188958[$CellContext`a1] = Part[
      $CellContext`sym$188958[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$188958[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$188958[$CellContext`a2] = Part[
      $CellContext`sym$188958[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$188958[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$188958[$CellContext`a3] = Part[
      $CellContext`sym$188958[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$188958[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$188958[$CellContext`a4] = Part[
      $CellContext`sym$188958[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$188958[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$188958[$CellContext`a5] = Part[
      $CellContext`sym$188958[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$188958[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$188958[$CellContext`a6] = Part[
      $CellContext`sym$188958[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$188958[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$188958[$CellContext`a7] = Part[
      $CellContext`sym$188958[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$188958[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$188958[All] = $CellContext`med[
     All], $CellContext`sym$188958[$CellContext`Chla] = Part[
      $CellContext`sym$188958[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$188958[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$188958[$CellContext`Cl] = Part[
      $CellContext`sym$188958[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$188958[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$188958[$CellContext`mnO2] = Part[
      $CellContext`sym$188958[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$188958[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$188958[$CellContext`mxPH] = Part[
      $CellContext`sym$188958[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$188958[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$188958[$CellContext`NH4] = Part[
      $CellContext`sym$188958[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$188958[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$188958[$CellContext`NO3] = Part[
      $CellContext`sym$188958[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$188958[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$188958[$CellContext`oPO4] = Part[
      $CellContext`sym$188958[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$188958[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$188958[$CellContext`PO4] = Part[
      $CellContext`sym$188958[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$188958[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$188958[$CellContext`season] = Part[
      $CellContext`sym$188958[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$188958[$CellContext`season, 
         "missing"]]]], $CellContext`sym$188958[$CellContext`size] = Part[
      $CellContext`sym$188958[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$188958[$CellContext`size, 
         "missing"]]]], $CellContext`sym$188958[$CellContext`speed] = Part[
      $CellContext`sym$188958[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$188958[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$188958[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$188958[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$188958, $CellContext`a1]], \
$CellContext`sym$188958[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$188958[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$188958[All], 
      All, $CellContext`i$190517], $CellContext`sym$188958[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$188958[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$188958, $CellContext`a2]], \
$CellContext`sym$188958[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$188958[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$188958[All], 
      All, $CellContext`i$190518], $CellContext`sym$188958[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$188958[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$188958, $CellContext`a3]], \
$CellContext`sym$188958[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$188958[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$188958[All], 
      All, $CellContext`i$190519], $CellContext`sym$188958[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$188958[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$188958, $CellContext`a4]], \
$CellContext`sym$188958[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$188958[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$188958[All], 
      All, $CellContext`i$190520], $CellContext`sym$188958[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$188958[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$188958, $CellContext`a5]], \
$CellContext`sym$188958[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$188958[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$188958[All], 
      All, $CellContext`i$190521], $CellContext`sym$188958[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$188958[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$188958, $CellContext`a6]], \
$CellContext`sym$188958[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$188958[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$188958[All], 
      All, $CellContext`i$190522], $CellContext`sym$188958[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$188958[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$188958, $CellContext`a7]], \
$CellContext`sym$188958[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$188958[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$188958[All], 
      All, $CellContext`i$190523], $CellContext`sym$188958[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$188958[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$188958[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$188958[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$188958, $CellContext`Chla]], \
$CellContext`sym$188958[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$188958[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$188958[All], 
      All, $CellContext`i$190516], $CellContext`sym$188958[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$188958[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$188958, $CellContext`Cl]], \
$CellContext`sym$188958[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$188958[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$188958[All], 
      All, $CellContext`i$190511], $CellContext`sym$188958[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$188958[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$188958, $CellContext`mnO2]], \
$CellContext`sym$188958[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$188958[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$188958[All], 
      All, $CellContext`i$190510], $CellContext`sym$188958[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$188958[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$188958, $CellContext`mxPH]], \
$CellContext`sym$188958[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$188958[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$188958[All], 
      All, $CellContext`i$190509], $CellContext`sym$188958[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$188958[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$188958, $CellContext`NH4]], \
$CellContext`sym$188958[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$188958[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$188958[All], 
      All, $CellContext`i$190513], $CellContext`sym$188958[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$188958[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$188958, $CellContext`NO3]], \
$CellContext`sym$188958[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$188958[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$188958[All], 
      All, $CellContext`i$190512], $CellContext`sym$188958[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$188958[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$188958, $CellContext`oPO4]], \
$CellContext`sym$188958[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$188958[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$188958[All], 
      All, $CellContext`i$190514], $CellContext`sym$188958[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$188958[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$188958, $CellContext`PO4]], \
$CellContext`sym$188958[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$188958[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$188958[All], 
      All, $CellContext`i$190515], \
$CellContext`sym$188958[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$188958[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$188958, $CellContext`season]], \
$CellContext`sym$188958[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$188958[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$188958[All], 
      All, $CellContext`i$188959], $CellContext`sym$188958[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$188958[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$188958, $CellContext`size]], \
$CellContext`sym$188958[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$188958[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$188958[All], 
      All, $CellContext`i$190507], $CellContext`sym$188958[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$188958[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$188958, $CellContext`speed]], \
$CellContext`sym$188958[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$188958[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$188958[All], All, $CellContext`i$190508], 
    Attributes[$CellContext`i$190508] = {Temporary}, $CellContext`i$190508 = 
    3, Attributes[$CellContext`i$190512] = {Temporary}, $CellContext`i$190512 = 
    7, Attributes[$CellContext`i$190510] = {Temporary}, $CellContext`i$190510 = 
    5, Attributes[$CellContext`i$190521] = {Temporary}, $CellContext`i$190521 = 
    16, Attributes[$CellContext`i$190519] = {
     Temporary}, $CellContext`i$190519 = 14, 
    Attributes[$CellContext`i$190523] = {Temporary}, $CellContext`i$190523 = 
    18, Attributes[$CellContext`i$190511] = {
     Temporary}, $CellContext`i$190511 = 6, 
    Attributes[$CellContext`i$190522] = {Temporary}, $CellContext`i$190522 = 
    17, Attributes[$CellContext`i$190513] = {
     Temporary}, $CellContext`i$190513 = 8, 
    Attributes[$CellContext`i$190509] = {Temporary}, $CellContext`i$190509 = 
    4, Attributes[$CellContext`i$190507] = {Temporary}, $CellContext`i$190507 = 
    2, Attributes[$CellContext`i$190514] = {Temporary}, $CellContext`i$190514 = 
    9, Attributes[$CellContext`i$190517] = {Temporary}, $CellContext`i$190517 = 
    12, Attributes[$CellContext`i$190515] = {
     Temporary}, $CellContext`i$190515 = 10, 
    Attributes[$CellContext`i$190516] = {Temporary}, $CellContext`i$190516 = 
    11, Attributes[$CellContext`i$190518] = {
     Temporary}, $CellContext`i$190518 = 13, 
    Attributes[$CellContext`i$188959] = {Temporary}, $CellContext`i$188959 = 
    1, Attributes[$CellContext`i$190520] = {Temporary}, $CellContext`i$190520 = 
    15, Attributes[$CellContext`sym$224686] = {
     Temporary}, $CellContext`sym$224686[$CellContext`a1] = Part[
      $CellContext`sym$224686[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$224686[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$224686[$CellContext`a2] = Part[
      $CellContext`sym$224686[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$224686[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$224686[$CellContext`a3] = Part[
      $CellContext`sym$224686[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$224686[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$224686[$CellContext`a4] = Part[
      $CellContext`sym$224686[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$224686[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$224686[$CellContext`a5] = Part[
      $CellContext`sym$224686[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$224686[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$224686[$CellContext`a6] = Part[
      $CellContext`sym$224686[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$224686[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$224686[$CellContext`a7] = Part[
      $CellContext`sym$224686[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$224686[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$224686[All] = $CellContext`med[
     All], $CellContext`sym$224686[$CellContext`Chla] = Part[
      $CellContext`sym$224686[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$224686[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$224686[$CellContext`Cl] = Part[
      $CellContext`sym$224686[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$224686[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$224686[$CellContext`mnO2] = Part[
      $CellContext`sym$224686[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$224686[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$224686[$CellContext`mxPH] = Part[
      $CellContext`sym$224686[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$224686[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$224686[$CellContext`NH4] = Part[
      $CellContext`sym$224686[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$224686[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$224686[$CellContext`NO3] = Part[
      $CellContext`sym$224686[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$224686[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$224686[$CellContext`oPO4] = Part[
      $CellContext`sym$224686[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$224686[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$224686[$CellContext`PO4] = Part[
      $CellContext`sym$224686[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$224686[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$224686[$CellContext`season] = Part[
      $CellContext`sym$224686[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$224686[$CellContext`season, 
         "missing"]]]], $CellContext`sym$224686[$CellContext`size] = Part[
      $CellContext`sym$224686[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$224686[$CellContext`size, 
         "missing"]]]], $CellContext`sym$224686[$CellContext`speed] = Part[
      $CellContext`sym$224686[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$224686[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$224686[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$224686[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$224686, $CellContext`a1]], \
$CellContext`sym$224686[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$224686[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$224686[All], 
      All, $CellContext`i$226245], $CellContext`sym$224686[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$224686[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$224686, $CellContext`a2]], \
$CellContext`sym$224686[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$224686[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$224686[All], 
      All, $CellContext`i$226246], $CellContext`sym$224686[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$224686[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$224686, $CellContext`a3]], \
$CellContext`sym$224686[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$224686[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$224686[All], 
      All, $CellContext`i$226247], $CellContext`sym$224686[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$224686[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$224686, $CellContext`a4]], \
$CellContext`sym$224686[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$224686[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$224686[All], 
      All, $CellContext`i$226248], $CellContext`sym$224686[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$224686[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$224686, $CellContext`a5]], \
$CellContext`sym$224686[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$224686[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$224686[All], 
      All, $CellContext`i$226249], $CellContext`sym$224686[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$224686[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$224686, $CellContext`a6]], \
$CellContext`sym$224686[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$224686[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$224686[All], 
      All, $CellContext`i$226250], $CellContext`sym$224686[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$224686[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$224686, $CellContext`a7]], \
$CellContext`sym$224686[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$224686[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$224686[All], 
      All, $CellContext`i$226251], $CellContext`sym$224686[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$224686[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$224686[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$224686[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$224686, $CellContext`Chla]], \
$CellContext`sym$224686[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$224686[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$224686[All], 
      All, $CellContext`i$226244], $CellContext`sym$224686[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$224686[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$224686, $CellContext`Cl]], \
$CellContext`sym$224686[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$224686[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$224686[All], 
      All, $CellContext`i$226239], $CellContext`sym$224686[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$224686[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$224686, $CellContext`mnO2]], \
$CellContext`sym$224686[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$224686[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$224686[All], 
      All, $CellContext`i$226238], $CellContext`sym$224686[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$224686[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$224686, $CellContext`mxPH]], \
$CellContext`sym$224686[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$224686[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$224686[All], 
      All, $CellContext`i$226237], $CellContext`sym$224686[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$224686[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$224686, $CellContext`NH4]], \
$CellContext`sym$224686[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$224686[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$224686[All], 
      All, $CellContext`i$226241], $CellContext`sym$224686[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$224686[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$224686, $CellContext`NO3]], \
$CellContext`sym$224686[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$224686[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$224686[All], 
      All, $CellContext`i$226240], $CellContext`sym$224686[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$224686[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$224686, $CellContext`oPO4]], \
$CellContext`sym$224686[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$224686[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$224686[All], 
      All, $CellContext`i$226242], $CellContext`sym$224686[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$224686[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$224686, $CellContext`PO4]], \
$CellContext`sym$224686[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$224686[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$224686[All], 
      All, $CellContext`i$226243], \
$CellContext`sym$224686[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$224686[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$224686, $CellContext`season]], \
$CellContext`sym$224686[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$224686[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$224686[All], 
      All, $CellContext`i$224687], $CellContext`sym$224686[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$224686[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$224686, $CellContext`size]], \
$CellContext`sym$224686[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$224686[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$224686[All], 
      All, $CellContext`i$226235], $CellContext`sym$224686[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$224686[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$224686, $CellContext`speed]], \
$CellContext`sym$224686[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$224686[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$224686[All], All, $CellContext`i$226236], 
    Attributes[$CellContext`i$226238] = {Temporary}, $CellContext`i$226238 = 
    5, Attributes[$CellContext`i$226243] = {Temporary}, $CellContext`i$226243 = 
    10, Attributes[$CellContext`i$224687] = {
     Temporary}, $CellContext`i$224687 = 1, 
    Attributes[$CellContext`i$226241] = {Temporary}, $CellContext`i$226241 = 
    8, Attributes[$CellContext`i$226246] = {Temporary}, $CellContext`i$226246 = 
    13, Attributes[$CellContext`i$226239] = {
     Temporary}, $CellContext`i$226239 = 6, 
    Attributes[$CellContext`i$226245] = {Temporary}, $CellContext`i$226245 = 
    12, Attributes[$CellContext`i$226235] = {
     Temporary}, $CellContext`i$226235 = 2, 
    Attributes[$CellContext`i$226240] = {Temporary}, $CellContext`i$226240 = 
    7, Attributes[$CellContext`i$226242] = {Temporary}, $CellContext`i$226242 = 
    9, Attributes[$CellContext`i$226236] = {Temporary}, $CellContext`i$226236 = 
    3, Attributes[$CellContext`i$226250] = {Temporary}, $CellContext`i$226250 = 
    17, Attributes[$CellContext`i$226249] = {
     Temporary}, $CellContext`i$226249 = 16, 
    Attributes[$CellContext`i$226244] = {Temporary}, $CellContext`i$226244 = 
    11, Attributes[$CellContext`i$226248] = {
     Temporary}, $CellContext`i$226248 = 15, 
    Attributes[$CellContext`i$226247] = {Temporary}, $CellContext`i$226247 = 
    14, Attributes[$CellContext`i$226251] = {
     Temporary}, $CellContext`i$226251 = 18, 
    Attributes[$CellContext`i$226237] = {Temporary}, $CellContext`i$226237 = 
    4, Attributes[$CellContext`sym$70989] = {
     Temporary}, $CellContext`sym$70989[$CellContext`a1] = $CellContext`med[
     All], $CellContext`sym$70989[$CellContext`a2] = $CellContext`med[
     All], $CellContext`sym$70989[$CellContext`a3] = $CellContext`med[
     All], $CellContext`sym$70989[$CellContext`a4] = $CellContext`med[
     All], $CellContext`sym$70989[$CellContext`a5] = $CellContext`med[
     All], $CellContext`sym$70989[$CellContext`a6] = $CellContext`med[
     All], $CellContext`sym$70989[$CellContext`a7] = $CellContext`med[
     All], $CellContext`sym$70989[All] = $CellContext`med[
     All], $CellContext`sym$70989[$CellContext`Chla] = $CellContext`med[
     All], $CellContext`sym$70989[$CellContext`Cl] = $CellContext`med[
     All], $CellContext`sym$70989[$CellContext`mnO2] = $CellContext`med[
     All], $CellContext`sym$70989[$CellContext`mxPH] = $CellContext`med[
     All], $CellContext`sym$70989[$CellContext`NH4] = $CellContext`med[
     All], $CellContext`sym$70989[$CellContext`NO3] = $CellContext`med[
     All], $CellContext`sym$70989[$CellContext`oPO4] = $CellContext`med[
     All], $CellContext`sym$70989[$CellContext`PO4] = $CellContext`med[
     All], $CellContext`sym$70989[$CellContext`season] = $CellContext`med[
     All], $CellContext`sym$70989[$CellContext`size] = $CellContext`med[
     All], $CellContext`sym$70989[$CellContext`speed] = $CellContext`med[
     All], $CellContext`sym$70989[$CellContext`a1, "factorized"] = 
    True, $CellContext`sym$70989[$CellContext`a1, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$70989[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$70989[$CellContext`a1, "raw"] = Part[
      $CellContext`med[All], All, 12], $CellContext`sym$70989[$CellContext`a2,
       "factorized"] = 
    True, $CellContext`sym$70989[$CellContext`a2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$70989[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$70989[$CellContext`a2, "raw"] = Part[
      $CellContext`med[All], All, 13], $CellContext`sym$70989[$CellContext`a3,
       "factorized"] = 
    True, $CellContext`sym$70989[$CellContext`a3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$70989[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$70989[$CellContext`a3, "raw"] = Part[
      $CellContext`med[All], All, 14], $CellContext`sym$70989[$CellContext`a4,
       "factorized"] = 
    True, $CellContext`sym$70989[$CellContext`a4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$70989[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$70989[$CellContext`a4, "raw"] = Part[
      $CellContext`med[All], All, 15], $CellContext`sym$70989[$CellContext`a5,
       "factorized"] = 
    True, $CellContext`sym$70989[$CellContext`a5, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$70989[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$70989[$CellContext`a5, "raw"] = Part[
      $CellContext`med[All], All, 16], $CellContext`sym$70989[$CellContext`a6,
       "factorized"] = 
    True, $CellContext`sym$70989[$CellContext`a6, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$70989[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$70989[$CellContext`a6, "raw"] = Part[
      $CellContext`med[All], All, 17], $CellContext`sym$70989[$CellContext`a7,
       "factorized"] = 
    True, $CellContext`sym$70989[$CellContext`a7, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$70989[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$70989[$CellContext`a7, "raw"] = Part[
      $CellContext`med[All], All, 18], $CellContext`sym$70989[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$70989[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$70989[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$70989[$CellContext`Chla, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$70989[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$70989[$CellContext`Chla, "raw"] = Part[
      $CellContext`med[All], All, 11], $CellContext`sym$70989[$CellContext`Cl,
       "factorized"] = 
    True, $CellContext`sym$70989[$CellContext`Cl, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$70989[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$70989[$CellContext`Cl, "raw"] = Part[
      $CellContext`med[All], All, 
      6], $CellContext`sym$70989[$CellContext`mnO2, "factorized"] = 
    True, $CellContext`sym$70989[$CellContext`mnO2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$70989[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$70989[$CellContext`mnO2, "raw"] = Part[
      $CellContext`med[All], All, 
      5], $CellContext`sym$70989[$CellContext`mxPH, "factorized"] = 
    True, $CellContext`sym$70989[$CellContext`mxPH, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$70989[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$70989[$CellContext`mxPH, "raw"] = Part[
      $CellContext`med[All], All, 4], $CellContext`sym$70989[$CellContext`NH4,
       "factorized"] = 
    True, $CellContext`sym$70989[$CellContext`NH4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$70989[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$70989[$CellContext`NH4, "raw"] = Part[
      $CellContext`med[All], All, 8], $CellContext`sym$70989[$CellContext`NO3,
       "factorized"] = 
    True, $CellContext`sym$70989[$CellContext`NO3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$70989[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$70989[$CellContext`NO3, "raw"] = Part[
      $CellContext`med[All], All, 
      7], $CellContext`sym$70989[$CellContext`oPO4, "factorized"] = 
    True, $CellContext`sym$70989[$CellContext`oPO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$70989[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$70989[$CellContext`oPO4, "raw"] = Part[
      $CellContext`med[All], All, 9], $CellContext`sym$70989[$CellContext`PO4,
       "factorized"] = 
    True, $CellContext`sym$70989[$CellContext`PO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$70989[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$70989[$CellContext`PO4, "raw"] = Part[
      $CellContext`med[All], All, 
      10], $CellContext`sym$70989[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$70989[$CellContext`season, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$70989[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$70989[$CellContext`season, "raw"] = 
    Part[
      $CellContext`med[All], All, 
      1], $CellContext`sym$70989[$CellContext`size, "factorized"] = 
    True, $CellContext`sym$70989[$CellContext`size, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$70989[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$70989[$CellContext`size, "raw"] = Part[
      $CellContext`med[All], All, 
      2], $CellContext`sym$70989[$CellContext`speed, "factorized"] = 
    True, $CellContext`sym$70989[$CellContext`speed, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$70989[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$70989[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`med[All], All, 3], 
    Attributes[$CellContext`sym$142065] = {
     Temporary}, $CellContext`sym$142065[$CellContext`a1] = Part[
      $CellContext`sym$142065[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$142065[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$142065[$CellContext`a2] = Part[
      $CellContext`sym$142065[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$142065[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$142065[$CellContext`a3] = Part[
      $CellContext`sym$142065[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$142065[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$142065[$CellContext`a4] = Part[
      $CellContext`sym$142065[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$142065[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$142065[$CellContext`a5] = Part[
      $CellContext`sym$142065[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$142065[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$142065[$CellContext`a6] = Part[
      $CellContext`sym$142065[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$142065[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$142065[$CellContext`a7] = Part[
      $CellContext`sym$142065[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$142065[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$142065[All] = $CellContext`med[
     All], $CellContext`sym$142065[$CellContext`Chla] = Part[
      $CellContext`sym$142065[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$142065[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$142065[$CellContext`Cl] = Part[
      $CellContext`sym$142065[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$142065[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$142065[$CellContext`mnO2] = Part[
      $CellContext`sym$142065[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$142065[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$142065[$CellContext`mxPH] = Part[
      $CellContext`sym$142065[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$142065[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$142065[$CellContext`NH4] = Part[
      $CellContext`sym$142065[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$142065[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$142065[$CellContext`NO3] = Part[
      $CellContext`sym$142065[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$142065[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$142065[$CellContext`oPO4] = Part[
      $CellContext`sym$142065[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$142065[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$142065[$CellContext`PO4] = Part[
      $CellContext`sym$142065[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$142065[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$142065[$CellContext`season] = Part[
      $CellContext`sym$142065[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$142065[$CellContext`season, 
         "missing"]]]], $CellContext`sym$142065[$CellContext`size] = Part[
      $CellContext`sym$142065[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$142065[$CellContext`size, 
         "missing"]]]], $CellContext`sym$142065[$CellContext`speed] = Part[
      $CellContext`sym$142065[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$142065[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$142065[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$142065[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$142065, $CellContext`a1]], \
$CellContext`sym$142065[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$142065[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$142065[All], 
      All, $CellContext`i$143624], $CellContext`sym$142065[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$142065[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$142065, $CellContext`a2]], \
$CellContext`sym$142065[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$142065[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$142065[All], 
      All, $CellContext`i$143625], $CellContext`sym$142065[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$142065[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$142065, $CellContext`a3]], \
$CellContext`sym$142065[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$142065[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$142065[All], 
      All, $CellContext`i$143626], $CellContext`sym$142065[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$142065[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$142065, $CellContext`a4]], \
$CellContext`sym$142065[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$142065[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$142065[All], 
      All, $CellContext`i$143627], $CellContext`sym$142065[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$142065[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$142065, $CellContext`a5]], \
$CellContext`sym$142065[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$142065[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$142065[All], 
      All, $CellContext`i$143628], $CellContext`sym$142065[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$142065[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$142065, $CellContext`a6]], \
$CellContext`sym$142065[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$142065[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$142065[All], 
      All, $CellContext`i$143629], $CellContext`sym$142065[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$142065[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$142065, $CellContext`a7]], \
$CellContext`sym$142065[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$142065[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$142065[All], 
      All, $CellContext`i$143630], $CellContext`sym$142065[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$142065[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$142065[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$142065[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$142065, $CellContext`Chla]], \
$CellContext`sym$142065[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$142065[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$142065[All], 
      All, $CellContext`i$143623], $CellContext`sym$142065[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$142065[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$142065, $CellContext`Cl]], \
$CellContext`sym$142065[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$142065[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$142065[All], 
      All, $CellContext`i$143618], $CellContext`sym$142065[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$142065[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$142065, $CellContext`mnO2]], \
$CellContext`sym$142065[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$142065[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$142065[All], 
      All, $CellContext`i$143617], $CellContext`sym$142065[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$142065[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$142065, $CellContext`mxPH]], \
$CellContext`sym$142065[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$142065[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$142065[All], 
      All, $CellContext`i$143616], $CellContext`sym$142065[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$142065[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$142065, $CellContext`NH4]], \
$CellContext`sym$142065[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$142065[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$142065[All], 
      All, $CellContext`i$143620], $CellContext`sym$142065[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$142065[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$142065, $CellContext`NO3]], \
$CellContext`sym$142065[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$142065[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$142065[All], 
      All, $CellContext`i$143619], $CellContext`sym$142065[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$142065[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$142065, $CellContext`oPO4]], \
$CellContext`sym$142065[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$142065[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$142065[All], 
      All, $CellContext`i$143621], $CellContext`sym$142065[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$142065[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$142065, $CellContext`PO4]], \
$CellContext`sym$142065[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$142065[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$142065[All], 
      All, $CellContext`i$143622], \
$CellContext`sym$142065[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$142065[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$142065, $CellContext`season]], \
$CellContext`sym$142065[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$142065[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$142065[All], 
      All, $CellContext`i$142066], $CellContext`sym$142065[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$142065[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$142065, $CellContext`size]], \
$CellContext`sym$142065[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$142065[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$142065[All], 
      All, $CellContext`i$143614], $CellContext`sym$142065[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$142065[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$142065, $CellContext`speed]], \
$CellContext`sym$142065[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$142065[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$142065[All], All, $CellContext`i$143615], 
    Attributes[$CellContext`i$143616] = {Temporary}, $CellContext`i$143616 = 
    4, Attributes[$CellContext`i$143622] = {Temporary}, $CellContext`i$143622 = 
    10, Attributes[$CellContext`i$143618] = {
     Temporary}, $CellContext`i$143618 = 6, 
    Attributes[$CellContext`i$143623] = {Temporary}, $CellContext`i$143623 = 
    11, Attributes[$CellContext`i$143627] = {
     Temporary}, $CellContext`i$143627 = 15, 
    Attributes[$CellContext`i$143617] = {Temporary}, $CellContext`i$143617 = 
    5, Attributes[$CellContext`i$143625] = {Temporary}, $CellContext`i$143625 = 
    13, Attributes[$CellContext`i$143628] = {
     Temporary}, $CellContext`i$143628 = 16, 
    Attributes[$CellContext`i$143619] = {Temporary}, $CellContext`i$143619 = 
    7, Attributes[$CellContext`i$142066] = {Temporary}, $CellContext`i$142066 = 
    1, Attributes[$CellContext`i$143621] = {Temporary}, $CellContext`i$143621 = 
    9, Attributes[$CellContext`i$143629] = {Temporary}, $CellContext`i$143629 = 
    17, Attributes[$CellContext`i$143624] = {
     Temporary}, $CellContext`i$143624 = 12, 
    Attributes[$CellContext`i$143630] = {Temporary}, $CellContext`i$143630 = 
    18, Attributes[$CellContext`i$143615] = {
     Temporary}, $CellContext`i$143615 = 3, 
    Attributes[$CellContext`i$143620] = {Temporary}, $CellContext`i$143620 = 
    8, Attributes[$CellContext`i$143626] = {Temporary}, $CellContext`i$143626 = 
    14, Attributes[$CellContext`i$143614] = {
     Temporary}, $CellContext`i$143614 = 2, 
    Attributes[$CellContext`sym$235138] = {
     Temporary}, $CellContext`sym$235138[$CellContext`a1] = Part[
      $CellContext`sym$235138[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$235138[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$235138[$CellContext`a2] = Part[
      $CellContext`sym$235138[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$235138[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$235138[$CellContext`a3] = Part[
      $CellContext`sym$235138[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$235138[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$235138[$CellContext`a4] = Part[
      $CellContext`sym$235138[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$235138[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$235138[$CellContext`a5] = Part[
      $CellContext`sym$235138[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$235138[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$235138[$CellContext`a6] = Part[
      $CellContext`sym$235138[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$235138[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$235138[$CellContext`a7] = Part[
      $CellContext`sym$235138[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$235138[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$235138[
     All] = {{"winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 
       170., 50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
      "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
       558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
      "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 125.667,
        187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
      "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 61.182, 
       138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
      "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222, 
       97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
      "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
       56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
      "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
       111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
      "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 44.667, 
       77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
      "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 71., 
       5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 0.8, 
       17., 0., 0., 2.9, 0., 0., 1.7}, {
      "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 20.75, 
       0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
      "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 19.,
        0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
      "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 41., 
       43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
      "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5, 
       31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
      "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 0.3, 
       52.2, 5., 7.8, 0., 4., 0., 0.}, {
      "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 98.25, 
       1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50., 
       1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
      "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 57.833, 
       0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
      "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 0.8, 
       50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
      "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
       564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
      "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 586.,
        16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
      "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 0.5, 
       15.5, 0., 0., 2.3, 0., 0., 0.}, {
      "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 7.6,
        23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
      "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
       27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
      "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 1.5,
        13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
      "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 44.136, 
       3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
      "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 0.5, 
       29.7, 0., 0., 4.9, 0., 0., 0.}, {
      "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
       Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
      "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 17.1,
        0., 19.6, 0., 0., 0., 2.5}, {
      "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5, 
       33.9, 1., 14.6, 0., 0., 0., 0.}, {
      "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 4.9, 
       3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
      "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 2.8, 
       6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
      "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 130.75, 
       5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
      "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47., 
       2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
      "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23., 
       0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
      "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 58.875, 
       84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
      "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 0.2,
        66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
       Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0., 
       0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
       196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
      "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
       182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
      "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001, 
       296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
      "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 59.429,
        175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
      "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
       344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
      "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 276.85001, 
       326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
      "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 40.667, 
       3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
      "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 3.3, 
       29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
      "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 0.8, 
       54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
       Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 0., 
       0.}, {"spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121.,
        2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 20.812,
        12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
      "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
       49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
      "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 22.9, 
       4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
      "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 11.8, 
       0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818, 
       0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
      "winter", "small", "high", 6.6, 10.8, 
       Missing[], 3.245, 10., 1., 6.5, 
       Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "medium", 5.6, 11.8, 
       Missing[], 2.22, 5., 1., 1., 
       Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 5.7, 10.8, 
       Missing[], 2.55, 10., 1., 4., 
       Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
      "spring", "small", "high", 6.6, 9.5, 
       Missing[], 1.32, 20., 1., 6., 
       Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
      "summer", "small", "high", 6.6, 10.8, 
       Missing[], 2.64, 10., 2., 11., 
       Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
      "autumn", "small", "medium", 6.6, 11.3, 
       Missing[], 4.17, 10., 1., 6., 
       Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
      "spring", "small", "medium", 6.5, 10.4, 
       Missing[], 5.97, 10., 2., 14., 
       Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
      "summer", "small", "medium", 6.4, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 14., 
       Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
      "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 6.667, 
       Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75, 1.,
        20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
      "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2, 
       0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
      "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 0.6,
        55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
      "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 10.75, 
       2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
      "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 0.5, 
       64.2, 0., 3., 0., 0., 0., 0.}, {
      "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75, 
       351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
      "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
       209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
      "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 151.125,
        279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
      "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
       152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
      "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
       58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
      "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
       249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
      "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 100., 
       233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
      "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 215.5, 
       18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
      "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 25.167, 
       102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
      "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
       105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
      "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
       111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
      "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 1.3, 
       6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
      "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 56.667, 
       2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
      "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 4.3,
        1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
      "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
       104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
      "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 69.93,
        3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
      "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
       214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
      "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
       254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
      "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 57.6,
        169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
      "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
       412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
      "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
       282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
      "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
       197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
      "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 267.75, 
       391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
      "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 191.75, 
       265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
      "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
       232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
      "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 144.66701, 
       244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
      "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 218., 
       6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
      "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 138.5,
        20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
      "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222, 
       239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
      "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
       235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
      "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75, 
       205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
      "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 31.333, 
       211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
      "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625, 
       186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
      "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 12.889, 
       154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
      "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 51.111, 
       183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
      "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
       292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
      "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
       285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
      "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
       201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
      "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
       275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
      "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
       124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
      "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 60.833, 
       141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
      "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71., 
       132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
      "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
       17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
      "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 0.3, 
       46.6, 0., 2.5, 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 8.692, 
       16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
      "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 37.857, 
       102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
      "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
       86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
      "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
       10.111, 
       Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 16.833, 
       18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
      "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545, 
       13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
      "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 261.60001, 
       432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
      "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
       320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
      "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 144., 
       287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
      "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
       166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
      "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
       222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
      "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 36.909, 
       122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
      "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556, 
       127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
      "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
       89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
      "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 55., 
       284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
      "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 102.333, 
       277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
      "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 75.875, 
       177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
      "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
       72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
      "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 48.667, 
       82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
      "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 48.625, 
       66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
      "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 23., 
       173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
      "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 317., 
       5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
      "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 84., 
       4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
      "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 2., 
       10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
      "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 88.5, 
       2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
      "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115., 
       11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
      "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 98.143, 
       2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
      "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
       143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
      "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
       197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
      "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 1., 
       19., 0., 22., 5., 1.1, 5.4, 0.}, {
      "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 10.583, 
       23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
      "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 200.231, 
       19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
      "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 77.333, 
       147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
      "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5, 
       276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
      "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
       123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
      "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 75.207,
        23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
      "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 116.2,
        7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
      "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
       188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
      "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
       72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
      "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 16., 
       0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
      "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 34., 
       53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
      "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 27.5, 
       76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
      "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
       58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
      "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 175.66701, 
       361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
      "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
       22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
      "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 26.8,
        0., 28., 0., 0., 0., 0., 15.1}, {
      "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
       54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
      "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333, 
       34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
      "spring", "large", "low", 9., 5.8, 
       Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 0., 
       0.}, {"spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
       151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
      "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
       269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
      "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 46.438, 
       81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
      "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 85., 
       2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
      "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 66.4, 
       171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
      "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 102.364, 
       232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
      "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 84.3, 
       146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
      "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
       246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
      "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 205.636, 
       219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
      "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 236.39999,
        272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
      "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 1081.66003, 
       346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 5.9, 1.7}, {
      "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 82.222,
        167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
      "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 64.389, 
       137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
      "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 87.333,
        194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
      "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
       159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
      "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 21.3, 
       1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
      "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 0.6,
        37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
      "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
       14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
      "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222, 7.,
        1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 0.8, 
       50.4, 3.8, 0., 0., 0., 0., 0.}, {
      "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 7.654, 
       4., 56.8, 5., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 2.86, 
       17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
      "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 56.091, 
       Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
      "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
       52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
      "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 104.727, 
       228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
      "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 85.4, 
       17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
      "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 87.125,
        14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
      "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 101.455, 
       18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
      "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 50.889, 
       127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
      "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
       81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
      "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 19.727, 
       50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
      "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111, 
       120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
      "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 51.111, 
       91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
      "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 19.111, 
       61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
      "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625, 
       79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
      "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333, 
       75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
      "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333, 
       140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
      "winter", "large", "medium", 8., 7.6, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
      "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
       140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 
       5.8}}, $CellContext`sym$235138[$CellContext`Chla] = Part[
      $CellContext`sym$235138[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$235138[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$235138[$CellContext`Cl] = Part[
      $CellContext`sym$235138[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$235138[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$235138[$CellContext`mnO2] = Part[
      $CellContext`sym$235138[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$235138[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$235138[$CellContext`mxPH] = Part[
      $CellContext`sym$235138[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$235138[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$235138[$CellContext`NH4] = Part[
      $CellContext`sym$235138[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$235138[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$235138[$CellContext`NO3] = Part[
      $CellContext`sym$235138[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$235138[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$235138[$CellContext`oPO4] = Part[
      $CellContext`sym$235138[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$235138[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$235138[$CellContext`PO4] = Part[
      $CellContext`sym$235138[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$235138[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$235138[$CellContext`season] = Part[
      $CellContext`sym$235138[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$235138[$CellContext`season, 
         "missing"]]]], $CellContext`sym$235138[$CellContext`size] = Part[
      $CellContext`sym$235138[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$235138[$CellContext`size, 
         "missing"]]]], $CellContext`sym$235138[$CellContext`speed] = Part[
      $CellContext`sym$235138[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$235138[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$235138[$CellContext`a1, 
      "factorized"] = 
    False, $CellContext`sym$235138[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$235138[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$235138[All], 
      All, $CellContext`i$235150], $CellContext`sym$235138[$CellContext`a2, 
      "factorized"] = 
    False, $CellContext`sym$235138[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$235138[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$235138[All], 
      All, $CellContext`i$235151], $CellContext`sym$235138[$CellContext`a3, 
      "factorized"] = 
    False, $CellContext`sym$235138[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$235138[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$235138[All], 
      All, $CellContext`i$235152], $CellContext`sym$235138[$CellContext`a4, 
      "factorized"] = 
    False, $CellContext`sym$235138[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$235138[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$235138[All], 
      All, $CellContext`i$235153], $CellContext`sym$235138[$CellContext`a5, 
      "factorized"] = 
    False, $CellContext`sym$235138[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$235138[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$235138[All], 
      All, $CellContext`i$235154], $CellContext`sym$235138[$CellContext`a6, 
      "factorized"] = 
    False, $CellContext`sym$235138[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$235138[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$235138[All], 
      All, $CellContext`i$235155], $CellContext`sym$235138[$CellContext`a7, 
      "factorized"] = 
    False, $CellContext`sym$235138[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$235138[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$235138[All], 
      All, $CellContext`i$235156], $CellContext`sym$235138[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$235138[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed}, $CellContext`sym$235138[$CellContext`Chla, "factorized"] = 
    False, $CellContext`sym$235138[$CellContext`Chla, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {63}, {116}, {184}, {
     199}}, $CellContext`sym$235138[$CellContext`Chla, "raw"] = Part[
      $CellContext`sym$235138[All], 
      All, $CellContext`i$235149], $CellContext`sym$235138[$CellContext`Cl, 
      "factorized"] = 
    False, $CellContext`sym$235138[$CellContext`Cl, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {161}, {
     199}}, $CellContext`sym$235138[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$235138[All], 
      All, $CellContext`i$235144], $CellContext`sym$235138[$CellContext`mnO2, 
      "factorized"] = 
    False, $CellContext`sym$235138[$CellContext`mnO2, "missing"] = {{38}, {
     62}}, $CellContext`sym$235138[$CellContext`mnO2, "raw"] = Part[
      $CellContext`sym$235138[All], 
      All, $CellContext`i$235143], $CellContext`sym$235138[$CellContext`mxPH, 
      "factorized"] = 
    False, $CellContext`sym$235138[$CellContext`mxPH, "missing"] = {{
     48}}, $CellContext`sym$235138[$CellContext`mxPH, "raw"] = Part[
      $CellContext`sym$235138[All], 
      All, $CellContext`i$235142], $CellContext`sym$235138[$CellContext`NH4, 
      "factorized"] = 
    False, $CellContext`sym$235138[$CellContext`NH4, "missing"] = {{62}, {
     199}}, $CellContext`sym$235138[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$235138[All], 
      All, $CellContext`i$235146], $CellContext`sym$235138[$CellContext`NO3, 
      "factorized"] = 
    False, $CellContext`sym$235138[$CellContext`NO3, "missing"] = {{62}, {
     199}}, $CellContext`sym$235138[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$235138[All], 
      All, $CellContext`i$235145], $CellContext`sym$235138[$CellContext`oPO4, 
      "factorized"] = 
    False, $CellContext`sym$235138[$CellContext`oPO4, "missing"] = {{62}, {
     199}}, $CellContext`sym$235138[$CellContext`oPO4, "raw"] = Part[
      $CellContext`sym$235138[All], 
      All, $CellContext`i$235147], $CellContext`sym$235138[$CellContext`PO4, 
      "factorized"] = 
    False, $CellContext`sym$235138[$CellContext`PO4, "missing"] = {{28}, {
     199}}, $CellContext`sym$235138[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$235138[All], 
      All, $CellContext`i$235148], \
$CellContext`sym$235138[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$235138[$CellContext`season, "factors"] = 
    Part[{"autumn", "spring", "summer", "winter"}, 
      $CellContext`fordering[$CellContext`sym$235138, $CellContext`season]], \
$CellContext`sym$235138[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$235138[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$235138[All], 
      All, $CellContext`i$235139], $CellContext`sym$235138[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$235138[$CellContext`size, "factors"] = 
    Part[{"large", "medium", "small"}, 
      $CellContext`fordering[$CellContext`sym$235138, $CellContext`size]], \
$CellContext`sym$235138[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$235138[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$235138[All], 
      All, $CellContext`i$235140], $CellContext`sym$235138[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$235138[$CellContext`speed, "factors"] = 
    Part[{"high", "low", "medium"}, 
      $CellContext`fordering[$CellContext`sym$235138, $CellContext`speed]], \
$CellContext`sym$235138[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$235138[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$235138[All], All, $CellContext`i$235141], 
    Attributes[$CellContext`i$235146] = {Temporary}, $CellContext`i$235146 = 
    8, Attributes[$CellContext`i$235149] = {Temporary}, $CellContext`i$235149 = 
    11, Attributes[$CellContext`i$235156] = {
     Temporary}, $CellContext`i$235156 = 18, 
    Attributes[$CellContext`i$235140] = {Temporary}, $CellContext`i$235140 = 
    2, Attributes[$CellContext`i$235147] = {Temporary}, $CellContext`i$235147 = 
    9, Attributes[$CellContext`i$235148] = {Temporary}, $CellContext`i$235148 = 
    10, Attributes[$CellContext`i$235152] = {
     Temporary}, $CellContext`i$235152 = 14, 
    Attributes[$CellContext`i$235153] = {Temporary}, $CellContext`i$235153 = 
    15, Attributes[$CellContext`i$235150] = {
     Temporary}, $CellContext`i$235150 = 12, 
    Attributes[$CellContext`i$235142] = {Temporary}, $CellContext`i$235142 = 
    4, Attributes[$CellContext`i$235145] = {Temporary}, $CellContext`i$235145 = 
    7, Attributes[$CellContext`i$235143] = {Temporary}, $CellContext`i$235143 = 
    5, Attributes[$CellContext`i$235151] = {Temporary}, $CellContext`i$235151 = 
    13, Attributes[$CellContext`i$235139] = {
     Temporary}, $CellContext`i$235139 = 1, 
    Attributes[$CellContext`i$235144] = {Temporary}, $CellContext`i$235144 = 
    6, Attributes[$CellContext`i$235155] = {Temporary}, $CellContext`i$235155 = 
    17, Attributes[$CellContext`i$235154] = {
     Temporary}, $CellContext`i$235154 = 16, 
    Attributes[$CellContext`i$235141] = {Temporary}, $CellContext`i$235141 = 
    3, Attributes[$CellContext`sym$153230] = {
     Temporary}, $CellContext`sym$153230[$CellContext`a1] = Part[
      $CellContext`sym$153230[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$153230[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$153230[$CellContext`a2] = Part[
      $CellContext`sym$153230[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$153230[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$153230[$CellContext`a3] = Part[
      $CellContext`sym$153230[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$153230[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$153230[$CellContext`a4] = Part[
      $CellContext`sym$153230[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$153230[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$153230[$CellContext`a5] = Part[
      $CellContext`sym$153230[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$153230[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$153230[$CellContext`a6] = Part[
      $CellContext`sym$153230[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$153230[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$153230[$CellContext`a7] = Part[
      $CellContext`sym$153230[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$153230[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$153230[All] = $CellContext`med[
     All], $CellContext`sym$153230[$CellContext`Chla] = Part[
      $CellContext`sym$153230[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$153230[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$153230[$CellContext`Cl] = Part[
      $CellContext`sym$153230[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$153230[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$153230[$CellContext`mnO2] = Part[
      $CellContext`sym$153230[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$153230[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$153230[$CellContext`mxPH] = Part[
      $CellContext`sym$153230[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$153230[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$153230[$CellContext`NH4] = Part[
      $CellContext`sym$153230[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$153230[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$153230[$CellContext`NO3] = Part[
      $CellContext`sym$153230[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$153230[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$153230[$CellContext`oPO4] = Part[
      $CellContext`sym$153230[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$153230[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$153230[$CellContext`PO4] = Part[
      $CellContext`sym$153230[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$153230[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$153230[$CellContext`season] = Part[
      $CellContext`sym$153230[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$153230[$CellContext`season, 
         "missing"]]]], $CellContext`sym$153230[$CellContext`size] = Part[
      $CellContext`sym$153230[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$153230[$CellContext`size, 
         "missing"]]]], $CellContext`sym$153230[$CellContext`speed] = Part[
      $CellContext`sym$153230[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$153230[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$153230[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$153230[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$153230, $CellContext`a1]], \
$CellContext`sym$153230[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$153230[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$153230[All], 
      All, $CellContext`i$154789], $CellContext`sym$153230[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$153230[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$153230, $CellContext`a2]], \
$CellContext`sym$153230[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$153230[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$153230[All], 
      All, $CellContext`i$154790], $CellContext`sym$153230[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$153230[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$153230, $CellContext`a3]], \
$CellContext`sym$153230[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$153230[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$153230[All], 
      All, $CellContext`i$154791], $CellContext`sym$153230[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$153230[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$153230, $CellContext`a4]], \
$CellContext`sym$153230[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$153230[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$153230[All], 
      All, $CellContext`i$154792], $CellContext`sym$153230[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$153230[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$153230, $CellContext`a5]], \
$CellContext`sym$153230[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$153230[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$153230[All], 
      All, $CellContext`i$154793], $CellContext`sym$153230[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$153230[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$153230, $CellContext`a6]], \
$CellContext`sym$153230[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$153230[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$153230[All], 
      All, $CellContext`i$154794], $CellContext`sym$153230[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$153230[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$153230, $CellContext`a7]], \
$CellContext`sym$153230[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$153230[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$153230[All], 
      All, $CellContext`i$154795], $CellContext`sym$153230[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$153230[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$153230[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$153230[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$153230, $CellContext`Chla]], \
$CellContext`sym$153230[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$153230[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$153230[All], 
      All, $CellContext`i$154788], $CellContext`sym$153230[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$153230[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$153230, $CellContext`Cl]], \
$CellContext`sym$153230[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$153230[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$153230[All], 
      All, $CellContext`i$154783], $CellContext`sym$153230[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$153230[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$153230, $CellContext`mnO2]], \
$CellContext`sym$153230[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$153230[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$153230[All], 
      All, $CellContext`i$154782], $CellContext`sym$153230[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$153230[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$153230, $CellContext`mxPH]], \
$CellContext`sym$153230[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$153230[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$153230[All], 
      All, $CellContext`i$154781], $CellContext`sym$153230[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$153230[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$153230, $CellContext`NH4]], \
$CellContext`sym$153230[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$153230[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$153230[All], 
      All, $CellContext`i$154785], $CellContext`sym$153230[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$153230[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$153230, $CellContext`NO3]], \
$CellContext`sym$153230[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$153230[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$153230[All], 
      All, $CellContext`i$154784], $CellContext`sym$153230[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$153230[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$153230, $CellContext`oPO4]], \
$CellContext`sym$153230[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$153230[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$153230[All], 
      All, $CellContext`i$154786], $CellContext`sym$153230[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$153230[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$153230, $CellContext`PO4]], \
$CellContext`sym$153230[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$153230[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$153230[All], 
      All, $CellContext`i$154787], \
$CellContext`sym$153230[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$153230[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$153230, $CellContext`season]], \
$CellContext`sym$153230[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$153230[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$153230[All], 
      All, $CellContext`i$153231], $CellContext`sym$153230[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$153230[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$153230, $CellContext`size]], \
$CellContext`sym$153230[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$153230[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$153230[All], 
      All, $CellContext`i$154779], $CellContext`sym$153230[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$153230[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$153230, $CellContext`speed]], \
$CellContext`sym$153230[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$153230[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$153230[All], All, $CellContext`i$154780], 
    Attributes[$CellContext`i$154781] = {Temporary}, $CellContext`i$154781 = 
    4, Attributes[$CellContext`i$154787] = {Temporary}, $CellContext`i$154787 = 
    10, Attributes[$CellContext`i$154783] = {
     Temporary}, $CellContext`i$154783 = 6, 
    Attributes[$CellContext`i$154786] = {Temporary}, $CellContext`i$154786 = 
    9, Attributes[$CellContext`i$154780] = {Temporary}, $CellContext`i$154780 = 
    3, Attributes[$CellContext`i$153231] = {Temporary}, $CellContext`i$153231 = 
    1, Attributes[$CellContext`i$154788] = {Temporary}, $CellContext`i$154788 = 
    11, Attributes[$CellContext`i$154785] = {
     Temporary}, $CellContext`i$154785 = 8, 
    Attributes[$CellContext`i$154784] = {Temporary}, $CellContext`i$154784 = 
    7, Attributes[$CellContext`i$154782] = {Temporary}, $CellContext`i$154782 = 
    5, Attributes[$CellContext`i$154795] = {Temporary}, $CellContext`i$154795 = 
    18, Attributes[$CellContext`i$154790] = {
     Temporary}, $CellContext`i$154790 = 13, 
    Attributes[$CellContext`i$154779] = {Temporary}, $CellContext`i$154779 = 
    2, Attributes[$CellContext`i$154793] = {Temporary}, $CellContext`i$154793 = 
    16, Attributes[$CellContext`i$154791] = {
     Temporary}, $CellContext`i$154791 = 14, 
    Attributes[$CellContext`i$154794] = {Temporary}, $CellContext`i$154794 = 
    17, Attributes[$CellContext`i$154792] = {
     Temporary}, $CellContext`i$154792 = 15, 
    Attributes[$CellContext`i$154789] = {Temporary}, $CellContext`i$154789 = 
    12, Attributes[$CellContext`sym$115269] = {
     Temporary}, $CellContext`sym$115269[$CellContext`a1] = Part[
      $CellContext`sym$115269[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$115269[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$115269[$CellContext`a2] = Part[
      $CellContext`sym$115269[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$115269[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$115269[$CellContext`a3] = Part[
      $CellContext`sym$115269[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$115269[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$115269[$CellContext`a4] = Part[
      $CellContext`sym$115269[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$115269[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$115269[$CellContext`a5] = Part[
      $CellContext`sym$115269[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$115269[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$115269[$CellContext`a6] = Part[
      $CellContext`sym$115269[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$115269[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$115269[$CellContext`a7] = Part[
      $CellContext`sym$115269[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$115269[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$115269[All] = $CellContext`med[
     All], $CellContext`sym$115269[$CellContext`Chla] = Part[
      $CellContext`sym$115269[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$115269[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$115269[$CellContext`Cl] = Part[
      $CellContext`sym$115269[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$115269[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$115269[$CellContext`mnO2] = Part[
      $CellContext`sym$115269[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$115269[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$115269[$CellContext`mxPH] = Part[
      $CellContext`sym$115269[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$115269[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$115269[$CellContext`NH4] = Part[
      $CellContext`sym$115269[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$115269[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$115269[$CellContext`NO3] = Part[
      $CellContext`sym$115269[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$115269[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$115269[$CellContext`oPO4] = Part[
      $CellContext`sym$115269[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$115269[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$115269[$CellContext`PO4] = Part[
      $CellContext`sym$115269[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$115269[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$115269[$CellContext`season] = Part[
      $CellContext`sym$115269[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$115269[$CellContext`season, 
         "missing"]]]], $CellContext`sym$115269[$CellContext`size] = Part[
      $CellContext`sym$115269[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$115269[$CellContext`size, 
         "missing"]]]], $CellContext`sym$115269[$CellContext`speed] = Part[
      $CellContext`sym$115269[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$115269[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$115269[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$115269[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$115269, $CellContext`a1]], \
$CellContext`sym$115269[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$115269[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$115269[All], 
      All, $CellContext`i$116828], $CellContext`sym$115269[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$115269[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$115269, $CellContext`a2]], \
$CellContext`sym$115269[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$115269[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$115269[All], 
      All, $CellContext`i$116829], $CellContext`sym$115269[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$115269[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$115269, $CellContext`a3]], \
$CellContext`sym$115269[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$115269[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$115269[All], 
      All, $CellContext`i$116830], $CellContext`sym$115269[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$115269[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$115269, $CellContext`a4]], \
$CellContext`sym$115269[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$115269[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$115269[All], 
      All, $CellContext`i$116831], $CellContext`sym$115269[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$115269[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$115269, $CellContext`a5]], \
$CellContext`sym$115269[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$115269[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$115269[All], 
      All, $CellContext`i$116832], $CellContext`sym$115269[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$115269[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$115269, $CellContext`a6]], \
$CellContext`sym$115269[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$115269[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$115269[All], 
      All, $CellContext`i$116833], $CellContext`sym$115269[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$115269[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$115269, $CellContext`a7]], \
$CellContext`sym$115269[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$115269[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$115269[All], 
      All, $CellContext`i$116834], $CellContext`sym$115269[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$115269[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$115269[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$115269[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$115269, $CellContext`Chla]], \
$CellContext`sym$115269[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$115269[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$115269[All], 
      All, $CellContext`i$116827], $CellContext`sym$115269[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$115269[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$115269, $CellContext`Cl]], \
$CellContext`sym$115269[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$115269[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$115269[All], 
      All, $CellContext`i$116822], $CellContext`sym$115269[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$115269[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$115269, $CellContext`mnO2]], \
$CellContext`sym$115269[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$115269[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$115269[All], 
      All, $CellContext`i$116821], $CellContext`sym$115269[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$115269[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$115269, $CellContext`mxPH]], \
$CellContext`sym$115269[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$115269[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$115269[All], 
      All, $CellContext`i$116820], $CellContext`sym$115269[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$115269[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$115269, $CellContext`NH4]], \
$CellContext`sym$115269[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$115269[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$115269[All], 
      All, $CellContext`i$116824], $CellContext`sym$115269[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$115269[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$115269, $CellContext`NO3]], \
$CellContext`sym$115269[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$115269[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$115269[All], 
      All, $CellContext`i$116823], $CellContext`sym$115269[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$115269[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$115269, $CellContext`oPO4]], \
$CellContext`sym$115269[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$115269[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$115269[All], 
      All, $CellContext`i$116825], $CellContext`sym$115269[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$115269[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$115269, $CellContext`PO4]], \
$CellContext`sym$115269[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$115269[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$115269[All], 
      All, $CellContext`i$116826], \
$CellContext`sym$115269[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$115269[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$115269, $CellContext`season]], \
$CellContext`sym$115269[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$115269[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$115269[All], 
      All, $CellContext`i$115270], $CellContext`sym$115269[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$115269[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$115269, $CellContext`size]], \
$CellContext`sym$115269[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$115269[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$115269[All], 
      All, $CellContext`i$116818], $CellContext`sym$115269[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$115269[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$115269, $CellContext`speed]], \
$CellContext`sym$115269[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$115269[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$115269[All], All, $CellContext`i$116819], 
    Attributes[$CellContext`i$116825] = {Temporary}, $CellContext`i$116825 = 
    9, Attributes[$CellContext`i$116819] = {Temporary}, $CellContext`i$116819 = 
    3, Attributes[$CellContext`i$116828] = {Temporary}, $CellContext`i$116828 = 
    12, Attributes[$CellContext`i$115270] = {
     Temporary}, $CellContext`i$115270 = 1, 
    Attributes[$CellContext`i$116818] = {Temporary}, $CellContext`i$116818 = 
    2, Attributes[$CellContext`i$116826] = {Temporary}, $CellContext`i$116826 = 
    10, Attributes[$CellContext`i$116830] = {
     Temporary}, $CellContext`i$116830 = 14, 
    Attributes[$CellContext`i$116831] = {Temporary}, $CellContext`i$116831 = 
    15, Attributes[$CellContext`i$116833] = {
     Temporary}, $CellContext`i$116833 = 17, 
    Attributes[$CellContext`i$116822] = {Temporary}, $CellContext`i$116822 = 
    6, Attributes[$CellContext`i$116834] = {Temporary}, $CellContext`i$116834 = 
    18, Attributes[$CellContext`i$116824] = {
     Temporary}, $CellContext`i$116824 = 8, 
    Attributes[$CellContext`i$116827] = {Temporary}, $CellContext`i$116827 = 
    11, Attributes[$CellContext`i$116820] = {
     Temporary}, $CellContext`i$116820 = 4, 
    Attributes[$CellContext`i$116829] = {Temporary}, $CellContext`i$116829 = 
    13, Attributes[$CellContext`i$116821] = {
     Temporary}, $CellContext`i$116821 = 5, 
    Attributes[$CellContext`i$116832] = {Temporary}, $CellContext`i$116832 = 
    16, Attributes[$CellContext`i$116823] = {
     Temporary}, $CellContext`i$116823 = 7, 
    Attributes[$CellContext`sym$217987] = {
     Temporary}, $CellContext`sym$217987[$CellContext`a1] = Part[
      $CellContext`sym$217987[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$217987[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$217987[$CellContext`a2] = Part[
      $CellContext`sym$217987[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$217987[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$217987[$CellContext`a3] = Part[
      $CellContext`sym$217987[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$217987[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$217987[$CellContext`a4] = Part[
      $CellContext`sym$217987[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$217987[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$217987[$CellContext`a5] = Part[
      $CellContext`sym$217987[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$217987[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$217987[$CellContext`a6] = Part[
      $CellContext`sym$217987[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$217987[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$217987[$CellContext`a7] = Part[
      $CellContext`sym$217987[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$217987[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$217987[All] = $CellContext`med[
     All], $CellContext`sym$217987[$CellContext`Chla] = Part[
      $CellContext`sym$217987[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$217987[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$217987[$CellContext`Cl] = Part[
      $CellContext`sym$217987[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$217987[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$217987[$CellContext`mnO2] = Part[
      $CellContext`sym$217987[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$217987[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$217987[$CellContext`mxPH] = Part[
      $CellContext`sym$217987[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$217987[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$217987[$CellContext`NH4] = Part[
      $CellContext`sym$217987[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$217987[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$217987[$CellContext`NO3] = Part[
      $CellContext`sym$217987[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$217987[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$217987[$CellContext`oPO4] = Part[
      $CellContext`sym$217987[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$217987[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$217987[$CellContext`PO4] = Part[
      $CellContext`sym$217987[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$217987[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$217987[$CellContext`season] = Part[
      $CellContext`sym$217987[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$217987[$CellContext`season, 
         "missing"]]]], $CellContext`sym$217987[$CellContext`size] = Part[
      $CellContext`sym$217987[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$217987[$CellContext`size, 
         "missing"]]]], $CellContext`sym$217987[$CellContext`speed] = Part[
      $CellContext`sym$217987[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$217987[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$217987[$CellContext`a1, 
      "factorized"] = 
    True, $CellContext`sym$217987[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$217987, $CellContext`a1]], \
$CellContext`sym$217987[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$217987[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$217987[All], 
      All, $CellContext`i$219546], $CellContext`sym$217987[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$217987[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$217987, $CellContext`a2]], \
$CellContext`sym$217987[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$217987[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$217987[All], 
      All, $CellContext`i$219547], $CellContext`sym$217987[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$217987[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$217987, $CellContext`a3]], \
$CellContext`sym$217987[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$217987[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$217987[All], 
      All, $CellContext`i$219548], $CellContext`sym$217987[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$217987[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$217987, $CellContext`a4]], \
$CellContext`sym$217987[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$217987[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$217987[All], 
      All, $CellContext`i$219549], $CellContext`sym$217987[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$217987[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$217987, $CellContext`a5]], \
$CellContext`sym$217987[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$217987[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$217987[All], 
      All, $CellContext`i$219550], $CellContext`sym$217987[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$217987[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$217987, $CellContext`a6]], \
$CellContext`sym$217987[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$217987[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$217987[All], 
      All, $CellContext`i$219551], $CellContext`sym$217987[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$217987[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$217987, $CellContext`a7]], \
$CellContext`sym$217987[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$217987[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$217987[All], 
      All, $CellContext`i$219552], $CellContext`sym$217987[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$217987[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$217987[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$217987[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$217987, $CellContext`Chla]], \
$CellContext`sym$217987[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$217987[$CellContext`Chla, "raw"] = 
    Part[
      $CellContext`sym$217987[All], 
      All, $CellContext`i$219545], $CellContext`sym$217987[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$217987[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$217987, $CellContext`Cl]], \
$CellContext`sym$217987[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$217987[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$217987[All], 
      All, $CellContext`i$219540], $CellContext`sym$217987[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$217987[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$217987, $CellContext`mnO2]], \
$CellContext`sym$217987[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$217987[$CellContext`mnO2, "raw"] = 
    Part[
      $CellContext`sym$217987[All], 
      All, $CellContext`i$219539], $CellContext`sym$217987[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$217987[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$217987, $CellContext`mxPH]], \
$CellContext`sym$217987[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$217987[$CellContext`mxPH, "raw"] = 
    Part[
      $CellContext`sym$217987[All], 
      All, $CellContext`i$219538], $CellContext`sym$217987[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$217987[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$217987, $CellContext`NH4]], \
$CellContext`sym$217987[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$217987[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$217987[All], 
      All, $CellContext`i$219542], $CellContext`sym$217987[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$217987[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$217987, $CellContext`NO3]], \
$CellContext`sym$217987[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$217987[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$217987[All], 
      All, $CellContext`i$219541], $CellContext`sym$217987[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$217987[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$217987, $CellContext`oPO4]], \
$CellContext`sym$217987[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$217987[$CellContext`oPO4, "raw"] = 
    Part[
      $CellContext`sym$217987[All], 
      All, $CellContext`i$219543], $CellContext`sym$217987[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$217987[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$217987, $CellContext`PO4]], \
$CellContext`sym$217987[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$217987[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$217987[All], 
      All, $CellContext`i$219544], \
$CellContext`sym$217987[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$217987[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$217987, $CellContext`season]], \
$CellContext`sym$217987[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$217987[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$217987[All], 
      All, $CellContext`i$217988], $CellContext`sym$217987[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$217987[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$217987, $CellContext`size]], \
$CellContext`sym$217987[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$217987[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$217987[All], 
      All, $CellContext`i$219536], $CellContext`sym$217987[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$217987[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$217987, $CellContext`speed]], \
$CellContext`sym$217987[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$217987[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$217987[All], All, $CellContext`i$219537], 
    Attributes[$CellContext`i$219543] = {Temporary}, $CellContext`i$219543 = 
    9, Attributes[$CellContext`i$219537] = {Temporary}, $CellContext`i$219537 = 
    3, Attributes[$CellContext`i$219544] = {Temporary}, $CellContext`i$219544 = 
    10, Attributes[$CellContext`i$217988] = {
     Temporary}, $CellContext`i$217988 = 1, 
    Attributes[$CellContext`i$219548] = {Temporary}, $CellContext`i$219548 = 
    14, Attributes[$CellContext`i$219552] = {
     Temporary}, $CellContext`i$219552 = 18, 
    Attributes[$CellContext`i$219546] = {Temporary}, $CellContext`i$219546 = 
    12, Attributes[$CellContext`i$219540] = {
     Temporary}, $CellContext`i$219540 = 6, 
    Attributes[$CellContext`i$219538] = {Temporary}, $CellContext`i$219538 = 
    4, Attributes[$CellContext`i$219536] = {Temporary}, $CellContext`i$219536 = 
    2, Attributes[$CellContext`i$219547] = {Temporary}, $CellContext`i$219547 = 
    13, Attributes[$CellContext`i$219549] = {
     Temporary}, $CellContext`i$219549 = 15, 
    Attributes[$CellContext`i$219539] = {Temporary}, $CellContext`i$219539 = 
    5, Attributes[$CellContext`i$219551] = {Temporary}, $CellContext`i$219551 = 
    17, Attributes[$CellContext`i$219545] = {
     Temporary}, $CellContext`i$219545 = 11, 
    Attributes[$CellContext`i$219541] = {Temporary}, $CellContext`i$219541 = 
    7, Attributes[$CellContext`i$219550] = {Temporary}, $CellContext`i$219550 = 
    16, Attributes[$CellContext`i$219542] = {
     Temporary}, $CellContext`i$219542 = 8, 
    Attributes[$CellContext`sym$234272] = {
     Temporary}, $CellContext`sym$234272[$CellContext`a1] = Part[
      $CellContext`sym$234272[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$234272[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$234272[$CellContext`a2] = Part[
      $CellContext`sym$234272[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$234272[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$234272[$CellContext`a3] = Part[
      $CellContext`sym$234272[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$234272[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$234272[$CellContext`a4] = Part[
      $CellContext`sym$234272[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$234272[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$234272[$CellContext`a5] = Part[
      $CellContext`sym$234272[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$234272[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$234272[$CellContext`a6] = Part[
      $CellContext`sym$234272[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$234272[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$234272[$CellContext`a7] = Part[
      $CellContext`sym$234272[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$234272[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$234272[
     All] = {{"winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 
       170., 50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
      "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
       558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
      "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 125.667,
        187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
      "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 61.182, 
       138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
      "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222, 
       97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
      "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
       56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
      "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
       111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
      "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 44.667, 
       77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
      "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 71., 
       5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 0.8, 
       17., 0., 0., 2.9, 0., 0., 1.7}, {
      "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 20.75, 
       0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
      "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 19.,
        0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
      "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 41., 
       43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
      "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5, 
       31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
      "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 0.3, 
       52.2, 5., 7.8, 0., 4., 0., 0.}, {
      "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 98.25, 
       1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50., 
       1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
      "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 57.833, 
       0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
      "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 0.8, 
       50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
      "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
       564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
      "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 586.,
        16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
      "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 0.5, 
       15.5, 0., 0., 2.3, 0., 0., 0.}, {
      "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 7.6,
        23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
      "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
       27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
      "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 1.5,
        13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
      "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 44.136, 
       3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
      "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 0.5, 
       29.7, 0., 0., 4.9, 0., 0., 0.}, {
      "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
       Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
      "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 17.1,
        0., 19.6, 0., 0., 0., 2.5}, {
      "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5, 
       33.9, 1., 14.6, 0., 0., 0., 0.}, {
      "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 4.9, 
       3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
      "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 2.8, 
       6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
      "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 130.75, 
       5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
      "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47., 
       2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
      "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23., 
       0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
      "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 58.875, 
       84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
      "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 0.2,
        66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
       Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0., 
       0.}, {
      "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 196.62, 
       253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
      "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
       182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
      "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001, 
       296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
      "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 59.429,
        175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
      "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
       344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
      "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 276.85001, 
       326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
      "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 40.667, 
       3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
      "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 3.3, 
       29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
      "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 0.8, 
       54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
       Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 0., 
       0.}, {"spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121.,
        2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 20.812,
        12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
      "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
       49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
      "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 22.9, 
       4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
      "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 11.8, 
       0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818, 
       0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
      "winter", "small", "high", 6.6, 10.8, 
       Missing[], 3.245, 10., 1., 6.5, 
       Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "medium", 5.6, 11.8, 
       Missing[], 2.22, 5., 1., 1., 
       Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 5.7, 10.8, 
       Missing[], 2.55, 10., 1., 4., 
       Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
      "spring", "small", "high", 6.6, 9.5, 
       Missing[], 1.32, 20., 1., 6., 
       Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
      "summer", "small", "high", 6.6, 10.8, 
       Missing[], 2.64, 10., 2., 11., 
       Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
      "autumn", "small", "medium", 6.6, 11.3, 
       Missing[], 4.17, 10., 1., 6., 
       Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
      "spring", "small", "medium", 6.5, 10.4, 
       Missing[], 5.97, 10., 2., 14., 
       Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
      "summer", "small", "medium", 6.4, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 14., 
       Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
      "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 6.667, 
       Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75, 1.,
        20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
      "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2, 
       0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
      "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 0.6,
        55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
      "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 10.75, 
       2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
      "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 0.5, 
       64.2, 0., 3., 0., 0., 0., 0.}, {
      "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75, 
       351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
      "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
       209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
      "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 151.125,
        279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
      "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
       152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
      "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
       58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
      "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
       249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
      "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 100., 
       233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
      "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 215.5, 
       18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
      "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 25.167, 
       102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
      "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
       105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
      "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
       111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
      "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 1.3, 
       6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
      "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 56.667, 
       2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
      "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 4.3,
        1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
      "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
       104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
      "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 69.93,
        3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
      "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
       214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
      "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
       254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
      "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 57.6,
        169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
      "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
       412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
      "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
       282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
      "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
       197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
      "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 267.75, 
       391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
      "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 191.75, 
       265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
      "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
       232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
      "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 144.66701, 
       244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
      "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 218., 
       6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
      "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 138.5,
        20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
      "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222, 
       239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
      "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
       235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
      "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75, 
       205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
      "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 31.333, 
       211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
      "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625, 
       186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
      "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 12.889, 
       154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
      "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 51.111, 
       183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
      "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
       292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
      "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
       285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
      "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
       201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
      "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
       275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
      "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
       124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
      "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 60.833, 
       141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
      "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71., 
       132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
      "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
       17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
      "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 0.3, 
       46.6, 0., 2.5, 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 8.692, 
       16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
      "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 37.857, 
       102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
      "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
       86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
      "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
       10.111, 
       Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 16.833, 
       18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
      "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545, 
       13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
      "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 261.60001, 
       432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
      "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
       320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
      "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 144., 
       287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
      "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
       166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
      "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
       222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
      "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 36.909, 
       122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
      "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556, 
       127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
      "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
       89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
      "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 55., 
       284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
      "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 102.333, 
       277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
      "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 75.875, 
       177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
      "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
       72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
      "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 48.667, 
       82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
      "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 48.625, 
       66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
      "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 23., 
       173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
      "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 317., 
       5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
      "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 84., 
       4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
      "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 2., 
       10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
      "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 88.5, 
       2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
      "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115., 
       11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
      "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 98.143, 
       2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
      "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
       143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
      "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
       197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
      "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 1., 
       19., 0., 22., 5., 1.1, 5.4, 0.}, {
      "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 10.583, 
       23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
      "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 200.231, 
       19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
      "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 77.333, 
       147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
      "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5, 
       276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
      "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
       123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
      "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 75.207,
        23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
      "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 116.2,
        7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
      "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
       188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
      "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
       72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
      "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 16., 
       0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
      "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 34., 
       53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
      "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 27.5, 
       76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
      "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
       58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
      "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 175.66701, 
       361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
      "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
       22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
      "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 26.8,
        0., 28., 0., 0., 0., 0., 15.1}, {
      "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
       54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
      "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333, 
       34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
      "spring", "large", "low", 9., 5.8, 
       Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 0., 
       0.}, {"spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
       151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
      "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
       269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
      "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 46.438, 
       81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
      "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 85., 
       2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
      "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 66.4, 
       171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
      "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 102.364, 
       232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
      "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 84.3, 
       146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
      "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
       246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
      "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 205.636, 
       219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
      "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 236.39999,
        272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
      "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 1081.66003, 
       346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 5.9, 1.7}, {
      "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 82.222,
        167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
      "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 64.389, 
       137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
      "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 87.333,
        194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
      "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
       159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
      "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 21.3, 
       1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
      "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 0.6,
        37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
      "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
       14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
      "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222, 7.,
        1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 0.8, 
       50.4, 3.8, 0., 0., 0., 0., 0.}, {
      "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 7.654, 
       4., 56.8, 5., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 2.86, 
       17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
      "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 56.091, 
       Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
      "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
       52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
      "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 104.727, 
       228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
      "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 85.4, 
       17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
      "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 87.125,
        14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
      "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 101.455, 
       18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
      "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 50.889, 
       127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
      "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
       81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
      "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 19.727, 
       50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
      "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111, 
       120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
      "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 51.111, 
       91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
      "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 19.111, 
       61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
      "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625, 
       79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
      "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333, 
       75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
      "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333, 
       140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
      "winter", "large", "medium", 8., 7.6, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
      "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
       140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 
       5.8}}, $CellContext`sym$234272[$CellContext`Chla] = Part[
      $CellContext`sym$234272[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$234272[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$234272[$CellContext`Cl] = Part[
      $CellContext`sym$234272[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$234272[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$234272[$CellContext`mnO2] = Part[
      $CellContext`sym$234272[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$234272[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$234272[$CellContext`mxPH] = Part[
      $CellContext`sym$234272[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$234272[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$234272[$CellContext`NH4] = Part[
      $CellContext`sym$234272[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$234272[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$234272[$CellContext`NO3] = Part[
      $CellContext`sym$234272[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$234272[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$234272[$CellContext`oPO4] = Part[
      $CellContext`sym$234272[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$234272[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$234272[$CellContext`PO4] = Part[
      $CellContext`sym$234272[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$234272[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$234272[$CellContext`season] = Part[
      $CellContext`sym$234272[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$234272[$CellContext`season, 
         "missing"]]]], $CellContext`sym$234272[$CellContext`size] = Part[
      $CellContext`sym$234272[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$234272[$CellContext`size, 
         "missing"]]]], $CellContext`sym$234272[$CellContext`speed] = Part[
      $CellContext`sym$234272[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$234272[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$234272[$CellContext`a1, 
      "factorized"] = 
    False, $CellContext`sym$234272[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$234272[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$234272[All], 
      All, $CellContext`i$234284], $CellContext`sym$234272[$CellContext`a2, 
      "factorized"] = 
    False, $CellContext`sym$234272[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$234272[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$234272[All], 
      All, $CellContext`i$234285], $CellContext`sym$234272[$CellContext`a3, 
      "factorized"] = 
    False, $CellContext`sym$234272[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$234272[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$234272[All], 
      All, $CellContext`i$234286], $CellContext`sym$234272[$CellContext`a4, 
      "factorized"] = 
    False, $CellContext`sym$234272[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$234272[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$234272[All], 
      All, $CellContext`i$234287], $CellContext`sym$234272[$CellContext`a5, 
      "factorized"] = 
    False, $CellContext`sym$234272[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$234272[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$234272[All], 
      All, $CellContext`i$234288], $CellContext`sym$234272[$CellContext`a6, 
      "factorized"] = 
    False, $CellContext`sym$234272[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$234272[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$234272[All], 
      All, $CellContext`i$234289], $CellContext`sym$234272[$CellContext`a7, 
      "factorized"] = 
    False, $CellContext`sym$234272[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$234272[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$234272[All], 
      All, $CellContext`i$234290], $CellContext`sym$234272[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$234272[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed}, $CellContext`sym$234272[$CellContext`Chla, "factorized"] = 
    False, $CellContext`sym$234272[$CellContext`Chla, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {63}, {116}, {184}, {
     199}}, $CellContext`sym$234272[$CellContext`Chla, "raw"] = Part[
      $CellContext`sym$234272[All], 
      All, $CellContext`i$234283], $CellContext`sym$234272[$CellContext`Cl, 
      "factorized"] = 
    False, $CellContext`sym$234272[$CellContext`Cl, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {161}, {
     199}}, $CellContext`sym$234272[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$234272[All], 
      All, $CellContext`i$234278], $CellContext`sym$234272[$CellContext`mnO2, 
      "factorized"] = 
    False, $CellContext`sym$234272[$CellContext`mnO2, "missing"] = {{38}, {
     62}}, $CellContext`sym$234272[$CellContext`mnO2, "raw"] = Part[
      $CellContext`sym$234272[All], 
      All, $CellContext`i$234277], $CellContext`sym$234272[$CellContext`mxPH, 
      "factorized"] = 
    False, $CellContext`sym$234272[$CellContext`mxPH, "missing"] = {{
     48}}, $CellContext`sym$234272[$CellContext`mxPH, "raw"] = Part[
      $CellContext`sym$234272[All], 
      All, $CellContext`i$234276], $CellContext`sym$234272[$CellContext`NH4, 
      "factorized"] = 
    False, $CellContext`sym$234272[$CellContext`NH4, "missing"] = {{62}, {
     199}}, $CellContext`sym$234272[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$234272[All], 
      All, $CellContext`i$234280], $CellContext`sym$234272[$CellContext`NO3, 
      "factorized"] = 
    False, $CellContext`sym$234272[$CellContext`NO3, "missing"] = {{62}, {
     199}}, $CellContext`sym$234272[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$234272[All], 
      All, $CellContext`i$234279], $CellContext`sym$234272[$CellContext`oPO4, 
      "factorized"] = 
    False, $CellContext`sym$234272[$CellContext`oPO4, "missing"] = {{62}, {
     199}}, $CellContext`sym$234272[$CellContext`oPO4, "raw"] = Part[
      $CellContext`sym$234272[All], 
      All, $CellContext`i$234281], $CellContext`sym$234272[$CellContext`PO4, 
      "factorized"] = 
    False, $CellContext`sym$234272[$CellContext`PO4, "missing"] = {{28}, {
     199}}, $CellContext`sym$234272[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$234272[All], 
      All, $CellContext`i$234282], \
$CellContext`sym$234272[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$234272[$CellContext`season, "factors"] = 
    Part[{"autumn", "spring", "summer", "winter"}, 
      $CellContext`fordering[$CellContext`sym$234272, $CellContext`season]], \
$CellContext`sym$234272[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$234272[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$234272[All], 
      All, $CellContext`i$234273], $CellContext`sym$234272[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$234272[$CellContext`size, "factors"] = 
    Part[{"large", "medium", "small"}, 
      $CellContext`fordering[$CellContext`sym$234272, $CellContext`size]], \
$CellContext`sym$234272[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$234272[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$234272[All], 
      All, $CellContext`i$234274], $CellContext`sym$234272[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$234272[$CellContext`speed, "factors"] = 
    Part[{"high", "low", "medium"}, 
      $CellContext`fordering[$CellContext`sym$234272, $CellContext`speed]], \
$CellContext`sym$234272[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$234272[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$234272[All], All, $CellContext`i$234275], 
    Attributes[$CellContext`i$234279] = {Temporary}, $CellContext`i$234279 = 
    7, Attributes[$CellContext`i$234285] = {Temporary}, $CellContext`i$234285 = 
    13, Attributes[$CellContext`i$234283] = {
     Temporary}, $CellContext`i$234283 = 11, 
    Attributes[$CellContext`i$234289] = {Temporary}, $CellContext`i$234289 = 
    17, Attributes[$CellContext`i$234286] = {
     Temporary}, $CellContext`i$234286 = 14, 
    Attributes[$CellContext`i$234282] = {Temporary}, $CellContext`i$234282 = 
    10, Attributes[$CellContext`i$234278] = {
     Temporary}, $CellContext`i$234278 = 6, 
    Attributes[$CellContext`i$234281] = {Temporary}, $CellContext`i$234281 = 
    9, Attributes[$CellContext`i$234273] = {Temporary}, $CellContext`i$234273 = 
    1, Attributes[$CellContext`i$234274] = {Temporary}, $CellContext`i$234274 = 
    2, Attributes[$CellContext`i$234288] = {Temporary}, $CellContext`i$234288 = 
    16, Attributes[$CellContext`i$234276] = {
     Temporary}, $CellContext`i$234276 = 4, 
    Attributes[$CellContext`i$234280] = {Temporary}, $CellContext`i$234280 = 
    8, Attributes[$CellContext`i$234287] = {Temporary}, $CellContext`i$234287 = 
    15, Attributes[$CellContext`i$234290] = {
     Temporary}, $CellContext`i$234290 = 18, 
    Attributes[$CellContext`i$234277] = {Temporary}, $CellContext`i$234277 = 
    5, Attributes[$CellContext`i$234284] = {Temporary}, $CellContext`i$234284 = 
    12, Attributes[$CellContext`i$234275] = {
     Temporary}, $CellContext`i$234275 = 3, 
    Attributes[$CellContext`sym$81774] = {
     Temporary}, $CellContext`sym$81774[$CellContext`a1] = Part[
      $CellContext`sym$81774[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$81774[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$81774[$CellContext`a2] = Part[
      $CellContext`sym$81774[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$81774[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$81774[$CellContext`a3] = Part[
      $CellContext`sym$81774[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$81774[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$81774[$CellContext`a4] = Part[
      $CellContext`sym$81774[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$81774[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$81774[$CellContext`a5] = Part[
      $CellContext`sym$81774[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$81774[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$81774[$CellContext`a6] = Part[
      $CellContext`sym$81774[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$81774[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$81774[$CellContext`a7] = Part[
      $CellContext`sym$81774[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$81774[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$81774[All] = $CellContext`med[
     All], $CellContext`sym$81774[$CellContext`Chla] = Part[
      $CellContext`sym$81774[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$81774[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$81774[$CellContext`Cl] = Part[
      $CellContext`sym$81774[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$81774[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$81774[$CellContext`mnO2] = Part[
      $CellContext`sym$81774[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$81774[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$81774[$CellContext`mxPH] = Part[
      $CellContext`sym$81774[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$81774[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$81774[$CellContext`NH4] = Part[
      $CellContext`sym$81774[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$81774[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$81774[$CellContext`NO3] = Part[
      $CellContext`sym$81774[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$81774[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$81774[$CellContext`oPO4] = Part[
      $CellContext`sym$81774[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$81774[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$81774[$CellContext`PO4] = Part[
      $CellContext`sym$81774[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$81774[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$81774[$CellContext`season] = Part[
      $CellContext`sym$81774[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$81774[$CellContext`season, 
         "missing"]]]], $CellContext`sym$81774[$CellContext`size] = Part[
      $CellContext`sym$81774[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$81774[$CellContext`size, 
         "missing"]]]], $CellContext`sym$81774[$CellContext`speed] = Part[
      $CellContext`sym$81774[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[
         $CellContext`med[All]]], 
       Flatten[
        $CellContext`sym$81774[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$81774[$CellContext`a1, "factorized"] = 
    True, $CellContext`sym$81774[$CellContext`a1, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$81774, $CellContext`a1]], \
$CellContext`sym$81774[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$81774[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$81774[All], 
      All, $CellContext`i$83333], $CellContext`sym$81774[$CellContext`a2, 
      "factorized"] = 
    True, $CellContext`sym$81774[$CellContext`a2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$81774, $CellContext`a2]], \
$CellContext`sym$81774[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$81774[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$81774[All], 
      All, $CellContext`i$83334], $CellContext`sym$81774[$CellContext`a3, 
      "factorized"] = 
    True, $CellContext`sym$81774[$CellContext`a3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$81774, $CellContext`a3]], \
$CellContext`sym$81774[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$81774[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$81774[All], 
      All, $CellContext`i$83335], $CellContext`sym$81774[$CellContext`a4, 
      "factorized"] = 
    True, $CellContext`sym$81774[$CellContext`a4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$81774, $CellContext`a4]], \
$CellContext`sym$81774[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$81774[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$81774[All], 
      All, $CellContext`i$83336], $CellContext`sym$81774[$CellContext`a5, 
      "factorized"] = 
    True, $CellContext`sym$81774[$CellContext`a5, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$81774, $CellContext`a5]], \
$CellContext`sym$81774[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$81774[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$81774[All], 
      All, $CellContext`i$83337], $CellContext`sym$81774[$CellContext`a6, 
      "factorized"] = 
    True, $CellContext`sym$81774[$CellContext`a6, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$81774, $CellContext`a6]], \
$CellContext`sym$81774[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$81774[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$81774[All], 
      All, $CellContext`i$83338], $CellContext`sym$81774[$CellContext`a7, 
      "factorized"] = 
    True, $CellContext`sym$81774[$CellContext`a7, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$81774, $CellContext`a7]], \
$CellContext`sym$81774[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$81774[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$81774[All], 
      All, $CellContext`i$83339], $CellContext`sym$81774[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$81774[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$81774[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$81774[$CellContext`Chla, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$81774, $CellContext`Chla]], \
$CellContext`sym$81774[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$81774[$CellContext`Chla, "raw"] = Part[
      $CellContext`sym$81774[All], 
      All, $CellContext`i$83332], $CellContext`sym$81774[$CellContext`Cl, 
      "factorized"] = 
    True, $CellContext`sym$81774[$CellContext`Cl, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$81774, $CellContext`Cl]], \
$CellContext`sym$81774[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$81774[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$81774[All], 
      All, $CellContext`i$83327], $CellContext`sym$81774[$CellContext`mnO2, 
      "factorized"] = 
    True, $CellContext`sym$81774[$CellContext`mnO2, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$81774, $CellContext`mnO2]], \
$CellContext`sym$81774[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$81774[$CellContext`mnO2, "raw"] = Part[
      $CellContext`sym$81774[All], 
      All, $CellContext`i$83326], $CellContext`sym$81774[$CellContext`mxPH, 
      "factorized"] = 
    True, $CellContext`sym$81774[$CellContext`mxPH, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$81774, $CellContext`mxPH]], \
$CellContext`sym$81774[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$81774[$CellContext`mxPH, "raw"] = Part[
      $CellContext`sym$81774[All], 
      All, $CellContext`i$83325], $CellContext`sym$81774[$CellContext`NH4, 
      "factorized"] = 
    True, $CellContext`sym$81774[$CellContext`NH4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$81774, $CellContext`NH4]], \
$CellContext`sym$81774[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$81774[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$81774[All], 
      All, $CellContext`i$83329], $CellContext`sym$81774[$CellContext`NO3, 
      "factorized"] = 
    True, $CellContext`sym$81774[$CellContext`NO3, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$81774, $CellContext`NO3]], \
$CellContext`sym$81774[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$81774[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$81774[All], 
      All, $CellContext`i$83328], $CellContext`sym$81774[$CellContext`oPO4, 
      "factorized"] = 
    True, $CellContext`sym$81774[$CellContext`oPO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$81774, $CellContext`oPO4]], \
$CellContext`sym$81774[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$81774[$CellContext`oPO4, "raw"] = Part[
      $CellContext`sym$81774[All], 
      All, $CellContext`i$83330], $CellContext`sym$81774[$CellContext`PO4, 
      "factorized"] = 
    True, $CellContext`sym$81774[$CellContext`PO4, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$81774, $CellContext`PO4]], \
$CellContext`sym$81774[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$81774[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$81774[All], 
      All, $CellContext`i$83331], $CellContext`sym$81774[$CellContext`season, 
      "factorized"] = 
    True, $CellContext`sym$81774[$CellContext`season, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$81774, $CellContext`season]], \
$CellContext`sym$81774[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$81774[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$81774[All], 
      All, $CellContext`i$81775], $CellContext`sym$81774[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$81774[$CellContext`size, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$81774, $CellContext`size]], \
$CellContext`sym$81774[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$81774[$CellContext`size, "raw"] = Part[
      $CellContext`sym$81774[All], 
      All, $CellContext`i$83323], $CellContext`sym$81774[$CellContext`speed, 
      "factorized"] = 
    True, $CellContext`sym$81774[$CellContext`speed, "factors"] = Part[
      $CellContext`med[All], 
      $CellContext`fordering[$CellContext`sym$81774, $CellContext`speed]], \
$CellContext`sym$81774[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$81774[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$81774[All], All, $CellContext`i$83324], 
    Attributes[$CellContext`i$83324] = {Temporary}, $CellContext`i$83324 = 3, 
    Attributes[$CellContext`i$83335] = {Temporary}, $CellContext`i$83335 = 14,
     Attributes[$CellContext`i$83331] = {Temporary}, $CellContext`i$83331 = 
    10, Attributes[$CellContext`i$83327] = {Temporary}, $CellContext`i$83327 = 
    6, Attributes[$CellContext`i$83329] = {Temporary}, $CellContext`i$83329 = 
    8, Attributes[$CellContext`i$83336] = {Temporary}, $CellContext`i$83336 = 
    15, Attributes[$CellContext`i$83339] = {Temporary}, $CellContext`i$83339 = 
    18, Attributes[$CellContext`i$83332] = {Temporary}, $CellContext`i$83332 = 
    11, Attributes[$CellContext`i$83328] = {Temporary}, $CellContext`i$83328 = 
    7, Attributes[$CellContext`i$81775] = {Temporary}, $CellContext`i$81775 = 
    1, Attributes[$CellContext`i$83325] = {Temporary}, $CellContext`i$83325 = 
    4, Attributes[$CellContext`i$83338] = {Temporary}, $CellContext`i$83338 = 
    17, Attributes[$CellContext`i$83333] = {Temporary}, $CellContext`i$83333 = 
    12, Attributes[$CellContext`i$83334] = {Temporary}, $CellContext`i$83334 = 
    13, Attributes[$CellContext`i$83326] = {Temporary}, $CellContext`i$83326 = 
    5, Attributes[$CellContext`i$83323] = {Temporary}, $CellContext`i$83323 = 
    2, Attributes[$CellContext`i$83330] = {Temporary}, $CellContext`i$83330 = 
    9, Attributes[$CellContext`i$83337] = {Temporary}, $CellContext`i$83337 = 
    16, Attributes[$CellContext`sym$231674] = {
     Temporary}, $CellContext`sym$231674[$CellContext`a1] = Part[
      $CellContext`sym$231674[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$231674[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$231674[$CellContext`a2] = Part[
      $CellContext`sym$231674[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$231674[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$231674[$CellContext`a3] = Part[
      $CellContext`sym$231674[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$231674[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$231674[$CellContext`a4] = Part[
      $CellContext`sym$231674[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$231674[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$231674[$CellContext`a5] = Part[
      $CellContext`sym$231674[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$231674[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$231674[$CellContext`a6] = Part[
      $CellContext`sym$231674[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$231674[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$231674[$CellContext`a7] = Part[
      $CellContext`sym$231674[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$231674[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$231674[
     All] = {{"winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 
       170., 50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
      "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
       558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
      "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 125.667,
        187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
      "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 61.182, 
       138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
      "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222, 
       97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
      "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
       56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
      "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
       111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
      "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 44.667, 
       77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
      "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 71., 
       5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 0.8, 
       17., 0., 0., 2.9, 0., 0., 1.7}, {
      "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 20.75, 
       0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
      "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 19.,
        0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
      "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 41., 
       43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
      "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5, 
       31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
      "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 0.3, 
       52.2, 5., 7.8, 0., 4., 0., 0.}, {
      "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 98.25, 
       1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50., 
       1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
      "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 57.833, 
       0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
      "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 0.8, 
       50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
      "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
       564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
      "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 586.,
        16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
      "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 0.5, 
       15.5, 0., 0., 2.3, 0., 0., 0.}, {
      "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 7.6,
        23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
      "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
       27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
      "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 1.5,
        13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
      "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 44.136, 
       3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
      "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 0.5, 
       29.7, 0., 0., 4.9, 0., 0., 0.}, {
      "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
       Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
      "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 17.1,
        0., 19.6, 0., 0., 0., 2.5}, {
      "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5, 
       33.9, 1., 14.6, 0., 0., 0., 0.}, {
      "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 4.9, 
       3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
      "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 2.8, 
       6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
      "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 130.75, 
       5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
      "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47., 
       2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
      "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23., 
       0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
      "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 58.875, 
       84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
      "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 0.2,
        66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
       Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0., 
       0.}, {
      "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 196.62, 
       253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
      "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
       182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
      "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001, 
       296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
      "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 59.429,
        175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
      "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
       344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
      "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 276.85001, 
       326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
      "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 40.667, 
       3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
      "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 3.3, 
       29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
      "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 0.8, 
       54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
       Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 0., 
       0.}, {"spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121.,
        2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 20.812,
        12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
      "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
       49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
      "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 22.9, 
       4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
      "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 11.8, 
       0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818, 
       0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
      "winter", "small", "high", 6.6, 10.8, 
       Missing[], 3.245, 10., 1., 6.5, 
       Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "medium", 5.6, 11.8, 
       Missing[], 2.22, 5., 1., 1., 
       Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 5.7, 10.8, 
       Missing[], 2.55, 10., 1., 4., 
       Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
      "spring", "small", "high", 6.6, 9.5, 
       Missing[], 1.32, 20., 1., 6., 
       Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
      "summer", "small", "high", 6.6, 10.8, 
       Missing[], 2.64, 10., 2., 11., 
       Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
      "autumn", "small", "medium", 6.6, 11.3, 
       Missing[], 4.17, 10., 1., 6., 
       Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
      "spring", "small", "medium", 6.5, 10.4, 
       Missing[], 5.97, 10., 2., 14., 
       Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
      "summer", "small", "medium", 6.4, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 14., 
       Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
      "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 6.667, 
       Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75, 1.,
        20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
      "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2, 
       0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
      "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 0.6,
        55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
      "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 10.75, 
       2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
      "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 0.5, 
       64.2, 0., 3., 0., 0., 0., 0.}, {
      "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75, 
       351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
      "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
       209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
      "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 151.125,
        279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
      "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
       152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
      "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
       58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
      "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
       249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
      "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 100., 
       233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
      "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 215.5, 
       18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
      "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 25.167, 
       102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
      "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
       105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
      "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
       111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
      "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 1.3, 
       6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
      "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 56.667, 
       2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
      "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 4.3,
        1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
      "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
       104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
      "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 69.93,
        3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
      "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
       214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
      "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
       254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
      "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 57.6,
        169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
      "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
       412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
      "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
       282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
      "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
       197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
      "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 267.75, 
       391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
      "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 191.75, 
       265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
      "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
       232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
      "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 144.66701, 
       244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
      "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 218., 
       6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
      "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 138.5,
        20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
      "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222, 
       239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
      "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
       235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
      "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75, 
       205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
      "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 31.333, 
       211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
      "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625, 
       186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
      "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 12.889, 
       154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
      "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 51.111, 
       183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
      "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
       292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
      "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
       285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
      "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
       201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
      "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
       275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
      "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
       124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
      "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 60.833, 
       141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
      "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71., 
       132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
      "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
       17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
      "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 0.3, 
       46.6, 0., 2.5, 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 8.692, 
       16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
      "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 37.857, 
       102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
      "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
       86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
      "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
       10.111, 
       Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 16.833, 
       18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
      "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545, 
       13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
      "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 261.60001, 
       432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
      "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
       320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
      "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 144., 
       287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
      "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
       166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
      "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
       222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
      "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 36.909, 
       122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
      "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556, 
       127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
      "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
       89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
      "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 55., 
       284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
      "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 102.333, 
       277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
      "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 75.875, 
       177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
      "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
       72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
      "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 48.667, 
       82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
      "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 48.625, 
       66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
      "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 23., 
       173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
      "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 317., 
       5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
      "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 84., 
       4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
      "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 2., 
       10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
      "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 88.5, 
       2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
      "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115., 
       11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
      "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 98.143, 
       2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
      "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
       143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
      "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
       197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
      "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 1., 
       19., 0., 22., 5., 1.1, 5.4, 0.}, {
      "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 10.583, 
       23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
      "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 200.231, 
       19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
      "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 77.333, 
       147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
      "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5, 
       276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
      "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
       123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
      "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 75.207,
        23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
      "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 116.2,
        7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
      "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
       188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
      "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
       72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
      "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 16., 
       0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
      "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 34., 
       53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
      "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 27.5, 
       76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
      "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
       58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
      "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 175.66701, 
       361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
      "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
       22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
      "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 26.8,
        0., 28., 0., 0., 0., 0., 15.1}, {
      "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
       54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
      "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333, 
       34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
      "spring", "large", "low", 9., 5.8, 
       Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 0., 
       0.}, {"spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
       151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
      "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
       269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
      "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 46.438, 
       81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
      "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 85., 
       2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
      "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 66.4, 
       171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
      "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 102.364, 
       232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
      "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 84.3, 
       146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
      "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
       246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
      "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 205.636, 
       219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
      "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 236.39999,
        272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
      "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 1081.66003, 
       346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 5.9, 1.7}, {
      "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 82.222,
        167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
      "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 64.389, 
       137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
      "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 87.333,
        194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
      "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
       159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
      "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 21.3, 
       1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
      "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 0.6,
        37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
      "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
       14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
      "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222, 7.,
        1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 0.8, 
       50.4, 3.8, 0., 0., 0., 0., 0.}, {
      "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 7.654, 
       4., 56.8, 5., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 2.86, 
       17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
      "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 56.091, 
       Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
      "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
       52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
      "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 104.727, 
       228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
      "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 85.4, 
       17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
      "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 87.125,
        14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
      "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 101.455, 
       18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
      "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 50.889, 
       127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
      "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
       81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
      "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 19.727, 
       50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
      "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111, 
       120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
      "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 51.111, 
       91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
      "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 19.111, 
       61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
      "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625, 
       79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
      "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333, 
       75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
      "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333, 
       140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
      "winter", "large", "medium", 8., 7.6, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
      "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
       140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 
       5.8}}, $CellContext`sym$231674[$CellContext`Chla] = Part[
      $CellContext`sym$231674[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$231674[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$231674[$CellContext`Cl] = Part[
      $CellContext`sym$231674[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$231674[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$231674[$CellContext`mnO2] = Part[
      $CellContext`sym$231674[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$231674[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$231674[$CellContext`mxPH] = Part[
      $CellContext`sym$231674[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$231674[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$231674[$CellContext`NH4] = Part[
      $CellContext`sym$231674[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$231674[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$231674[$CellContext`NO3] = Part[
      $CellContext`sym$231674[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$231674[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$231674[$CellContext`oPO4] = Part[
      $CellContext`sym$231674[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$231674[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$231674[$CellContext`PO4] = Part[
      $CellContext`sym$231674[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$231674[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$231674[$CellContext`season] = Part[
      $CellContext`sym$231674[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$231674[$CellContext`season, 
         "missing"]]]], $CellContext`sym$231674[$CellContext`size] = Part[
      $CellContext`sym$231674[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$231674[$CellContext`size, 
         "missing"]]]], $CellContext`sym$231674[$CellContext`speed] = Part[
      $CellContext`sym$231674[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$231674[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$231674[$CellContext`a1, 
      "factorized"] = 
    False, $CellContext`sym$231674[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$231674[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$231674[All], 
      All, $CellContext`i$231686], $CellContext`sym$231674[$CellContext`a2, 
      "factorized"] = 
    False, $CellContext`sym$231674[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$231674[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$231674[All], 
      All, $CellContext`i$231687], $CellContext`sym$231674[$CellContext`a3, 
      "factorized"] = 
    False, $CellContext`sym$231674[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$231674[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$231674[All], 
      All, $CellContext`i$231688], $CellContext`sym$231674[$CellContext`a4, 
      "factorized"] = 
    False, $CellContext`sym$231674[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$231674[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$231674[All], 
      All, $CellContext`i$231689], $CellContext`sym$231674[$CellContext`a5, 
      "factorized"] = 
    False, $CellContext`sym$231674[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$231674[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$231674[All], 
      All, $CellContext`i$231690], $CellContext`sym$231674[$CellContext`a6, 
      "factorized"] = 
    False, $CellContext`sym$231674[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$231674[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$231674[All], 
      All, $CellContext`i$231691], $CellContext`sym$231674[$CellContext`a7, 
      "factorized"] = 
    False, $CellContext`sym$231674[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$231674[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$231674[All], 
      All, $CellContext`i$231692], $CellContext`sym$231674[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$231674[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed}, $CellContext`sym$231674[$CellContext`Chla, "factorized"] = 
    False, $CellContext`sym$231674[$CellContext`Chla, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {63}, {116}, {184}, {
     199}}, $CellContext`sym$231674[$CellContext`Chla, "raw"] = Part[
      $CellContext`sym$231674[All], 
      All, $CellContext`i$231685], $CellContext`sym$231674[$CellContext`Cl, 
      "factorized"] = 
    False, $CellContext`sym$231674[$CellContext`Cl, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {161}, {
     199}}, $CellContext`sym$231674[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$231674[All], 
      All, $CellContext`i$231680], $CellContext`sym$231674[$CellContext`mnO2, 
      "factorized"] = 
    False, $CellContext`sym$231674[$CellContext`mnO2, "missing"] = {{38}, {
     62}}, $CellContext`sym$231674[$CellContext`mnO2, "raw"] = Part[
      $CellContext`sym$231674[All], 
      All, $CellContext`i$231679], $CellContext`sym$231674[$CellContext`mxPH, 
      "factorized"] = 
    False, $CellContext`sym$231674[$CellContext`mxPH, "missing"] = {{
     48}}, $CellContext`sym$231674[$CellContext`mxPH, "raw"] = Part[
      $CellContext`sym$231674[All], 
      All, $CellContext`i$231678], $CellContext`sym$231674[$CellContext`NH4, 
      "factorized"] = 
    False, $CellContext`sym$231674[$CellContext`NH4, "missing"] = {{62}, {
     199}}, $CellContext`sym$231674[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$231674[All], 
      All, $CellContext`i$231682], $CellContext`sym$231674[$CellContext`NO3, 
      "factorized"] = 
    False, $CellContext`sym$231674[$CellContext`NO3, "missing"] = {{62}, {
     199}}, $CellContext`sym$231674[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$231674[All], 
      All, $CellContext`i$231681], $CellContext`sym$231674[$CellContext`oPO4, 
      "factorized"] = 
    False, $CellContext`sym$231674[$CellContext`oPO4, "missing"] = {{62}, {
     199}}, $CellContext`sym$231674[$CellContext`oPO4, "raw"] = Part[
      $CellContext`sym$231674[All], 
      All, $CellContext`i$231683], $CellContext`sym$231674[$CellContext`PO4, 
      "factorized"] = 
    False, $CellContext`sym$231674[$CellContext`PO4, "missing"] = {{28}, {
     199}}, $CellContext`sym$231674[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$231674[All], 
      All, $CellContext`i$231684], \
$CellContext`sym$231674[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$231674[$CellContext`season, "factors"] = 
    Part[{"autumn", "spring", "summer", "winter"}, 
      $CellContext`fordering[$CellContext`sym$231674, $CellContext`season]], \
$CellContext`sym$231674[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$231674[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$231674[All], 
      All, $CellContext`i$231675], $CellContext`sym$231674[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$231674[$CellContext`size, "factors"] = 
    Part[{"large", "medium", "small"}, 
      $CellContext`fordering[$CellContext`sym$231674, $CellContext`size]], \
$CellContext`sym$231674[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$231674[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$231674[All], 
      All, $CellContext`i$231676], $CellContext`sym$231674[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$231674[$CellContext`speed, "factors"] = 
    Part[{"high", "low", "medium"}, 
      $CellContext`fordering[$CellContext`sym$231674, $CellContext`speed]], \
$CellContext`sym$231674[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$231674[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$231674[All], All, $CellContext`i$231677], 
    Attributes[$CellContext`i$231679] = {Temporary}, $CellContext`i$231679 = 
    5, Attributes[$CellContext`i$231692] = {Temporary}, $CellContext`i$231692 = 
    18, Attributes[$CellContext`i$231691] = {
     Temporary}, $CellContext`i$231691 = 17, 
    Attributes[$CellContext`i$231690] = {Temporary}, $CellContext`i$231690 = 
    16, Attributes[$CellContext`i$231681] = {
     Temporary}, $CellContext`i$231681 = 7, 
    Attributes[$CellContext`i$231685] = {Temporary}, $CellContext`i$231685 = 
    11, Attributes[$CellContext`i$231687] = {
     Temporary}, $CellContext`i$231687 = 13, 
    Attributes[$CellContext`i$231684] = {Temporary}, $CellContext`i$231684 = 
    10, Attributes[$CellContext`i$231686] = {
     Temporary}, $CellContext`i$231686 = 12, 
    Attributes[$CellContext`i$231677] = {Temporary}, $CellContext`i$231677 = 
    3, Attributes[$CellContext`i$231675] = {Temporary}, $CellContext`i$231675 = 
    1, Attributes[$CellContext`i$231683] = {Temporary}, $CellContext`i$231683 = 
    9, Attributes[$CellContext`i$231678] = {Temporary}, $CellContext`i$231678 = 
    4, Attributes[$CellContext`i$231689] = {Temporary}, $CellContext`i$231689 = 
    15, Attributes[$CellContext`i$231688] = {
     Temporary}, $CellContext`i$231688 = 14, 
    Attributes[$CellContext`i$231682] = {Temporary}, $CellContext`i$231682 = 
    8, Attributes[$CellContext`i$231680] = {Temporary}, $CellContext`i$231680 = 
    6, Attributes[$CellContext`i$231676] = {Temporary}, $CellContext`i$231676 = 
    2, Attributes[$CellContext`sym$232540] = {
     Temporary}, $CellContext`sym$232540[$CellContext`a1] = Part[
      $CellContext`sym$232540[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232540[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$232540[$CellContext`a2] = Part[
      $CellContext`sym$232540[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232540[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$232540[$CellContext`a3] = Part[
      $CellContext`sym$232540[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232540[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$232540[$CellContext`a4] = Part[
      $CellContext`sym$232540[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232540[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$232540[$CellContext`a5] = Part[
      $CellContext`sym$232540[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232540[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$232540[$CellContext`a6] = Part[
      $CellContext`sym$232540[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232540[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$232540[$CellContext`a7] = Part[
      $CellContext`sym$232540[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232540[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$232540[
     All] = {{"winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 
       170., 50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
      "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
       558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
      "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 125.667,
        187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
      "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 61.182, 
       138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
      "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222, 
       97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
      "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
       56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
      "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
       111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
      "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 44.667, 
       77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
      "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 71., 
       5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 0.8, 
       17., 0., 0., 2.9, 0., 0., 1.7}, {
      "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 20.75, 
       0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
      "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 19.,
        0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
      "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 41., 
       43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
      "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5, 
       31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
      "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 0.3, 
       52.2, 5., 7.8, 0., 4., 0., 0.}, {
      "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 98.25, 
       1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50., 
       1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
      "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 57.833, 
       0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
      "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 0.8, 
       50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
      "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
       564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
      "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 586.,
        16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
      "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 0.5, 
       15.5, 0., 0., 2.3, 0., 0., 0.}, {
      "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 7.6,
        23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
      "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
       27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
      "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 1.5,
        13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
      "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 44.136, 
       3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
      "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 0.5, 
       29.7, 0., 0., 4.9, 0., 0., 0.}, {
      "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
       Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
      "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 17.1,
        0., 19.6, 0., 0., 0., 2.5}, {
      "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5, 
       33.9, 1., 14.6, 0., 0., 0., 0.}, {
      "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 4.9, 
       3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
      "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 2.8, 
       6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
      "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 130.75, 
       5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
      "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47., 
       2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
      "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23., 
       0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
      "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 58.875, 
       84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
      "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 0.2,
        66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
       Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0., 
       0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
       196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
      "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
       182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
      "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001, 
       296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
      "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 59.429,
        175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
      "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
       344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
      "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 276.85001, 
       326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
      "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 40.667, 
       3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
      "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 3.3, 
       29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
      "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 0.8, 
       54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
       Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 0., 
       0.}, {"spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121.,
        2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 20.812,
        12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
      "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
       49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
      "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 22.9, 
       4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
      "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 11.8, 
       0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818, 
       0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
      "winter", "small", "high", 6.6, 10.8, 
       Missing[], 3.245, 10., 1., 6.5, 
       Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "medium", 5.6, 11.8, 
       Missing[], 2.22, 5., 1., 1., 
       Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 5.7, 10.8, 
       Missing[], 2.55, 10., 1., 4., 
       Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
      "spring", "small", "high", 6.6, 9.5, 
       Missing[], 1.32, 20., 1., 6., 
       Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
      "summer", "small", "high", 6.6, 10.8, 
       Missing[], 2.64, 10., 2., 11., 
       Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
      "autumn", "small", "medium", 6.6, 11.3, 
       Missing[], 4.17, 10., 1., 6., 
       Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
      "spring", "small", "medium", 6.5, 10.4, 
       Missing[], 5.97, 10., 2., 14., 
       Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
      "summer", "small", "medium", 6.4, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 14., 
       Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
      "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 6.667, 
       Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75, 1.,
        20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
      "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2, 
       0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
      "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 0.6,
        55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
      "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 10.75, 
       2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
      "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 0.5, 
       64.2, 0., 3., 0., 0., 0., 0.}, {
      "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75, 
       351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
      "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
       209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
      "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 151.125,
        279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
      "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
       152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
      "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
       58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
      "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
       249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
      "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 100., 
       233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
      "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 215.5, 
       18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
      "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 25.167, 
       102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
      "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
       105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
      "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
       111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
      "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 1.3, 
       6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
      "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 56.667, 
       2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
      "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 4.3,
        1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
      "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
       104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
      "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 69.93,
        3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
      "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
       214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
      "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
       254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
      "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 57.6,
        169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
      "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
       412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
      "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
       282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
      "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
       197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
      "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 267.75, 
       391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
      "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 191.75, 
       265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
      "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
       232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
      "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 144.66701, 
       244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
      "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 218., 
       6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
      "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 138.5,
        20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
      "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222, 
       239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
      "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
       235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
      "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75, 
       205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
      "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 31.333, 
       211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
      "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625, 
       186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
      "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 12.889, 
       154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
      "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 51.111, 
       183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
      "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
       292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
      "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
       285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
      "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
       201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
      "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
       275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
      "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
       124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
      "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 60.833, 
       141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
      "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71., 
       132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
      "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
       17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
      "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 0.3, 
       46.6, 0., 2.5, 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 8.692, 
       16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
      "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 37.857, 
       102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
      "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
       86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
      "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
       10.111, 
       Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 16.833, 
       18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
      "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545, 
       13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
      "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 261.60001, 
       432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
      "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
       320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
      "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 144., 
       287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
      "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
       166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
      "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
       222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
      "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 36.909, 
       122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
      "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556, 
       127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
      "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
       89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
      "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 55., 
       284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
      "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 102.333, 
       277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
      "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 75.875, 
       177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
      "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
       72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
      "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 48.667, 
       82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
      "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 48.625, 
       66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
      "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 23., 
       173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
      "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 317., 
       5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
      "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 84., 
       4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
      "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 2., 
       10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
      "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 88.5, 
       2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
      "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115., 
       11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
      "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 98.143, 
       2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
      "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
       143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
      "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
       197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
      "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 1., 
       19., 0., 22., 5., 1.1, 5.4, 0.}, {
      "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 10.583, 
       23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
      "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 200.231, 
       19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
      "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 77.333, 
       147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
      "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5, 
       276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
      "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
       123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
      "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 75.207,
        23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
      "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 116.2,
        7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
      "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
       188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
      "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
       72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
      "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 16., 
       0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
      "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 34., 
       53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
      "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 27.5, 
       76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
      "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
       58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
      "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 175.66701, 
       361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
      "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
       22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
      "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 26.8,
        0., 28., 0., 0., 0., 0., 15.1}, {
      "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
       54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
      "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333, 
       34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
      "spring", "large", "low", 9., 5.8, 
       Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 0., 
       0.}, {"spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
       151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
      "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
       269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
      "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 46.438, 
       81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
      "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 85., 
       2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
      "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 66.4, 
       171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
      "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 102.364, 
       232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
      "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 84.3, 
       146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
      "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
       246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
      "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 205.636, 
       219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
      "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 236.39999,
        272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
      "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 1081.66003, 
       346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 5.9, 1.7}, {
      "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 82.222,
        167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
      "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 64.389, 
       137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
      "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 87.333,
        194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
      "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
       159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
      "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 21.3, 
       1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
      "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 0.6,
        37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
      "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
       14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
      "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222, 7.,
        1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 0.8, 
       50.4, 3.8, 0., 0., 0., 0., 0.}, {
      "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 7.654, 
       4., 56.8, 5., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 2.86, 
       17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
      "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 56.091, 
       Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
      "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
       52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
      "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 104.727, 
       228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
      "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 85.4, 
       17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
      "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 87.125,
        14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
      "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 101.455, 
       18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
      "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 50.889, 
       127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
      "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
       81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
      "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 19.727, 
       50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
      "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111, 
       120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
      "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 51.111, 
       91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
      "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 19.111, 
       61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
      "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625, 
       79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
      "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333, 
       75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
      "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333, 
       140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
      "winter", "large", "medium", 8., 7.6, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
      "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
       140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 
       5.8}}, $CellContext`sym$232540[$CellContext`Chla] = Part[
      $CellContext`sym$232540[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232540[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$232540[$CellContext`Cl] = Part[
      $CellContext`sym$232540[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232540[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$232540[$CellContext`mnO2] = Part[
      $CellContext`sym$232540[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232540[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$232540[$CellContext`mxPH] = Part[
      $CellContext`sym$232540[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232540[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$232540[$CellContext`NH4] = Part[
      $CellContext`sym$232540[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232540[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$232540[$CellContext`NO3] = Part[
      $CellContext`sym$232540[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232540[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$232540[$CellContext`oPO4] = Part[
      $CellContext`sym$232540[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232540[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$232540[$CellContext`PO4] = Part[
      $CellContext`sym$232540[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232540[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$232540[$CellContext`season] = Part[
      $CellContext`sym$232540[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232540[$CellContext`season, 
         "missing"]]]], $CellContext`sym$232540[$CellContext`size] = Part[
      $CellContext`sym$232540[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232540[$CellContext`size, 
         "missing"]]]], $CellContext`sym$232540[$CellContext`speed] = Part[
      $CellContext`sym$232540[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232540[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$232540[$CellContext`a1, 
      "factorized"] = 
    False, $CellContext`sym$232540[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$232540[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$232540[All], 
      All, $CellContext`i$232552], $CellContext`sym$232540[$CellContext`a2, 
      "factorized"] = 
    False, $CellContext`sym$232540[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$232540[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$232540[All], 
      All, $CellContext`i$232553], $CellContext`sym$232540[$CellContext`a3, 
      "factorized"] = 
    False, $CellContext`sym$232540[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$232540[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$232540[All], 
      All, $CellContext`i$232554], $CellContext`sym$232540[$CellContext`a4, 
      "factorized"] = 
    False, $CellContext`sym$232540[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$232540[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$232540[All], 
      All, $CellContext`i$232555], $CellContext`sym$232540[$CellContext`a5, 
      "factorized"] = 
    False, $CellContext`sym$232540[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$232540[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$232540[All], 
      All, $CellContext`i$232556], $CellContext`sym$232540[$CellContext`a6, 
      "factorized"] = 
    False, $CellContext`sym$232540[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$232540[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$232540[All], 
      All, $CellContext`i$232557], $CellContext`sym$232540[$CellContext`a7, 
      "factorized"] = 
    False, $CellContext`sym$232540[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$232540[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$232540[All], 
      All, $CellContext`i$232558], $CellContext`sym$232540[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$232540[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed}, $CellContext`sym$232540[$CellContext`Chla, "factorized"] = 
    False, $CellContext`sym$232540[$CellContext`Chla, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {63}, {116}, {184}, {
     199}}, $CellContext`sym$232540[$CellContext`Chla, "raw"] = Part[
      $CellContext`sym$232540[All], 
      All, $CellContext`i$232551], $CellContext`sym$232540[$CellContext`Cl, 
      "factorized"] = 
    False, $CellContext`sym$232540[$CellContext`Cl, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {161}, {
     199}}, $CellContext`sym$232540[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$232540[All], 
      All, $CellContext`i$232546], $CellContext`sym$232540[$CellContext`mnO2, 
      "factorized"] = 
    False, $CellContext`sym$232540[$CellContext`mnO2, "missing"] = {{38}, {
     62}}, $CellContext`sym$232540[$CellContext`mnO2, "raw"] = Part[
      $CellContext`sym$232540[All], 
      All, $CellContext`i$232545], $CellContext`sym$232540[$CellContext`mxPH, 
      "factorized"] = 
    False, $CellContext`sym$232540[$CellContext`mxPH, "missing"] = {{
     48}}, $CellContext`sym$232540[$CellContext`mxPH, "raw"] = Part[
      $CellContext`sym$232540[All], 
      All, $CellContext`i$232544], $CellContext`sym$232540[$CellContext`NH4, 
      "factorized"] = 
    False, $CellContext`sym$232540[$CellContext`NH4, "missing"] = {{62}, {
     199}}, $CellContext`sym$232540[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$232540[All], 
      All, $CellContext`i$232548], $CellContext`sym$232540[$CellContext`NO3, 
      "factorized"] = 
    False, $CellContext`sym$232540[$CellContext`NO3, "missing"] = {{62}, {
     199}}, $CellContext`sym$232540[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$232540[All], 
      All, $CellContext`i$232547], $CellContext`sym$232540[$CellContext`oPO4, 
      "factorized"] = 
    False, $CellContext`sym$232540[$CellContext`oPO4, "missing"] = {{62}, {
     199}}, $CellContext`sym$232540[$CellContext`oPO4, "raw"] = Part[
      $CellContext`sym$232540[All], 
      All, $CellContext`i$232549], $CellContext`sym$232540[$CellContext`PO4, 
      "factorized"] = 
    False, $CellContext`sym$232540[$CellContext`PO4, "missing"] = {{28}, {
     199}}, $CellContext`sym$232540[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$232540[All], 
      All, $CellContext`i$232550], \
$CellContext`sym$232540[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$232540[$CellContext`season, "factors"] = 
    Part[{"autumn", "spring", "summer", "winter"}, 
      $CellContext`fordering[$CellContext`sym$232540, $CellContext`season]], \
$CellContext`sym$232540[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$232540[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$232540[All], 
      All, $CellContext`i$232541], $CellContext`sym$232540[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$232540[$CellContext`size, "factors"] = 
    Part[{"large", "medium", "small"}, 
      $CellContext`fordering[$CellContext`sym$232540, $CellContext`size]], \
$CellContext`sym$232540[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$232540[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$232540[All], 
      All, $CellContext`i$232542], $CellContext`sym$232540[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$232540[$CellContext`speed, "factors"] = 
    Part[{"high", "low", "medium"}, 
      $CellContext`fordering[$CellContext`sym$232540, $CellContext`speed]], \
$CellContext`sym$232540[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$232540[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$232540[All], All, $CellContext`i$232543], 
    Attributes[$CellContext`i$232543] = {Temporary}, $CellContext`i$232543 = 
    3, Attributes[$CellContext`i$232551] = {Temporary}, $CellContext`i$232551 = 
    11, Attributes[$CellContext`i$232545] = {
     Temporary}, $CellContext`i$232545 = 5, 
    Attributes[$CellContext`i$232546] = {Temporary}, $CellContext`i$232546 = 
    6, Attributes[$CellContext`i$232557] = {Temporary}, $CellContext`i$232557 = 
    17, Attributes[$CellContext`i$232549] = {
     Temporary}, $CellContext`i$232549 = 9, 
    Attributes[$CellContext`i$232554] = {Temporary}, $CellContext`i$232554 = 
    14, Attributes[$CellContext`i$232541] = {
     Temporary}, $CellContext`i$232541 = 1, 
    Attributes[$CellContext`i$232555] = {Temporary}, $CellContext`i$232555 = 
    15, Attributes[$CellContext`i$232550] = {
     Temporary}, $CellContext`i$232550 = 10, 
    Attributes[$CellContext`i$232553] = {Temporary}, $CellContext`i$232553 = 
    13, Attributes[$CellContext`i$232556] = {
     Temporary}, $CellContext`i$232556 = 16, 
    Attributes[$CellContext`i$232547] = {Temporary}, $CellContext`i$232547 = 
    7, Attributes[$CellContext`i$232542] = {Temporary}, $CellContext`i$232542 = 
    2, Attributes[$CellContext`i$232544] = {Temporary}, $CellContext`i$232544 = 
    4, Attributes[$CellContext`i$232548] = {Temporary}, $CellContext`i$232548 = 
    8, Attributes[$CellContext`i$232552] = {Temporary}, $CellContext`i$232552 = 
    12, Attributes[$CellContext`i$232558] = {
     Temporary}, $CellContext`i$232558 = 18, 
    Attributes[$CellContext`sym$229076] = {
     Temporary}, $CellContext`sym$229076[$CellContext`a1] = Part[
      $CellContext`sym$229076[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229076[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$229076[$CellContext`a2] = Part[
      $CellContext`sym$229076[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229076[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$229076[$CellContext`a3] = Part[
      $CellContext`sym$229076[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229076[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$229076[$CellContext`a4] = Part[
      $CellContext`sym$229076[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229076[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$229076[$CellContext`a5] = Part[
      $CellContext`sym$229076[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229076[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$229076[$CellContext`a6] = Part[
      $CellContext`sym$229076[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229076[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$229076[$CellContext`a7] = Part[
      $CellContext`sym$229076[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229076[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$229076[
     All] = {{"winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 
       170., 50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
      "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
       558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
      "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 125.667,
        187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
      "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 61.182, 
       138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
      "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222, 
       97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
      "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
       56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
      "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
       111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
      "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 44.667, 
       77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
      "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 71., 
       5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 0.8, 
       17., 0., 0., 2.9, 0., 0., 1.7}, {
      "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 20.75, 
       0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
      "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 19.,
        0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
      "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 41., 
       43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
      "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5, 
       31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
      "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 0.3, 
       52.2, 5., 7.8, 0., 4., 0., 0.}, {
      "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 98.25, 
       1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50., 
       1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
      "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 57.833, 
       0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
      "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 0.8, 
       50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
      "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
       564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
      "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 586.,
        16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
      "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 0.5, 
       15.5, 0., 0., 2.3, 0., 0., 0.}, {
      "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 7.6,
        23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
      "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
       27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
      "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 1.5,
        13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
      "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 44.136, 
       3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
      "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 0.5, 
       29.7, 0., 0., 4.9, 0., 0., 0.}, {
      "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
       Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
      "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 17.1,
        0., 19.6, 0., 0., 0., 2.5}, {
      "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5, 
       33.9, 1., 14.6, 0., 0., 0., 0.}, {
      "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 4.9, 
       3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
      "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 2.8, 
       6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
      "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 130.75, 
       5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
      "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47., 
       2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
      "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23., 
       0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
      "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 58.875, 
       84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
      "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 0.2,
        66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
       Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0., 
       0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
       196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
      "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
       182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
      "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001, 
       296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
      "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 59.429,
        175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
      "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
       344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
      "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 276.85001, 
       326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
      "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 40.667, 
       3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
      "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 3.3, 
       29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
      "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 0.8, 
       54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
       Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 0., 
       0.}, {"spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121.,
        2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 20.812,
        12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
      "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
       49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
      "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 22.9, 
       4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
      "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 11.8, 
       0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818, 
       0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
      "winter", "small", "high", 6.6, 10.8, 
       Missing[], 3.245, 10., 1., 6.5, 
       Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "medium", 5.6, 11.8, 
       Missing[], 2.22, 5., 1., 1., 
       Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 5.7, 10.8, 
       Missing[], 2.55, 10., 1., 4., 
       Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
      "spring", "small", "high", 6.6, 9.5, 
       Missing[], 1.32, 20., 1., 6., 
       Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
      "summer", "small", "high", 6.6, 10.8, 
       Missing[], 2.64, 10., 2., 11., 
       Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
      "autumn", "small", "medium", 6.6, 11.3, 
       Missing[], 4.17, 10., 1., 6., 
       Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
      "spring", "small", "medium", 6.5, 10.4, 
       Missing[], 5.97, 10., 2., 14., 
       Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
      "summer", "small", "medium", 6.4, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 14., 
       Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
      "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 6.667, 
       Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75, 1.,
        20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
      "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2, 
       0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
      "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 0.6,
        55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
      "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 10.75, 
       2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
      "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 0.5, 
       64.2, 0., 3., 0., 0., 0., 0.}, {
      "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75, 
       351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
      "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
       209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
      "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 151.125,
        279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
      "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
       152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
      "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
       58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
      "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
       249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
      "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 100., 
       233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
      "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 215.5, 
       18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
      "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 25.167, 
       102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
      "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
       105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
      "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
       111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
      "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 1.3, 
       6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
      "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 56.667, 
       2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
      "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 4.3,
        1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
      "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
       104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
      "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 69.93,
        3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
      "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
       214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
      "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
       254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
      "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 57.6,
        169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
      "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
       412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
      "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
       282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
      "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
       197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
      "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 267.75, 
       391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
      "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 191.75, 
       265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
      "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
       232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
      "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 144.66701, 
       244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
      "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 218., 
       6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
      "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 138.5,
        20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
      "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222, 
       239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
      "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
       235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
      "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75, 
       205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
      "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 31.333, 
       211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
      "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625, 
       186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
      "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 12.889, 
       154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
      "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 51.111, 
       183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
      "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
       292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
      "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
       285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
      "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
       201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
      "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
       275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
      "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
       124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
      "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 60.833, 
       141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
      "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71., 
       132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
      "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
       17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
      "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 0.3, 
       46.6, 0., 2.5, 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 8.692, 
       16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
      "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 37.857, 
       102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
      "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
       86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
      "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
       10.111, 
       Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 16.833, 
       18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
      "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545, 
       13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
      "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 261.60001, 
       432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
      "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
       320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
      "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 144., 
       287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
      "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
       166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
      "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
       222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
      "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 36.909, 
       122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
      "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556, 
       127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
      "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
       89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
      "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 55., 
       284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
      "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 102.333, 
       277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
      "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 75.875, 
       177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
      "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
       72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
      "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 48.667, 
       82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
      "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 48.625, 
       66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
      "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 23., 
       173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
      "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 317., 
       5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
      "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 84., 
       4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
      "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 2., 
       10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
      "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 88.5, 
       2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
      "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115., 
       11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
      "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 98.143, 
       2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
      "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
       143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
      "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
       197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
      "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 1., 
       19., 0., 22., 5., 1.1, 5.4, 0.}, {
      "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 10.583, 
       23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
      "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 200.231, 
       19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
      "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 77.333, 
       147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
      "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5, 
       276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
      "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
       123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
      "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 75.207,
        23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
      "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 116.2,
        7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
      "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
       188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
      "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
       72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
      "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 16., 
       0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
      "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 34., 
       53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
      "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 27.5, 
       76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
      "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
       58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
      "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 175.66701, 
       361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
      "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
       22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
      "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 26.8,
        0., 28., 0., 0., 0., 0., 15.1}, {
      "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
       54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
      "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333, 
       34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
      "spring", "large", "low", 9., 5.8, 
       Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 0., 
       0.}, {"spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
       151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
      "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
       269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
      "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 46.438, 
       81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
      "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 85., 
       2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
      "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 66.4, 
       171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
      "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 102.364, 
       232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
      "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 84.3, 
       146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
      "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
       246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
      "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 205.636, 
       219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
      "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 236.39999,
        272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
      "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 1081.66003, 
       346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 5.9, 1.7}, {
      "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 82.222,
        167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
      "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 64.389, 
       137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
      "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 87.333,
        194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
      "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
       159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
      "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 21.3, 
       1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
      "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 0.6,
        37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
      "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
       14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
      "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222, 7.,
        1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 0.8, 
       50.4, 3.8, 0., 0., 0., 0., 0.}, {
      "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 7.654, 
       4., 56.8, 5., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 2.86, 
       17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
      "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 56.091, 
       Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
      "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
       52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
      "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 104.727, 
       228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
      "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 85.4, 
       17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
      "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 87.125,
        14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
      "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 101.455, 
       18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
      "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 50.889, 
       127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
      "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
       81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
      "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 19.727, 
       50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
      "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111, 
       120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
      "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 51.111, 
       91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
      "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 19.111, 
       61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
      "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625, 
       79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
      "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333, 
       75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
      "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333, 
       140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
      "winter", "large", "medium", 8., 7.6, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
      "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
       140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 
       5.8}}, $CellContext`sym$229076[$CellContext`Chla] = Part[
      $CellContext`sym$229076[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {
          "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
           196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229076[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$229076[$CellContext`Cl] = Part[
      $CellContext`sym$229076[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229076[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$229076[$CellContext`mnO2] = Part[
      $CellContext`sym$229076[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229076[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$229076[$CellContext`mxPH] = Part[
      $CellContext`sym$229076[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229076[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$229076[$CellContext`NH4] = Part[
      $CellContext`sym$229076[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229076[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$229076[$CellContext`NO3] = Part[
      $CellContext`sym$229076[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229076[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$229076[$CellContext`oPO4] = Part[
      $CellContext`sym$229076[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229076[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$229076[$CellContext`PO4] = Part[
      $CellContext`sym$229076[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229076[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$229076[$CellContext`season] = Part[
      $CellContext`sym$229076[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229076[$CellContext`season, 
         "missing"]]]], $CellContext`sym$229076[$CellContext`size] = Part[
      $CellContext`sym$229076[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229076[$CellContext`size, 
         "missing"]]]], $CellContext`sym$229076[$CellContext`speed] = Part[
      $CellContext`sym$229076[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229076[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$229076[$CellContext`a1, 
      "factorized"] = 
    False, $CellContext`sym$229076[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$229076[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$229076[All], 
      All, $CellContext`i$229088], $CellContext`sym$229076[$CellContext`a2, 
      "factorized"] = 
    False, $CellContext`sym$229076[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$229076[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$229076[All], 
      All, $CellContext`i$229089], $CellContext`sym$229076[$CellContext`a3, 
      "factorized"] = 
    False, $CellContext`sym$229076[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$229076[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$229076[All], 
      All, $CellContext`i$229090], $CellContext`sym$229076[$CellContext`a4, 
      "factorized"] = 
    False, $CellContext`sym$229076[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$229076[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$229076[All], 
      All, $CellContext`i$229091], $CellContext`sym$229076[$CellContext`a5, 
      "factorized"] = 
    False, $CellContext`sym$229076[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$229076[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$229076[All], 
      All, $CellContext`i$229092], $CellContext`sym$229076[$CellContext`a6, 
      "factorized"] = 
    False, $CellContext`sym$229076[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$229076[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$229076[All], 
      All, $CellContext`i$229093], $CellContext`sym$229076[$CellContext`a7, 
      "factorized"] = 
    False, $CellContext`sym$229076[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$229076[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$229076[All], 
      All, $CellContext`i$229094], $CellContext`sym$229076[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$229076[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed}, $CellContext`sym$229076[$CellContext`Chla, "factorized"] = 
    False, $CellContext`sym$229076[$CellContext`Chla, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {63}, {116}, {184}, {
     199}}, $CellContext`sym$229076[$CellContext`Chla, "raw"] = Part[
      $CellContext`sym$229076[All], 
      All, $CellContext`i$229087], $CellContext`sym$229076[$CellContext`Cl, 
      "factorized"] = 
    False, $CellContext`sym$229076[$CellContext`Cl, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {161}, {
     199}}, $CellContext`sym$229076[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$229076[All], 
      All, $CellContext`i$229082], $CellContext`sym$229076[$CellContext`mnO2, 
      "factorized"] = 
    False, $CellContext`sym$229076[$CellContext`mnO2, "missing"] = {{38}, {
     62}}, $CellContext`sym$229076[$CellContext`mnO2, "raw"] = Part[
      $CellContext`sym$229076[All], 
      All, $CellContext`i$229081], $CellContext`sym$229076[$CellContext`mxPH, 
      "factorized"] = 
    False, $CellContext`sym$229076[$CellContext`mxPH, "missing"] = {{
     48}}, $CellContext`sym$229076[$CellContext`mxPH, "raw"] = Part[
      $CellContext`sym$229076[All], 
      All, $CellContext`i$229080], $CellContext`sym$229076[$CellContext`NH4, 
      "factorized"] = 
    False, $CellContext`sym$229076[$CellContext`NH4, "missing"] = {{62}, {
     199}}, $CellContext`sym$229076[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$229076[All], 
      All, $CellContext`i$229084], $CellContext`sym$229076[$CellContext`NO3, 
      "factorized"] = 
    False, $CellContext`sym$229076[$CellContext`NO3, "missing"] = {{62}, {
     199}}, $CellContext`sym$229076[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$229076[All], 
      All, $CellContext`i$229083], $CellContext`sym$229076[$CellContext`oPO4, 
      "factorized"] = 
    False, $CellContext`sym$229076[$CellContext`oPO4, "missing"] = {{62}, {
     199}}, $CellContext`sym$229076[$CellContext`oPO4, "raw"] = Part[
      $CellContext`sym$229076[All], 
      All, $CellContext`i$229085], $CellContext`sym$229076[$CellContext`PO4, 
      "factorized"] = 
    False, $CellContext`sym$229076[$CellContext`PO4, "missing"] = {{28}, {
     199}}, $CellContext`sym$229076[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$229076[All], 
      All, $CellContext`i$229086], \
$CellContext`sym$229076[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$229076[$CellContext`season, "factors"] = 
    Part[{"autumn", "spring", "summer", "winter"}, 
      $CellContext`fordering[$CellContext`sym$229076, $CellContext`season]], \
$CellContext`sym$229076[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$229076[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$229076[All], 
      All, $CellContext`i$229077], $CellContext`sym$229076[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$229076[$CellContext`size, "factors"] = 
    Part[{"large", "medium", "small"}, 
      $CellContext`fordering[$CellContext`sym$229076, $CellContext`size]], \
$CellContext`sym$229076[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$229076[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$229076[All], 
      All, $CellContext`i$229078], $CellContext`sym$229076[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$229076[$CellContext`speed, "factors"] = 
    Part[{"high", "low", "medium"}, 
      $CellContext`fordering[$CellContext`sym$229076, $CellContext`speed]], \
$CellContext`sym$229076[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$229076[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$229076[All], All, $CellContext`i$229079], 
    Attributes[$CellContext`i$229080] = {Temporary}, $CellContext`i$229080 = 
    4, Attributes[$CellContext`i$229086] = {Temporary}, $CellContext`i$229086 = 
    10, Attributes[$CellContext`i$229079] = {
     Temporary}, $CellContext`i$229079 = 3, 
    Attributes[$CellContext`i$229093] = {Temporary}, $CellContext`i$229093 = 
    17, Attributes[$CellContext`i$229078] = {
     Temporary}, $CellContext`i$229078 = 2, 
    Attributes[$CellContext`i$229091] = {Temporary}, $CellContext`i$229091 = 
    15, Attributes[$CellContext`i$229077] = {
     Temporary}, $CellContext`i$229077 = 1, 
    Attributes[$CellContext`i$229087] = {Temporary}, $CellContext`i$229087 = 
    11, Attributes[$CellContext`i$229089] = {
     Temporary}, $CellContext`i$229089 = 13, 
    Attributes[$CellContext`i$229092] = {Temporary}, $CellContext`i$229092 = 
    16, Attributes[$CellContext`i$229085] = {
     Temporary}, $CellContext`i$229085 = 9, 
    Attributes[$CellContext`i$229082] = {Temporary}, $CellContext`i$229082 = 
    6, Attributes[$CellContext`i$229090] = {Temporary}, $CellContext`i$229090 = 
    14, Attributes[$CellContext`i$229083] = {
     Temporary}, $CellContext`i$229083 = 7, 
    Attributes[$CellContext`i$229094] = {Temporary}, $CellContext`i$229094 = 
    18, Attributes[$CellContext`i$229081] = {
     Temporary}, $CellContext`i$229081 = 5, 
    Attributes[$CellContext`i$229088] = {Temporary}, $CellContext`i$229088 = 
    12, Attributes[$CellContext`i$229084] = {
     Temporary}, $CellContext`i$229084 = 8, 
    Attributes[$CellContext`sym$30337] = {
     Temporary}, $CellContext`sym$30337[$CellContext`a1] = $CellContext`med[
     All], $CellContext`sym$30337[$CellContext`a2] = $CellContext`med[
     All], $CellContext`sym$30337[$CellContext`a3] = $CellContext`med[
     All], $CellContext`sym$30337[$CellContext`a4] = $CellContext`med[
     All], $CellContext`sym$30337[$CellContext`a5] = $CellContext`med[
     All], $CellContext`sym$30337[$CellContext`a6] = $CellContext`med[
     All], $CellContext`sym$30337[$CellContext`a7] = $CellContext`med[
     All], $CellContext`sym$30337[All] = $CellContext`med[
     All], $CellContext`sym$30337[$CellContext`Chla] = $CellContext`med[
     All], $CellContext`sym$30337[$CellContext`Cl] = $CellContext`med[
     All], $CellContext`sym$30337[$CellContext`mnO2] = $CellContext`med[
     All], $CellContext`sym$30337[$CellContext`mxPH] = $CellContext`med[
     All], $CellContext`sym$30337[$CellContext`NH4] = $CellContext`med[
     All], $CellContext`sym$30337[$CellContext`NO3] = $CellContext`med[
     All], $CellContext`sym$30337[$CellContext`oPO4] = $CellContext`med[
     All], $CellContext`sym$30337[$CellContext`PO4] = $CellContext`med[
     All], $CellContext`sym$30337[$CellContext`season] = $CellContext`med[
     All], $CellContext`sym$30337[$CellContext`size] = $CellContext`med[
     All], $CellContext`sym$30337[$CellContext`speed] = $CellContext`med[
     All], $CellContext`sym$30337[$CellContext`a1, "factorized"] = 
    True, $CellContext`sym$30337[$CellContext`a1, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$30337[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$30337[$CellContext`a1, "raw"] = Part[
      $CellContext`med[All], All, 12], $CellContext`sym$30337[$CellContext`a2,
       "factorized"] = 
    True, $CellContext`sym$30337[$CellContext`a2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$30337[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$30337[$CellContext`a2, "raw"] = Part[
      $CellContext`med[All], All, 13], $CellContext`sym$30337[$CellContext`a3,
       "factorized"] = 
    True, $CellContext`sym$30337[$CellContext`a3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$30337[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$30337[$CellContext`a3, "raw"] = Part[
      $CellContext`med[All], All, 14], $CellContext`sym$30337[$CellContext`a4,
       "factorized"] = 
    True, $CellContext`sym$30337[$CellContext`a4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$30337[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$30337[$CellContext`a4, "raw"] = Part[
      $CellContext`med[All], All, 15], $CellContext`sym$30337[$CellContext`a5,
       "factorized"] = 
    True, $CellContext`sym$30337[$CellContext`a5, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$30337[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$30337[$CellContext`a5, "raw"] = Part[
      $CellContext`med[All], All, 16], $CellContext`sym$30337[$CellContext`a6,
       "factorized"] = 
    True, $CellContext`sym$30337[$CellContext`a6, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$30337[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$30337[$CellContext`a6, "raw"] = Part[
      $CellContext`med[All], All, 17], $CellContext`sym$30337[$CellContext`a7,
       "factorized"] = 
    True, $CellContext`sym$30337[$CellContext`a7, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$30337[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$30337[$CellContext`a7, "raw"] = Part[
      $CellContext`med[All], All, 18], $CellContext`sym$30337[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$30337[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$30337[$CellContext`Chla, "factorized"] = 
    True, $CellContext`sym$30337[$CellContext`Chla, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$30337[$CellContext`Chla, 
      "missing"] = {}, $CellContext`sym$30337[$CellContext`Chla, "raw"] = Part[
      $CellContext`med[All], All, 11], $CellContext`sym$30337[$CellContext`Cl,
       "factorized"] = 
    True, $CellContext`sym$30337[$CellContext`Cl, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$30337[$CellContext`Cl, 
      "missing"] = {}, $CellContext`sym$30337[$CellContext`Cl, "raw"] = Part[
      $CellContext`med[All], All, 
      6], $CellContext`sym$30337[$CellContext`mnO2, "factorized"] = 
    True, $CellContext`sym$30337[$CellContext`mnO2, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$30337[$CellContext`mnO2, 
      "missing"] = {}, $CellContext`sym$30337[$CellContext`mnO2, "raw"] = Part[
      $CellContext`med[All], All, 
      5], $CellContext`sym$30337[$CellContext`mxPH, "factorized"] = 
    True, $CellContext`sym$30337[$CellContext`mxPH, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$30337[$CellContext`mxPH, 
      "missing"] = {}, $CellContext`sym$30337[$CellContext`mxPH, "raw"] = Part[
      $CellContext`med[All], All, 4], $CellContext`sym$30337[$CellContext`NH4,
       "factorized"] = 
    True, $CellContext`sym$30337[$CellContext`NH4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$30337[$CellContext`NH4, 
      "missing"] = {}, $CellContext`sym$30337[$CellContext`NH4, "raw"] = Part[
      $CellContext`med[All], All, 8], $CellContext`sym$30337[$CellContext`NO3,
       "factorized"] = 
    True, $CellContext`sym$30337[$CellContext`NO3, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$30337[$CellContext`NO3, 
      "missing"] = {}, $CellContext`sym$30337[$CellContext`NO3, "raw"] = Part[
      $CellContext`med[All], All, 
      7], $CellContext`sym$30337[$CellContext`oPO4, "factorized"] = 
    True, $CellContext`sym$30337[$CellContext`oPO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$30337[$CellContext`oPO4, 
      "missing"] = {}, $CellContext`sym$30337[$CellContext`oPO4, "raw"] = Part[
      $CellContext`med[All], All, 9], $CellContext`sym$30337[$CellContext`PO4,
       "factorized"] = 
    True, $CellContext`sym$30337[$CellContext`PO4, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$30337[$CellContext`PO4, 
      "missing"] = {}, $CellContext`sym$30337[$CellContext`PO4, "raw"] = Part[
      $CellContext`med[All], All, 
      10], $CellContext`sym$30337[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$30337[$CellContext`season, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$30337[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$30337[$CellContext`season, "raw"] = 
    Part[
      $CellContext`med[All], All, 
      1], $CellContext`sym$30337[$CellContext`size, "factorized"] = 
    True, $CellContext`sym$30337[$CellContext`size, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$30337[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$30337[$CellContext`size, "raw"] = Part[
      $CellContext`med[All], All, 
      2], $CellContext`sym$30337[$CellContext`speed, "factorized"] = 
    True, $CellContext`sym$30337[$CellContext`speed, 
      "factors"] = $CellContext`med[
     All], $CellContext`sym$30337[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$30337[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`med[All], All, 3], 
    Attributes[$CellContext`sym$234705] = {
     Temporary}, $CellContext`sym$234705[$CellContext`a1] = Part[
      $CellContext`sym$234705[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$234705[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$234705[$CellContext`a2] = Part[
      $CellContext`sym$234705[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$234705[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$234705[$CellContext`a3] = Part[
      $CellContext`sym$234705[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$234705[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$234705[$CellContext`a4] = Part[
      $CellContext`sym$234705[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$234705[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$234705[$CellContext`a5] = Part[
      $CellContext`sym$234705[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$234705[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$234705[$CellContext`a6] = Part[
      $CellContext`sym$234705[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$234705[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$234705[$CellContext`a7] = Part[
      $CellContext`sym$234705[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$234705[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$234705[
     All] = {{"winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 
       170., 50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
      "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
       558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
      "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 125.667,
        187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
      "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 61.182, 
       138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
      "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222, 
       97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
      "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
       56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
      "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
       111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
      "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 44.667, 
       77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
      "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 71., 
       5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 0.8, 
       17., 0., 0., 2.9, 0., 0., 1.7}, {
      "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 20.75, 
       0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
      "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 19.,
        0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
      "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 41., 
       43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
      "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5, 
       31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
      "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 0.3, 
       52.2, 5., 7.8, 0., 4., 0., 0.}, {
      "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 98.25, 
       1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50., 
       1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
      "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 57.833, 
       0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
      "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 0.8, 
       50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
      "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
       564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
      "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 586.,
        16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
      "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 0.5, 
       15.5, 0., 0., 2.3, 0., 0., 0.}, {
      "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 7.6,
        23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
      "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
       27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
      "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 1.5,
        13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
      "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 44.136, 
       3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
      "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 0.5, 
       29.7, 0., 0., 4.9, 0., 0., 0.}, {
      "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
       Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
      "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 17.1,
        0., 19.6, 0., 0., 0., 2.5}, {
      "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5, 
       33.9, 1., 14.6, 0., 0., 0., 0.}, {
      "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 4.9, 
       3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
      "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 2.8, 
       6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
      "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 130.75, 
       5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
      "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47., 
       2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
      "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23., 
       0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
      "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 58.875, 
       84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
      "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 0.2,
        66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
       Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0., 
       0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
       196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
      "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
       182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
      "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001, 
       296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
      "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 59.429,
        175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
      "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
       344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
      "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 276.85001, 
       326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
      "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 40.667, 
       3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
      "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 3.3, 
       29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
      "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 0.8, 
       54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
       Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 0., 
       0.}, {"spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121.,
        2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 20.812,
        12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
      "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
       49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
      "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 22.9, 
       4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
      "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 11.8, 
       0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818, 
       0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
      "winter", "small", "high", 6.6, 10.8, 
       Missing[], 3.245, 10., 1., 6.5, 
       Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "medium", 5.6, 11.8, 
       Missing[], 2.22, 5., 1., 1., 
       Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 5.7, 10.8, 
       Missing[], 2.55, 10., 1., 4., 
       Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
      "spring", "small", "high", 6.6, 9.5, 
       Missing[], 1.32, 20., 1., 6., 
       Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
      "summer", "small", "high", 6.6, 10.8, 
       Missing[], 2.64, 10., 2., 11., 
       Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
      "autumn", "small", "medium", 6.6, 11.3, 
       Missing[], 4.17, 10., 1., 6., 
       Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
      "spring", "small", "medium", 6.5, 10.4, 
       Missing[], 5.97, 10., 2., 14., 
       Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
      "summer", "small", "medium", 6.4, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 14., 
       Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
      "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 6.667, 
       Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75, 1.,
        20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
      "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2, 
       0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
      "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 0.6,
        55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
      "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 10.75, 
       2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
      "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 0.5, 
       64.2, 0., 3., 0., 0., 0., 0.}, {
      "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75, 
       351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
      "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
       209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
      "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 151.125,
        279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
      "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
       152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
      "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
       58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
      "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
       249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
      "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 100., 
       233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
      "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 215.5, 
       18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
      "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 25.167, 
       102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
      "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
       105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
      "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
       111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
      "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 1.3, 
       6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
      "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 56.667, 
       2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
      "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 4.3,
        1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
      "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
       104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
      "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 69.93,
        3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
      "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
       214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
      "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
       254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
      "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 57.6,
        169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
      "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
       412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
      "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
       282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
      "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
       197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
      "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 267.75, 
       391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
      "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 191.75, 
       265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
      "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
       232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
      "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 144.66701, 
       244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
      "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 218., 
       6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
      "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 138.5,
        20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
      "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222, 
       239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
      "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
       235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
      "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75, 
       205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
      "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 31.333, 
       211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
      "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625, 
       186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
      "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 12.889, 
       154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
      "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 51.111, 
       183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
      "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
       292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
      "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
       285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
      "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
       201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
      "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
       275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
      "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
       124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
      "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 60.833, 
       141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
      "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71., 
       132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
      "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
       17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
      "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 0.3, 
       46.6, 0., 2.5, 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 8.692, 
       16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
      "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 37.857, 
       102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
      "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
       86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
      "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
       10.111, 
       Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 16.833, 
       18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
      "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545, 
       13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
      "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 261.60001, 
       432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
      "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
       320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
      "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 144., 
       287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
      "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
       166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
      "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
       222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
      "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 36.909, 
       122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
      "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556, 
       127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
      "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
       89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
      "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 55., 
       284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
      "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 102.333, 
       277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
      "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 75.875, 
       177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
      "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
       72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
      "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 48.667, 
       82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
      "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 48.625, 
       66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
      "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 23., 
       173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
      "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 317., 
       5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
      "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 84., 
       4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
      "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 2., 
       10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
      "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 88.5, 
       2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
      "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115., 
       11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
      "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 98.143, 
       2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
      "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
       143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
      "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
       197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
      "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 1., 
       19., 0., 22., 5., 1.1, 5.4, 0.}, {
      "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 10.583, 
       23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
      "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 200.231, 
       19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
      "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 77.333, 
       147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
      "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5, 
       276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
      "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
       123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
      "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 75.207,
        23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
      "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 116.2,
        7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
      "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
       188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
      "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
       72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
      "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 16., 
       0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
      "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 34., 
       53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
      "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 27.5, 
       76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
      "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
       58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
      "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 175.66701, 
       361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
      "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
       22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
      "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 26.8,
        0., 28., 0., 0., 0., 0., 15.1}, {
      "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
       54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
      "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333, 
       34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
      "spring", "large", "low", 9., 5.8, 
       Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 0., 
       0.}, {"spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
       151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
      "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
       269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
      "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 46.438, 
       81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
      "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 85., 
       2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
      "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 66.4, 
       171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
      "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 102.364, 
       232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
      "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 84.3, 
       146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
      "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
       246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
      "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 205.636, 
       219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
      "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 236.39999,
        272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
      "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 1081.66003, 
       346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 5.9, 1.7}, {
      "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 82.222,
        167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
      "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 64.389, 
       137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
      "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 87.333,
        194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
      "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
       159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
      "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 21.3, 
       1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
      "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 0.6,
        37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
      "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
       14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
      "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222, 7.,
        1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 0.8, 
       50.4, 3.8, 0., 0., 0., 0., 0.}, {
      "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 7.654, 
       4., 56.8, 5., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 2.86, 
       17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
      "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 56.091, 
       Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
      "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
       52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
      "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 104.727, 
       228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
      "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 85.4, 
       17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
      "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 87.125,
        14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
      "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 101.455, 
       18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
      "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 50.889, 
       127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
      "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
       81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
      "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 19.727, 
       50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
      "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111, 
       120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
      "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 51.111, 
       91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
      "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 19.111, 
       61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
      "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625, 
       79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
      "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333, 
       75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
      "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333, 
       140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
      "winter", "large", "medium", 8., 7.6, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
      "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
       140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 
       5.8}}, $CellContext`sym$234705[$CellContext`Chla] = Part[
      $CellContext`sym$234705[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {
          "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
           196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$234705[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$234705[$CellContext`Cl] = Part[
      $CellContext`sym$234705[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$234705[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$234705[$CellContext`mnO2] = Part[
      $CellContext`sym$234705[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$234705[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$234705[$CellContext`mxPH] = Part[
      $CellContext`sym$234705[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$234705[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$234705[$CellContext`NH4] = Part[
      $CellContext`sym$234705[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$234705[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$234705[$CellContext`NO3] = Part[
      $CellContext`sym$234705[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$234705[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$234705[$CellContext`oPO4] = Part[
      $CellContext`sym$234705[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$234705[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$234705[$CellContext`PO4] = Part[
      $CellContext`sym$234705[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$234705[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$234705[$CellContext`season] = Part[
      $CellContext`sym$234705[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$234705[$CellContext`season, 
         "missing"]]]], $CellContext`sym$234705[$CellContext`size] = Part[
      $CellContext`sym$234705[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$234705[$CellContext`size, 
         "missing"]]]], $CellContext`sym$234705[$CellContext`speed] = Part[
      $CellContext`sym$234705[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$234705[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$234705[$CellContext`a1, 
      "factorized"] = 
    False, $CellContext`sym$234705[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$234705[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$234705[All], 
      All, $CellContext`i$234717], $CellContext`sym$234705[$CellContext`a2, 
      "factorized"] = 
    False, $CellContext`sym$234705[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$234705[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$234705[All], 
      All, $CellContext`i$234718], $CellContext`sym$234705[$CellContext`a3, 
      "factorized"] = 
    False, $CellContext`sym$234705[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$234705[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$234705[All], 
      All, $CellContext`i$234719], $CellContext`sym$234705[$CellContext`a4, 
      "factorized"] = 
    False, $CellContext`sym$234705[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$234705[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$234705[All], 
      All, $CellContext`i$234720], $CellContext`sym$234705[$CellContext`a5, 
      "factorized"] = 
    False, $CellContext`sym$234705[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$234705[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$234705[All], 
      All, $CellContext`i$234721], $CellContext`sym$234705[$CellContext`a6, 
      "factorized"] = 
    False, $CellContext`sym$234705[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$234705[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$234705[All], 
      All, $CellContext`i$234722], $CellContext`sym$234705[$CellContext`a7, 
      "factorized"] = 
    False, $CellContext`sym$234705[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$234705[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$234705[All], 
      All, $CellContext`i$234723], $CellContext`sym$234705[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$234705[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed}, $CellContext`sym$234705[$CellContext`Chla, "factorized"] = 
    False, $CellContext`sym$234705[$CellContext`Chla, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {63}, {116}, {184}, {
     199}}, $CellContext`sym$234705[$CellContext`Chla, "raw"] = Part[
      $CellContext`sym$234705[All], 
      All, $CellContext`i$234716], $CellContext`sym$234705[$CellContext`Cl, 
      "factorized"] = 
    False, $CellContext`sym$234705[$CellContext`Cl, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {161}, {
     199}}, $CellContext`sym$234705[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$234705[All], 
      All, $CellContext`i$234711], $CellContext`sym$234705[$CellContext`mnO2, 
      "factorized"] = 
    False, $CellContext`sym$234705[$CellContext`mnO2, "missing"] = {{38}, {
     62}}, $CellContext`sym$234705[$CellContext`mnO2, "raw"] = Part[
      $CellContext`sym$234705[All], 
      All, $CellContext`i$234710], $CellContext`sym$234705[$CellContext`mxPH, 
      "factorized"] = 
    False, $CellContext`sym$234705[$CellContext`mxPH, "missing"] = {{
     48}}, $CellContext`sym$234705[$CellContext`mxPH, "raw"] = Part[
      $CellContext`sym$234705[All], 
      All, $CellContext`i$234709], $CellContext`sym$234705[$CellContext`NH4, 
      "factorized"] = 
    False, $CellContext`sym$234705[$CellContext`NH4, "missing"] = {{62}, {
     199}}, $CellContext`sym$234705[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$234705[All], 
      All, $CellContext`i$234713], $CellContext`sym$234705[$CellContext`NO3, 
      "factorized"] = 
    False, $CellContext`sym$234705[$CellContext`NO3, "missing"] = {{62}, {
     199}}, $CellContext`sym$234705[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$234705[All], 
      All, $CellContext`i$234712], $CellContext`sym$234705[$CellContext`oPO4, 
      "factorized"] = 
    False, $CellContext`sym$234705[$CellContext`oPO4, "missing"] = {{62}, {
     199}}, $CellContext`sym$234705[$CellContext`oPO4, "raw"] = Part[
      $CellContext`sym$234705[All], 
      All, $CellContext`i$234714], $CellContext`sym$234705[$CellContext`PO4, 
      "factorized"] = 
    False, $CellContext`sym$234705[$CellContext`PO4, "missing"] = {{28}, {
     199}}, $CellContext`sym$234705[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$234705[All], 
      All, $CellContext`i$234715], \
$CellContext`sym$234705[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$234705[$CellContext`season, "factors"] = 
    Part[{"autumn", "spring", "summer", "winter"}, 
      $CellContext`fordering[$CellContext`sym$234705, $CellContext`season]], \
$CellContext`sym$234705[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$234705[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$234705[All], 
      All, $CellContext`i$234706], $CellContext`sym$234705[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$234705[$CellContext`size, "factors"] = 
    Part[{"large", "medium", "small"}, 
      $CellContext`fordering[$CellContext`sym$234705, $CellContext`size]], \
$CellContext`sym$234705[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$234705[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$234705[All], 
      All, $CellContext`i$234707], $CellContext`sym$234705[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$234705[$CellContext`speed, "factors"] = 
    Part[{"high", "low", "medium"}, 
      $CellContext`fordering[$CellContext`sym$234705, $CellContext`speed]], \
$CellContext`sym$234705[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$234705[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$234705[All], All, $CellContext`i$234708], 
    Attributes[$CellContext`i$234715] = {Temporary}, $CellContext`i$234715 = 
    10, Attributes[$CellContext`i$234716] = {
     Temporary}, $CellContext`i$234716 = 11, 
    Attributes[$CellContext`i$234708] = {Temporary}, $CellContext`i$234708 = 
    3, Attributes[$CellContext`i$234719] = {Temporary}, $CellContext`i$234719 = 
    14, Attributes[$CellContext`i$234721] = {
     Temporary}, $CellContext`i$234721 = 16, 
    Attributes[$CellContext`i$234713] = {Temporary}, $CellContext`i$234713 = 
    8, Attributes[$CellContext`i$234714] = {Temporary}, $CellContext`i$234714 = 
    9, Attributes[$CellContext`i$234717] = {Temporary}, $CellContext`i$234717 = 
    12, Attributes[$CellContext`i$234712] = {
     Temporary}, $CellContext`i$234712 = 7, 
    Attributes[$CellContext`i$234720] = {Temporary}, $CellContext`i$234720 = 
    15, Attributes[$CellContext`i$234723] = {
     Temporary}, $CellContext`i$234723 = 18, 
    Attributes[$CellContext`i$234709] = {Temporary}, $CellContext`i$234709 = 
    4, Attributes[$CellContext`i$234711] = {Temporary}, $CellContext`i$234711 = 
    6, Attributes[$CellContext`i$234718] = {Temporary}, $CellContext`i$234718 = 
    13, Attributes[$CellContext`i$234707] = {
     Temporary}, $CellContext`i$234707 = 2, 
    Attributes[$CellContext`i$234710] = {Temporary}, $CellContext`i$234710 = 
    5, Attributes[$CellContext`i$234722] = {Temporary}, $CellContext`i$234722 = 
    17, Attributes[$CellContext`i$234706] = {
     Temporary}, $CellContext`i$234706 = 1, 
    Attributes[$CellContext`sym$228209] = {
     Temporary}, $CellContext`sym$228209[$CellContext`a1] = Part[
      $CellContext`sym$228209[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228209[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$228209[$CellContext`a2] = Part[
      $CellContext`sym$228209[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228209[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$228209[$CellContext`a3] = Part[
      $CellContext`sym$228209[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228209[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$228209[$CellContext`a4] = Part[
      $CellContext`sym$228209[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228209[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$228209[$CellContext`a5] = Part[
      $CellContext`sym$228209[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228209[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$228209[$CellContext`a6] = Part[
      $CellContext`sym$228209[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228209[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$228209[$CellContext`a7] = Part[
      $CellContext`sym$228209[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228209[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$228209[
     All] = {{"winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 
       170., 50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
      "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
       558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
      "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 125.667,
        187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
      "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 61.182, 
       138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
      "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222, 
       97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
      "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
       56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
      "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
       111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
      "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 44.667, 
       77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
      "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 71., 
       5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 0.8, 
       17., 0., 0., 2.9, 0., 0., 1.7}, {
      "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 20.75, 
       0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
      "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 19.,
        0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
      "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 41., 
       43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
      "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5, 
       31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
      "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 0.3, 
       52.2, 5., 7.8, 0., 4., 0., 0.}, {
      "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 98.25, 
       1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50., 
       1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
      "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 57.833, 
       0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
      "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 0.8, 
       50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
      "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
       564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
      "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 586.,
        16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
      "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 0.5, 
       15.5, 0., 0., 2.3, 0., 0., 0.}, {
      "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 7.6,
        23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
      "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
       27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
      "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 1.5,
        13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
      "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 44.136, 
       3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
      "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 0.5, 
       29.7, 0., 0., 4.9, 0., 0., 0.}, {
      "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
       Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
      "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 17.1,
        0., 19.6, 0., 0., 0., 2.5}, {
      "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5, 
       33.9, 1., 14.6, 0., 0., 0., 0.}, {
      "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 4.9, 
       3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
      "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 2.8, 
       6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
      "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 130.75, 
       5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
      "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47., 
       2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
      "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23., 
       0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
      "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 58.875, 
       84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
      "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 0.2,
        66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
       Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0., 
       0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
       196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
      "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
       182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
      "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001, 
       296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
      "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 59.429,
        175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
      "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
       344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
      "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 276.85001, 
       326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
      "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 40.667, 
       3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
      "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 3.3, 
       29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
      "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 0.8, 
       54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
       Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 0., 
       0.}, {"spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121.,
        2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 20.812,
        12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
      "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
       49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
      "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 22.9, 
       4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
      "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 11.8, 
       0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818, 
       0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
      "winter", "small", "high", 6.6, 10.8, 
       Missing[], 3.245, 10., 1., 6.5, 
       Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "medium", 5.6, 11.8, 
       Missing[], 2.22, 5., 1., 1., 
       Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 5.7, 10.8, 
       Missing[], 2.55, 10., 1., 4., 
       Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
      "spring", "small", "high", 6.6, 9.5, 
       Missing[], 1.32, 20., 1., 6., 
       Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
      "summer", "small", "high", 6.6, 10.8, 
       Missing[], 2.64, 10., 2., 11., 
       Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
      "autumn", "small", "medium", 6.6, 11.3, 
       Missing[], 4.17, 10., 1., 6., 
       Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
      "spring", "small", "medium", 6.5, 10.4, 
       Missing[], 5.97, 10., 2., 14., 
       Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
      "summer", "small", "medium", 6.4, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 14., 
       Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
      "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 6.667, 
       Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75, 1.,
        20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
      "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2, 
       0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
      "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 0.6,
        55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
      "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 10.75, 
       2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
      "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 0.5, 
       64.2, 0., 3., 0., 0., 0., 0.}, {
      "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75, 
       351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
      "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
       209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
      "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 151.125,
        279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
      "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
       152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
      "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
       58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
      "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
       249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
      "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 100., 
       233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
      "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 215.5, 
       18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
      "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 25.167, 
       102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
      "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
       105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
      "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
       111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
      "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 1.3, 
       6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
      "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 56.667, 
       2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
      "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 4.3,
        1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
      "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
       104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
      "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 69.93,
        3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
      "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
       214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
      "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
       254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
      "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 57.6,
        169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
      "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
       412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
      "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
       282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
      "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
       197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
      "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 267.75, 
       391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
      "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 191.75, 
       265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
      "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
       232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
      "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 144.66701, 
       244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
      "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 218., 
       6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
      "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 138.5,
        20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
      "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222, 
       239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
      "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
       235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
      "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75, 
       205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
      "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 31.333, 
       211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
      "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625, 
       186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
      "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 12.889, 
       154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
      "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 51.111, 
       183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
      "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
       292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
      "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
       285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
      "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
       201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
      "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
       275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
      "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
       124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
      "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 60.833, 
       141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
      "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71., 
       132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
      "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
       17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
      "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 0.3, 
       46.6, 0., 2.5, 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 8.692, 
       16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
      "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 37.857, 
       102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
      "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
       86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
      "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
       10.111, 
       Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 16.833, 
       18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
      "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545, 
       13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
      "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 261.60001, 
       432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
      "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
       320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
      "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 144., 
       287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
      "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
       166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
      "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
       222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
      "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 36.909, 
       122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
      "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556, 
       127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
      "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
       89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
      "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 55., 
       284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
      "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 102.333, 
       277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
      "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 75.875, 
       177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
      "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
       72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
      "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 48.667, 
       82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
      "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 48.625, 
       66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
      "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 23., 
       173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
      "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 317., 
       5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
      "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 84., 
       4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
      "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 2., 
       10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
      "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 88.5, 
       2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
      "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115., 
       11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
      "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 98.143, 
       2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
      "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
       143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
      "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
       197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
      "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 1., 
       19., 0., 22., 5., 1.1, 5.4, 0.}, {
      "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 10.583, 
       23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
      "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 200.231, 
       19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
      "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 77.333, 
       147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
      "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5, 
       276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
      "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
       123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
      "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 75.207,
        23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
      "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 116.2,
        7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
      "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
       188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
      "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
       72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
      "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 16., 
       0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
      "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 34., 
       53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
      "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 27.5, 
       76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
      "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
       58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
      "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 175.66701, 
       361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
      "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
       22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
      "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 26.8,
        0., 28., 0., 0., 0., 0., 15.1}, {
      "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
       54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
      "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333, 
       34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
      "spring", "large", "low", 9., 5.8, 
       Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 0., 
       0.}, {"spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
       151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
      "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
       269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
      "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 46.438, 
       81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
      "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 85., 
       2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
      "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 66.4, 
       171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
      "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 102.364, 
       232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
      "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 84.3, 
       146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
      "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
       246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
      "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 205.636, 
       219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
      "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 236.39999,
        272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
      "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 1081.66003, 
       346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 5.9, 1.7}, {
      "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 82.222,
        167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
      "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 64.389, 
       137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
      "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 87.333,
        194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
      "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
       159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
      "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 21.3, 
       1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
      "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 0.6,
        37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
      "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
       14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
      "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222, 7.,
        1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 0.8, 
       50.4, 3.8, 0., 0., 0., 0., 0.}, {
      "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 7.654, 
       4., 56.8, 5., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 2.86, 
       17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
      "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 56.091, 
       Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
      "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
       52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
      "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 104.727, 
       228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
      "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 85.4, 
       17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
      "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 87.125,
        14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
      "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 101.455, 
       18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
      "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 50.889, 
       127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
      "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
       81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
      "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 19.727, 
       50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
      "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111, 
       120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
      "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 51.111, 
       91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
      "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 19.111, 
       61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
      "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625, 
       79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
      "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333, 
       75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
      "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333, 
       140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
      "winter", "large", "medium", 8., 7.6, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
      "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
       140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 
       5.8}}, $CellContext`sym$228209[$CellContext`Chla] = Part[
      $CellContext`sym$228209[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {
          "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
           196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228209[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$228209[$CellContext`Cl] = Part[
      $CellContext`sym$228209[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228209[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$228209[$CellContext`mnO2] = Part[
      $CellContext`sym$228209[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228209[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$228209[$CellContext`mxPH] = Part[
      $CellContext`sym$228209[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228209[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$228209[$CellContext`NH4] = Part[
      $CellContext`sym$228209[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228209[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$228209[$CellContext`NO3] = Part[
      $CellContext`sym$228209[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228209[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$228209[$CellContext`oPO4] = Part[
      $CellContext`sym$228209[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228209[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$228209[$CellContext`PO4] = Part[
      $CellContext`sym$228209[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228209[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$228209[$CellContext`season] = Part[
      $CellContext`sym$228209[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228209[$CellContext`season, 
         "missing"]]]], $CellContext`sym$228209[$CellContext`size] = Part[
      $CellContext`sym$228209[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228209[$CellContext`size, 
         "missing"]]]], $CellContext`sym$228209[$CellContext`speed] = Part[
      $CellContext`sym$228209[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228209[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$228209[$CellContext`a1, 
      "factorized"] = 
    False, $CellContext`sym$228209[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$228209[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$228209[All], 
      All, $CellContext`i$228221], $CellContext`sym$228209[$CellContext`a2, 
      "factorized"] = 
    False, $CellContext`sym$228209[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$228209[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$228209[All], 
      All, $CellContext`i$228222], $CellContext`sym$228209[$CellContext`a3, 
      "factorized"] = 
    False, $CellContext`sym$228209[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$228209[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$228209[All], 
      All, $CellContext`i$228223], $CellContext`sym$228209[$CellContext`a4, 
      "factorized"] = 
    False, $CellContext`sym$228209[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$228209[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$228209[All], 
      All, $CellContext`i$228224], $CellContext`sym$228209[$CellContext`a5, 
      "factorized"] = 
    False, $CellContext`sym$228209[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$228209[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$228209[All], 
      All, $CellContext`i$228225], $CellContext`sym$228209[$CellContext`a6, 
      "factorized"] = 
    False, $CellContext`sym$228209[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$228209[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$228209[All], 
      All, $CellContext`i$228226], $CellContext`sym$228209[$CellContext`a7, 
      "factorized"] = 
    False, $CellContext`sym$228209[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$228209[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$228209[All], 
      All, $CellContext`i$228227], $CellContext`sym$228209[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$228209[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed}, $CellContext`sym$228209[$CellContext`Chla, "factorized"] = 
    False, $CellContext`sym$228209[$CellContext`Chla, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {63}, {116}, {184}, {
     199}}, $CellContext`sym$228209[$CellContext`Chla, "raw"] = Part[
      $CellContext`sym$228209[All], 
      All, $CellContext`i$228220], $CellContext`sym$228209[$CellContext`Cl, 
      "factorized"] = 
    False, $CellContext`sym$228209[$CellContext`Cl, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {161}, {
     199}}, $CellContext`sym$228209[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$228209[All], 
      All, $CellContext`i$228215], $CellContext`sym$228209[$CellContext`mnO2, 
      "factorized"] = 
    False, $CellContext`sym$228209[$CellContext`mnO2, "missing"] = {{38}, {
     62}}, $CellContext`sym$228209[$CellContext`mnO2, "raw"] = Part[
      $CellContext`sym$228209[All], 
      All, $CellContext`i$228214], $CellContext`sym$228209[$CellContext`mxPH, 
      "factorized"] = 
    False, $CellContext`sym$228209[$CellContext`mxPH, "missing"] = {{
     48}}, $CellContext`sym$228209[$CellContext`mxPH, "raw"] = Part[
      $CellContext`sym$228209[All], 
      All, $CellContext`i$228213], $CellContext`sym$228209[$CellContext`NH4, 
      "factorized"] = 
    False, $CellContext`sym$228209[$CellContext`NH4, "missing"] = {{62}, {
     199}}, $CellContext`sym$228209[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$228209[All], 
      All, $CellContext`i$228217], $CellContext`sym$228209[$CellContext`NO3, 
      "factorized"] = 
    False, $CellContext`sym$228209[$CellContext`NO3, "missing"] = {{62}, {
     199}}, $CellContext`sym$228209[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$228209[All], 
      All, $CellContext`i$228216], $CellContext`sym$228209[$CellContext`oPO4, 
      "factorized"] = 
    False, $CellContext`sym$228209[$CellContext`oPO4, "missing"] = {{62}, {
     199}}, $CellContext`sym$228209[$CellContext`oPO4, "raw"] = Part[
      $CellContext`sym$228209[All], 
      All, $CellContext`i$228218], $CellContext`sym$228209[$CellContext`PO4, 
      "factorized"] = 
    False, $CellContext`sym$228209[$CellContext`PO4, "missing"] = {{28}, {
     199}}, $CellContext`sym$228209[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$228209[All], 
      All, $CellContext`i$228219], \
$CellContext`sym$228209[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$228209[$CellContext`season, "factors"] = 
    Part[{"autumn", "spring", "summer", "winter"}, 
      $CellContext`fordering[$CellContext`sym$228209, $CellContext`season]], \
$CellContext`sym$228209[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$228209[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$228209[All], 
      All, $CellContext`i$228210], $CellContext`sym$228209[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$228209[$CellContext`size, "factors"] = 
    Part[{"large", "medium", "small"}, 
      $CellContext`fordering[$CellContext`sym$228209, $CellContext`size]], \
$CellContext`sym$228209[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$228209[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$228209[All], 
      All, $CellContext`i$228211], $CellContext`sym$228209[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$228209[$CellContext`speed, "factors"] = 
    Part[{"high", "low", "medium"}, 
      $CellContext`fordering[$CellContext`sym$228209, $CellContext`speed]], \
$CellContext`sym$228209[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$228209[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$228209[All], All, $CellContext`i$228212], 
    Attributes[$CellContext`i$228212] = {Temporary}, $CellContext`i$228212 = 
    3, Attributes[$CellContext`i$228218] = {Temporary}, $CellContext`i$228218 = 
    9, Attributes[$CellContext`i$228214] = {Temporary}, $CellContext`i$228214 = 
    5, Attributes[$CellContext`i$228220] = {Temporary}, $CellContext`i$228220 = 
    11, Attributes[$CellContext`i$228210] = {
     Temporary}, $CellContext`i$228210 = 1, 
    Attributes[$CellContext`i$228221] = {Temporary}, $CellContext`i$228221 = 
    12, Attributes[$CellContext`i$228224] = {
     Temporary}, $CellContext`i$228224 = 15, 
    Attributes[$CellContext`i$228223] = {Temporary}, $CellContext`i$228223 = 
    14, Attributes[$CellContext`i$228217] = {
     Temporary}, $CellContext`i$228217 = 8, 
    Attributes[$CellContext`i$228227] = {Temporary}, $CellContext`i$228227 = 
    18, Attributes[$CellContext`i$228222] = {
     Temporary}, $CellContext`i$228222 = 13, 
    Attributes[$CellContext`i$228216] = {Temporary}, $CellContext`i$228216 = 
    7, Attributes[$CellContext`i$228215] = {Temporary}, $CellContext`i$228215 = 
    6, Attributes[$CellContext`i$228211] = {Temporary}, $CellContext`i$228211 = 
    2, Attributes[$CellContext`i$228225] = {Temporary}, $CellContext`i$228225 = 
    16, Attributes[$CellContext`i$228213] = {
     Temporary}, $CellContext`i$228213 = 4, 
    Attributes[$CellContext`i$228226] = {Temporary}, $CellContext`i$228226 = 
    17, Attributes[$CellContext`i$228219] = {
     Temporary}, $CellContext`i$228219 = 10, 
    Attributes[$CellContext`sym$237297] = {
     Temporary}, $CellContext`sym$237297[$CellContext`a1] = Part[
      $CellContext`sym$237297[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$237297[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$237297[$CellContext`a2] = Part[
      $CellContext`sym$237297[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$237297[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$237297[$CellContext`a3] = Part[
      $CellContext`sym$237297[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$237297[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$237297[$CellContext`a4] = Part[
      $CellContext`sym$237297[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$237297[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$237297[$CellContext`a5] = Part[
      $CellContext`sym$237297[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$237297[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$237297[$CellContext`a6] = Part[
      $CellContext`sym$237297[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$237297[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$237297[$CellContext`a7] = Part[
      $CellContext`sym$237297[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$237297[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$237297[
     All] = {{"winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 
       170., 50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
      "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
       558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
      "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 125.667,
        187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
      "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 61.182, 
       138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
      "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222, 
       97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
      "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
       56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
      "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
       111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
      "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 44.667, 
       77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
      "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 71., 
       5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 0.8, 
       17., 0., 0., 2.9, 0., 0., 1.7}, {
      "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 20.75, 
       0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
      "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 19.,
        0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
      "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 41., 
       43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
      "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5, 
       31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
      "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 0.3, 
       52.2, 5., 7.8, 0., 4., 0., 0.}, {
      "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 98.25, 
       1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50., 
       1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
      "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 57.833, 
       0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
      "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 0.8, 
       50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
      "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
       564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
      "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 586.,
        16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
      "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 0.5, 
       15.5, 0., 0., 2.3, 0., 0., 0.}, {
      "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 7.6,
        23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
      "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
       27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
      "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 1.5,
        13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
      "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 44.136, 
       3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
      "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 0.5, 
       29.7, 0., 0., 4.9, 0., 0., 0.}, {
      "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
       Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
      "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 17.1,
        0., 19.6, 0., 0., 0., 2.5}, {
      "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5, 
       33.9, 1., 14.6, 0., 0., 0., 0.}, {
      "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 4.9, 
       3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
      "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 2.8, 
       6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
      "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 130.75, 
       5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
      "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47., 
       2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
      "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23., 
       0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
      "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 58.875, 
       84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
      "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 0.2,
        66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
       Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0., 
       0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
       196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
      "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
       182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
      "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001, 
       296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
      "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 59.429,
        175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
      "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
       344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
      "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 276.85001, 
       326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
      "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 40.667, 
       3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
      "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 3.3, 
       29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
      "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 0.8, 
       54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
       Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 0., 
       0.}, {"spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121.,
        2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 20.812,
        12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
      "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
       49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
      "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 22.9, 
       4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
      "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 11.8, 
       0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818, 
       0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
      "winter", "small", "high", 6.6, 10.8, 
       Missing[], 3.245, 10., 1., 6.5, 
       Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "medium", 5.6, 11.8, 
       Missing[], 2.22, 5., 1., 1., 
       Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 5.7, 10.8, 
       Missing[], 2.55, 10., 1., 4., 
       Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
      "spring", "small", "high", 6.6, 9.5, 
       Missing[], 1.32, 20., 1., 6., 
       Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
      "summer", "small", "high", 6.6, 10.8, 
       Missing[], 2.64, 10., 2., 11., 
       Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
      "autumn", "small", "medium", 6.6, 11.3, 
       Missing[], 4.17, 10., 1., 6., 
       Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
      "spring", "small", "medium", 6.5, 10.4, 
       Missing[], 5.97, 10., 2., 14., 
       Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
      "summer", "small", "medium", 6.4, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 14., 
       Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
      "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 6.667, 
       Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75, 1.,
        20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
      "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2, 
       0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
      "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 0.6,
        55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
      "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 10.75, 
       2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
      "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 0.5, 
       64.2, 0., 3., 0., 0., 0., 0.}, {
      "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75, 
       351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
      "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
       209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
      "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 151.125,
        279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
      "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
       152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
      "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
       58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
      "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
       249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
      "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 100., 
       233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
      "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 215.5, 
       18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
      "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 25.167, 
       102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
      "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
       105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
      "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
       111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
      "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 1.3, 
       6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
      "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 56.667, 
       2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
      "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 4.3,
        1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
      "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
       104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
      "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 69.93,
        3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
      "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
       214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
      "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
       254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
      "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 57.6,
        169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
      "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
       412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
      "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
       282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
      "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
       197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
      "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 267.75, 
       391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
      "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 191.75, 
       265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
      "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
       232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
      "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 144.66701, 
       244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
      "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 218., 
       6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
      "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 138.5,
        20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
      "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222, 
       239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
      "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
       235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
      "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75, 
       205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
      "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 31.333, 
       211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
      "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625, 
       186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
      "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 12.889, 
       154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
      "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 51.111, 
       183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
      "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
       292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
      "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
       285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
      "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
       201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
      "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
       275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
      "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
       124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
      "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 60.833, 
       141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
      "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71., 
       132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
      "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
       17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
      "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 0.3, 
       46.6, 0., 2.5, 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 8.692, 
       16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
      "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 37.857, 
       102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
      "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
       86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
      "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
       10.111, 
       Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 16.833, 
       18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
      "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545, 
       13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
      "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 261.60001, 
       432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
      "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
       320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
      "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 144., 
       287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
      "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
       166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
      "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
       222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
      "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 36.909, 
       122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
      "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556, 
       127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
      "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
       89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
      "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 55., 
       284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
      "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 102.333, 
       277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
      "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 75.875, 
       177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
      "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
       72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
      "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 48.667, 
       82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
      "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 48.625, 
       66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
      "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 23., 
       173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
      "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 317., 
       5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
      "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 84., 
       4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
      "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 2., 
       10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
      "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 88.5, 
       2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
      "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115., 
       11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
      "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 98.143, 
       2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
      "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
       143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
      "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
       197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
      "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 1., 
       19., 0., 22., 5., 1.1, 5.4, 0.}, {
      "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 10.583, 
       23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
      "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 200.231, 
       19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
      "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 77.333, 
       147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
      "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5, 
       276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
      "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
       123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
      "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 75.207,
        23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
      "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 116.2,
        7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
      "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
       188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
      "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
       72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
      "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 16., 
       0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
      "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 34., 
       53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
      "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 27.5, 
       76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
      "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
       58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
      "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 175.66701, 
       361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
      "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
       22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
      "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 26.8,
        0., 28., 0., 0., 0., 0., 15.1}, {
      "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
       54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
      "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333, 
       34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
      "spring", "large", "low", 9., 5.8, 
       Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 0., 
       0.}, {"spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
       151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
      "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
       269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
      "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 46.438, 
       81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
      "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 85., 
       2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
      "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 66.4, 
       171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
      "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 102.364, 
       232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
      "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 84.3, 
       146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
      "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
       246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
      "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 205.636, 
       219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
      "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 236.39999,
        272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
      "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 1081.66003, 
       346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 5.9, 1.7}, {
      "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 82.222,
        167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
      "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 64.389, 
       137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
      "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 87.333,
        194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
      "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
       159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
      "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 21.3, 
       1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
      "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 0.6,
        37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
      "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
       14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
      "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222, 7.,
        1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 0.8, 
       50.4, 3.8, 0., 0., 0., 0., 0.}, {
      "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 7.654, 
       4., 56.8, 5., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 2.86, 
       17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
      "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 56.091, 
       Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
      "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
       52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
      "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 104.727, 
       228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
      "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 85.4, 
       17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
      "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 87.125,
        14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
      "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 101.455, 
       18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
      "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 50.889, 
       127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
      "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
       81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
      "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 19.727, 
       50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
      "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111, 
       120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
      "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 51.111, 
       91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
      "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 19.111, 
       61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
      "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625, 
       79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
      "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333, 
       75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
      "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333, 
       140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
      "winter", "large", "medium", 8., 7.6, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
      "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
       140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 
       5.8}}, $CellContext`sym$237297[$CellContext`Chla] = Part[
      $CellContext`sym$237297[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {
          "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
           196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$237297[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$237297[$CellContext`Cl] = Part[
      $CellContext`sym$237297[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$237297[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$237297[$CellContext`mnO2] = Part[
      $CellContext`sym$237297[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$237297[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$237297[$CellContext`mxPH] = Part[
      $CellContext`sym$237297[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$237297[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$237297[$CellContext`NH4] = Part[
      $CellContext`sym$237297[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$237297[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$237297[$CellContext`NO3] = Part[
      $CellContext`sym$237297[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$237297[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$237297[$CellContext`oPO4] = Part[
      $CellContext`sym$237297[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$237297[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$237297[$CellContext`PO4] = Part[
      $CellContext`sym$237297[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$237297[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$237297[$CellContext`season] = Part[
      $CellContext`sym$237297[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$237297[$CellContext`season, 
         "missing"]]]], $CellContext`sym$237297[$CellContext`size] = Part[
      $CellContext`sym$237297[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$237297[$CellContext`size, 
         "missing"]]]], $CellContext`sym$237297[$CellContext`speed] = Part[
      $CellContext`sym$237297[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$237297[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$237297[$CellContext`a1, 
      "factorized"] = 
    False, $CellContext`sym$237297[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$237297[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$237297[All], 
      All, $CellContext`i$237309], $CellContext`sym$237297[$CellContext`a2, 
      "factorized"] = 
    False, $CellContext`sym$237297[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$237297[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$237297[All], 
      All, $CellContext`i$237310], $CellContext`sym$237297[$CellContext`a3, 
      "factorized"] = 
    False, $CellContext`sym$237297[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$237297[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$237297[All], 
      All, $CellContext`i$237311], $CellContext`sym$237297[$CellContext`a4, 
      "factorized"] = 
    False, $CellContext`sym$237297[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$237297[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$237297[All], 
      All, $CellContext`i$237312], $CellContext`sym$237297[$CellContext`a5, 
      "factorized"] = 
    False, $CellContext`sym$237297[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$237297[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$237297[All], 
      All, $CellContext`i$237313], $CellContext`sym$237297[$CellContext`a6, 
      "factorized"] = 
    False, $CellContext`sym$237297[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$237297[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$237297[All], 
      All, $CellContext`i$237314], $CellContext`sym$237297[$CellContext`a7, 
      "factorized"] = 
    False, $CellContext`sym$237297[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$237297[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$237297[All], 
      All, $CellContext`i$237315], $CellContext`sym$237297[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$237297[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed}, $CellContext`sym$237297[$CellContext`Chla, "factorized"] = 
    False, $CellContext`sym$237297[$CellContext`Chla, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {63}, {116}, {184}, {
     199}}, $CellContext`sym$237297[$CellContext`Chla, "raw"] = Part[
      $CellContext`sym$237297[All], 
      All, $CellContext`i$237308], $CellContext`sym$237297[$CellContext`Cl, 
      "factorized"] = 
    False, $CellContext`sym$237297[$CellContext`Cl, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {161}, {
     199}}, $CellContext`sym$237297[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$237297[All], 
      All, $CellContext`i$237303], $CellContext`sym$237297[$CellContext`mnO2, 
      "factorized"] = 
    False, $CellContext`sym$237297[$CellContext`mnO2, "missing"] = {{38}, {
     62}}, $CellContext`sym$237297[$CellContext`mnO2, "raw"] = Part[
      $CellContext`sym$237297[All], 
      All, $CellContext`i$237302], $CellContext`sym$237297[$CellContext`mxPH, 
      "factorized"] = 
    False, $CellContext`sym$237297[$CellContext`mxPH, "missing"] = {{
     48}}, $CellContext`sym$237297[$CellContext`mxPH, "raw"] = Part[
      $CellContext`sym$237297[All], 
      All, $CellContext`i$237301], $CellContext`sym$237297[$CellContext`NH4, 
      "factorized"] = 
    False, $CellContext`sym$237297[$CellContext`NH4, "missing"] = {{62}, {
     199}}, $CellContext`sym$237297[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$237297[All], 
      All, $CellContext`i$237305], $CellContext`sym$237297[$CellContext`NO3, 
      "factorized"] = 
    False, $CellContext`sym$237297[$CellContext`NO3, "missing"] = {{62}, {
     199}}, $CellContext`sym$237297[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$237297[All], 
      All, $CellContext`i$237304], $CellContext`sym$237297[$CellContext`oPO4, 
      "factorized"] = 
    False, $CellContext`sym$237297[$CellContext`oPO4, "missing"] = {{62}, {
     199}}, $CellContext`sym$237297[$CellContext`oPO4, "raw"] = Part[
      $CellContext`sym$237297[All], 
      All, $CellContext`i$237306], $CellContext`sym$237297[$CellContext`PO4, 
      "factorized"] = 
    False, $CellContext`sym$237297[$CellContext`PO4, "missing"] = {{28}, {
     199}}, $CellContext`sym$237297[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$237297[All], 
      All, $CellContext`i$237307], \
$CellContext`sym$237297[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$237297[$CellContext`season, "factors"] = 
    Part[{"autumn", "spring", "summer", "winter"}, 
      $CellContext`fordering[$CellContext`sym$237297, $CellContext`season]], \
$CellContext`sym$237297[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$237297[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$237297[All], 
      All, $CellContext`i$237298], $CellContext`sym$237297[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$237297[$CellContext`size, "factors"] = 
    Part[{"large", "medium", "small"}, 
      $CellContext`fordering[$CellContext`sym$237297, $CellContext`size]], \
$CellContext`sym$237297[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$237297[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$237297[All], 
      All, $CellContext`i$237299], $CellContext`sym$237297[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$237297[$CellContext`speed, "factors"] = 
    Part[{"high", "low", "medium"}, 
      $CellContext`fordering[$CellContext`sym$237297, $CellContext`speed]], \
$CellContext`sym$237297[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$237297[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$237297[All], All, $CellContext`i$237300], 
    Attributes[$CellContext`i$237312] = {Temporary}, $CellContext`i$237312 = 
    15, Attributes[$CellContext`i$237308] = {
     Temporary}, $CellContext`i$237308 = 11, 
    Attributes[$CellContext`i$237309] = {Temporary}, $CellContext`i$237309 = 
    12, Attributes[$CellContext`i$237305] = {
     Temporary}, $CellContext`i$237305 = 8, 
    Attributes[$CellContext`i$237300] = {Temporary}, $CellContext`i$237300 = 
    3, Attributes[$CellContext`i$237303] = {Temporary}, $CellContext`i$237303 = 
    6, Attributes[$CellContext`i$237298] = {Temporary}, $CellContext`i$237298 = 
    1, Attributes[$CellContext`i$237310] = {Temporary}, $CellContext`i$237310 = 
    13, Attributes[$CellContext`i$237311] = {
     Temporary}, $CellContext`i$237311 = 14, 
    Attributes[$CellContext`i$237302] = {Temporary}, $CellContext`i$237302 = 
    5, Attributes[$CellContext`i$237307] = {Temporary}, $CellContext`i$237307 = 
    10, Attributes[$CellContext`i$237301] = {
     Temporary}, $CellContext`i$237301 = 4, 
    Attributes[$CellContext`i$237304] = {Temporary}, $CellContext`i$237304 = 
    7, Attributes[$CellContext`i$237306] = {Temporary}, $CellContext`i$237306 = 
    9, Attributes[$CellContext`i$237313] = {Temporary}, $CellContext`i$237313 = 
    16, Attributes[$CellContext`i$237299] = {
     Temporary}, $CellContext`i$237299 = 2, 
    Attributes[$CellContext`i$237314] = {Temporary}, $CellContext`i$237314 = 
    17, Attributes[$CellContext`i$237315] = {
     Temporary}, $CellContext`i$237315 = 18, 
    Attributes[$CellContext`sym$233406] = {
     Temporary}, $CellContext`sym$233406[$CellContext`a1] = Part[
      $CellContext`sym$233406[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$233406[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$233406[$CellContext`a2] = Part[
      $CellContext`sym$233406[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$233406[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$233406[$CellContext`a3] = Part[
      $CellContext`sym$233406[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$233406[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$233406[$CellContext`a4] = Part[
      $CellContext`sym$233406[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$233406[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$233406[$CellContext`a5] = Part[
      $CellContext`sym$233406[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$233406[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$233406[$CellContext`a6] = Part[
      $CellContext`sym$233406[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$233406[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$233406[$CellContext`a7] = Part[
      $CellContext`sym$233406[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$233406[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$233406[
     All] = {{"winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 
       170., 50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
      "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
       558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
      "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 125.667,
        187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
      "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 61.182, 
       138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
      "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222, 
       97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
      "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
       56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
      "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
       111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
      "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 44.667, 
       77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
      "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 71., 
       5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 0.8, 
       17., 0., 0., 2.9, 0., 0., 1.7}, {
      "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 20.75, 
       0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
      "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 19.,
        0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
      "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 41., 
       43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
      "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5, 
       31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
      "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 0.3, 
       52.2, 5., 7.8, 0., 4., 0., 0.}, {
      "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 98.25, 
       1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50., 
       1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
      "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 57.833, 
       0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
      "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 0.8, 
       50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
      "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
       564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
      "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 586.,
        16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
      "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 0.5, 
       15.5, 0., 0., 2.3, 0., 0., 0.}, {
      "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 7.6,
        23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
      "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
       27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
      "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 1.5,
        13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
      "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 44.136, 
       3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
      "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 0.5, 
       29.7, 0., 0., 4.9, 0., 0., 0.}, {
      "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
       Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
      "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 17.1,
        0., 19.6, 0., 0., 0., 2.5}, {
      "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5, 
       33.9, 1., 14.6, 0., 0., 0., 0.}, {
      "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 4.9, 
       3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
      "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 2.8, 
       6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
      "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 130.75, 
       5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
      "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47., 
       2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
      "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23., 
       0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
      "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 58.875, 
       84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
      "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 0.2,
        66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
       Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0., 
       0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
       196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
      "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
       182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
      "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001, 
       296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
      "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 59.429,
        175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
      "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
       344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
      "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 276.85001, 
       326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
      "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 40.667, 
       3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
      "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 3.3, 
       29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
      "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 0.8, 
       54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
       Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 0., 
       0.}, {"spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121.,
        2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 20.812,
        12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
      "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
       49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
      "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 22.9, 
       4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
      "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 11.8, 
       0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818, 
       0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
      "winter", "small", "high", 6.6, 10.8, 
       Missing[], 3.245, 10., 1., 6.5, 
       Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "medium", 5.6, 11.8, 
       Missing[], 2.22, 5., 1., 1., 
       Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 5.7, 10.8, 
       Missing[], 2.55, 10., 1., 4., 
       Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
      "spring", "small", "high", 6.6, 9.5, 
       Missing[], 1.32, 20., 1., 6., 
       Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
      "summer", "small", "high", 6.6, 10.8, 
       Missing[], 2.64, 10., 2., 11., 
       Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
      "autumn", "small", "medium", 6.6, 11.3, 
       Missing[], 4.17, 10., 1., 6., 
       Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
      "spring", "small", "medium", 6.5, 10.4, 
       Missing[], 5.97, 10., 2., 14., 
       Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
      "summer", "small", "medium", 6.4, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 14., 
       Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
      "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 6.667, 
       Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75, 1.,
        20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
      "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2, 
       0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
      "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 0.6,
        55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
      "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 10.75, 
       2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
      "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 0.5, 
       64.2, 0., 3., 0., 0., 0., 0.}, {
      "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75, 
       351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
      "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
       209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
      "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 151.125,
        279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
      "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
       152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
      "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
       58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
      "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
       249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
      "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 100., 
       233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
      "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 215.5, 
       18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
      "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 25.167, 
       102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
      "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
       105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
      "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
       111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
      "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 1.3, 
       6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
      "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 56.667, 
       2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
      "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 4.3,
        1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
      "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
       104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
      "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 69.93,
        3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
      "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
       214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
      "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
       254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
      "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 57.6,
        169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
      "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
       412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
      "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
       282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
      "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
       197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
      "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 267.75, 
       391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
      "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 191.75, 
       265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
      "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
       232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
      "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 144.66701, 
       244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
      "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 218., 
       6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
      "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 138.5,
        20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
      "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222, 
       239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
      "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
       235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
      "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75, 
       205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
      "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 31.333, 
       211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
      "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625, 
       186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
      "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 12.889, 
       154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
      "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 51.111, 
       183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
      "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
       292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
      "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
       285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
      "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
       201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
      "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
       275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
      "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
       124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
      "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 60.833, 
       141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
      "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71., 
       132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
      "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
       17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
      "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 0.3, 
       46.6, 0., 2.5, 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 8.692, 
       16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
      "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 37.857, 
       102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
      "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
       86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
      "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
       10.111, 
       Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 16.833, 
       18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
      "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545, 
       13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
      "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 261.60001, 
       432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
      "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
       320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
      "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 144., 
       287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
      "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
       166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
      "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
       222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
      "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 36.909, 
       122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
      "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556, 
       127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
      "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
       89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
      "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 55., 
       284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
      "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 102.333, 
       277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
      "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 75.875, 
       177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
      "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
       72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
      "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 48.667, 
       82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
      "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 48.625, 
       66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
      "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 23., 
       173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
      "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 317., 
       5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
      "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 84., 
       4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
      "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 2., 
       10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
      "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 88.5, 
       2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
      "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115., 
       11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
      "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 98.143, 
       2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
      "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
       143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
      "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
       197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
      "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 1., 
       19., 0., 22., 5., 1.1, 5.4, 0.}, {
      "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 10.583, 
       23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
      "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 200.231, 
       19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
      "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 77.333, 
       147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
      "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5, 
       276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
      "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
       123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
      "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 75.207,
        23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
      "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 116.2,
        7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
      "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
       188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
      "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
       72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
      "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 16., 
       0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
      "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 34., 
       53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
      "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 27.5, 
       76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
      "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
       58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
      "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 175.66701, 
       361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
      "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
       22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
      "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 26.8,
        0., 28., 0., 0., 0., 0., 15.1}, {
      "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
       54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
      "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333, 
       34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
      "spring", "large", "low", 9., 5.8, 
       Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 0., 
       0.}, {"spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
       151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
      "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
       269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
      "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 46.438, 
       81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
      "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 85., 
       2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
      "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 66.4, 
       171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
      "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 102.364, 
       232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
      "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 84.3, 
       146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
      "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
       246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
      "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 205.636, 
       219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
      "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 236.39999,
        272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
      "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 1081.66003, 
       346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 5.9, 1.7}, {
      "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 82.222,
        167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
      "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 64.389, 
       137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
      "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 87.333,
        194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
      "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
       159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
      "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 21.3, 
       1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
      "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 0.6,
        37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
      "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
       14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
      "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222, 7.,
        1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 0.8, 
       50.4, 3.8, 0., 0., 0., 0., 0.}, {
      "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 7.654, 
       4., 56.8, 5., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 2.86, 
       17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
      "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 56.091, 
       Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
      "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
       52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
      "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 104.727, 
       228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
      "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 85.4, 
       17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
      "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 87.125,
        14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
      "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 101.455, 
       18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
      "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 50.889, 
       127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
      "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
       81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
      "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 19.727, 
       50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
      "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111, 
       120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
      "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 51.111, 
       91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
      "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 19.111, 
       61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
      "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625, 
       79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
      "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333, 
       75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
      "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333, 
       140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
      "winter", "large", "medium", 8., 7.6, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
      "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
       140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 
       5.8}}, $CellContext`sym$233406[$CellContext`Chla] = Part[
      $CellContext`sym$233406[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {
          "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
           196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$233406[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$233406[$CellContext`Cl] = Part[
      $CellContext`sym$233406[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$233406[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$233406[$CellContext`mnO2] = Part[
      $CellContext`sym$233406[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$233406[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$233406[$CellContext`mxPH] = Part[
      $CellContext`sym$233406[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$233406[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$233406[$CellContext`NH4] = Part[
      $CellContext`sym$233406[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$233406[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$233406[$CellContext`NO3] = Part[
      $CellContext`sym$233406[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$233406[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$233406[$CellContext`oPO4] = Part[
      $CellContext`sym$233406[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$233406[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$233406[$CellContext`PO4] = Part[
      $CellContext`sym$233406[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$233406[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$233406[$CellContext`season] = Part[
      $CellContext`sym$233406[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$233406[$CellContext`season, 
         "missing"]]]], $CellContext`sym$233406[$CellContext`size] = Part[
      $CellContext`sym$233406[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$233406[$CellContext`size, 
         "missing"]]]], $CellContext`sym$233406[$CellContext`speed] = Part[
      $CellContext`sym$233406[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$233406[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$233406[$CellContext`a1, 
      "factorized"] = 
    False, $CellContext`sym$233406[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$233406[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$233406[All], 
      All, $CellContext`i$233418], $CellContext`sym$233406[$CellContext`a2, 
      "factorized"] = 
    False, $CellContext`sym$233406[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$233406[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$233406[All], 
      All, $CellContext`i$233419], $CellContext`sym$233406[$CellContext`a3, 
      "factorized"] = 
    False, $CellContext`sym$233406[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$233406[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$233406[All], 
      All, $CellContext`i$233420], $CellContext`sym$233406[$CellContext`a4, 
      "factorized"] = 
    False, $CellContext`sym$233406[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$233406[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$233406[All], 
      All, $CellContext`i$233421], $CellContext`sym$233406[$CellContext`a5, 
      "factorized"] = 
    False, $CellContext`sym$233406[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$233406[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$233406[All], 
      All, $CellContext`i$233422], $CellContext`sym$233406[$CellContext`a6, 
      "factorized"] = 
    False, $CellContext`sym$233406[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$233406[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$233406[All], 
      All, $CellContext`i$233423], $CellContext`sym$233406[$CellContext`a7, 
      "factorized"] = 
    False, $CellContext`sym$233406[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$233406[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$233406[All], 
      All, $CellContext`i$233424], $CellContext`sym$233406[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$233406[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed}, $CellContext`sym$233406[$CellContext`Chla, "factorized"] = 
    False, $CellContext`sym$233406[$CellContext`Chla, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {63}, {116}, {184}, {
     199}}, $CellContext`sym$233406[$CellContext`Chla, "raw"] = Part[
      $CellContext`sym$233406[All], 
      All, $CellContext`i$233417], $CellContext`sym$233406[$CellContext`Cl, 
      "factorized"] = 
    False, $CellContext`sym$233406[$CellContext`Cl, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {161}, {
     199}}, $CellContext`sym$233406[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$233406[All], 
      All, $CellContext`i$233412], $CellContext`sym$233406[$CellContext`mnO2, 
      "factorized"] = 
    False, $CellContext`sym$233406[$CellContext`mnO2, "missing"] = {{38}, {
     62}}, $CellContext`sym$233406[$CellContext`mnO2, "raw"] = Part[
      $CellContext`sym$233406[All], 
      All, $CellContext`i$233411], $CellContext`sym$233406[$CellContext`mxPH, 
      "factorized"] = 
    False, $CellContext`sym$233406[$CellContext`mxPH, "missing"] = {{
     48}}, $CellContext`sym$233406[$CellContext`mxPH, "raw"] = Part[
      $CellContext`sym$233406[All], 
      All, $CellContext`i$233410], $CellContext`sym$233406[$CellContext`NH4, 
      "factorized"] = 
    False, $CellContext`sym$233406[$CellContext`NH4, "missing"] = {{62}, {
     199}}, $CellContext`sym$233406[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$233406[All], 
      All, $CellContext`i$233414], $CellContext`sym$233406[$CellContext`NO3, 
      "factorized"] = 
    False, $CellContext`sym$233406[$CellContext`NO3, "missing"] = {{62}, {
     199}}, $CellContext`sym$233406[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$233406[All], 
      All, $CellContext`i$233413], $CellContext`sym$233406[$CellContext`oPO4, 
      "factorized"] = 
    False, $CellContext`sym$233406[$CellContext`oPO4, "missing"] = {{62}, {
     199}}, $CellContext`sym$233406[$CellContext`oPO4, "raw"] = Part[
      $CellContext`sym$233406[All], 
      All, $CellContext`i$233415], $CellContext`sym$233406[$CellContext`PO4, 
      "factorized"] = 
    False, $CellContext`sym$233406[$CellContext`PO4, "missing"] = {{28}, {
     199}}, $CellContext`sym$233406[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$233406[All], 
      All, $CellContext`i$233416], \
$CellContext`sym$233406[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$233406[$CellContext`season, "factors"] = 
    Part[{"autumn", "spring", "summer", "winter"}, 
      $CellContext`fordering[$CellContext`sym$233406, $CellContext`season]], \
$CellContext`sym$233406[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$233406[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$233406[All], 
      All, $CellContext`i$233407], $CellContext`sym$233406[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$233406[$CellContext`size, "factors"] = 
    Part[{"large", "medium", "small"}, 
      $CellContext`fordering[$CellContext`sym$233406, $CellContext`size]], \
$CellContext`sym$233406[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$233406[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$233406[All], 
      All, $CellContext`i$233408], $CellContext`sym$233406[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$233406[$CellContext`speed, "factors"] = 
    Part[{"high", "low", "medium"}, 
      $CellContext`fordering[$CellContext`sym$233406, $CellContext`speed]], \
$CellContext`sym$233406[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$233406[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$233406[All], All, $CellContext`i$233409], 
    Attributes[$CellContext`i$233420] = {Temporary}, $CellContext`i$233420 = 
    14, Attributes[$CellContext`i$233415] = {
     Temporary}, $CellContext`i$233415 = 9, 
    Attributes[$CellContext`i$233410] = {Temporary}, $CellContext`i$233410 = 
    4, Attributes[$CellContext`i$233407] = {Temporary}, $CellContext`i$233407 = 
    1, Attributes[$CellContext`i$233408] = {Temporary}, $CellContext`i$233408 = 
    2, Attributes[$CellContext`i$233422] = {Temporary}, $CellContext`i$233422 = 
    16, Attributes[$CellContext`i$233417] = {
     Temporary}, $CellContext`i$233417 = 11, 
    Attributes[$CellContext`i$233414] = {Temporary}, $CellContext`i$233414 = 
    8, Attributes[$CellContext`i$233412] = {Temporary}, $CellContext`i$233412 = 
    6, Attributes[$CellContext`i$233411] = {Temporary}, $CellContext`i$233411 = 
    5, Attributes[$CellContext`i$233413] = {Temporary}, $CellContext`i$233413 = 
    7, Attributes[$CellContext`i$233418] = {Temporary}, $CellContext`i$233418 = 
    12, Attributes[$CellContext`i$233416] = {
     Temporary}, $CellContext`i$233416 = 10, 
    Attributes[$CellContext`i$233409] = {Temporary}, $CellContext`i$233409 = 
    3, Attributes[$CellContext`i$233419] = {Temporary}, $CellContext`i$233419 = 
    13, Attributes[$CellContext`i$233421] = {
     Temporary}, $CellContext`i$233421 = 15, 
    Attributes[$CellContext`i$233424] = {Temporary}, $CellContext`i$233424 = 
    18, Attributes[$CellContext`i$233423] = {
     Temporary}, $CellContext`i$233423 = 17, 
    Attributes[$CellContext`sym$230808] = {
     Temporary}, $CellContext`sym$230808[$CellContext`a1] = Part[
      $CellContext`sym$230808[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$230808[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$230808[$CellContext`a2] = Part[
      $CellContext`sym$230808[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$230808[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$230808[$CellContext`a3] = Part[
      $CellContext`sym$230808[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$230808[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$230808[$CellContext`a4] = Part[
      $CellContext`sym$230808[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$230808[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$230808[$CellContext`a5] = Part[
      $CellContext`sym$230808[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$230808[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$230808[$CellContext`a6] = Part[
      $CellContext`sym$230808[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$230808[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$230808[$CellContext`a7] = Part[
      $CellContext`sym$230808[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$230808[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$230808[
     All] = {{"winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 
       170., 50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
      "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
       558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
      "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 125.667,
        187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
      "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 61.182, 
       138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
      "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222, 
       97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
      "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
       56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
      "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
       111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
      "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 44.667, 
       77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
      "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 71., 
       5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 0.8, 
       17., 0., 0., 2.9, 0., 0., 1.7}, {
      "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 20.75, 
       0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
      "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 19.,
        0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
      "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 41., 
       43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
      "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5, 
       31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
      "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 0.3, 
       52.2, 5., 7.8, 0., 4., 0., 0.}, {
      "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 98.25, 
       1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50., 
       1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
      "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 57.833, 
       0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
      "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 0.8, 
       50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
      "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
       564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
      "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 586.,
        16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
      "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 0.5, 
       15.5, 0., 0., 2.3, 0., 0., 0.}, {
      "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 7.6,
        23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
      "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
       27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
      "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 1.5,
        13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
      "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 44.136, 
       3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
      "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 0.5, 
       29.7, 0., 0., 4.9, 0., 0., 0.}, {
      "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
       Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
      "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 17.1,
        0., 19.6, 0., 0., 0., 2.5}, {
      "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5, 
       33.9, 1., 14.6, 0., 0., 0., 0.}, {
      "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 4.9, 
       3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
      "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 2.8, 
       6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
      "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 130.75, 
       5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
      "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47., 
       2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
      "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23., 
       0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
      "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 58.875, 
       84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
      "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 0.2,
        66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
       Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0., 
       0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
       196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
      "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
       182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
      "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001, 
       296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
      "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 59.429,
        175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
      "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
       344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
      "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 276.85001, 
       326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
      "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 40.667, 
       3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
      "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 3.3, 
       29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
      "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 0.8, 
       54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
       Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 0., 
       0.}, {"spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121.,
        2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 20.812,
        12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
      "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
       49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
      "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 22.9, 
       4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
      "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 11.8, 
       0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818, 
       0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
      "winter", "small", "high", 6.6, 10.8, 
       Missing[], 3.245, 10., 1., 6.5, 
       Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "medium", 5.6, 11.8, 
       Missing[], 2.22, 5., 1., 1., 
       Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 5.7, 10.8, 
       Missing[], 2.55, 10., 1., 4., 
       Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
      "spring", "small", "high", 6.6, 9.5, 
       Missing[], 1.32, 20., 1., 6., 
       Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
      "summer", "small", "high", 6.6, 10.8, 
       Missing[], 2.64, 10., 2., 11., 
       Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
      "autumn", "small", "medium", 6.6, 11.3, 
       Missing[], 4.17, 10., 1., 6., 
       Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
      "spring", "small", "medium", 6.5, 10.4, 
       Missing[], 5.97, 10., 2., 14., 
       Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
      "summer", "small", "medium", 6.4, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 14., 
       Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
      "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 6.667, 
       Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75, 1.,
        20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
      "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2, 
       0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
      "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 0.6,
        55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
      "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 10.75, 
       2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
      "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 0.5, 
       64.2, 0., 3., 0., 0., 0., 0.}, {
      "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75, 
       351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
      "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
       209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
      "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 151.125,
        279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
      "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
       152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
      "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
       58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
      "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
       249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
      "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 100., 
       233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
      "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 215.5, 
       18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
      "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 25.167, 
       102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
      "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
       105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
      "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
       111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
      "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 1.3, 
       6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
      "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 56.667, 
       2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
      "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 4.3,
        1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
      "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
       104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
      "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 69.93,
        3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
      "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
       214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
      "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
       254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
      "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 57.6,
        169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
      "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
       412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
      "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
       282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
      "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
       197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
      "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 267.75, 
       391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
      "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 191.75, 
       265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
      "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
       232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
      "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 144.66701, 
       244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
      "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 218., 
       6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
      "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 138.5,
        20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
      "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222, 
       239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
      "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
       235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
      "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75, 
       205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
      "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 31.333, 
       211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
      "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625, 
       186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
      "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 12.889, 
       154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
      "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 51.111, 
       183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
      "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
       292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
      "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
       285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
      "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
       201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
      "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
       275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
      "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
       124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
      "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 60.833, 
       141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
      "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71., 
       132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
      "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
       17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
      "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 0.3, 
       46.6, 0., 2.5, 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 8.692, 
       16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
      "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 37.857, 
       102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
      "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
       86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
      "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
       10.111, 
       Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 16.833, 
       18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
      "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545, 
       13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
      "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 261.60001, 
       432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
      "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
       320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
      "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 144., 
       287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
      "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
       166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
      "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
       222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
      "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 36.909, 
       122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
      "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556, 
       127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
      "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
       89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
      "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 55., 
       284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
      "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 102.333, 
       277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
      "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 75.875, 
       177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
      "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
       72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
      "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 48.667, 
       82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
      "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 48.625, 
       66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
      "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 23., 
       173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
      "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 317., 
       5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
      "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 84., 
       4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
      "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 2., 
       10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
      "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 88.5, 
       2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
      "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115., 
       11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
      "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 98.143, 
       2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
      "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
       143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
      "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
       197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
      "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 1., 
       19., 0., 22., 5., 1.1, 5.4, 0.}, {
      "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 10.583, 
       23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
      "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 200.231, 
       19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
      "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 77.333, 
       147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
      "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5, 
       276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
      "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
       123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
      "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 75.207,
        23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
      "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 116.2,
        7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
      "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
       188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
      "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
       72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
      "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 16., 
       0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
      "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 34., 
       53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
      "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 27.5, 
       76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
      "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
       58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
      "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 175.66701, 
       361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
      "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
       22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
      "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 26.8,
        0., 28., 0., 0., 0., 0., 15.1}, {
      "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
       54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
      "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333, 
       34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
      "spring", "large", "low", 9., 5.8, 
       Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 0., 
       0.}, {"spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
       151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
      "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
       269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
      "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 46.438, 
       81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
      "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 85., 
       2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
      "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 66.4, 
       171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
      "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 102.364, 
       232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
      "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 84.3, 
       146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
      "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
       246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
      "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 205.636, 
       219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
      "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 236.39999,
        272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
      "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 1081.66003, 
       346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 5.9, 1.7}, {
      "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 82.222,
        167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
      "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 64.389, 
       137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
      "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 87.333,
        194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
      "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
       159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
      "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 21.3, 
       1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
      "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 0.6,
        37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
      "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
       14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
      "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222, 7.,
        1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 0.8, 
       50.4, 3.8, 0., 0., 0., 0., 0.}, {
      "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 7.654, 
       4., 56.8, 5., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 2.86, 
       17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
      "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 56.091, 
       Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
      "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
       52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
      "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 104.727, 
       228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
      "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 85.4, 
       17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
      "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 87.125,
        14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
      "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 101.455, 
       18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
      "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 50.889, 
       127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
      "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
       81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
      "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 19.727, 
       50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
      "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111, 
       120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
      "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 51.111, 
       91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
      "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 19.111, 
       61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
      "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625, 
       79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
      "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333, 
       75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
      "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333, 
       140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
      "winter", "large", "medium", 8., 7.6, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
      "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
       140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 
       5.8}}, $CellContext`sym$230808[$CellContext`Chla] = Part[
      $CellContext`sym$230808[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {
          "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
           196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$230808[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$230808[$CellContext`Cl] = Part[
      $CellContext`sym$230808[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$230808[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$230808[$CellContext`mnO2] = Part[
      $CellContext`sym$230808[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$230808[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$230808[$CellContext`mxPH] = Part[
      $CellContext`sym$230808[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$230808[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$230808[$CellContext`NH4] = Part[
      $CellContext`sym$230808[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$230808[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$230808[$CellContext`NO3] = Part[
      $CellContext`sym$230808[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$230808[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$230808[$CellContext`oPO4] = Part[
      $CellContext`sym$230808[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$230808[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$230808[$CellContext`PO4] = Part[
      $CellContext`sym$230808[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$230808[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$230808[$CellContext`season] = Part[
      $CellContext`sym$230808[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$230808[$CellContext`season, 
         "missing"]]]], $CellContext`sym$230808[$CellContext`size] = Part[
      $CellContext`sym$230808[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$230808[$CellContext`size, 
         "missing"]]]], $CellContext`sym$230808[$CellContext`speed] = Part[
      $CellContext`sym$230808[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$230808[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$230808[$CellContext`a1, 
      "factorized"] = 
    False, $CellContext`sym$230808[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$230808[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$230808[All], 
      All, $CellContext`i$230820], $CellContext`sym$230808[$CellContext`a2, 
      "factorized"] = 
    False, $CellContext`sym$230808[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$230808[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$230808[All], 
      All, $CellContext`i$230821], $CellContext`sym$230808[$CellContext`a3, 
      "factorized"] = 
    False, $CellContext`sym$230808[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$230808[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$230808[All], 
      All, $CellContext`i$230822], $CellContext`sym$230808[$CellContext`a4, 
      "factorized"] = 
    False, $CellContext`sym$230808[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$230808[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$230808[All], 
      All, $CellContext`i$230823], $CellContext`sym$230808[$CellContext`a5, 
      "factorized"] = 
    False, $CellContext`sym$230808[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$230808[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$230808[All], 
      All, $CellContext`i$230824], $CellContext`sym$230808[$CellContext`a6, 
      "factorized"] = 
    False, $CellContext`sym$230808[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$230808[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$230808[All], 
      All, $CellContext`i$230825], $CellContext`sym$230808[$CellContext`a7, 
      "factorized"] = 
    False, $CellContext`sym$230808[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$230808[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$230808[All], 
      All, $CellContext`i$230826], $CellContext`sym$230808[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$230808[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed}, $CellContext`sym$230808[$CellContext`Chla, "factorized"] = 
    False, $CellContext`sym$230808[$CellContext`Chla, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {63}, {116}, {184}, {
     199}}, $CellContext`sym$230808[$CellContext`Chla, "raw"] = Part[
      $CellContext`sym$230808[All], 
      All, $CellContext`i$230819], $CellContext`sym$230808[$CellContext`Cl, 
      "factorized"] = 
    False, $CellContext`sym$230808[$CellContext`Cl, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {161}, {
     199}}, $CellContext`sym$230808[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$230808[All], 
      All, $CellContext`i$230814], $CellContext`sym$230808[$CellContext`mnO2, 
      "factorized"] = 
    False, $CellContext`sym$230808[$CellContext`mnO2, "missing"] = {{38}, {
     62}}, $CellContext`sym$230808[$CellContext`mnO2, "raw"] = Part[
      $CellContext`sym$230808[All], 
      All, $CellContext`i$230813], $CellContext`sym$230808[$CellContext`mxPH, 
      "factorized"] = 
    False, $CellContext`sym$230808[$CellContext`mxPH, "missing"] = {{
     48}}, $CellContext`sym$230808[$CellContext`mxPH, "raw"] = Part[
      $CellContext`sym$230808[All], 
      All, $CellContext`i$230812], $CellContext`sym$230808[$CellContext`NH4, 
      "factorized"] = 
    False, $CellContext`sym$230808[$CellContext`NH4, "missing"] = {{62}, {
     199}}, $CellContext`sym$230808[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$230808[All], 
      All, $CellContext`i$230816], $CellContext`sym$230808[$CellContext`NO3, 
      "factorized"] = 
    False, $CellContext`sym$230808[$CellContext`NO3, "missing"] = {{62}, {
     199}}, $CellContext`sym$230808[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$230808[All], 
      All, $CellContext`i$230815], $CellContext`sym$230808[$CellContext`oPO4, 
      "factorized"] = 
    False, $CellContext`sym$230808[$CellContext`oPO4, "missing"] = {{62}, {
     199}}, $CellContext`sym$230808[$CellContext`oPO4, "raw"] = Part[
      $CellContext`sym$230808[All], 
      All, $CellContext`i$230817], $CellContext`sym$230808[$CellContext`PO4, 
      "factorized"] = 
    False, $CellContext`sym$230808[$CellContext`PO4, "missing"] = {{28}, {
     199}}, $CellContext`sym$230808[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$230808[All], 
      All, $CellContext`i$230818], \
$CellContext`sym$230808[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$230808[$CellContext`season, "factors"] = 
    Part[{"autumn", "spring", "summer", "winter"}, 
      $CellContext`fordering[$CellContext`sym$230808, $CellContext`season]], \
$CellContext`sym$230808[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$230808[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$230808[All], 
      All, $CellContext`i$230809], $CellContext`sym$230808[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$230808[$CellContext`size, "factors"] = 
    Part[{"large", "medium", "small"}, 
      $CellContext`fordering[$CellContext`sym$230808, $CellContext`size]], \
$CellContext`sym$230808[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$230808[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$230808[All], 
      All, $CellContext`i$230810], $CellContext`sym$230808[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$230808[$CellContext`speed, "factors"] = 
    Part[{"high", "low", "medium"}, 
      $CellContext`fordering[$CellContext`sym$230808, $CellContext`speed]], \
$CellContext`sym$230808[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$230808[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$230808[All], All, $CellContext`i$230811], 
    Attributes[$CellContext`i$230820] = {Temporary}, $CellContext`i$230820 = 
    12, Attributes[$CellContext`i$230814] = {
     Temporary}, $CellContext`i$230814 = 6, 
    Attributes[$CellContext`i$230819] = {Temporary}, $CellContext`i$230819 = 
    11, Attributes[$CellContext`i$230813] = {
     Temporary}, $CellContext`i$230813 = 5, 
    Attributes[$CellContext`i$230824] = {Temporary}, $CellContext`i$230824 = 
    16, Attributes[$CellContext`i$230817] = {
     Temporary}, $CellContext`i$230817 = 9, 
    Attributes[$CellContext`i$230825] = {Temporary}, $CellContext`i$230825 = 
    17, Attributes[$CellContext`i$230815] = {
     Temporary}, $CellContext`i$230815 = 7, 
    Attributes[$CellContext`i$230816] = {Temporary}, $CellContext`i$230816 = 
    8, Attributes[$CellContext`i$230810] = {Temporary}, $CellContext`i$230810 = 
    2, Attributes[$CellContext`i$230809] = {Temporary}, $CellContext`i$230809 = 
    1, Attributes[$CellContext`i$230811] = {Temporary}, $CellContext`i$230811 = 
    3, Attributes[$CellContext`i$230822] = {Temporary}, $CellContext`i$230822 = 
    14, Attributes[$CellContext`i$230823] = {
     Temporary}, $CellContext`i$230823 = 15, 
    Attributes[$CellContext`i$230826] = {Temporary}, $CellContext`i$230826 = 
    18, Attributes[$CellContext`i$230812] = {
     Temporary}, $CellContext`i$230812 = 4, 
    Attributes[$CellContext`i$230818] = {Temporary}, $CellContext`i$230818 = 
    10, Attributes[$CellContext`i$230821] = {
     Temporary}, $CellContext`i$230821 = 13, 
    Attributes[$CellContext`sym$228643] = {
     Temporary}, $CellContext`sym$228643[$CellContext`a1] = Part[
      $CellContext`sym$228643[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228643[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$228643[$CellContext`a2] = Part[
      $CellContext`sym$228643[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228643[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$228643[$CellContext`a3] = Part[
      $CellContext`sym$228643[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228643[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$228643[$CellContext`a4] = Part[
      $CellContext`sym$228643[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228643[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$228643[$CellContext`a5] = Part[
      $CellContext`sym$228643[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228643[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$228643[$CellContext`a6] = Part[
      $CellContext`sym$228643[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228643[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$228643[$CellContext`a7] = Part[
      $CellContext`sym$228643[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228643[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$228643[
     All] = {{"winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 
       170., 50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
      "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
       558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
      "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 125.667,
        187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
      "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 61.182, 
       138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
      "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222, 
       97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
      "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
       56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
      "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
       111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
      "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 44.667, 
       77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
      "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 71., 
       5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 0.8, 
       17., 0., 0., 2.9, 0., 0., 1.7}, {
      "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 20.75, 
       0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
      "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 19.,
        0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
      "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 41., 
       43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
      "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5, 
       31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
      "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 0.3, 
       52.2, 5., 7.8, 0., 4., 0., 0.}, {
      "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 98.25, 
       1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50., 
       1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
      "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 57.833, 
       0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
      "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 0.8, 
       50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
      "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
       564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
      "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 586.,
        16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
      "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 0.5, 
       15.5, 0., 0., 2.3, 0., 0., 0.}, {
      "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 7.6,
        23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
      "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
       27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
      "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 1.5,
        13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
      "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 44.136, 
       3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
      "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 0.5, 
       29.7, 0., 0., 4.9, 0., 0., 0.}, {
      "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
       Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
      "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 17.1,
        0., 19.6, 0., 0., 0., 2.5}, {
      "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5, 
       33.9, 1., 14.6, 0., 0., 0., 0.}, {
      "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 4.9, 
       3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
      "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 2.8, 
       6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
      "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 130.75, 
       5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
      "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47., 
       2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
      "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23., 
       0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
      "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 58.875, 
       84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
      "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 0.2,
        66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
       Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0., 
       0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
       196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
      "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
       182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
      "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001, 
       296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
      "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 59.429,
        175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
      "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
       344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
      "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 276.85001, 
       326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
      "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 40.667, 
       3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
      "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 3.3, 
       29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
      "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 0.8, 
       54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
       Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 0., 
       0.}, {"spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121.,
        2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 20.812,
        12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
      "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
       49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
      "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 22.9, 
       4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
      "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 11.8, 
       0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818, 
       0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
      "winter", "small", "high", 6.6, 10.8, 
       Missing[], 3.245, 10., 1., 6.5, 
       Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "medium", 5.6, 11.8, 
       Missing[], 2.22, 5., 1., 1., 
       Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 5.7, 10.8, 
       Missing[], 2.55, 10., 1., 4., 
       Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
      "spring", "small", "high", 6.6, 9.5, 
       Missing[], 1.32, 20., 1., 6., 
       Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
      "summer", "small", "high", 6.6, 10.8, 
       Missing[], 2.64, 10., 2., 11., 
       Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
      "autumn", "small", "medium", 6.6, 11.3, 
       Missing[], 4.17, 10., 1., 6., 
       Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
      "spring", "small", "medium", 6.5, 10.4, 
       Missing[], 5.97, 10., 2., 14., 
       Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
      "summer", "small", "medium", 6.4, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 14., 
       Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
      "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 6.667, 
       Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75, 1.,
        20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
      "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2, 
       0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
      "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 0.6,
        55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
      "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 10.75, 
       2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
      "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 0.5, 
       64.2, 0., 3., 0., 0., 0., 0.}, {
      "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75, 
       351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
      "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
       209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
      "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 151.125,
        279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
      "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
       152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
      "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
       58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
      "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
       249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
      "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 100., 
       233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
      "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 215.5, 
       18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
      "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 25.167, 
       102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
      "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
       105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
      "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
       111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
      "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 1.3, 
       6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
      "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 56.667, 
       2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
      "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 4.3,
        1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
      "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
       104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
      "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 69.93,
        3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
      "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
       214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
      "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
       254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
      "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 57.6,
        169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
      "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
       412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
      "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
       282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
      "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
       197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
      "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 267.75, 
       391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
      "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 191.75, 
       265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
      "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
       232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
      "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 144.66701, 
       244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
      "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 218., 
       6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
      "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 138.5,
        20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
      "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222, 
       239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
      "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
       235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
      "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75, 
       205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
      "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 31.333, 
       211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
      "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625, 
       186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
      "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 12.889, 
       154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
      "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 51.111, 
       183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
      "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
       292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
      "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
       285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
      "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
       201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
      "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
       275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
      "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
       124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
      "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 60.833, 
       141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
      "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71., 
       132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
      "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
       17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
      "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 0.3, 
       46.6, 0., 2.5, 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 8.692, 
       16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
      "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 37.857, 
       102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
      "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
       86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
      "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
       10.111, 
       Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 16.833, 
       18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
      "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545, 
       13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
      "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 261.60001, 
       432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
      "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
       320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
      "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 144., 
       287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
      "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
       166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
      "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
       222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
      "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 36.909, 
       122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
      "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556, 
       127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
      "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
       89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
      "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 55., 
       284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
      "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 102.333, 
       277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
      "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 75.875, 
       177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
      "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
       72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
      "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 48.667, 
       82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
      "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 48.625, 
       66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
      "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 23., 
       173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
      "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 317., 
       5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
      "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 84., 
       4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
      "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 2., 
       10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
      "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 88.5, 
       2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
      "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115., 
       11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
      "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 98.143, 
       2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
      "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
       143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
      "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
       197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
      "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 1., 
       19., 0., 22., 5., 1.1, 5.4, 0.}, {
      "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 10.583, 
       23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
      "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 200.231, 
       19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
      "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 77.333, 
       147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
      "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5, 
       276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
      "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
       123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
      "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 75.207,
        23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
      "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 116.2,
        7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
      "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
       188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
      "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
       72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
      "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 16., 
       0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
      "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 34., 
       53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
      "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 27.5, 
       76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
      "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
       58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
      "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 175.66701, 
       361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
      "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
       22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
      "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 26.8,
        0., 28., 0., 0., 0., 0., 15.1}, {
      "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
       54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
      "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333, 
       34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
      "spring", "large", "low", 9., 5.8, 
       Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 0., 
       0.}, {"spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
       151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
      "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
       269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
      "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 46.438, 
       81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
      "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 85., 
       2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
      "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 66.4, 
       171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
      "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 102.364, 
       232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
      "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 84.3, 
       146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
      "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
       246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
      "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 205.636, 
       219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
      "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 236.39999,
        272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
      "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 1081.66003, 
       346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 5.9, 1.7}, {
      "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 82.222,
        167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
      "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 64.389, 
       137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
      "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 87.333,
        194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
      "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
       159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
      "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 21.3, 
       1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
      "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 0.6,
        37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
      "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
       14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
      "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222, 7.,
        1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 0.8, 
       50.4, 3.8, 0., 0., 0., 0., 0.}, {
      "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 7.654, 
       4., 56.8, 5., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 2.86, 
       17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
      "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 56.091, 
       Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
      "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
       52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
      "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 104.727, 
       228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
      "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 85.4, 
       17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
      "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 87.125,
        14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
      "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 101.455, 
       18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
      "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 50.889, 
       127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
      "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
       81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
      "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 19.727, 
       50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
      "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111, 
       120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
      "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 51.111, 
       91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
      "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 19.111, 
       61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
      "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625, 
       79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
      "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333, 
       75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
      "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333, 
       140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
      "winter", "large", "medium", 8., 7.6, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
      "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
       140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 
       5.8}}, $CellContext`sym$228643[$CellContext`Chla] = Part[
      $CellContext`sym$228643[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {
          "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
           196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228643[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$228643[$CellContext`Cl] = Part[
      $CellContext`sym$228643[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228643[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$228643[$CellContext`mnO2] = Part[
      $CellContext`sym$228643[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228643[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$228643[$CellContext`mxPH] = Part[
      $CellContext`sym$228643[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228643[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$228643[$CellContext`NH4] = Part[
      $CellContext`sym$228643[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228643[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$228643[$CellContext`NO3] = Part[
      $CellContext`sym$228643[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228643[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$228643[$CellContext`oPO4] = Part[
      $CellContext`sym$228643[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228643[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$228643[$CellContext`PO4] = Part[
      $CellContext`sym$228643[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228643[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$228643[$CellContext`season] = Part[
      $CellContext`sym$228643[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228643[$CellContext`season, 
         "missing"]]]], $CellContext`sym$228643[$CellContext`size] = Part[
      $CellContext`sym$228643[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228643[$CellContext`size, 
         "missing"]]]], $CellContext`sym$228643[$CellContext`speed] = Part[
      $CellContext`sym$228643[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$228643[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$228643[$CellContext`a1, 
      "factorized"] = 
    False, $CellContext`sym$228643[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$228643[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$228643[All], 
      All, $CellContext`i$228655], $CellContext`sym$228643[$CellContext`a2, 
      "factorized"] = 
    False, $CellContext`sym$228643[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$228643[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$228643[All], 
      All, $CellContext`i$228656], $CellContext`sym$228643[$CellContext`a3, 
      "factorized"] = 
    False, $CellContext`sym$228643[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$228643[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$228643[All], 
      All, $CellContext`i$228657], $CellContext`sym$228643[$CellContext`a4, 
      "factorized"] = 
    False, $CellContext`sym$228643[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$228643[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$228643[All], 
      All, $CellContext`i$228658], $CellContext`sym$228643[$CellContext`a5, 
      "factorized"] = 
    False, $CellContext`sym$228643[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$228643[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$228643[All], 
      All, $CellContext`i$228659], $CellContext`sym$228643[$CellContext`a6, 
      "factorized"] = 
    False, $CellContext`sym$228643[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$228643[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$228643[All], 
      All, $CellContext`i$228660], $CellContext`sym$228643[$CellContext`a7, 
      "factorized"] = 
    False, $CellContext`sym$228643[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$228643[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$228643[All], 
      All, $CellContext`i$228661], $CellContext`sym$228643[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$228643[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed}, $CellContext`sym$228643[$CellContext`Chla, "factorized"] = 
    False, $CellContext`sym$228643[$CellContext`Chla, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {63}, {116}, {184}, {
     199}}, $CellContext`sym$228643[$CellContext`Chla, "raw"] = Part[
      $CellContext`sym$228643[All], 
      All, $CellContext`i$228654], $CellContext`sym$228643[$CellContext`Cl, 
      "factorized"] = 
    False, $CellContext`sym$228643[$CellContext`Cl, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {161}, {
     199}}, $CellContext`sym$228643[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$228643[All], 
      All, $CellContext`i$228649], $CellContext`sym$228643[$CellContext`mnO2, 
      "factorized"] = 
    False, $CellContext`sym$228643[$CellContext`mnO2, "missing"] = {{38}, {
     62}}, $CellContext`sym$228643[$CellContext`mnO2, "raw"] = Part[
      $CellContext`sym$228643[All], 
      All, $CellContext`i$228648], $CellContext`sym$228643[$CellContext`mxPH, 
      "factorized"] = 
    False, $CellContext`sym$228643[$CellContext`mxPH, "missing"] = {{
     48}}, $CellContext`sym$228643[$CellContext`mxPH, "raw"] = Part[
      $CellContext`sym$228643[All], 
      All, $CellContext`i$228647], $CellContext`sym$228643[$CellContext`NH4, 
      "factorized"] = 
    False, $CellContext`sym$228643[$CellContext`NH4, "missing"] = {{62}, {
     199}}, $CellContext`sym$228643[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$228643[All], 
      All, $CellContext`i$228651], $CellContext`sym$228643[$CellContext`NO3, 
      "factorized"] = 
    False, $CellContext`sym$228643[$CellContext`NO3, "missing"] = {{62}, {
     199}}, $CellContext`sym$228643[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$228643[All], 
      All, $CellContext`i$228650], $CellContext`sym$228643[$CellContext`oPO4, 
      "factorized"] = 
    False, $CellContext`sym$228643[$CellContext`oPO4, "missing"] = {{62}, {
     199}}, $CellContext`sym$228643[$CellContext`oPO4, "raw"] = Part[
      $CellContext`sym$228643[All], 
      All, $CellContext`i$228652], $CellContext`sym$228643[$CellContext`PO4, 
      "factorized"] = 
    False, $CellContext`sym$228643[$CellContext`PO4, "missing"] = {{28}, {
     199}}, $CellContext`sym$228643[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$228643[All], 
      All, $CellContext`i$228653], \
$CellContext`sym$228643[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$228643[$CellContext`season, "factors"] = 
    Part[{"autumn", "spring", "summer", "winter"}, 
      $CellContext`fordering[$CellContext`sym$228643, $CellContext`season]], \
$CellContext`sym$228643[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$228643[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$228643[All], 
      All, $CellContext`i$228644], $CellContext`sym$228643[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$228643[$CellContext`size, "factors"] = 
    Part[{"large", "medium", "small"}, 
      $CellContext`fordering[$CellContext`sym$228643, $CellContext`size]], \
$CellContext`sym$228643[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$228643[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$228643[All], 
      All, $CellContext`i$228645], $CellContext`sym$228643[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$228643[$CellContext`speed, "factors"] = 
    Part[{"high", "low", "medium"}, 
      $CellContext`fordering[$CellContext`sym$228643, $CellContext`speed]], \
$CellContext`sym$228643[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$228643[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$228643[All], All, $CellContext`i$228646], 
    Attributes[$CellContext`i$228653] = {Temporary}, $CellContext`i$228653 = 
    10, Attributes[$CellContext`i$228658] = {
     Temporary}, $CellContext`i$228658 = 15, 
    Attributes[$CellContext`i$228654] = {Temporary}, $CellContext`i$228654 = 
    11, Attributes[$CellContext`i$228646] = {
     Temporary}, $CellContext`i$228646 = 3, 
    Attributes[$CellContext`i$228656] = {Temporary}, $CellContext`i$228656 = 
    13, Attributes[$CellContext`i$228645] = {
     Temporary}, $CellContext`i$228645 = 2, 
    Attributes[$CellContext`i$228649] = {Temporary}, $CellContext`i$228649 = 
    6, Attributes[$CellContext`i$228650] = {Temporary}, $CellContext`i$228650 = 
    7, Attributes[$CellContext`i$228660] = {Temporary}, $CellContext`i$228660 = 
    17, Attributes[$CellContext`i$228644] = {
     Temporary}, $CellContext`i$228644 = 1, 
    Attributes[$CellContext`i$228648] = {Temporary}, $CellContext`i$228648 = 
    5, Attributes[$CellContext`i$228659] = {Temporary}, $CellContext`i$228659 = 
    16, Attributes[$CellContext`i$228647] = {
     Temporary}, $CellContext`i$228647 = 4, 
    Attributes[$CellContext`i$228655] = {Temporary}, $CellContext`i$228655 = 
    12, Attributes[$CellContext`i$228661] = {
     Temporary}, $CellContext`i$228661 = 18, 
    Attributes[$CellContext`i$228652] = {Temporary}, $CellContext`i$228652 = 
    9, Attributes[$CellContext`i$228657] = {Temporary}, $CellContext`i$228657 = 
    14, Attributes[$CellContext`i$228651] = {
     Temporary}, $CellContext`i$228651 = 8, 
    Attributes[$CellContext`sym$232107] = {
     Temporary}, $CellContext`sym$232107[$CellContext`a1] = Part[
      $CellContext`sym$232107[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232107[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$232107[$CellContext`a2] = Part[
      $CellContext`sym$232107[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232107[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$232107[$CellContext`a3] = Part[
      $CellContext`sym$232107[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232107[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$232107[$CellContext`a4] = Part[
      $CellContext`sym$232107[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232107[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$232107[$CellContext`a5] = Part[
      $CellContext`sym$232107[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232107[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$232107[$CellContext`a6] = Part[
      $CellContext`sym$232107[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232107[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$232107[$CellContext`a7] = Part[
      $CellContext`sym$232107[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232107[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$232107[
     All] = {{"winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 
       170., 50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
      "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
       558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
      "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 125.667,
        187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
      "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 61.182, 
       138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
      "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222, 
       97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
      "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
       56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
      "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
       111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
      "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 44.667, 
       77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
      "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 71., 
       5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 0.8, 
       17., 0., 0., 2.9, 0., 0., 1.7}, {
      "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 20.75, 
       0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
      "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 19.,
        0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
      "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 41., 
       43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
      "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5, 
       31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
      "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 0.3, 
       52.2, 5., 7.8, 0., 4., 0., 0.}, {
      "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 98.25, 
       1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50., 
       1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
      "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 57.833, 
       0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
      "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 0.8, 
       50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
      "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
       564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
      "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 586.,
        16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
      "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 0.5, 
       15.5, 0., 0., 2.3, 0., 0., 0.}, {
      "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 7.6,
        23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
      "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
       27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
      "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 1.5,
        13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
      "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 44.136, 
       3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
      "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 0.5, 
       29.7, 0., 0., 4.9, 0., 0., 0.}, {
      "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
       Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
      "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 17.1,
        0., 19.6, 0., 0., 0., 2.5}, {
      "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5, 
       33.9, 1., 14.6, 0., 0., 0., 0.}, {
      "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 4.9, 
       3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
      "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 2.8, 
       6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
      "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 130.75, 
       5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
      "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47., 
       2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
      "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23., 
       0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
      "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 58.875, 
       84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
      "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 0.2,
        66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
       Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0., 
       0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
       196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
      "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
       182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
      "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001, 
       296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
      "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 59.429,
        175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
      "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
       344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
      "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 276.85001, 
       326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
      "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 40.667, 
       3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
      "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 3.3, 
       29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
      "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 0.8, 
       54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
       Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 0., 
       0.}, {"spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121.,
        2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 20.812,
        12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
      "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
       49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
      "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 22.9, 
       4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
      "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 11.8, 
       0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818, 
       0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
      "winter", "small", "high", 6.6, 10.8, 
       Missing[], 3.245, 10., 1., 6.5, 
       Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "medium", 5.6, 11.8, 
       Missing[], 2.22, 5., 1., 1., 
       Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 5.7, 10.8, 
       Missing[], 2.55, 10., 1., 4., 
       Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
      "spring", "small", "high", 6.6, 9.5, 
       Missing[], 1.32, 20., 1., 6., 
       Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
      "summer", "small", "high", 6.6, 10.8, 
       Missing[], 2.64, 10., 2., 11., 
       Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
      "autumn", "small", "medium", 6.6, 11.3, 
       Missing[], 4.17, 10., 1., 6., 
       Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
      "spring", "small", "medium", 6.5, 10.4, 
       Missing[], 5.97, 10., 2., 14., 
       Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
      "summer", "small", "medium", 6.4, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 14., 
       Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
      "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 6.667, 
       Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75, 1.,
        20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
      "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2, 
       0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
      "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 0.6,
        55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
      "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 10.75, 
       2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
      "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 0.5, 
       64.2, 0., 3., 0., 0., 0., 0.}, {
      "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75, 
       351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
      "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
       209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
      "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 151.125,
        279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
      "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
       152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
      "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
       58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
      "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
       249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
      "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 100., 
       233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
      "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 215.5, 
       18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
      "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 25.167, 
       102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
      "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
       105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
      "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
       111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
      "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 1.3, 
       6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
      "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 56.667, 
       2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
      "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 4.3,
        1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
      "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
       104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
      "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 69.93,
        3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
      "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
       214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
      "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
       254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
      "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 57.6,
        169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
      "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
       412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
      "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
       282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
      "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
       197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
      "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 267.75, 
       391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
      "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 191.75, 
       265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
      "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
       232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
      "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 144.66701, 
       244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
      "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 218., 
       6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
      "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 138.5,
        20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
      "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222, 
       239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
      "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
       235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
      "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75, 
       205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
      "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 31.333, 
       211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
      "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625, 
       186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
      "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 12.889, 
       154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
      "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 51.111, 
       183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
      "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
       292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
      "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
       285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
      "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
       201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
      "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
       275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
      "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
       124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
      "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 60.833, 
       141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
      "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71., 
       132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
      "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
       17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
      "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 0.3, 
       46.6, 0., 2.5, 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 8.692, 
       16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
      "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 37.857, 
       102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
      "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
       86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
      "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
       10.111, 
       Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 16.833, 
       18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
      "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545, 
       13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
      "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 261.60001, 
       432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
      "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
       320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
      "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 144., 
       287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
      "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
       166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
      "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
       222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
      "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 36.909, 
       122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
      "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556, 
       127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
      "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
       89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
      "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 55., 
       284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
      "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 102.333, 
       277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
      "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 75.875, 
       177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
      "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
       72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
      "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 48.667, 
       82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
      "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 48.625, 
       66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
      "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 23., 
       173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
      "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 317., 
       5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
      "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 84., 
       4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
      "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 2., 
       10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
      "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 88.5, 
       2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
      "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115., 
       11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
      "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 98.143, 
       2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
      "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
       143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
      "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
       197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
      "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 1., 
       19., 0., 22., 5., 1.1, 5.4, 0.}, {
      "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 10.583, 
       23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
      "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 200.231, 
       19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
      "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 77.333, 
       147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
      "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5, 
       276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
      "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
       123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
      "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 75.207,
        23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
      "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 116.2,
        7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
      "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
       188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
      "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
       72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
      "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 16., 
       0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
      "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 34., 
       53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
      "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 27.5, 
       76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
      "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
       58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
      "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 175.66701, 
       361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
      "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
       22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
      "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 26.8,
        0., 28., 0., 0., 0., 0., 15.1}, {
      "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
       54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
      "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333, 
       34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
      "spring", "large", "low", 9., 5.8, 
       Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 0., 
       0.}, {"spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
       151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
      "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
       269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
      "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 46.438, 
       81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
      "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 85., 
       2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
      "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 66.4, 
       171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
      "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 102.364, 
       232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
      "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 84.3, 
       146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
      "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
       246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
      "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 205.636, 
       219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
      "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 236.39999,
        272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
      "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 1081.66003, 
       346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 5.9, 1.7}, {
      "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 82.222,
        167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
      "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 64.389, 
       137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
      "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 87.333,
        194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
      "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
       159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
      "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 21.3, 
       1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
      "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 0.6,
        37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
      "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
       14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
      "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222, 7.,
        1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 0.8, 
       50.4, 3.8, 0., 0., 0., 0., 0.}, {
      "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 7.654, 
       4., 56.8, 5., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 2.86, 
       17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
      "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 56.091, 
       Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
      "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
       52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
      "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 104.727, 
       228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
      "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 85.4, 
       17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
      "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 87.125,
        14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
      "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 101.455, 
       18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
      "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 50.889, 
       127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
      "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
       81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
      "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 19.727, 
       50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
      "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111, 
       120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
      "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 51.111, 
       91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
      "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 19.111, 
       61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
      "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625, 
       79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
      "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333, 
       75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
      "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333, 
       140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
      "winter", "large", "medium", 8., 7.6, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
      "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
       140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 
       5.8}}, $CellContext`sym$232107[$CellContext`Chla] = Part[
      $CellContext`sym$232107[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {
          "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
           196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232107[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$232107[$CellContext`Cl] = Part[
      $CellContext`sym$232107[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232107[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$232107[$CellContext`mnO2] = Part[
      $CellContext`sym$232107[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232107[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$232107[$CellContext`mxPH] = Part[
      $CellContext`sym$232107[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232107[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$232107[$CellContext`NH4] = Part[
      $CellContext`sym$232107[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232107[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$232107[$CellContext`NO3] = Part[
      $CellContext`sym$232107[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232107[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$232107[$CellContext`oPO4] = Part[
      $CellContext`sym$232107[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232107[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$232107[$CellContext`PO4] = Part[
      $CellContext`sym$232107[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232107[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$232107[$CellContext`season] = Part[
      $CellContext`sym$232107[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232107[$CellContext`season, 
         "missing"]]]], $CellContext`sym$232107[$CellContext`size] = Part[
      $CellContext`sym$232107[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232107[$CellContext`size, 
         "missing"]]]], $CellContext`sym$232107[$CellContext`speed] = Part[
      $CellContext`sym$232107[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$232107[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$232107[$CellContext`a1, 
      "factorized"] = 
    False, $CellContext`sym$232107[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$232107[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$232107[All], 
      All, $CellContext`i$232119], $CellContext`sym$232107[$CellContext`a2, 
      "factorized"] = 
    False, $CellContext`sym$232107[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$232107[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$232107[All], 
      All, $CellContext`i$232120], $CellContext`sym$232107[$CellContext`a3, 
      "factorized"] = 
    False, $CellContext`sym$232107[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$232107[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$232107[All], 
      All, $CellContext`i$232121], $CellContext`sym$232107[$CellContext`a4, 
      "factorized"] = 
    False, $CellContext`sym$232107[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$232107[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$232107[All], 
      All, $CellContext`i$232122], $CellContext`sym$232107[$CellContext`a5, 
      "factorized"] = 
    False, $CellContext`sym$232107[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$232107[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$232107[All], 
      All, $CellContext`i$232123], $CellContext`sym$232107[$CellContext`a6, 
      "factorized"] = 
    False, $CellContext`sym$232107[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$232107[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$232107[All], 
      All, $CellContext`i$232124], $CellContext`sym$232107[$CellContext`a7, 
      "factorized"] = 
    False, $CellContext`sym$232107[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$232107[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$232107[All], 
      All, $CellContext`i$232125], $CellContext`sym$232107[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$232107[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed}, $CellContext`sym$232107[$CellContext`Chla, "factorized"] = 
    False, $CellContext`sym$232107[$CellContext`Chla, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {63}, {116}, {184}, {
     199}}, $CellContext`sym$232107[$CellContext`Chla, "raw"] = Part[
      $CellContext`sym$232107[All], 
      All, $CellContext`i$232118], $CellContext`sym$232107[$CellContext`Cl, 
      "factorized"] = 
    False, $CellContext`sym$232107[$CellContext`Cl, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {161}, {
     199}}, $CellContext`sym$232107[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$232107[All], 
      All, $CellContext`i$232113], $CellContext`sym$232107[$CellContext`mnO2, 
      "factorized"] = 
    False, $CellContext`sym$232107[$CellContext`mnO2, "missing"] = {{38}, {
     62}}, $CellContext`sym$232107[$CellContext`mnO2, "raw"] = Part[
      $CellContext`sym$232107[All], 
      All, $CellContext`i$232112], $CellContext`sym$232107[$CellContext`mxPH, 
      "factorized"] = 
    False, $CellContext`sym$232107[$CellContext`mxPH, "missing"] = {{
     48}}, $CellContext`sym$232107[$CellContext`mxPH, "raw"] = Part[
      $CellContext`sym$232107[All], 
      All, $CellContext`i$232111], $CellContext`sym$232107[$CellContext`NH4, 
      "factorized"] = 
    False, $CellContext`sym$232107[$CellContext`NH4, "missing"] = {{62}, {
     199}}, $CellContext`sym$232107[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$232107[All], 
      All, $CellContext`i$232115], $CellContext`sym$232107[$CellContext`NO3, 
      "factorized"] = 
    False, $CellContext`sym$232107[$CellContext`NO3, "missing"] = {{62}, {
     199}}, $CellContext`sym$232107[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$232107[All], 
      All, $CellContext`i$232114], $CellContext`sym$232107[$CellContext`oPO4, 
      "factorized"] = 
    False, $CellContext`sym$232107[$CellContext`oPO4, "missing"] = {{62}, {
     199}}, $CellContext`sym$232107[$CellContext`oPO4, "raw"] = Part[
      $CellContext`sym$232107[All], 
      All, $CellContext`i$232116], $CellContext`sym$232107[$CellContext`PO4, 
      "factorized"] = 
    False, $CellContext`sym$232107[$CellContext`PO4, "missing"] = {{28}, {
     199}}, $CellContext`sym$232107[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$232107[All], 
      All, $CellContext`i$232117], \
$CellContext`sym$232107[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$232107[$CellContext`season, "factors"] = 
    Part[{"autumn", "spring", "summer", "winter"}, 
      $CellContext`fordering[$CellContext`sym$232107, $CellContext`season]], \
$CellContext`sym$232107[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$232107[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$232107[All], 
      All, $CellContext`i$232108], $CellContext`sym$232107[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$232107[$CellContext`size, "factors"] = 
    Part[{"large", "medium", "small"}, 
      $CellContext`fordering[$CellContext`sym$232107, $CellContext`size]], \
$CellContext`sym$232107[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$232107[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$232107[All], 
      All, $CellContext`i$232109], $CellContext`sym$232107[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$232107[$CellContext`speed, "factors"] = 
    Part[{"high", "low", "medium"}, 
      $CellContext`fordering[$CellContext`sym$232107, $CellContext`speed]], \
$CellContext`sym$232107[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$232107[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$232107[All], All, $CellContext`i$232110], 
    Attributes[$CellContext`i$232118] = {Temporary}, $CellContext`i$232118 = 
    11, Attributes[$CellContext`i$232117] = {
     Temporary}, $CellContext`i$232117 = 10, 
    Attributes[$CellContext`i$232123] = {Temporary}, $CellContext`i$232123 = 
    16, Attributes[$CellContext`i$232113] = {
     Temporary}, $CellContext`i$232113 = 6, 
    Attributes[$CellContext`i$232110] = {Temporary}, $CellContext`i$232110 = 
    3, Attributes[$CellContext`i$232115] = {Temporary}, $CellContext`i$232115 = 
    8, Attributes[$CellContext`i$232114] = {Temporary}, $CellContext`i$232114 = 
    7, Attributes[$CellContext`i$232109] = {Temporary}, $CellContext`i$232109 = 
    2, Attributes[$CellContext`i$232111] = {Temporary}, $CellContext`i$232111 = 
    4, Attributes[$CellContext`i$232122] = {Temporary}, $CellContext`i$232122 = 
    15, Attributes[$CellContext`i$232121] = {
     Temporary}, $CellContext`i$232121 = 14, 
    Attributes[$CellContext`i$232108] = {Temporary}, $CellContext`i$232108 = 
    1, Attributes[$CellContext`i$232112] = {Temporary}, $CellContext`i$232112 = 
    5, Attributes[$CellContext`i$232125] = {Temporary}, $CellContext`i$232125 = 
    18, Attributes[$CellContext`i$232116] = {
     Temporary}, $CellContext`i$232116 = 9, 
    Attributes[$CellContext`i$232124] = {Temporary}, $CellContext`i$232124 = 
    17, Attributes[$CellContext`i$232120] = {
     Temporary}, $CellContext`i$232120 = 13, 
    Attributes[$CellContext`i$232119] = {Temporary}, $CellContext`i$232119 = 
    12, Attributes[$CellContext`sym$237731] = {
     Temporary}, $CellContext`sym$237731[$CellContext`a1] = Part[
      $CellContext`sym$237731[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$237731[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$237731[$CellContext`a2] = Part[
      $CellContext`sym$237731[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$237731[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$237731[$CellContext`a3] = Part[
      $CellContext`sym$237731[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$237731[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$237731[$CellContext`a4] = Part[
      $CellContext`sym$237731[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$237731[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$237731[$CellContext`a5] = Part[
      $CellContext`sym$237731[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$237731[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$237731[$CellContext`a6] = Part[
      $CellContext`sym$237731[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$237731[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$237731[$CellContext`a7] = Part[
      $CellContext`sym$237731[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$237731[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$237731[
     All] = {{"winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 
       170., 50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
      "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
       558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
      "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 125.667,
        187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
      "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 61.182, 
       138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
      "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222, 
       97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
      "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
       56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
      "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
       111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
      "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 44.667, 
       77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
      "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 71., 
       5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 0.8, 
       17., 0., 0., 2.9, 0., 0., 1.7}, {
      "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 20.75, 
       0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
      "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 19.,
        0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
      "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 41., 
       43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
      "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5, 
       31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
      "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 0.3, 
       52.2, 5., 7.8, 0., 4., 0., 0.}, {
      "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 98.25, 
       1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50., 
       1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
      "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 57.833, 
       0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
      "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 0.8, 
       50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
      "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
       564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
      "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 586.,
        16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
      "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 0.5, 
       15.5, 0., 0., 2.3, 0., 0., 0.}, {
      "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 7.6,
        23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
      "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
       27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
      "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 1.5,
        13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
      "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 44.136, 
       3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
      "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 0.5, 
       29.7, 0., 0., 4.9, 0., 0., 0.}, {
      "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
       Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
      "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 17.1,
        0., 19.6, 0., 0., 0., 2.5}, {
      "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5, 
       33.9, 1., 14.6, 0., 0., 0., 0.}, {
      "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 4.9, 
       3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
      "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 2.8, 
       6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
      "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 130.75, 
       5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
      "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47., 
       2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
      "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23., 
       0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
      "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 58.875, 
       84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
      "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 0.2,
        66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
       Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0., 
       0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
       196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
      "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
       182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
      "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001, 
       296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
      "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 59.429,
        175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
      "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
       344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
      "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 276.85001, 
       326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
      "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 40.667, 
       3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
      "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 3.3, 
       29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
      "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 0.8, 
       54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
       Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 0., 
       0.}, {"spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121.,
        2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 20.812,
        12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
      "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
       49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
      "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 22.9, 
       4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
      "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 11.8, 
       0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818, 
       0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
      "winter", "small", "high", 6.6, 10.8, 
       Missing[], 3.245, 10., 1., 6.5, 
       Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "medium", 5.6, 11.8, 
       Missing[], 2.22, 5., 1., 1., 
       Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 5.7, 10.8, 
       Missing[], 2.55, 10., 1., 4., 
       Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
      "spring", "small", "high", 6.6, 9.5, 
       Missing[], 1.32, 20., 1., 6., 
       Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
      "summer", "small", "high", 6.6, 10.8, 
       Missing[], 2.64, 10., 2., 11., 
       Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
      "autumn", "small", "medium", 6.6, 11.3, 
       Missing[], 4.17, 10., 1., 6., 
       Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
      "spring", "small", "medium", 6.5, 10.4, 
       Missing[], 5.97, 10., 2., 14., 
       Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
      "summer", "small", "medium", 6.4, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 14., 
       Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
      "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 6.667, 
       Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75, 1.,
        20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
      "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2, 
       0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
      "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 0.6,
        55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
      "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 10.75, 
       2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
      "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 0.5, 
       64.2, 0., 3., 0., 0., 0., 0.}, {
      "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75, 
       351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
      "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
       209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
      "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 151.125,
        279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
      "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
       152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
      "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
       58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
      "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
       249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
      "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 100., 
       233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
      "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 215.5, 
       18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
      "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 25.167, 
       102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
      "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
       105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
      "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
       111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
      "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 1.3, 
       6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
      "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 56.667, 
       2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
      "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 4.3,
        1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
      "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
       104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
      "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 69.93,
        3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
      "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
       214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
      "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
       254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
      "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 57.6,
        169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
      "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
       412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
      "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
       282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
      "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
       197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
      "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 267.75, 
       391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
      "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 191.75, 
       265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
      "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
       232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
      "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 144.66701, 
       244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
      "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 218., 
       6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
      "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 138.5,
        20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
      "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222, 
       239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
      "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
       235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
      "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75, 
       205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
      "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 31.333, 
       211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
      "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625, 
       186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
      "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 12.889, 
       154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
      "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 51.111, 
       183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
      "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
       292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
      "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
       285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
      "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
       201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
      "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
       275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
      "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
       124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
      "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 60.833, 
       141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
      "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71., 
       132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
      "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
       17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
      "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 0.3, 
       46.6, 0., 2.5, 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 8.692, 
       16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
      "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 37.857, 
       102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
      "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
       86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
      "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
       10.111, 
       Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 16.833, 
       18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
      "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545, 
       13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
      "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 261.60001, 
       432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
      "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
       320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
      "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 144., 
       287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
      "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
       166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
      "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
       222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
      "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 36.909, 
       122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
      "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556, 
       127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
      "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
       89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
      "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 55., 
       284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
      "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 102.333, 
       277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
      "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 75.875, 
       177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
      "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
       72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
      "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 48.667, 
       82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
      "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 48.625, 
       66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
      "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 23., 
       173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
      "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 317., 
       5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
      "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 84., 
       4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
      "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 2., 
       10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
      "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 88.5, 
       2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
      "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115., 
       11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
      "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 98.143, 
       2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
      "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
       143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
      "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
       197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
      "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 1., 
       19., 0., 22., 5., 1.1, 5.4, 0.}, {
      "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 10.583, 
       23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
      "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 200.231, 
       19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
      "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 77.333, 
       147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
      "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5, 
       276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
      "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
       123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
      "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 75.207,
        23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
      "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 116.2,
        7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
      "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
       188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
      "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
       72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
      "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 16., 
       0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
      "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 34., 
       53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
      "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 27.5, 
       76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
      "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
       58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
      "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 175.66701, 
       361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
      "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
       22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
      "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 26.8,
        0., 28., 0., 0., 0., 0., 15.1}, {
      "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
       54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
      "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333, 
       34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
      "spring", "large", "low", 9., 5.8, 
       Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 0., 
       0.}, {"spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
       151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
      "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
       269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
      "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 46.438, 
       81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
      "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 85., 
       2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
      "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 66.4, 
       171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
      "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 102.364, 
       232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
      "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 84.3, 
       146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
      "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
       246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
      "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 205.636, 
       219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
      "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 236.39999,
        272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
      "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 1081.66003, 
       346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 5.9, 1.7}, {
      "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 82.222,
        167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
      "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 64.389, 
       137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
      "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 87.333,
        194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
      "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
       159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
      "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 21.3, 
       1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
      "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 0.6,
        37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
      "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
       14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
      "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222, 7.,
        1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 0.8, 
       50.4, 3.8, 0., 0., 0., 0., 0.}, {
      "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 7.654, 
       4., 56.8, 5., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 2.86, 
       17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
      "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 56.091, 
       Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
      "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
       52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
      "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 104.727, 
       228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
      "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 85.4, 
       17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
      "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 87.125,
        14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
      "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 101.455, 
       18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
      "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 50.889, 
       127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
      "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
       81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
      "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 19.727, 
       50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
      "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111, 
       120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
      "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 51.111, 
       91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
      "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 19.111, 
       61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
      "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625, 
       79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
      "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333, 
       75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
      "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333, 
       140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
      "winter", "large", "medium", 8., 7.6, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
      "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
       140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 
       5.8}}, $CellContext`sym$237731[$CellContext`Chla] = Part[
      $CellContext`sym$237731[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {
          "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
           196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$237731[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$237731[$CellContext`Cl] = Part[
      $CellContext`sym$237731[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$237731[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$237731[$CellContext`mnO2] = Part[
      $CellContext`sym$237731[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$237731[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$237731[$CellContext`mxPH] = Part[
      $CellContext`sym$237731[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$237731[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$237731[$CellContext`NH4] = Part[
      $CellContext`sym$237731[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$237731[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$237731[$CellContext`NO3] = Part[
      $CellContext`sym$237731[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$237731[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$237731[$CellContext`oPO4] = Part[
      $CellContext`sym$237731[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$237731[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$237731[$CellContext`PO4] = Part[
      $CellContext`sym$237731[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$237731[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$237731[$CellContext`season] = Part[
      $CellContext`sym$237731[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$237731[$CellContext`season, 
         "missing"]]]], $CellContext`sym$237731[$CellContext`size] = Part[
      $CellContext`sym$237731[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$237731[$CellContext`size, 
         "missing"]]]], $CellContext`sym$237731[$CellContext`speed] = Part[
      $CellContext`sym$237731[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$237731[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$237731[$CellContext`a1, 
      "factorized"] = 
    False, $CellContext`sym$237731[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$237731[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$237731[All], 
      All, $CellContext`i$237743], $CellContext`sym$237731[$CellContext`a2, 
      "factorized"] = 
    False, $CellContext`sym$237731[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$237731[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$237731[All], 
      All, $CellContext`i$237744], $CellContext`sym$237731[$CellContext`a3, 
      "factorized"] = 
    False, $CellContext`sym$237731[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$237731[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$237731[All], 
      All, $CellContext`i$237745], $CellContext`sym$237731[$CellContext`a4, 
      "factorized"] = 
    False, $CellContext`sym$237731[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$237731[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$237731[All], 
      All, $CellContext`i$237746], $CellContext`sym$237731[$CellContext`a5, 
      "factorized"] = 
    False, $CellContext`sym$237731[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$237731[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$237731[All], 
      All, $CellContext`i$237747], $CellContext`sym$237731[$CellContext`a6, 
      "factorized"] = 
    False, $CellContext`sym$237731[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$237731[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$237731[All], 
      All, $CellContext`i$237748], $CellContext`sym$237731[$CellContext`a7, 
      "factorized"] = 
    False, $CellContext`sym$237731[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$237731[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$237731[All], 
      All, $CellContext`i$237749], $CellContext`sym$237731[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$237731[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed}, $CellContext`sym$237731[$CellContext`Chla, "factorized"] = 
    False, $CellContext`sym$237731[$CellContext`Chla, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {63}, {116}, {184}, {
     199}}, $CellContext`sym$237731[$CellContext`Chla, "raw"] = Part[
      $CellContext`sym$237731[All], 
      All, $CellContext`i$237742], $CellContext`sym$237731[$CellContext`Cl, 
      "factorized"] = 
    False, $CellContext`sym$237731[$CellContext`Cl, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {161}, {
     199}}, $CellContext`sym$237731[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$237731[All], 
      All, $CellContext`i$237737], $CellContext`sym$237731[$CellContext`mnO2, 
      "factorized"] = 
    False, $CellContext`sym$237731[$CellContext`mnO2, "missing"] = {{38}, {
     62}}, $CellContext`sym$237731[$CellContext`mnO2, "raw"] = Part[
      $CellContext`sym$237731[All], 
      All, $CellContext`i$237736], $CellContext`sym$237731[$CellContext`mxPH, 
      "factorized"] = 
    False, $CellContext`sym$237731[$CellContext`mxPH, "missing"] = {{
     48}}, $CellContext`sym$237731[$CellContext`mxPH, "raw"] = Part[
      $CellContext`sym$237731[All], 
      All, $CellContext`i$237735], $CellContext`sym$237731[$CellContext`NH4, 
      "factorized"] = 
    False, $CellContext`sym$237731[$CellContext`NH4, "missing"] = {{62}, {
     199}}, $CellContext`sym$237731[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$237731[All], 
      All, $CellContext`i$237739], $CellContext`sym$237731[$CellContext`NO3, 
      "factorized"] = 
    False, $CellContext`sym$237731[$CellContext`NO3, "missing"] = {{62}, {
     199}}, $CellContext`sym$237731[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$237731[All], 
      All, $CellContext`i$237738], $CellContext`sym$237731[$CellContext`oPO4, 
      "factorized"] = 
    False, $CellContext`sym$237731[$CellContext`oPO4, "missing"] = {{62}, {
     199}}, $CellContext`sym$237731[$CellContext`oPO4, "raw"] = Part[
      $CellContext`sym$237731[All], 
      All, $CellContext`i$237740], $CellContext`sym$237731[$CellContext`PO4, 
      "factorized"] = 
    False, $CellContext`sym$237731[$CellContext`PO4, "missing"] = {{28}, {
     199}}, $CellContext`sym$237731[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$237731[All], 
      All, $CellContext`i$237741], \
$CellContext`sym$237731[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$237731[$CellContext`season, "factors"] = 
    Part[{"autumn", "spring", "summer", "winter"}, 
      $CellContext`fordering[$CellContext`sym$237731, $CellContext`season]], \
$CellContext`sym$237731[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$237731[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$237731[All], 
      All, $CellContext`i$237732], $CellContext`sym$237731[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$237731[$CellContext`size, "factors"] = 
    Part[{"large", "medium", "small"}, 
      $CellContext`fordering[$CellContext`sym$237731, $CellContext`size]], \
$CellContext`sym$237731[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$237731[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$237731[All], 
      All, $CellContext`i$237733], $CellContext`sym$237731[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$237731[$CellContext`speed, "factors"] = 
    Part[{"high", "low", "medium"}, 
      $CellContext`fordering[$CellContext`sym$237731, $CellContext`speed]], \
$CellContext`sym$237731[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$237731[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$237731[All], All, $CellContext`i$237734], 
    Attributes[$CellContext`i$237743] = {Temporary}, $CellContext`i$237743 = 
    12, Attributes[$CellContext`i$237738] = {
     Temporary}, $CellContext`i$237738 = 7, 
    Attributes[$CellContext`i$237741] = {Temporary}, $CellContext`i$237741 = 
    10, Attributes[$CellContext`i$237749] = {
     Temporary}, $CellContext`i$237749 = 18, 
    Attributes[$CellContext`i$237747] = {Temporary}, $CellContext`i$237747 = 
    16, Attributes[$CellContext`i$237732] = {
     Temporary}, $CellContext`i$237732 = 1, 
    Attributes[$CellContext`i$237739] = {Temporary}, $CellContext`i$237739 = 
    8, Attributes[$CellContext`i$237742] = {Temporary}, $CellContext`i$237742 = 
    11, Attributes[$CellContext`i$237740] = {
     Temporary}, $CellContext`i$237740 = 9, 
    Attributes[$CellContext`i$237733] = {Temporary}, $CellContext`i$237733 = 
    2, Attributes[$CellContext`i$237737] = {Temporary}, $CellContext`i$237737 = 
    6, Attributes[$CellContext`i$237746] = {Temporary}, $CellContext`i$237746 = 
    15, Attributes[$CellContext`i$237744] = {
     Temporary}, $CellContext`i$237744 = 13, 
    Attributes[$CellContext`i$237735] = {Temporary}, $CellContext`i$237735 = 
    4, Attributes[$CellContext`i$237745] = {Temporary}, $CellContext`i$237745 = 
    14, Attributes[$CellContext`i$237748] = {
     Temporary}, $CellContext`i$237748 = 17, 
    Attributes[$CellContext`i$237736] = {Temporary}, $CellContext`i$237736 = 
    5, Attributes[$CellContext`i$237734] = {Temporary}, $CellContext`i$237734 = 
    3, Attributes[$CellContext`sym$238165] = {
     Temporary}, $CellContext`sym$238165[$CellContext`a1] = Part[
      $CellContext`sym$238165[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$238165[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$238165[$CellContext`a2] = Part[
      $CellContext`sym$238165[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$238165[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$238165[$CellContext`a3] = Part[
      $CellContext`sym$238165[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$238165[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$238165[$CellContext`a4] = Part[
      $CellContext`sym$238165[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$238165[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$238165[$CellContext`a5] = Part[
      $CellContext`sym$238165[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$238165[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$238165[$CellContext`a6] = Part[
      $CellContext`sym$238165[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$238165[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$238165[$CellContext`a7] = Part[
      $CellContext`sym$238165[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$238165[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$238165[
     All] = {{"winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 
       170., 50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
      "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
       558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
      "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 125.667,
        187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
      "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 61.182, 
       138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
      "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222, 
       97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
      "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
       56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
      "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
       111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
      "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 44.667, 
       77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
      "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 71., 
       5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 0.8, 
       17., 0., 0., 2.9, 0., 0., 1.7}, {
      "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 20.75, 
       0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
      "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 19.,
        0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
      "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 41., 
       43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
      "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5, 
       31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
      "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 0.3, 
       52.2, 5., 7.8, 0., 4., 0., 0.}, {
      "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 98.25, 
       1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50., 
       1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
      "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 57.833, 
       0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
      "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 0.8, 
       50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
      "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
       564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
      "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 586.,
        16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
      "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 0.5, 
       15.5, 0., 0., 2.3, 0., 0., 0.}, {
      "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 7.6,
        23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
      "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
       27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
      "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 1.5,
        13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
      "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 44.136, 
       3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
      "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 0.5, 
       29.7, 0., 0., 4.9, 0., 0., 0.}, {
      "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
       Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
      "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 17.1,
        0., 19.6, 0., 0., 0., 2.5}, {
      "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5, 
       33.9, 1., 14.6, 0., 0., 0., 0.}, {
      "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 4.9, 
       3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
      "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 2.8, 
       6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
      "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 130.75, 
       5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
      "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47., 
       2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
      "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23., 
       0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
      "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 58.875, 
       84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
      "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 0.2,
        66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
       Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0., 
       0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
       196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
      "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
       182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
      "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001, 
       296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
      "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 59.429,
        175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
      "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
       344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
      "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 276.85001, 
       326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
      "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 40.667, 
       3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
      "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 3.3, 
       29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
      "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 0.8, 
       54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
       Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 0., 
       0.}, {"spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121.,
        2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 20.812,
        12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
      "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
       49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
      "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 22.9, 
       4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
      "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 11.8, 
       0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818, 
       0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
      "winter", "small", "high", 6.6, 10.8, 
       Missing[], 3.245, 10., 1., 6.5, 
       Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "medium", 5.6, 11.8, 
       Missing[], 2.22, 5., 1., 1., 
       Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 5.7, 10.8, 
       Missing[], 2.55, 10., 1., 4., 
       Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
      "spring", "small", "high", 6.6, 9.5, 
       Missing[], 1.32, 20., 1., 6., 
       Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
      "summer", "small", "high", 6.6, 10.8, 
       Missing[], 2.64, 10., 2., 11., 
       Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
      "autumn", "small", "medium", 6.6, 11.3, 
       Missing[], 4.17, 10., 1., 6., 
       Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
      "spring", "small", "medium", 6.5, 10.4, 
       Missing[], 5.97, 10., 2., 14., 
       Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
      "summer", "small", "medium", 6.4, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 14., 
       Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
      "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 6.667, 
       Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75, 1.,
        20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
      "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2, 
       0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
      "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 0.6,
        55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
      "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 10.75, 
       2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
      "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 0.5, 
       64.2, 0., 3., 0., 0., 0., 0.}, {
      "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75, 
       351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
      "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
       209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
      "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 151.125,
        279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
      "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
       152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
      "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
       58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
      "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
       249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
      "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 100., 
       233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
      "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 215.5, 
       18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
      "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 25.167, 
       102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
      "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
       105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
      "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
       111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
      "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 1.3, 
       6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
      "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 56.667, 
       2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
      "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 4.3,
        1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
      "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
       104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
      "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 69.93,
        3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
      "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
       214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
      "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
       254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
      "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 57.6,
        169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
      "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
       412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
      "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
       282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
      "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
       197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
      "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 267.75, 
       391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
      "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 191.75, 
       265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
      "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
       232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
      "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 144.66701, 
       244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
      "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 218., 
       6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
      "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 138.5,
        20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
      "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222, 
       239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
      "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
       235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
      "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75, 
       205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
      "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 31.333, 
       211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
      "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625, 
       186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
      "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 12.889, 
       154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
      "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 51.111, 
       183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
      "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
       292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
      "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
       285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
      "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
       201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
      "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
       275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
      "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
       124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
      "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 60.833, 
       141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
      "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71., 
       132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
      "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
       17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
      "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 0.3, 
       46.6, 0., 2.5, 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 8.692, 
       16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
      "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 37.857, 
       102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
      "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
       86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
      "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
       10.111, 
       Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 16.833, 
       18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
      "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545, 
       13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
      "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 261.60001, 
       432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
      "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
       320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
      "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 144., 
       287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
      "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
       166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
      "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
       222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
      "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 36.909, 
       122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
      "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556, 
       127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
      "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
       89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
      "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 55., 
       284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
      "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 102.333, 
       277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
      "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 75.875, 
       177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
      "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
       72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
      "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 48.667, 
       82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
      "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 48.625, 
       66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
      "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 23., 
       173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
      "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 317., 
       5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
      "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 84., 
       4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
      "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 2., 
       10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
      "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 88.5, 
       2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
      "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115., 
       11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
      "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 98.143, 
       2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
      "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
       143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
      "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
       197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
      "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 1., 
       19., 0., 22., 5., 1.1, 5.4, 0.}, {
      "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 10.583, 
       23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
      "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 200.231, 
       19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
      "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 77.333, 
       147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
      "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5, 
       276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
      "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
       123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
      "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 75.207,
        23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
      "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 116.2,
        7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
      "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
       188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
      "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
       72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
      "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 16., 
       0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
      "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 34., 
       53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
      "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 27.5, 
       76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
      "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
       58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
      "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 175.66701, 
       361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
      "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
       22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
      "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 26.8,
        0., 28., 0., 0., 0., 0., 15.1}, {
      "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
       54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
      "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333, 
       34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
      "spring", "large", "low", 9., 5.8, 
       Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 0., 
       0.}, {"spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
       151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
      "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
       269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
      "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 46.438, 
       81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
      "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 85., 
       2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
      "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 66.4, 
       171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
      "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 102.364, 
       232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
      "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 84.3, 
       146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
      "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
       246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
      "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 205.636, 
       219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
      "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 236.39999,
        272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
      "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 1081.66003, 
       346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 5.9, 1.7}, {
      "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 82.222,
        167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
      "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 64.389, 
       137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
      "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 87.333,
        194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
      "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
       159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
      "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 21.3, 
       1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
      "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 0.6,
        37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
      "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
       14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
      "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222, 7.,
        1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 0.8, 
       50.4, 3.8, 0., 0., 0., 0., 0.}, {
      "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 7.654, 
       4., 56.8, 5., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 2.86, 
       17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
      "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 56.091, 
       Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
      "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
       52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
      "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 104.727, 
       228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
      "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 85.4, 
       17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
      "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 87.125,
        14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
      "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 101.455, 
       18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
      "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 50.889, 
       127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
      "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
       81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
      "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 19.727, 
       50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
      "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111, 
       120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
      "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 51.111, 
       91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
      "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 19.111, 
       61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
      "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625, 
       79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
      "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333, 
       75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
      "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333, 
       140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
      "winter", "large", "medium", 8., 7.6, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
      "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
       140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 
       5.8}}, $CellContext`sym$238165[$CellContext`Chla] = Part[
      $CellContext`sym$238165[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {
          "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
           196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$238165[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$238165[$CellContext`Cl] = Part[
      $CellContext`sym$238165[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$238165[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$238165[$CellContext`mnO2] = Part[
      $CellContext`sym$238165[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$238165[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$238165[$CellContext`mxPH] = Part[
      $CellContext`sym$238165[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$238165[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$238165[$CellContext`NH4] = Part[
      $CellContext`sym$238165[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$238165[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$238165[$CellContext`NO3] = Part[
      $CellContext`sym$238165[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$238165[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$238165[$CellContext`oPO4] = Part[
      $CellContext`sym$238165[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$238165[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$238165[$CellContext`PO4] = Part[
      $CellContext`sym$238165[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$238165[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$238165[$CellContext`season] = Part[
      $CellContext`sym$238165[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$238165[$CellContext`season, 
         "missing"]]]], $CellContext`sym$238165[$CellContext`size] = Part[
      $CellContext`sym$238165[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$238165[$CellContext`size, 
         "missing"]]]], $CellContext`sym$238165[$CellContext`speed] = Part[
      $CellContext`sym$238165[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$238165[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$238165[$CellContext`a1, 
      "factorized"] = 
    False, $CellContext`sym$238165[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$238165[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$238165[All], 
      All, $CellContext`i$238177], $CellContext`sym$238165[$CellContext`a2, 
      "factorized"] = 
    False, $CellContext`sym$238165[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$238165[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$238165[All], 
      All, $CellContext`i$238178], $CellContext`sym$238165[$CellContext`a3, 
      "factorized"] = 
    False, $CellContext`sym$238165[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$238165[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$238165[All], 
      All, $CellContext`i$238179], $CellContext`sym$238165[$CellContext`a4, 
      "factorized"] = 
    False, $CellContext`sym$238165[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$238165[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$238165[All], 
      All, $CellContext`i$238180], $CellContext`sym$238165[$CellContext`a5, 
      "factorized"] = 
    False, $CellContext`sym$238165[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$238165[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$238165[All], 
      All, $CellContext`i$238181], $CellContext`sym$238165[$CellContext`a6, 
      "factorized"] = 
    False, $CellContext`sym$238165[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$238165[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$238165[All], 
      All, $CellContext`i$238182], $CellContext`sym$238165[$CellContext`a7, 
      "factorized"] = 
    False, $CellContext`sym$238165[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$238165[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$238165[All], 
      All, $CellContext`i$238183], $CellContext`sym$238165[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$238165[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed}, $CellContext`sym$238165[$CellContext`Chla, "factorized"] = 
    False, $CellContext`sym$238165[$CellContext`Chla, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {63}, {116}, {184}, {
     199}}, $CellContext`sym$238165[$CellContext`Chla, "raw"] = Part[
      $CellContext`sym$238165[All], 
      All, $CellContext`i$238176], $CellContext`sym$238165[$CellContext`Cl, 
      "factorized"] = 
    False, $CellContext`sym$238165[$CellContext`Cl, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {161}, {
     199}}, $CellContext`sym$238165[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$238165[All], 
      All, $CellContext`i$238171], $CellContext`sym$238165[$CellContext`mnO2, 
      "factorized"] = 
    False, $CellContext`sym$238165[$CellContext`mnO2, "missing"] = {{38}, {
     62}}, $CellContext`sym$238165[$CellContext`mnO2, "raw"] = Part[
      $CellContext`sym$238165[All], 
      All, $CellContext`i$238170], $CellContext`sym$238165[$CellContext`mxPH, 
      "factorized"] = 
    False, $CellContext`sym$238165[$CellContext`mxPH, "missing"] = {{
     48}}, $CellContext`sym$238165[$CellContext`mxPH, "raw"] = Part[
      $CellContext`sym$238165[All], 
      All, $CellContext`i$238169], $CellContext`sym$238165[$CellContext`NH4, 
      "factorized"] = 
    False, $CellContext`sym$238165[$CellContext`NH4, "missing"] = {{62}, {
     199}}, $CellContext`sym$238165[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$238165[All], 
      All, $CellContext`i$238173], $CellContext`sym$238165[$CellContext`NO3, 
      "factorized"] = 
    False, $CellContext`sym$238165[$CellContext`NO3, "missing"] = {{62}, {
     199}}, $CellContext`sym$238165[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$238165[All], 
      All, $CellContext`i$238172], $CellContext`sym$238165[$CellContext`oPO4, 
      "factorized"] = 
    False, $CellContext`sym$238165[$CellContext`oPO4, "missing"] = {{62}, {
     199}}, $CellContext`sym$238165[$CellContext`oPO4, "raw"] = Part[
      $CellContext`sym$238165[All], 
      All, $CellContext`i$238174], $CellContext`sym$238165[$CellContext`PO4, 
      "factorized"] = 
    False, $CellContext`sym$238165[$CellContext`PO4, "missing"] = {{28}, {
     199}}, $CellContext`sym$238165[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$238165[All], 
      All, $CellContext`i$238175], \
$CellContext`sym$238165[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$238165[$CellContext`season, "factors"] = 
    Part[{"autumn", "spring", "summer", "winter"}, 
      $CellContext`fordering[$CellContext`sym$238165, $CellContext`season]], \
$CellContext`sym$238165[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$238165[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$238165[All], 
      All, $CellContext`i$238166], $CellContext`sym$238165[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$238165[$CellContext`size, "factors"] = 
    Part[{"large", "medium", "small"}, 
      $CellContext`fordering[$CellContext`sym$238165, $CellContext`size]], \
$CellContext`sym$238165[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$238165[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$238165[All], 
      All, $CellContext`i$238167], $CellContext`sym$238165[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$238165[$CellContext`speed, "factors"] = 
    Part[{"high", "low", "medium"}, 
      $CellContext`fordering[$CellContext`sym$238165, $CellContext`speed]], \
$CellContext`sym$238165[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$238165[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$238165[All], All, $CellContext`i$238168], 
    Attributes[$CellContext`i$238176] = {Temporary}, $CellContext`i$238176 = 
    11, Attributes[$CellContext`i$238173] = {
     Temporary}, $CellContext`i$238173 = 8, 
    Attributes[$CellContext`i$238181] = {Temporary}, $CellContext`i$238181 = 
    16, Attributes[$CellContext`i$238168] = {
     Temporary}, $CellContext`i$238168 = 3, 
    Attributes[$CellContext`i$238183] = {Temporary}, $CellContext`i$238183 = 
    18, Attributes[$CellContext`i$238169] = {
     Temporary}, $CellContext`i$238169 = 4, 
    Attributes[$CellContext`i$238170] = {Temporary}, $CellContext`i$238170 = 
    5, Attributes[$CellContext`i$238175] = {Temporary}, $CellContext`i$238175 = 
    10, Attributes[$CellContext`i$238171] = {
     Temporary}, $CellContext`i$238171 = 6, 
    Attributes[$CellContext`i$238166] = {Temporary}, $CellContext`i$238166 = 
    1, Attributes[$CellContext`i$238174] = {Temporary}, $CellContext`i$238174 = 
    9, Attributes[$CellContext`i$238179] = {Temporary}, $CellContext`i$238179 = 
    14, Attributes[$CellContext`i$238182] = {
     Temporary}, $CellContext`i$238182 = 17, 
    Attributes[$CellContext`i$238178] = {Temporary}, $CellContext`i$238178 = 
    13, Attributes[$CellContext`i$238167] = {
     Temporary}, $CellContext`i$238167 = 2, 
    Attributes[$CellContext`i$238180] = {Temporary}, $CellContext`i$238180 = 
    15, Attributes[$CellContext`i$238172] = {
     Temporary}, $CellContext`i$238172 = 7, 
    Attributes[$CellContext`i$238177] = {Temporary}, $CellContext`i$238177 = 
    12, Attributes[$CellContext`sym$238599] = {
     Temporary}, $CellContext`sym$238599[$CellContext`a1] = Part[
      $CellContext`sym$238599[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$238599[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$238599[$CellContext`a2] = Part[
      $CellContext`sym$238599[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$238599[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$238599[$CellContext`a3] = Part[
      $CellContext`sym$238599[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$238599[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$238599[$CellContext`a4] = Part[
      $CellContext`sym$238599[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$238599[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$238599[$CellContext`a5] = Part[
      $CellContext`sym$238599[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$238599[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$238599[$CellContext`a6] = Part[
      $CellContext`sym$238599[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$238599[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$238599[$CellContext`a7] = Part[
      $CellContext`sym$238599[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$238599[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$238599[
     All] = {{"winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 
       170., 50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
      "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
       558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
      "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 125.667,
        187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
      "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 61.182, 
       138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
      "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222, 
       97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
      "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
       56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
      "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
       111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
      "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 44.667, 
       77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
      "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 71., 
       5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 0.8, 
       17., 0., 0., 2.9, 0., 0., 1.7}, {
      "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 20.75, 
       0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
      "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 19.,
        0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
      "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 41., 
       43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
      "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5, 
       31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
      "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 0.3, 
       52.2, 5., 7.8, 0., 4., 0., 0.}, {
      "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 98.25, 
       1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50., 
       1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
      "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 57.833, 
       0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
      "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 0.8, 
       50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
      "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
       564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
      "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 586.,
        16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
      "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 0.5, 
       15.5, 0., 0., 2.3, 0., 0., 0.}, {
      "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 7.6,
        23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
      "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
       27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
      "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 1.5,
        13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
      "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 44.136, 
       3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
      "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 0.5, 
       29.7, 0., 0., 4.9, 0., 0., 0.}, {
      "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
       Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
      "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 17.1,
        0., 19.6, 0., 0., 0., 2.5}, {
      "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5, 
       33.9, 1., 14.6, 0., 0., 0., 0.}, {
      "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 4.9, 
       3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
      "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 2.8, 
       6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
      "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 130.75, 
       5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
      "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47., 
       2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
      "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23., 
       0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
      "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 58.875, 
       84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
      "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 0.2,
        66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
       Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0., 
       0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
       196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
      "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
       182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
      "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001, 
       296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
      "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 59.429,
        175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
      "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
       344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
      "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 276.85001, 
       326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
      "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 40.667, 
       3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
      "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 3.3, 
       29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
      "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 0.8, 
       54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
       Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 0., 
       0.}, {"spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121.,
        2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 20.812,
        12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
      "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
       49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
      "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 22.9, 
       4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
      "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 11.8, 
       0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818, 
       0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
      "winter", "small", "high", 6.6, 10.8, 
       Missing[], 3.245, 10., 1., 6.5, 
       Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "medium", 5.6, 11.8, 
       Missing[], 2.22, 5., 1., 1., 
       Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 5.7, 10.8, 
       Missing[], 2.55, 10., 1., 4., 
       Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
      "spring", "small", "high", 6.6, 9.5, 
       Missing[], 1.32, 20., 1., 6., 
       Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
      "summer", "small", "high", 6.6, 10.8, 
       Missing[], 2.64, 10., 2., 11., 
       Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
      "autumn", "small", "medium", 6.6, 11.3, 
       Missing[], 4.17, 10., 1., 6., 
       Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
      "spring", "small", "medium", 6.5, 10.4, 
       Missing[], 5.97, 10., 2., 14., 
       Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
      "summer", "small", "medium", 6.4, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 14., 
       Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
      "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 6.667, 
       Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75, 1.,
        20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
      "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2, 
       0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
      "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 0.6,
        55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
      "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 10.75, 
       2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
      "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 0.5, 
       64.2, 0., 3., 0., 0., 0., 0.}, {
      "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75, 
       351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
      "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
       209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
      "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 151.125,
        279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
      "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
       152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
      "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
       58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
      "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
       249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
      "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 100., 
       233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
      "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 215.5, 
       18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
      "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 25.167, 
       102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
      "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
       105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
      "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
       111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
      "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 1.3, 
       6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
      "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 56.667, 
       2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
      "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 4.3,
        1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
      "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
       104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
      "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 69.93,
        3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
      "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
       214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
      "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
       254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
      "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 57.6,
        169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
      "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
       412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
      "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
       282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
      "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
       197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
      "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 267.75, 
       391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
      "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 191.75, 
       265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
      "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
       232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
      "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 144.66701, 
       244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
      "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 218., 
       6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
      "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 138.5,
        20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
      "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222, 
       239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
      "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
       235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
      "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75, 
       205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
      "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 31.333, 
       211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
      "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625, 
       186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
      "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 12.889, 
       154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
      "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 51.111, 
       183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
      "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
       292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
      "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
       285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
      "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
       201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
      "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
       275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
      "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
       124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
      "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 60.833, 
       141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
      "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71., 
       132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
      "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
       17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
      "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 0.3, 
       46.6, 0., 2.5, 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 8.692, 
       16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
      "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 37.857, 
       102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
      "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
       86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
      "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
       10.111, 
       Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 16.833, 
       18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
      "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545, 
       13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
      "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 261.60001, 
       432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
      "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
       320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
      "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 144., 
       287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
      "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
       166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
      "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
       222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
      "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 36.909, 
       122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
      "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556, 
       127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
      "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
       89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
      "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 55., 
       284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
      "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 102.333, 
       277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
      "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 75.875, 
       177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
      "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
       72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
      "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 48.667, 
       82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
      "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 48.625, 
       66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
      "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 23., 
       173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
      "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 317., 
       5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
      "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 84., 
       4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
      "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 2., 
       10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
      "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 88.5, 
       2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
      "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115., 
       11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
      "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 98.143, 
       2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
      "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
       143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
      "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
       197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
      "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 1., 
       19., 0., 22., 5., 1.1, 5.4, 0.}, {
      "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 10.583, 
       23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
      "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 200.231, 
       19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
      "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 77.333, 
       147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
      "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5, 
       276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
      "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
       123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
      "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 75.207,
        23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
      "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 116.2,
        7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
      "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
       188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
      "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
       72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
      "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 16., 
       0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
      "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 34., 
       53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
      "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 27.5, 
       76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
      "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
       58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
      "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 175.66701, 
       361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
      "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
       22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
      "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 26.8,
        0., 28., 0., 0., 0., 0., 15.1}, {
      "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
       54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
      "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333, 
       34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
      "spring", "large", "low", 9., 5.8, 
       Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 0., 
       0.}, {"spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
       151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
      "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
       269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
      "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 46.438, 
       81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
      "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 85., 
       2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
      "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 66.4, 
       171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
      "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 102.364, 
       232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
      "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 84.3, 
       146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
      "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
       246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
      "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 205.636, 
       219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
      "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 236.39999,
        272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
      "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 1081.66003, 
       346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 5.9, 1.7}, {
      "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 82.222,
        167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
      "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 64.389, 
       137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
      "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 87.333,
        194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
      "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
       159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
      "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 21.3, 
       1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
      "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 0.6,
        37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
      "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
       14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
      "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222, 7.,
        1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 0.8, 
       50.4, 3.8, 0., 0., 0., 0., 0.}, {
      "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 7.654, 
       4., 56.8, 5., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 2.86, 
       17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
      "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 56.091, 
       Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
      "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
       52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
      "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 104.727, 
       228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
      "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 85.4, 
       17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
      "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 87.125,
        14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
      "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 101.455, 
       18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
      "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 50.889, 
       127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
      "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
       81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
      "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 19.727, 
       50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
      "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111, 
       120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
      "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 51.111, 
       91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
      "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 19.111, 
       61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
      "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625, 
       79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
      "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333, 
       75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
      "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333, 
       140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
      "winter", "large", "medium", 8., 7.6, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
      "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
       140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 
       5.8}}, $CellContext`sym$238599[$CellContext`Chla] = Part[
      $CellContext`sym$238599[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {
          "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
           196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$238599[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$238599[$CellContext`Cl] = Part[
      $CellContext`sym$238599[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$238599[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$238599[$CellContext`mnO2] = Part[
      $CellContext`sym$238599[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$238599[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$238599[$CellContext`mxPH] = Part[
      $CellContext`sym$238599[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$238599[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$238599[$CellContext`NH4] = Part[
      $CellContext`sym$238599[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$238599[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$238599[$CellContext`NO3] = Part[
      $CellContext`sym$238599[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$238599[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$238599[$CellContext`oPO4] = Part[
      $CellContext`sym$238599[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$238599[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$238599[$CellContext`PO4] = Part[
      $CellContext`sym$238599[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$238599[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$238599[$CellContext`season] = Part[
      $CellContext`sym$238599[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$238599[$CellContext`season, 
         "missing"]]]], $CellContext`sym$238599[$CellContext`size] = Part[
      $CellContext`sym$238599[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$238599[$CellContext`size, 
         "missing"]]]], $CellContext`sym$238599[$CellContext`speed] = Part[
      $CellContext`sym$238599[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$238599[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$238599[$CellContext`a1, 
      "factorized"] = 
    False, $CellContext`sym$238599[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$238599[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$238599[All], 
      All, $CellContext`i$238611], $CellContext`sym$238599[$CellContext`a2, 
      "factorized"] = 
    False, $CellContext`sym$238599[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$238599[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$238599[All], 
      All, $CellContext`i$238612], $CellContext`sym$238599[$CellContext`a3, 
      "factorized"] = 
    False, $CellContext`sym$238599[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$238599[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$238599[All], 
      All, $CellContext`i$238613], $CellContext`sym$238599[$CellContext`a4, 
      "factorized"] = 
    False, $CellContext`sym$238599[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$238599[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$238599[All], 
      All, $CellContext`i$238614], $CellContext`sym$238599[$CellContext`a5, 
      "factorized"] = 
    False, $CellContext`sym$238599[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$238599[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$238599[All], 
      All, $CellContext`i$238615], $CellContext`sym$238599[$CellContext`a6, 
      "factorized"] = 
    False, $CellContext`sym$238599[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$238599[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$238599[All], 
      All, $CellContext`i$238616], $CellContext`sym$238599[$CellContext`a7, 
      "factorized"] = 
    False, $CellContext`sym$238599[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$238599[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$238599[All], 
      All, $CellContext`i$238617], $CellContext`sym$238599[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$238599[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed}, $CellContext`sym$238599[$CellContext`Chla, "factorized"] = 
    False, $CellContext`sym$238599[$CellContext`Chla, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {63}, {116}, {184}, {
     199}}, $CellContext`sym$238599[$CellContext`Chla, "raw"] = Part[
      $CellContext`sym$238599[All], 
      All, $CellContext`i$238610], $CellContext`sym$238599[$CellContext`Cl, 
      "factorized"] = 
    False, $CellContext`sym$238599[$CellContext`Cl, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {161}, {
     199}}, $CellContext`sym$238599[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$238599[All], 
      All, $CellContext`i$238605], $CellContext`sym$238599[$CellContext`mnO2, 
      "factorized"] = 
    False, $CellContext`sym$238599[$CellContext`mnO2, "missing"] = {{38}, {
     62}}, $CellContext`sym$238599[$CellContext`mnO2, "raw"] = Part[
      $CellContext`sym$238599[All], 
      All, $CellContext`i$238604], $CellContext`sym$238599[$CellContext`mxPH, 
      "factorized"] = 
    False, $CellContext`sym$238599[$CellContext`mxPH, "missing"] = {{
     48}}, $CellContext`sym$238599[$CellContext`mxPH, "raw"] = Part[
      $CellContext`sym$238599[All], 
      All, $CellContext`i$238603], $CellContext`sym$238599[$CellContext`NH4, 
      "factorized"] = 
    False, $CellContext`sym$238599[$CellContext`NH4, "missing"] = {{62}, {
     199}}, $CellContext`sym$238599[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$238599[All], 
      All, $CellContext`i$238607], $CellContext`sym$238599[$CellContext`NO3, 
      "factorized"] = 
    False, $CellContext`sym$238599[$CellContext`NO3, "missing"] = {{62}, {
     199}}, $CellContext`sym$238599[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$238599[All], 
      All, $CellContext`i$238606], $CellContext`sym$238599[$CellContext`oPO4, 
      "factorized"] = 
    False, $CellContext`sym$238599[$CellContext`oPO4, "missing"] = {{62}, {
     199}}, $CellContext`sym$238599[$CellContext`oPO4, "raw"] = Part[
      $CellContext`sym$238599[All], 
      All, $CellContext`i$238608], $CellContext`sym$238599[$CellContext`PO4, 
      "factorized"] = 
    False, $CellContext`sym$238599[$CellContext`PO4, "missing"] = {{28}, {
     199}}, $CellContext`sym$238599[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$238599[All], 
      All, $CellContext`i$238609], \
$CellContext`sym$238599[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$238599[$CellContext`season, "factors"] = 
    Part[{"autumn", "spring", "summer", "winter"}, 
      $CellContext`fordering[$CellContext`sym$238599, $CellContext`season]], \
$CellContext`sym$238599[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$238599[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$238599[All], 
      All, $CellContext`i$238600], $CellContext`sym$238599[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$238599[$CellContext`size, "factors"] = 
    Part[{"large", "medium", "small"}, 
      $CellContext`fordering[$CellContext`sym$238599, $CellContext`size]], \
$CellContext`sym$238599[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$238599[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$238599[All], 
      All, $CellContext`i$238601], $CellContext`sym$238599[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$238599[$CellContext`speed, "factors"] = 
    Part[{"high", "low", "medium"}, 
      $CellContext`fordering[$CellContext`sym$238599, $CellContext`speed]], \
$CellContext`sym$238599[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$238599[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$238599[All], All, $CellContext`i$238602], 
    Attributes[$CellContext`i$238615] = {Temporary}, $CellContext`i$238615 = 
    16, Attributes[$CellContext`i$238605] = {
     Temporary}, $CellContext`i$238605 = 6, 
    Attributes[$CellContext`i$238600] = {Temporary}, $CellContext`i$238600 = 
    1, Attributes[$CellContext`i$238610] = {Temporary}, $CellContext`i$238610 = 
    11, Attributes[$CellContext`i$238604] = {
     Temporary}, $CellContext`i$238604 = 5, 
    Attributes[$CellContext`i$238609] = {Temporary}, $CellContext`i$238609 = 
    10, Attributes[$CellContext`i$238611] = {
     Temporary}, $CellContext`i$238611 = 12, 
    Attributes[$CellContext`i$238614] = {Temporary}, $CellContext`i$238614 = 
    15, Attributes[$CellContext`i$238602] = {
     Temporary}, $CellContext`i$238602 = 3, 
    Attributes[$CellContext`i$238608] = {Temporary}, $CellContext`i$238608 = 
    9, Attributes[$CellContext`i$238617] = {Temporary}, $CellContext`i$238617 = 
    18, Attributes[$CellContext`i$238607] = {
     Temporary}, $CellContext`i$238607 = 8, 
    Attributes[$CellContext`i$238613] = {Temporary}, $CellContext`i$238613 = 
    14, Attributes[$CellContext`i$238606] = {
     Temporary}, $CellContext`i$238606 = 7, 
    Attributes[$CellContext`i$238603] = {Temporary}, $CellContext`i$238603 = 
    4, Attributes[$CellContext`i$238601] = {Temporary}, $CellContext`i$238601 = 
    2, Attributes[$CellContext`i$238612] = {Temporary}, $CellContext`i$238612 = 
    13, Attributes[$CellContext`i$238616] = {
     Temporary}, $CellContext`i$238616 = 17, 
    Attributes[$CellContext`sym$233839] = {
     Temporary}, $CellContext`sym$233839[$CellContext`a1] = Part[
      $CellContext`sym$233839[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$233839[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$233839[$CellContext`a2] = Part[
      $CellContext`sym$233839[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$233839[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$233839[$CellContext`a3] = Part[
      $CellContext`sym$233839[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$233839[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$233839[$CellContext`a4] = Part[
      $CellContext`sym$233839[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$233839[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$233839[$CellContext`a5] = Part[
      $CellContext`sym$233839[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$233839[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$233839[$CellContext`a6] = Part[
      $CellContext`sym$233839[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$233839[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$233839[$CellContext`a7] = Part[
      $CellContext`sym$233839[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$233839[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$233839[
     All] = {{"winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 
       170., 50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
      "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
       558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
      "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 125.667,
        187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
      "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 61.182, 
       138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
      "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222, 
       97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
      "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
       56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
      "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
       111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
      "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 44.667, 
       77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
      "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 71., 
       5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 0.8, 
       17., 0., 0., 2.9, 0., 0., 1.7}, {
      "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 20.75, 
       0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
      "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 19.,
        0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
      "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 41., 
       43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
      "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5, 
       31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
      "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 0.3, 
       52.2, 5., 7.8, 0., 4., 0., 0.}, {
      "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 98.25, 
       1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50., 
       1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
      "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 57.833, 
       0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
      "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 0.8, 
       50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
      "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
       564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
      "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 586.,
        16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
      "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 0.5, 
       15.5, 0., 0., 2.3, 0., 0., 0.}, {
      "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 7.6,
        23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
      "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
       27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
      "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 1.5,
        13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
      "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 44.136, 
       3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
      "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 0.5, 
       29.7, 0., 0., 4.9, 0., 0., 0.}, {
      "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
       Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
      "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 17.1,
        0., 19.6, 0., 0., 0., 2.5}, {
      "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5, 
       33.9, 1., 14.6, 0., 0., 0., 0.}, {
      "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 4.9, 
       3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
      "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 2.8, 
       6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
      "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 130.75, 
       5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
      "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47., 
       2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
      "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23., 
       0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
      "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 58.875, 
       84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
      "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 0.2,
        66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
       Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0., 
       0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
       196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
      "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
       182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
      "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001, 
       296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
      "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 59.429,
        175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
      "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
       344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
      "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 276.85001, 
       326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
      "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 40.667, 
       3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
      "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 3.3, 
       29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
      "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 0.8, 
       54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
       Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 0., 
       0.}, {"spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121.,
        2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 20.812,
        12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
      "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
       49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
      "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 22.9, 
       4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
      "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 11.8, 
       0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818, 
       0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
      "winter", "small", "high", 6.6, 10.8, 
       Missing[], 3.245, 10., 1., 6.5, 
       Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "medium", 5.6, 11.8, 
       Missing[], 2.22, 5., 1., 1., 
       Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 5.7, 10.8, 
       Missing[], 2.55, 10., 1., 4., 
       Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
      "spring", "small", "high", 6.6, 9.5, 
       Missing[], 1.32, 20., 1., 6., 
       Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
      "summer", "small", "high", 6.6, 10.8, 
       Missing[], 2.64, 10., 2., 11., 
       Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
      "autumn", "small", "medium", 6.6, 11.3, 
       Missing[], 4.17, 10., 1., 6., 
       Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
      "spring", "small", "medium", 6.5, 10.4, 
       Missing[], 5.97, 10., 2., 14., 
       Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
      "summer", "small", "medium", 6.4, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 14., 
       Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
      "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 6.667, 
       Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75, 1.,
        20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
      "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2, 
       0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
      "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 0.6,
        55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
      "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 10.75, 
       2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
      "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 0.5, 
       64.2, 0., 3., 0., 0., 0., 0.}, {
      "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75, 
       351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
      "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
       209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
      "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 151.125,
        279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
      "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
       152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
      "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
       58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
      "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
       249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
      "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 100., 
       233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
      "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 215.5, 
       18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
      "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 25.167, 
       102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
      "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
       105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
      "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
       111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
      "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 1.3, 
       6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
      "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 56.667, 
       2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
      "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 4.3,
        1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
      "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
       104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
      "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 69.93,
        3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
      "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
       214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
      "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
       254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
      "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 57.6,
        169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
      "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
       412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
      "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
       282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
      "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
       197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
      "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 267.75, 
       391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
      "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 191.75, 
       265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
      "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
       232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
      "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 144.66701, 
       244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
      "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 218., 
       6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
      "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 138.5,
        20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
      "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222, 
       239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
      "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
       235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
      "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75, 
       205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
      "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 31.333, 
       211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
      "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625, 
       186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
      "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 12.889, 
       154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
      "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 51.111, 
       183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
      "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
       292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
      "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
       285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
      "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
       201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
      "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
       275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
      "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
       124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
      "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 60.833, 
       141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
      "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71., 
       132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
      "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
       17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
      "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 0.3, 
       46.6, 0., 2.5, 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 8.692, 
       16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
      "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 37.857, 
       102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
      "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
       86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
      "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
       10.111, 
       Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 16.833, 
       18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
      "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545, 
       13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
      "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 261.60001, 
       432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
      "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
       320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
      "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 144., 
       287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
      "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
       166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
      "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
       222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
      "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 36.909, 
       122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
      "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556, 
       127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
      "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
       89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
      "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 55., 
       284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
      "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 102.333, 
       277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
      "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 75.875, 
       177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
      "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
       72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
      "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 48.667, 
       82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
      "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 48.625, 
       66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
      "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 23., 
       173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
      "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 317., 
       5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
      "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 84., 
       4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
      "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 2., 
       10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
      "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 88.5, 
       2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
      "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115., 
       11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
      "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 98.143, 
       2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
      "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
       143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
      "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
       197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
      "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 1., 
       19., 0., 22., 5., 1.1, 5.4, 0.}, {
      "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 10.583, 
       23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
      "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 200.231, 
       19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
      "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 77.333, 
       147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
      "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5, 
       276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
      "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
       123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
      "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 75.207,
        23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
      "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 116.2,
        7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
      "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
       188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
      "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
       72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
      "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 16., 
       0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
      "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 34., 
       53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
      "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 27.5, 
       76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
      "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
       58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
      "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 175.66701, 
       361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
      "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
       22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
      "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 26.8,
        0., 28., 0., 0., 0., 0., 15.1}, {
      "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
       54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
      "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333, 
       34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
      "spring", "large", "low", 9., 5.8, 
       Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 0., 
       0.}, {"spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
       151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
      "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
       269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
      "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 46.438, 
       81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
      "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 85., 
       2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
      "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 66.4, 
       171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
      "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 102.364, 
       232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
      "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 84.3, 
       146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
      "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
       246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
      "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 205.636, 
       219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
      "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 236.39999,
        272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
      "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 1081.66003, 
       346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 5.9, 1.7}, {
      "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 82.222,
        167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
      "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 64.389, 
       137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
      "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 87.333,
        194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
      "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
       159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
      "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 21.3, 
       1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
      "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 0.6,
        37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
      "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
       14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
      "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222, 7.,
        1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 0.8, 
       50.4, 3.8, 0., 0., 0., 0., 0.}, {
      "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 7.654, 
       4., 56.8, 5., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 2.86, 
       17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
      "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 56.091, 
       Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
      "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
       52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
      "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 104.727, 
       228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
      "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 85.4, 
       17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
      "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 87.125,
        14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
      "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 101.455, 
       18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
      "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 50.889, 
       127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
      "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
       81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
      "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 19.727, 
       50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
      "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111, 
       120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
      "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 51.111, 
       91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
      "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 19.111, 
       61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
      "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625, 
       79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
      "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333, 
       75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
      "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333, 
       140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
      "winter", "large", "medium", 8., 7.6, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
      "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
       140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 
       5.8}}, $CellContext`sym$233839[$CellContext`Chla] = Part[
      $CellContext`sym$233839[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {
          "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
           196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$233839[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$233839[$CellContext`Cl] = Part[
      $CellContext`sym$233839[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$233839[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$233839[$CellContext`mnO2] = Part[
      $CellContext`sym$233839[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$233839[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$233839[$CellContext`mxPH] = Part[
      $CellContext`sym$233839[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$233839[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$233839[$CellContext`NH4] = Part[
      $CellContext`sym$233839[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$233839[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$233839[$CellContext`NO3] = Part[
      $CellContext`sym$233839[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$233839[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$233839[$CellContext`oPO4] = Part[
      $CellContext`sym$233839[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$233839[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$233839[$CellContext`PO4] = Part[
      $CellContext`sym$233839[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$233839[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$233839[$CellContext`season] = Part[
      $CellContext`sym$233839[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$233839[$CellContext`season, 
         "missing"]]]], $CellContext`sym$233839[$CellContext`size] = Part[
      $CellContext`sym$233839[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$233839[$CellContext`size, 
         "missing"]]]], $CellContext`sym$233839[$CellContext`speed] = Part[
      $CellContext`sym$233839[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$233839[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$233839[$CellContext`a1, 
      "factorized"] = 
    False, $CellContext`sym$233839[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$233839[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$233839[All], 
      All, $CellContext`i$233851], $CellContext`sym$233839[$CellContext`a2, 
      "factorized"] = 
    False, $CellContext`sym$233839[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$233839[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$233839[All], 
      All, $CellContext`i$233852], $CellContext`sym$233839[$CellContext`a3, 
      "factorized"] = 
    False, $CellContext`sym$233839[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$233839[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$233839[All], 
      All, $CellContext`i$233853], $CellContext`sym$233839[$CellContext`a4, 
      "factorized"] = 
    False, $CellContext`sym$233839[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$233839[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$233839[All], 
      All, $CellContext`i$233854], $CellContext`sym$233839[$CellContext`a5, 
      "factorized"] = 
    False, $CellContext`sym$233839[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$233839[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$233839[All], 
      All, $CellContext`i$233855], $CellContext`sym$233839[$CellContext`a6, 
      "factorized"] = 
    False, $CellContext`sym$233839[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$233839[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$233839[All], 
      All, $CellContext`i$233856], $CellContext`sym$233839[$CellContext`a7, 
      "factorized"] = 
    False, $CellContext`sym$233839[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$233839[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$233839[All], 
      All, $CellContext`i$233857], $CellContext`sym$233839[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$233839[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed}, $CellContext`sym$233839[$CellContext`Chla, "factorized"] = 
    False, $CellContext`sym$233839[$CellContext`Chla, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {63}, {116}, {184}, {
     199}}, $CellContext`sym$233839[$CellContext`Chla, "raw"] = Part[
      $CellContext`sym$233839[All], 
      All, $CellContext`i$233850], $CellContext`sym$233839[$CellContext`Cl, 
      "factorized"] = 
    False, $CellContext`sym$233839[$CellContext`Cl, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {161}, {
     199}}, $CellContext`sym$233839[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$233839[All], 
      All, $CellContext`i$233845], $CellContext`sym$233839[$CellContext`mnO2, 
      "factorized"] = 
    False, $CellContext`sym$233839[$CellContext`mnO2, "missing"] = {{38}, {
     62}}, $CellContext`sym$233839[$CellContext`mnO2, "raw"] = Part[
      $CellContext`sym$233839[All], 
      All, $CellContext`i$233844], $CellContext`sym$233839[$CellContext`mxPH, 
      "factorized"] = 
    False, $CellContext`sym$233839[$CellContext`mxPH, "missing"] = {{
     48}}, $CellContext`sym$233839[$CellContext`mxPH, "raw"] = Part[
      $CellContext`sym$233839[All], 
      All, $CellContext`i$233843], $CellContext`sym$233839[$CellContext`NH4, 
      "factorized"] = 
    False, $CellContext`sym$233839[$CellContext`NH4, "missing"] = {{62}, {
     199}}, $CellContext`sym$233839[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$233839[All], 
      All, $CellContext`i$233847], $CellContext`sym$233839[$CellContext`NO3, 
      "factorized"] = 
    False, $CellContext`sym$233839[$CellContext`NO3, "missing"] = {{62}, {
     199}}, $CellContext`sym$233839[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$233839[All], 
      All, $CellContext`i$233846], $CellContext`sym$233839[$CellContext`oPO4, 
      "factorized"] = 
    False, $CellContext`sym$233839[$CellContext`oPO4, "missing"] = {{62}, {
     199}}, $CellContext`sym$233839[$CellContext`oPO4, "raw"] = Part[
      $CellContext`sym$233839[All], 
      All, $CellContext`i$233848], $CellContext`sym$233839[$CellContext`PO4, 
      "factorized"] = 
    False, $CellContext`sym$233839[$CellContext`PO4, "missing"] = {{28}, {
     199}}, $CellContext`sym$233839[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$233839[All], 
      All, $CellContext`i$233849], \
$CellContext`sym$233839[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$233839[$CellContext`season, "factors"] = 
    Part[{"autumn", "spring", "summer", "winter"}, 
      $CellContext`fordering[$CellContext`sym$233839, $CellContext`season]], \
$CellContext`sym$233839[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$233839[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$233839[All], 
      All, $CellContext`i$233840], $CellContext`sym$233839[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$233839[$CellContext`size, "factors"] = 
    Part[{"large", "medium", "small"}, 
      $CellContext`fordering[$CellContext`sym$233839, $CellContext`size]], \
$CellContext`sym$233839[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$233839[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$233839[All], 
      All, $CellContext`i$233841], $CellContext`sym$233839[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$233839[$CellContext`speed, "factors"] = 
    Part[{"high", "low", "medium"}, 
      $CellContext`fordering[$CellContext`sym$233839, $CellContext`speed]], \
$CellContext`sym$233839[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$233839[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$233839[All], All, $CellContext`i$233842], 
    Attributes[$CellContext`i$233844] = {Temporary}, $CellContext`i$233844 = 
    5, Attributes[$CellContext`i$233853] = {Temporary}, $CellContext`i$233853 = 
    14, Attributes[$CellContext`i$233845] = {
     Temporary}, $CellContext`i$233845 = 6, 
    Attributes[$CellContext`i$233855] = {Temporary}, $CellContext`i$233855 = 
    16, Attributes[$CellContext`i$233848] = {
     Temporary}, $CellContext`i$233848 = 9, 
    Attributes[$CellContext`i$233850] = {Temporary}, $CellContext`i$233850 = 
    11, Attributes[$CellContext`i$233856] = {
     Temporary}, $CellContext`i$233856 = 17, 
    Attributes[$CellContext`i$233842] = {Temporary}, $CellContext`i$233842 = 
    3, Attributes[$CellContext`i$233840] = {Temporary}, $CellContext`i$233840 = 
    1, Attributes[$CellContext`i$233847] = {Temporary}, $CellContext`i$233847 = 
    8, Attributes[$CellContext`i$233857] = {Temporary}, $CellContext`i$233857 = 
    18, Attributes[$CellContext`i$233841] = {
     Temporary}, $CellContext`i$233841 = 2, 
    Attributes[$CellContext`i$233851] = {Temporary}, $CellContext`i$233851 = 
    12, Attributes[$CellContext`i$233846] = {
     Temporary}, $CellContext`i$233846 = 7, 
    Attributes[$CellContext`i$233849] = {Temporary}, $CellContext`i$233849 = 
    10, Attributes[$CellContext`i$233854] = {
     Temporary}, $CellContext`i$233854 = 15, 
    Attributes[$CellContext`i$233843] = {Temporary}, $CellContext`i$233843 = 
    4, Attributes[$CellContext`i$233852] = {Temporary}, $CellContext`i$233852 = 
    13, Attributes[$CellContext`sym$231241] = {
     Temporary}, $CellContext`sym$231241[$CellContext`a1] = Part[
      $CellContext`sym$231241[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {
          "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
           196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$231241[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$231241[$CellContext`a2] = Part[
      $CellContext`sym$231241[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$231241[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$231241[$CellContext`a3] = Part[
      $CellContext`sym$231241[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$231241[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$231241[$CellContext`a4] = Part[
      $CellContext`sym$231241[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$231241[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$231241[$CellContext`a5] = Part[
      $CellContext`sym$231241[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$231241[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$231241[$CellContext`a6] = Part[
      $CellContext`sym$231241[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$231241[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$231241[$CellContext`a7] = Part[
      $CellContext`sym$231241[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$231241[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$231241[
     All] = {{"winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 
       170., 50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
      "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
       558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
      "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 125.667,
        187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
      "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 61.182, 
       138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
      "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222, 
       97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
      "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
       56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
      "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
       111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
      "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 44.667, 
       77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
      "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 71., 
       5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 0.8, 
       17., 0., 0., 2.9, 0., 0., 1.7}, {
      "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 20.75, 
       0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
      "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 19.,
        0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
      "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 41., 
       43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
      "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5, 
       31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
      "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 0.3, 
       52.2, 5., 7.8, 0., 4., 0., 0.}, {
      "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 98.25, 
       1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50., 
       1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
      "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 57.833, 
       0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
      "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 0.8, 
       50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
      "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
       564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
      "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 586.,
        16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
      "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 0.5, 
       15.5, 0., 0., 2.3, 0., 0., 0.}, {
      "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 7.6,
        23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
      "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
       27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
      "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 1.5,
        13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
      "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 44.136, 
       3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
      "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 0.5, 
       29.7, 0., 0., 4.9, 0., 0., 0.}, {
      "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
       Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
      "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 17.1,
        0., 19.6, 0., 0., 0., 2.5}, {
      "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5, 
       33.9, 1., 14.6, 0., 0., 0., 0.}, {
      "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 4.9, 
       3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
      "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 2.8, 
       6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
      "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 130.75, 
       5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
      "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47., 
       2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
      "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23., 
       0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
      "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 58.875, 
       84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
      "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 0.2,
        66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
       Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0., 
       0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
       196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
      "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
       182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
      "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001, 
       296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
      "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 59.429,
        175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
      "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
       344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
      "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 276.85001, 
       326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
      "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 40.667, 
       3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
      "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 3.3, 
       29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
      "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 0.8, 
       54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
       Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 0., 
       0.}, {"spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121.,
        2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 20.812,
        12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
      "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
       49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
      "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 22.9, 
       4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
      "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 11.8, 
       0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818, 
       0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
      "winter", "small", "high", 6.6, 10.8, 
       Missing[], 3.245, 10., 1., 6.5, 
       Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "medium", 5.6, 11.8, 
       Missing[], 2.22, 5., 1., 1., 
       Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 5.7, 10.8, 
       Missing[], 2.55, 10., 1., 4., 
       Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
      "spring", "small", "high", 6.6, 9.5, 
       Missing[], 1.32, 20., 1., 6., 
       Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
      "summer", "small", "high", 6.6, 10.8, 
       Missing[], 2.64, 10., 2., 11., 
       Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
      "autumn", "small", "medium", 6.6, 11.3, 
       Missing[], 4.17, 10., 1., 6., 
       Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
      "spring", "small", "medium", 6.5, 10.4, 
       Missing[], 5.97, 10., 2., 14., 
       Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
      "summer", "small", "medium", 6.4, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 14., 
       Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
      "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 6.667, 
       Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75, 1.,
        20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
      "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2, 
       0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
      "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 0.6,
        55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
      "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 10.75, 
       2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
      "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 0.5, 
       64.2, 0., 3., 0., 0., 0., 0.}, {
      "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75, 
       351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
      "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
       209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
      "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 151.125,
        279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
      "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
       152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
      "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
       58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
      "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
       249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
      "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 100., 
       233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
      "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 215.5, 
       18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
      "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 25.167, 
       102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
      "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
       105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
      "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
       111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
      "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 1.3, 
       6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
      "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 56.667, 
       2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
      "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 4.3,
        1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
      "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
       104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
      "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 69.93,
        3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
      "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
       214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
      "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
       254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
      "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 57.6,
        169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
      "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
       412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
      "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
       282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
      "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
       197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
      "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 267.75, 
       391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
      "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 191.75, 
       265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
      "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
       232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
      "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 144.66701, 
       244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
      "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 218., 
       6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
      "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 138.5,
        20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
      "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222, 
       239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
      "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
       235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
      "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75, 
       205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
      "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 31.333, 
       211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
      "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625, 
       186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
      "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 12.889, 
       154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
      "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 51.111, 
       183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
      "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
       292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
      "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
       285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
      "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
       201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
      "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
       275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
      "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
       124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
      "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 60.833, 
       141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
      "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71., 
       132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
      "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
       17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
      "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 0.3, 
       46.6, 0., 2.5, 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 8.692, 
       16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
      "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 37.857, 
       102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
      "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
       86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
      "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
       10.111, 
       Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 16.833, 
       18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
      "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545, 
       13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
      "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 261.60001, 
       432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
      "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
       320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
      "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 144., 
       287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
      "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
       166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
      "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
       222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
      "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 36.909, 
       122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
      "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556, 
       127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
      "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
       89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
      "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 55., 
       284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
      "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 102.333, 
       277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
      "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 75.875, 
       177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
      "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
       72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
      "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 48.667, 
       82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
      "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 48.625, 
       66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
      "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 23., 
       173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
      "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 317., 
       5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
      "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 84., 
       4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
      "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 2., 
       10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
      "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 88.5, 
       2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
      "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115., 
       11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
      "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 98.143, 
       2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
      "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
       143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
      "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
       197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
      "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 1., 
       19., 0., 22., 5., 1.1, 5.4, 0.}, {
      "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 10.583, 
       23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
      "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 200.231, 
       19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
      "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 77.333, 
       147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
      "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5, 
       276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
      "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
       123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
      "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 75.207,
        23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
      "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 116.2,
        7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
      "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
       188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
      "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
       72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
      "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 16., 
       0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
      "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 34., 
       53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
      "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 27.5, 
       76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
      "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
       58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
      "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 175.66701, 
       361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
      "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
       22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
      "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 26.8,
        0., 28., 0., 0., 0., 0., 15.1}, {
      "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
       54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
      "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333, 
       34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
      "spring", "large", "low", 9., 5.8, 
       Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 0., 
       0.}, {"spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
       151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
      "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
       269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
      "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 46.438, 
       81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
      "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 85., 
       2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
      "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 66.4, 
       171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
      "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 102.364, 
       232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
      "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 84.3, 
       146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
      "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
       246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
      "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 205.636, 
       219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
      "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 236.39999,
        272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
      "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 1081.66003, 
       346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 5.9, 1.7}, {
      "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 82.222,
        167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
      "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 64.389, 
       137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
      "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 87.333,
        194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
      "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
       159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
      "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 21.3, 
       1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
      "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 0.6,
        37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
      "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
       14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
      "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222, 7.,
        1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 0.8, 
       50.4, 3.8, 0., 0., 0., 0., 0.}, {
      "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 7.654, 
       4., 56.8, 5., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 2.86, 
       17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
      "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 56.091, 
       Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
      "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
       52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
      "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 104.727, 
       228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
      "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 85.4, 
       17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
      "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 87.125,
        14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
      "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 101.455, 
       18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
      "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 50.889, 
       127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
      "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
       81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
      "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 19.727, 
       50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
      "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111, 
       120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
      "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 51.111, 
       91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
      "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 19.111, 
       61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
      "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625, 
       79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
      "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333, 
       75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
      "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333, 
       140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
      "winter", "large", "medium", 8., 7.6, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
      "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
       140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 
       5.8}}, $CellContext`sym$231241[$CellContext`Chla] = Part[
      $CellContext`sym$231241[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {
          "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
           196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$231241[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$231241[$CellContext`Cl] = Part[
      $CellContext`sym$231241[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$231241[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$231241[$CellContext`mnO2] = Part[
      $CellContext`sym$231241[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$231241[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$231241[$CellContext`mxPH] = Part[
      $CellContext`sym$231241[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$231241[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$231241[$CellContext`NH4] = Part[
      $CellContext`sym$231241[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$231241[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$231241[$CellContext`NO3] = Part[
      $CellContext`sym$231241[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$231241[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$231241[$CellContext`oPO4] = Part[
      $CellContext`sym$231241[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$231241[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$231241[$CellContext`PO4] = Part[
      $CellContext`sym$231241[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$231241[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$231241[$CellContext`season] = Part[
      $CellContext`sym$231241[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$231241[$CellContext`season, 
         "missing"]]]], $CellContext`sym$231241[$CellContext`size] = Part[
      $CellContext`sym$231241[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$231241[$CellContext`size, 
         "missing"]]]], $CellContext`sym$231241[$CellContext`speed] = Part[
      $CellContext`sym$231241[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$231241[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$231241[$CellContext`a1, 
      "factorized"] = 
    False, $CellContext`sym$231241[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$231241[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$231241[All], 
      All, $CellContext`i$231253], $CellContext`sym$231241[$CellContext`a2, 
      "factorized"] = 
    False, $CellContext`sym$231241[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$231241[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$231241[All], 
      All, $CellContext`i$231254], $CellContext`sym$231241[$CellContext`a3, 
      "factorized"] = 
    False, $CellContext`sym$231241[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$231241[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$231241[All], 
      All, $CellContext`i$231255], $CellContext`sym$231241[$CellContext`a4, 
      "factorized"] = 
    False, $CellContext`sym$231241[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$231241[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$231241[All], 
      All, $CellContext`i$231256], $CellContext`sym$231241[$CellContext`a5, 
      "factorized"] = 
    False, $CellContext`sym$231241[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$231241[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$231241[All], 
      All, $CellContext`i$231257], $CellContext`sym$231241[$CellContext`a6, 
      "factorized"] = 
    False, $CellContext`sym$231241[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$231241[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$231241[All], 
      All, $CellContext`i$231258], $CellContext`sym$231241[$CellContext`a7, 
      "factorized"] = 
    False, $CellContext`sym$231241[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$231241[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$231241[All], 
      All, $CellContext`i$231259], $CellContext`sym$231241[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$231241[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed}, $CellContext`sym$231241[$CellContext`Chla, "factorized"] = 
    False, $CellContext`sym$231241[$CellContext`Chla, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {63}, {116}, {184}, {
     199}}, $CellContext`sym$231241[$CellContext`Chla, "raw"] = Part[
      $CellContext`sym$231241[All], 
      All, $CellContext`i$231252], $CellContext`sym$231241[$CellContext`Cl, 
      "factorized"] = 
    False, $CellContext`sym$231241[$CellContext`Cl, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {161}, {
     199}}, $CellContext`sym$231241[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$231241[All], 
      All, $CellContext`i$231247], $CellContext`sym$231241[$CellContext`mnO2, 
      "factorized"] = 
    False, $CellContext`sym$231241[$CellContext`mnO2, "missing"] = {{38}, {
     62}}, $CellContext`sym$231241[$CellContext`mnO2, "raw"] = Part[
      $CellContext`sym$231241[All], 
      All, $CellContext`i$231246], $CellContext`sym$231241[$CellContext`mxPH, 
      "factorized"] = 
    False, $CellContext`sym$231241[$CellContext`mxPH, "missing"] = {{
     48}}, $CellContext`sym$231241[$CellContext`mxPH, "raw"] = Part[
      $CellContext`sym$231241[All], 
      All, $CellContext`i$231245], $CellContext`sym$231241[$CellContext`NH4, 
      "factorized"] = 
    False, $CellContext`sym$231241[$CellContext`NH4, "missing"] = {{62}, {
     199}}, $CellContext`sym$231241[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$231241[All], 
      All, $CellContext`i$231249], $CellContext`sym$231241[$CellContext`NO3, 
      "factorized"] = 
    False, $CellContext`sym$231241[$CellContext`NO3, "missing"] = {{62}, {
     199}}, $CellContext`sym$231241[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$231241[All], 
      All, $CellContext`i$231248], $CellContext`sym$231241[$CellContext`oPO4, 
      "factorized"] = 
    False, $CellContext`sym$231241[$CellContext`oPO4, "missing"] = {{62}, {
     199}}, $CellContext`sym$231241[$CellContext`oPO4, "raw"] = Part[
      $CellContext`sym$231241[All], 
      All, $CellContext`i$231250], $CellContext`sym$231241[$CellContext`PO4, 
      "factorized"] = 
    False, $CellContext`sym$231241[$CellContext`PO4, "missing"] = {{28}, {
     199}}, $CellContext`sym$231241[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$231241[All], 
      All, $CellContext`i$231251], \
$CellContext`sym$231241[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$231241[$CellContext`season, "factors"] = 
    Part[{"autumn", "spring", "summer", "winter"}, 
      $CellContext`fordering[$CellContext`sym$231241, $CellContext`season]], \
$CellContext`sym$231241[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$231241[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$231241[All], 
      All, $CellContext`i$231242], $CellContext`sym$231241[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$231241[$CellContext`size, "factors"] = 
    Part[{"large", "medium", "small"}, 
      $CellContext`fordering[$CellContext`sym$231241, $CellContext`size]], \
$CellContext`sym$231241[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$231241[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$231241[All], 
      All, $CellContext`i$231243], $CellContext`sym$231241[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$231241[$CellContext`speed, "factors"] = 
    Part[{"high", "low", "medium"}, 
      $CellContext`fordering[$CellContext`sym$231241, $CellContext`speed]], \
$CellContext`sym$231241[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$231241[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$231241[All], All, $CellContext`i$231244], 
    Attributes[$CellContext`i$231259] = {Temporary}, $CellContext`i$231259 = 
    18, Attributes[$CellContext`i$231244] = {
     Temporary}, $CellContext`i$231244 = 3, 
    Attributes[$CellContext`i$231257] = {Temporary}, $CellContext`i$231257 = 
    16, Attributes[$CellContext`i$231242] = {
     Temporary}, $CellContext`i$231242 = 1, 
    Attributes[$CellContext`i$231251] = {Temporary}, $CellContext`i$231251 = 
    10, Attributes[$CellContext`i$231247] = {
     Temporary}, $CellContext`i$231247 = 6, 
    Attributes[$CellContext`i$231253] = {Temporary}, $CellContext`i$231253 = 
    12, Attributes[$CellContext`i$231252] = {
     Temporary}, $CellContext`i$231252 = 11, 
    Attributes[$CellContext`i$231254] = {Temporary}, $CellContext`i$231254 = 
    13, Attributes[$CellContext`i$231249] = {
     Temporary}, $CellContext`i$231249 = 8, 
    Attributes[$CellContext`i$231256] = {Temporary}, $CellContext`i$231256 = 
    15, Attributes[$CellContext`i$231245] = {
     Temporary}, $CellContext`i$231245 = 4, 
    Attributes[$CellContext`i$231248] = {Temporary}, $CellContext`i$231248 = 
    7, Attributes[$CellContext`i$231243] = {Temporary}, $CellContext`i$231243 = 
    2, Attributes[$CellContext`i$231246] = {Temporary}, $CellContext`i$231246 = 
    5, Attributes[$CellContext`i$231250] = {Temporary}, $CellContext`i$231250 = 
    9, Attributes[$CellContext`i$231258] = {Temporary}, $CellContext`i$231258 = 
    17, Attributes[$CellContext`i$231255] = {
     Temporary}, $CellContext`i$231255 = 14, 
    Attributes[$CellContext`sym$227724] = {
     Temporary}, $CellContext`sym$227724[$CellContext`a1] = Part[
      $CellContext`sym$227724[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$227724[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$227724[$CellContext`a2] = Part[
      $CellContext`sym$227724[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$227724[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$227724[$CellContext`a3] = Part[
      $CellContext`sym$227724[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$227724[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$227724[$CellContext`a4] = Part[
      $CellContext`sym$227724[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$227724[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$227724[$CellContext`a5] = Part[
      $CellContext`sym$227724[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$227724[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$227724[$CellContext`a6] = Part[
      $CellContext`sym$227724[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$227724[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$227724[$CellContext`a7] = Part[
      $CellContext`sym$227724[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$227724[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$227724[
     All] = {{"winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 
       170., 50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
      "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
       558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
      "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 125.667,
        187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
      "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 61.182, 
       138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
      "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222, 
       97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
      "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
       56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
      "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
       111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
      "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 44.667, 
       77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
      "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 71., 
       5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 0.8, 
       17., 0., 0., 2.9, 0., 0., 1.7}, {
      "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 20.75, 
       0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
      "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 19.,
        0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
      "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 41., 
       43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
      "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5, 
       31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
      "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 0.3, 
       52.2, 5., 7.8, 0., 4., 0., 0.}, {
      "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 98.25, 
       1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50., 
       1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
      "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 57.833, 
       0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
      "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 0.8, 
       50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
      "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
       564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
      "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 586.,
        16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
      "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 0.5, 
       15.5, 0., 0., 2.3, 0., 0., 0.}, {
      "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 7.6,
        23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
      "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
       27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
      "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 1.5,
        13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
      "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 44.136, 
       3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
      "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 0.5, 
       29.7, 0., 0., 4.9, 0., 0., 0.}, {
      "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
       Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
      "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 17.1,
        0., 19.6, 0., 0., 0., 2.5}, {
      "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5, 
       33.9, 1., 14.6, 0., 0., 0., 0.}, {
      "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 4.9, 
       3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
      "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 2.8, 
       6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
      "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 130.75, 
       5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
      "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47., 
       2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
      "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23., 
       0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
      "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 58.875, 
       84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
      "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 0.2,
        66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
       Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0., 
       0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
       196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
      "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
       182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
      "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001, 
       296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
      "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 59.429,
        175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
      "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
       344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
      "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 276.85001, 
       326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
      "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 40.667, 
       3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
      "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 3.3, 
       29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
      "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 0.8, 
       54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
       Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 0., 
       0.}, {"spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121.,
        2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 20.812,
        12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
      "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
       49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
      "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 22.9, 
       4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
      "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 11.8, 
       0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818, 
       0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
      "winter", "small", "high", 6.6, 10.8, 
       Missing[], 3.245, 10., 1., 6.5, 
       Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "medium", 5.6, 11.8, 
       Missing[], 2.22, 5., 1., 1., 
       Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 5.7, 10.8, 
       Missing[], 2.55, 10., 1., 4., 
       Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
      "spring", "small", "high", 6.6, 9.5, 
       Missing[], 1.32, 20., 1., 6., 
       Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
      "summer", "small", "high", 6.6, 10.8, 
       Missing[], 2.64, 10., 2., 11., 
       Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
      "autumn", "small", "medium", 6.6, 11.3, 
       Missing[], 4.17, 10., 1., 6., 
       Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
      "spring", "small", "medium", 6.5, 10.4, 
       Missing[], 5.97, 10., 2., 14., 
       Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
      "summer", "small", "medium", 6.4, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 14., 
       Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
      "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 6.667, 
       Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75, 1.,
        20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
      "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2, 
       0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
      "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 0.6,
        55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
      "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 10.75, 
       2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
      "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 0.5, 
       64.2, 0., 3., 0., 0., 0., 0.}, {
      "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75, 
       351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
      "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
       209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
      "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 151.125,
        279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
      "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
       152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
      "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
       58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
      "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
       249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
      "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 100., 
       233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
      "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 215.5, 
       18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
      "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 25.167, 
       102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
      "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
       105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
      "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
       111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
      "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 1.3, 
       6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
      "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 56.667, 
       2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
      "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 4.3,
        1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
      "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
       104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
      "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 69.93,
        3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
      "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
       214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
      "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
       254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
      "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 57.6,
        169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
      "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
       412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
      "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
       282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
      "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
       197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
      "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 267.75, 
       391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
      "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 191.75, 
       265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
      "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
       232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
      "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 144.66701, 
       244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
      "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 218., 
       6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
      "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 138.5,
        20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
      "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222, 
       239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
      "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
       235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
      "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75, 
       205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
      "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 31.333, 
       211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
      "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625, 
       186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
      "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 12.889, 
       154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
      "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 51.111, 
       183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
      "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
       292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
      "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
       285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
      "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
       201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
      "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
       275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
      "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
       124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
      "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 60.833, 
       141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
      "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71., 
       132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
      "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
       17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
      "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 0.3, 
       46.6, 0., 2.5, 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 8.692, 
       16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
      "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 37.857, 
       102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
      "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
       86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
      "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
       10.111, 
       Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 16.833, 
       18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
      "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545, 
       13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
      "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 261.60001, 
       432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
      "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
       320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
      "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 144., 
       287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
      "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
       166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
      "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
       222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
      "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 36.909, 
       122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
      "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556, 
       127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
      "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
       89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
      "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 55., 
       284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
      "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 102.333, 
       277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
      "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 75.875, 
       177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
      "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
       72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
      "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 48.667, 
       82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
      "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 48.625, 
       66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
      "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 23., 
       173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
      "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 317., 
       5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
      "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 84., 
       4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
      "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 2., 
       10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
      "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 88.5, 
       2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
      "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115., 
       11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
      "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 98.143, 
       2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
      "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
       143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
      "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
       197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
      "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 1., 
       19., 0., 22., 5., 1.1, 5.4, 0.}, {
      "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 10.583, 
       23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
      "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 200.231, 
       19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
      "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 77.333, 
       147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
      "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5, 
       276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
      "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
       123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
      "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 75.207,
        23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
      "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 116.2,
        7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
      "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
       188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
      "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
       72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
      "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 16., 
       0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
      "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 34., 
       53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
      "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 27.5, 
       76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
      "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
       58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
      "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 175.66701, 
       361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
      "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
       22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
      "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 26.8,
        0., 28., 0., 0., 0., 0., 15.1}, {
      "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
       54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
      "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333, 
       34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
      "spring", "large", "low", 9., 5.8, 
       Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 0., 
       0.}, {"spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
       151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
      "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
       269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
      "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 46.438, 
       81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
      "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 85., 
       2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
      "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 66.4, 
       171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
      "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 102.364, 
       232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
      "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 84.3, 
       146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
      "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
       246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
      "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 205.636, 
       219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
      "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 236.39999,
        272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
      "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 1081.66003, 
       346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 5.9, 1.7}, {
      "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 82.222,
        167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
      "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 64.389, 
       137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
      "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 87.333,
        194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
      "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
       159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
      "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 21.3, 
       1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
      "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 0.6,
        37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
      "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
       14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
      "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222, 7.,
        1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 0.8, 
       50.4, 3.8, 0., 0., 0., 0., 0.}, {
      "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 7.654, 
       4., 56.8, 5., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 2.86, 
       17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
      "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 56.091, 
       Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
      "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
       52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
      "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 104.727, 
       228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
      "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 85.4, 
       17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
      "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 87.125,
        14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
      "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 101.455, 
       18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
      "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 50.889, 
       127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
      "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
       81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
      "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 19.727, 
       50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
      "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111, 
       120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
      "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 51.111, 
       91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
      "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 19.111, 
       61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
      "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625, 
       79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
      "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333, 
       75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
      "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333, 
       140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
      "winter", "large", "medium", 8., 7.6, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
      "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
       140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 
       5.8}}, $CellContext`sym$227724[$CellContext`Chla] = Part[
      $CellContext`sym$227724[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {
          "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
           196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$227724[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$227724[$CellContext`Cl] = Part[
      $CellContext`sym$227724[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$227724[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$227724[$CellContext`mnO2] = Part[
      $CellContext`sym$227724[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$227724[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$227724[$CellContext`mxPH] = Part[
      $CellContext`sym$227724[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$227724[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$227724[$CellContext`NH4] = Part[
      $CellContext`sym$227724[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$227724[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$227724[$CellContext`NO3] = Part[
      $CellContext`sym$227724[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$227724[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$227724[$CellContext`oPO4] = Part[
      $CellContext`sym$227724[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$227724[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$227724[$CellContext`PO4] = Part[
      $CellContext`sym$227724[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$227724[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$227724[$CellContext`season] = Part[
      $CellContext`sym$227724[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$227724[$CellContext`season, 
         "missing"]]]], $CellContext`sym$227724[$CellContext`size] = Part[
      $CellContext`sym$227724[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$227724[$CellContext`size, 
         "missing"]]]], $CellContext`sym$227724[$CellContext`speed] = Part[
      $CellContext`sym$227724[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$227724[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$227724[$CellContext`a1, 
      "factorized"] = 
    False, $CellContext`sym$227724[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$227724[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$227724[All], 
      All, $CellContext`i$227736], $CellContext`sym$227724[$CellContext`a2, 
      "factorized"] = 
    False, $CellContext`sym$227724[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$227724[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$227724[All], 
      All, $CellContext`i$227737], $CellContext`sym$227724[$CellContext`a3, 
      "factorized"] = 
    False, $CellContext`sym$227724[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$227724[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$227724[All], 
      All, $CellContext`i$227738], $CellContext`sym$227724[$CellContext`a4, 
      "factorized"] = 
    False, $CellContext`sym$227724[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$227724[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$227724[All], 
      All, $CellContext`i$227739], $CellContext`sym$227724[$CellContext`a5, 
      "factorized"] = 
    False, $CellContext`sym$227724[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$227724[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$227724[All], 
      All, $CellContext`i$227740], $CellContext`sym$227724[$CellContext`a6, 
      "factorized"] = 
    False, $CellContext`sym$227724[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$227724[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$227724[All], 
      All, $CellContext`i$227741], $CellContext`sym$227724[$CellContext`a7, 
      "factorized"] = 
    False, $CellContext`sym$227724[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$227724[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$227724[All], 
      All, $CellContext`i$227742], $CellContext`sym$227724[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$227724[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed}, $CellContext`sym$227724[$CellContext`Chla, "factorized"] = 
    False, $CellContext`sym$227724[$CellContext`Chla, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {63}, {116}, {184}, {
     199}}, $CellContext`sym$227724[$CellContext`Chla, "raw"] = Part[
      $CellContext`sym$227724[All], 
      All, $CellContext`i$227735], $CellContext`sym$227724[$CellContext`Cl, 
      "factorized"] = 
    False, $CellContext`sym$227724[$CellContext`Cl, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {161}, {
     199}}, $CellContext`sym$227724[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$227724[All], 
      All, $CellContext`i$227730], $CellContext`sym$227724[$CellContext`mnO2, 
      "factorized"] = 
    False, $CellContext`sym$227724[$CellContext`mnO2, "missing"] = {{38}, {
     62}}, $CellContext`sym$227724[$CellContext`mnO2, "raw"] = Part[
      $CellContext`sym$227724[All], 
      All, $CellContext`i$227729], $CellContext`sym$227724[$CellContext`mxPH, 
      "factorized"] = 
    False, $CellContext`sym$227724[$CellContext`mxPH, "missing"] = {{
     48}}, $CellContext`sym$227724[$CellContext`mxPH, "raw"] = Part[
      $CellContext`sym$227724[All], 
      All, $CellContext`i$227728], $CellContext`sym$227724[$CellContext`NH4, 
      "factorized"] = 
    False, $CellContext`sym$227724[$CellContext`NH4, "missing"] = {{62}, {
     199}}, $CellContext`sym$227724[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$227724[All], 
      All, $CellContext`i$227732], $CellContext`sym$227724[$CellContext`NO3, 
      "factorized"] = 
    False, $CellContext`sym$227724[$CellContext`NO3, "missing"] = {{62}, {
     199}}, $CellContext`sym$227724[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$227724[All], 
      All, $CellContext`i$227731], $CellContext`sym$227724[$CellContext`oPO4, 
      "factorized"] = 
    False, $CellContext`sym$227724[$CellContext`oPO4, "missing"] = {{62}, {
     199}}, $CellContext`sym$227724[$CellContext`oPO4, "raw"] = Part[
      $CellContext`sym$227724[All], 
      All, $CellContext`i$227733], $CellContext`sym$227724[$CellContext`PO4, 
      "factorized"] = 
    False, $CellContext`sym$227724[$CellContext`PO4, "missing"] = {{28}, {
     199}}, $CellContext`sym$227724[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$227724[All], 
      All, $CellContext`i$227734], \
$CellContext`sym$227724[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$227724[$CellContext`season, "factors"] = 
    Part[{"autumn", "spring", "summer", "winter"}, 
      $CellContext`fordering[$CellContext`sym$227724, $CellContext`season]], \
$CellContext`sym$227724[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$227724[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$227724[All], 
      All, $CellContext`i$227725], $CellContext`sym$227724[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$227724[$CellContext`size, "factors"] = 
    Part[{"large", "medium", "small"}, 
      $CellContext`fordering[$CellContext`sym$227724, $CellContext`size]], \
$CellContext`sym$227724[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$227724[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$227724[All], 
      All, $CellContext`i$227726], $CellContext`sym$227724[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$227724[$CellContext`speed, "factors"] = 
    Part[{"high", "low", "medium"}, 
      $CellContext`fordering[$CellContext`sym$227724, $CellContext`speed]], \
$CellContext`sym$227724[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$227724[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$227724[All], All, $CellContext`i$227727], 
    Attributes[$CellContext`i$227734] = {Temporary}, $CellContext`i$227734 = 
    10, Attributes[$CellContext`i$227727] = {
     Temporary}, $CellContext`i$227727 = 3, 
    Attributes[$CellContext`i$227729] = {Temporary}, $CellContext`i$227729 = 
    5, Attributes[$CellContext`i$227725] = {Temporary}, $CellContext`i$227725 = 
    1, Attributes[$CellContext`i$227740] = {Temporary}, $CellContext`i$227740 = 
    16, Attributes[$CellContext`i$227726] = {
     Temporary}, $CellContext`i$227726 = 2, 
    Attributes[$CellContext`i$227739] = {Temporary}, $CellContext`i$227739 = 
    15, Attributes[$CellContext`i$227736] = {
     Temporary}, $CellContext`i$227736 = 12, 
    Attributes[$CellContext`i$227732] = {Temporary}, $CellContext`i$227732 = 
    8, Attributes[$CellContext`i$227733] = {Temporary}, $CellContext`i$227733 = 
    9, Attributes[$CellContext`i$227741] = {Temporary}, $CellContext`i$227741 = 
    17, Attributes[$CellContext`i$227737] = {
     Temporary}, $CellContext`i$227737 = 13, 
    Attributes[$CellContext`i$227735] = {Temporary}, $CellContext`i$227735 = 
    11, Attributes[$CellContext`i$227728] = {
     Temporary}, $CellContext`i$227728 = 4, 
    Attributes[$CellContext`i$227731] = {Temporary}, $CellContext`i$227731 = 
    7, Attributes[$CellContext`i$227742] = {Temporary}, $CellContext`i$227742 = 
    18, Attributes[$CellContext`i$227730] = {
     Temporary}, $CellContext`i$227730 = 6, 
    Attributes[$CellContext`i$227738] = {Temporary}, $CellContext`i$227738 = 
    14, Attributes[$CellContext`sym$236130] = {
     Temporary}, $CellContext`sym$236130[$CellContext`a1] = Part[
      $CellContext`sym$236130[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$236130[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$236130[$CellContext`a2] = Part[
      $CellContext`sym$236130[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$236130[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$236130[$CellContext`a3] = Part[
      $CellContext`sym$236130[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$236130[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$236130[$CellContext`a4] = Part[
      $CellContext`sym$236130[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$236130[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$236130[$CellContext`a5] = Part[
      $CellContext`sym$236130[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$236130[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$236130[$CellContext`a6] = Part[
      $CellContext`sym$236130[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$236130[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$236130[$CellContext`a7] = Part[
      $CellContext`sym$236130[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$236130[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$236130[
     All] = {{"winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 
       170., 50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
      "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
       558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
      "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 125.667,
        187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
      "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 61.182, 
       138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
      "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222, 
       97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
      "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
       56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
      "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
       111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
      "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 44.667, 
       77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
      "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 71., 
       5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 0.8, 
       17., 0., 0., 2.9, 0., 0., 1.7}, {
      "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 20.75, 
       0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
      "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 19.,
        0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
      "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 41., 
       43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
      "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5, 
       31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
      "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 0.3, 
       52.2, 5., 7.8, 0., 4., 0., 0.}, {
      "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 98.25, 
       1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50., 
       1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
      "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 57.833, 
       0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
      "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 0.8, 
       50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
      "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
       564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
      "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 586.,
        16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
      "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 0.5, 
       15.5, 0., 0., 2.3, 0., 0., 0.}, {
      "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 7.6,
        23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
      "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
       27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
      "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 1.5,
        13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
      "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 44.136, 
       3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
      "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 0.5, 
       29.7, 0., 0., 4.9, 0., 0., 0.}, {
      "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
       Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
      "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 17.1,
        0., 19.6, 0., 0., 0., 2.5}, {
      "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5, 
       33.9, 1., 14.6, 0., 0., 0., 0.}, {
      "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 4.9, 
       3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
      "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 2.8, 
       6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
      "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 130.75, 
       5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
      "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47., 
       2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
      "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23., 
       0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
      "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 58.875, 
       84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
      "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 0.2,
        66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
       Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0., 
       0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
       196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
      "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
       182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
      "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001, 
       296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
      "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 59.429,
        175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
      "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
       344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
      "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 276.85001, 
       326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
      "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 40.667, 
       3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
      "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 3.3, 
       29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
      "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 0.8, 
       54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
       Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 0., 
       0.}, {"spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121.,
        2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 20.812,
        12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
      "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
       49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
      "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 22.9, 
       4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
      "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 11.8, 
       0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818, 
       0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
      "winter", "small", "high", 6.6, 10.8, 
       Missing[], 3.245, 10., 1., 6.5, 
       Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "medium", 5.6, 11.8, 
       Missing[], 2.22, 5., 1., 1., 
       Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 5.7, 10.8, 
       Missing[], 2.55, 10., 1., 4., 
       Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
      "spring", "small", "high", 6.6, 9.5, 
       Missing[], 1.32, 20., 1., 6., 
       Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
      "summer", "small", "high", 6.6, 10.8, 
       Missing[], 2.64, 10., 2., 11., 
       Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
      "autumn", "small", "medium", 6.6, 11.3, 
       Missing[], 4.17, 10., 1., 6., 
       Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
      "spring", "small", "medium", 6.5, 10.4, 
       Missing[], 5.97, 10., 2., 14., 
       Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
      "summer", "small", "medium", 6.4, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 14., 
       Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
      "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 6.667, 
       Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75, 1.,
        20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
      "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2, 
       0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
      "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 0.6,
        55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
      "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 10.75, 
       2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
      "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 0.5, 
       64.2, 0., 3., 0., 0., 0., 0.}, {
      "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75, 
       351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
      "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
       209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
      "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 151.125,
        279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
      "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
       152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
      "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
       58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
      "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
       249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
      "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 100., 
       233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
      "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 215.5, 
       18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
      "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 25.167, 
       102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
      "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
       105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
      "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
       111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
      "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 1.3, 
       6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
      "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 56.667, 
       2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
      "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 4.3,
        1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
      "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
       104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
      "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 69.93,
        3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
      "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
       214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
      "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
       254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
      "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 57.6,
        169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
      "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
       412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
      "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
       282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
      "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
       197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
      "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 267.75, 
       391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
      "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 191.75, 
       265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
      "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
       232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
      "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 144.66701, 
       244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
      "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 218., 
       6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
      "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 138.5,
        20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
      "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222, 
       239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
      "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
       235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
      "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75, 
       205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
      "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 31.333, 
       211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
      "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625, 
       186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
      "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 12.889, 
       154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
      "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 51.111, 
       183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
      "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
       292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
      "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
       285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
      "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
       201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
      "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
       275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
      "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
       124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
      "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 60.833, 
       141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
      "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71., 
       132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
      "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
       17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
      "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 0.3, 
       46.6, 0., 2.5, 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 8.692, 
       16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
      "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 37.857, 
       102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
      "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
       86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
      "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
       10.111, 
       Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 16.833, 
       18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
      "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545, 
       13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
      "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 261.60001, 
       432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
      "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
       320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
      "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 144., 
       287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
      "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
       166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
      "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
       222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
      "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 36.909, 
       122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
      "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556, 
       127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
      "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
       89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
      "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 55., 
       284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
      "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 102.333, 
       277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
      "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 75.875, 
       177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
      "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
       72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
      "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 48.667, 
       82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
      "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 48.625, 
       66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
      "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 23., 
       173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
      "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 317., 
       5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
      "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 84., 
       4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
      "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 2., 
       10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
      "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 88.5, 
       2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
      "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115., 
       11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
      "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 98.143, 
       2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
      "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
       143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
      "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
       197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
      "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 1., 
       19., 0., 22., 5., 1.1, 5.4, 0.}, {
      "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 10.583, 
       23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
      "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 200.231, 
       19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
      "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 77.333, 
       147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
      "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5, 
       276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
      "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
       123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
      "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 75.207,
        23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
      "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 116.2,
        7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
      "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
       188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
      "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
       72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
      "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 16., 
       0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
      "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 34., 
       53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
      "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 27.5, 
       76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
      "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
       58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
      "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 175.66701, 
       361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
      "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
       22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
      "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 26.8,
        0., 28., 0., 0., 0., 0., 15.1}, {
      "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
       54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
      "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333, 
       34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
      "spring", "large", "low", 9., 5.8, 
       Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 0., 
       0.}, {"spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
       151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
      "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
       269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
      "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 46.438, 
       81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
      "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 85., 
       2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
      "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 66.4, 
       171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
      "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 102.364, 
       232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
      "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 84.3, 
       146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
      "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
       246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
      "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 205.636, 
       219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
      "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 236.39999,
        272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
      "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 1081.66003, 
       346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 5.9, 1.7}, {
      "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 82.222,
        167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
      "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 64.389, 
       137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
      "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 87.333,
        194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
      "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
       159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
      "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 21.3, 
       1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
      "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 0.6,
        37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
      "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
       14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
      "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222, 7.,
        1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 0.8, 
       50.4, 3.8, 0., 0., 0., 0., 0.}, {
      "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 7.654, 
       4., 56.8, 5., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 2.86, 
       17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
      "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 56.091, 
       Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
      "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
       52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
      "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 104.727, 
       228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
      "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 85.4, 
       17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
      "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 87.125,
        14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
      "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 101.455, 
       18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
      "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 50.889, 
       127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
      "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
       81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
      "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 19.727, 
       50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
      "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111, 
       120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
      "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 51.111, 
       91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
      "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 19.111, 
       61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
      "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625, 
       79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
      "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333, 
       75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
      "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333, 
       140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
      "winter", "large", "medium", 8., 7.6, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
      "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
       140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 
       5.8}}, $CellContext`sym$236130[$CellContext`Chla] = Part[
      $CellContext`sym$236130[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {
          "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
           196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$236130[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$236130[$CellContext`Cl] = Part[
      $CellContext`sym$236130[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$236130[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$236130[$CellContext`mnO2] = Part[
      $CellContext`sym$236130[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$236130[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$236130[$CellContext`mxPH] = Part[
      $CellContext`sym$236130[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$236130[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$236130[$CellContext`NH4] = Part[
      $CellContext`sym$236130[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$236130[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$236130[$CellContext`NO3] = Part[
      $CellContext`sym$236130[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$236130[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$236130[$CellContext`oPO4] = Part[
      $CellContext`sym$236130[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$236130[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$236130[$CellContext`PO4] = Part[
      $CellContext`sym$236130[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$236130[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$236130[$CellContext`season] = Part[
      $CellContext`sym$236130[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$236130[$CellContext`season, 
         "missing"]]]], $CellContext`sym$236130[$CellContext`size] = Part[
      $CellContext`sym$236130[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$236130[$CellContext`size, 
         "missing"]]]], $CellContext`sym$236130[$CellContext`speed] = Part[
      $CellContext`sym$236130[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$236130[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$236130[$CellContext`a1, 
      "factorized"] = 
    False, $CellContext`sym$236130[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$236130[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$236130[All], 
      All, $CellContext`i$236142], $CellContext`sym$236130[$CellContext`a2, 
      "factorized"] = 
    False, $CellContext`sym$236130[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$236130[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$236130[All], 
      All, $CellContext`i$236143], $CellContext`sym$236130[$CellContext`a3, 
      "factorized"] = 
    False, $CellContext`sym$236130[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$236130[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$236130[All], 
      All, $CellContext`i$236144], $CellContext`sym$236130[$CellContext`a4, 
      "factorized"] = 
    False, $CellContext`sym$236130[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$236130[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$236130[All], 
      All, $CellContext`i$236145], $CellContext`sym$236130[$CellContext`a5, 
      "factorized"] = 
    False, $CellContext`sym$236130[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$236130[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$236130[All], 
      All, $CellContext`i$236146], $CellContext`sym$236130[$CellContext`a6, 
      "factorized"] = 
    False, $CellContext`sym$236130[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$236130[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$236130[All], 
      All, $CellContext`i$236147], $CellContext`sym$236130[$CellContext`a7, 
      "factorized"] = 
    False, $CellContext`sym$236130[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$236130[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$236130[All], 
      All, $CellContext`i$236148], $CellContext`sym$236130[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$236130[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed}, $CellContext`sym$236130[$CellContext`Chla, "factorized"] = 
    False, $CellContext`sym$236130[$CellContext`Chla, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {63}, {116}, {184}, {
     199}}, $CellContext`sym$236130[$CellContext`Chla, "raw"] = Part[
      $CellContext`sym$236130[All], 
      All, $CellContext`i$236141], $CellContext`sym$236130[$CellContext`Cl, 
      "factorized"] = 
    False, $CellContext`sym$236130[$CellContext`Cl, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {161}, {
     199}}, $CellContext`sym$236130[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$236130[All], 
      All, $CellContext`i$236136], $CellContext`sym$236130[$CellContext`mnO2, 
      "factorized"] = 
    False, $CellContext`sym$236130[$CellContext`mnO2, "missing"] = {{38}, {
     62}}, $CellContext`sym$236130[$CellContext`mnO2, "raw"] = Part[
      $CellContext`sym$236130[All], 
      All, $CellContext`i$236135], $CellContext`sym$236130[$CellContext`mxPH, 
      "factorized"] = 
    False, $CellContext`sym$236130[$CellContext`mxPH, "missing"] = {{
     48}}, $CellContext`sym$236130[$CellContext`mxPH, "raw"] = Part[
      $CellContext`sym$236130[All], 
      All, $CellContext`i$236134], $CellContext`sym$236130[$CellContext`NH4, 
      "factorized"] = 
    False, $CellContext`sym$236130[$CellContext`NH4, "missing"] = {{62}, {
     199}}, $CellContext`sym$236130[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$236130[All], 
      All, $CellContext`i$236138], $CellContext`sym$236130[$CellContext`NO3, 
      "factorized"] = 
    False, $CellContext`sym$236130[$CellContext`NO3, "missing"] = {{62}, {
     199}}, $CellContext`sym$236130[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$236130[All], 
      All, $CellContext`i$236137], $CellContext`sym$236130[$CellContext`oPO4, 
      "factorized"] = 
    False, $CellContext`sym$236130[$CellContext`oPO4, "missing"] = {{62}, {
     199}}, $CellContext`sym$236130[$CellContext`oPO4, "raw"] = Part[
      $CellContext`sym$236130[All], 
      All, $CellContext`i$236139], $CellContext`sym$236130[$CellContext`PO4, 
      "factorized"] = 
    False, $CellContext`sym$236130[$CellContext`PO4, "missing"] = {{28}, {
     199}}, $CellContext`sym$236130[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$236130[All], 
      All, $CellContext`i$236140], \
$CellContext`sym$236130[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$236130[$CellContext`season, "factors"] = 
    Part[{"autumn", "spring", "summer", "winter"}, 
      $CellContext`fordering[$CellContext`sym$236130, $CellContext`season]], \
$CellContext`sym$236130[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$236130[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$236130[All], 
      All, $CellContext`i$236131], $CellContext`sym$236130[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$236130[$CellContext`size, "factors"] = 
    Part[{"large", "medium", "small"}, 
      $CellContext`fordering[$CellContext`sym$236130, $CellContext`size]], \
$CellContext`sym$236130[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$236130[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$236130[All], 
      All, $CellContext`i$236132], $CellContext`sym$236130[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$236130[$CellContext`speed, "factors"] = 
    Part[{"high", "low", "medium"}, 
      $CellContext`fordering[$CellContext`sym$236130, $CellContext`speed]], \
$CellContext`sym$236130[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$236130[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$236130[All], All, $CellContext`i$236133], 
    Attributes[$CellContext`i$236136] = {Temporary}, $CellContext`i$236136 = 
    6, Attributes[$CellContext`i$236148] = {Temporary}, $CellContext`i$236148 = 
    18, Attributes[$CellContext`i$236131] = {
     Temporary}, $CellContext`i$236131 = 1, 
    Attributes[$CellContext`i$236135] = {Temporary}, $CellContext`i$236135 = 
    5, Attributes[$CellContext`i$236146] = {Temporary}, $CellContext`i$236146 = 
    16, Attributes[$CellContext`i$236144] = {
     Temporary}, $CellContext`i$236144 = 14, 
    Attributes[$CellContext`i$236138] = {Temporary}, $CellContext`i$236138 = 
    8, Attributes[$CellContext`i$236132] = {Temporary}, $CellContext`i$236132 = 
    2, Attributes[$CellContext`i$236137] = {Temporary}, $CellContext`i$236137 = 
    7, Attributes[$CellContext`i$236140] = {Temporary}, $CellContext`i$236140 = 
    10, Attributes[$CellContext`i$236134] = {
     Temporary}, $CellContext`i$236134 = 4, 
    Attributes[$CellContext`i$236139] = {Temporary}, $CellContext`i$236139 = 
    9, Attributes[$CellContext`i$236145] = {Temporary}, $CellContext`i$236145 = 
    15, Attributes[$CellContext`i$236143] = {
     Temporary}, $CellContext`i$236143 = 13, 
    Attributes[$CellContext`i$236147] = {Temporary}, $CellContext`i$236147 = 
    17, Attributes[$CellContext`i$236141] = {
     Temporary}, $CellContext`i$236141 = 11, 
    Attributes[$CellContext`i$236142] = {Temporary}, $CellContext`i$236142 = 
    12, Attributes[$CellContext`i$236133] = {
     Temporary}, $CellContext`i$236133 = 3, 
    Attributes[$CellContext`sym$229509] = {
     Temporary}, $CellContext`sym$229509[$CellContext`a1] = Part[
      $CellContext`sym$229509[$CellContext`a1, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {
          "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
           196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229509[$CellContext`a1, 
         "missing"]]]], $CellContext`sym$229509[$CellContext`a2] = Part[
      $CellContext`sym$229509[$CellContext`a2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229509[$CellContext`a2, 
         "missing"]]]], $CellContext`sym$229509[$CellContext`a3] = Part[
      $CellContext`sym$229509[$CellContext`a3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229509[$CellContext`a3, 
         "missing"]]]], $CellContext`sym$229509[$CellContext`a4] = Part[
      $CellContext`sym$229509[$CellContext`a4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229509[$CellContext`a4, 
         "missing"]]]], $CellContext`sym$229509[$CellContext`a5] = Part[
      $CellContext`sym$229509[$CellContext`a5, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229509[$CellContext`a5, 
         "missing"]]]], $CellContext`sym$229509[$CellContext`a6] = Part[
      $CellContext`sym$229509[$CellContext`a6, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229509[$CellContext`a6, 
         "missing"]]]], $CellContext`sym$229509[$CellContext`a7] = Part[
      $CellContext`sym$229509[$CellContext`a7, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229509[$CellContext`a7, 
         "missing"]]]], $CellContext`sym$229509[
     All] = {{"winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 
       170., 50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
      "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
       558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
      "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 125.667,
        187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
      "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 61.182, 
       138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
      "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222, 
       97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
      "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
       56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
      "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
       111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
      "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 44.667, 
       77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
      "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 71., 
       5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 0.8, 
       17., 0., 0., 2.9, 0., 0., 1.7}, {
      "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 20.75, 
       0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
      "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 19.,
        0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
      "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 41., 
       43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
      "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5, 
       31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
      "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 0.3, 
       52.2, 5., 7.8, 0., 4., 0., 0.}, {
      "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 98.25, 
       1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
      "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50., 
       1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
      "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 57.833, 
       0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
      "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 0.8, 
       50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
      "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
       564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
      "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 586.,
        16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
      "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 0.5, 
       15.5, 0., 0., 2.3, 0., 0., 0.}, {
      "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 7.6,
        23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
      "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
       27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
      "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 1.5,
        13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
      "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 44.136, 
       3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
      "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 0.5, 
       29.7, 0., 0., 4.9, 0., 0., 0.}, {
      "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
       Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
      "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 17.1,
        0., 19.6, 0., 0., 0., 2.5}, {
      "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5, 
       33.9, 1., 14.6, 0., 0., 0., 0.}, {
      "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 4.9, 
       3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
      "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 2.8, 
       6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
      "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 130.75, 
       5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
      "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47., 
       2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
      "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23., 
       0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
      "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 58.875, 
       84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
      "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 0.2,
        66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
       Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0., 
       0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
       196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
      "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
       182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
      "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001, 
       296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
      "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 59.429,
        175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
      "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
       344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
      "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 276.85001, 
       326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
      "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 40.667, 
       3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
      "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 3.3, 
       29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
      "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 0.8, 
       54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
       Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 0., 
       0.}, {"spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121.,
        2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 20.812,
        12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
      "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
       49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
      "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 22.9, 
       4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
      "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 11.8, 
       0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818, 
       0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
      "winter", "small", "high", 6.6, 10.8, 
       Missing[], 3.245, 10., 1., 6.5, 
       Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "medium", 5.6, 11.8, 
       Missing[], 2.22, 5., 1., 1., 
       Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
      "autumn", "small", "medium", 5.7, 10.8, 
       Missing[], 2.55, 10., 1., 4., 
       Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
      "spring", "small", "high", 6.6, 9.5, 
       Missing[], 1.32, 20., 1., 6., 
       Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
      "summer", "small", "high", 6.6, 10.8, 
       Missing[], 2.64, 10., 2., 11., 
       Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
      "autumn", "small", "medium", 6.6, 11.3, 
       Missing[], 4.17, 10., 1., 6., 
       Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
      "spring", "small", "medium", 6.5, 10.4, 
       Missing[], 5.97, 10., 2., 14., 
       Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
      "summer", "small", "medium", 6.4, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 14., 
       Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
      "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 6.667, 
       Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
      "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75, 1.,
        20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
      "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2, 
       0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
      "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 0.6,
        55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
      "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 10.75, 
       2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
      "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 0.5, 
       64.2, 0., 3., 0., 0., 0., 0.}, {
      "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75, 
       351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
      "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
       209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
      "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 151.125,
        279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
      "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
       152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
      "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
       58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
      "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
       249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
      "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 100., 
       233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
      "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 215.5, 
       18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
      "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 25.167, 
       102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
      "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
       105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
      "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
       111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
      "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 1.3, 
       6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
      "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 56.667, 
       2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
      "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 4.3,
        1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
      "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
       104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
      "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 69.93,
        3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
      "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
       214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
      "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
       254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
      "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 57.6,
        169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
      "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
       412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
      "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
       282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
      "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
       197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
      "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 267.75, 
       391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
      "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 191.75, 
       265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
      "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
       232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
      "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 144.66701, 
       244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
      "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 218., 
       6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
      "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 138.5,
        20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
      "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222, 
       239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
      "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
       235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
      "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75, 
       205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
      "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 31.333, 
       211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
      "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625, 
       186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
      "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 12.889, 
       154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
      "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 51.111, 
       183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
      "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
       292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
      "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
       285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
      "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
       201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
      "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
       275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
      "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
       124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
      "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 60.833, 
       141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
      "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71., 
       132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
      "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
       17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
      "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 0.3, 
       46.6, 0., 2.5, 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 8.692, 
       16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
      "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 37.857, 
       102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
      "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
       86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
      "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
       10.111, 
       Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
      "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 16.833, 
       18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
      "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545, 
       13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
      "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 261.60001, 
       432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
      "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
       320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
      "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 144., 
       287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
      "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
       166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
      "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
       222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
      "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 36.909, 
       122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
      "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556, 
       127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
      "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
       89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
      "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 55., 
       284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
      "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 102.333, 
       277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
      "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 75.875, 
       177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
      "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
       72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
      "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 48.667, 
       82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
      "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 48.625, 
       66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
      "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 23., 
       173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
      "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 317., 
       5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
      "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 84., 
       4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
      "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 2., 
       10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
      "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 88.5, 
       2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
      "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115., 
       11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
      "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 98.143, 
       2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
      "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
       143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
      "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
       197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
      "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 1., 
       19., 0., 22., 5., 1.1, 5.4, 0.}, {
      "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 10.583, 
       23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
      "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 200.231, 
       19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
      "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 77.333, 
       147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
      "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5, 
       276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
      "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
       123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
      "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 75.207,
        23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
      "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 116.2,
        7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
      "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
       188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
      "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
       72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
      "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 16., 
       0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
      "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 34., 
       53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
      "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 27.5, 
       76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
      "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
       58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
      "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 175.66701, 
       361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
      "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
       22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
      "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 26.8,
        0., 28., 0., 0., 0., 0., 15.1}, {
      "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
       54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
      "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333, 
       34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
      "spring", "large", "low", 9., 5.8, 
       Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 0., 
       0.}, {"spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
       151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
      "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
       269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
      "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 46.438, 
       81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
      "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 85., 
       2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
      "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 66.4, 
       171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
      "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 102.364, 
       232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
      "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 84.3, 
       146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
      "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
       246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
      "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 205.636, 
       219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
      "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 236.39999,
        272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
      "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 1081.66003, 
       346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 5.9, 1.7}, {
      "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 82.222,
        167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
      "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 64.389, 
       137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
      "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 87.333,
        194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
      "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
       159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
      "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 21.3, 
       1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
      "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 0.6,
        37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
      "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
       14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
      "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222, 7.,
        1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 0.8, 
       50.4, 3.8, 0., 0., 0., 0., 0.}, {
      "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 7.654, 
       4., 56.8, 5., 0., 0., 0., 0., 0.}, {
      "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 2.86, 
       17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
      "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 56.091, 
       Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
      "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
       52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
      "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 104.727, 
       228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
      "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 85.4, 
       17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
      "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 87.125,
        14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
      "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 101.455, 
       18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
      "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 50.889, 
       127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
      "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
       81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
      "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 19.727, 
       50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
      "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111, 
       120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
      "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 51.111, 
       91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
      "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 19.111, 
       61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
      "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625, 
       79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
      "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333, 
       75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
      "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333, 
       140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
      "winter", "large", "medium", 8., 7.6, 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 
       Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
      "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
       140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 
       5.8}}, $CellContext`sym$229509[$CellContext`Chla] = Part[
      $CellContext`sym$229509[$CellContext`Chla, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {
          "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 
           196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229509[$CellContext`Chla, 
         "missing"]]]], $CellContext`sym$229509[$CellContext`Cl] = Part[
      $CellContext`sym$229509[$CellContext`Cl, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229509[$CellContext`Cl, 
         "missing"]]]], $CellContext`sym$229509[$CellContext`mnO2] = Part[
      $CellContext`sym$229509[$CellContext`mnO2, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229509[$CellContext`mnO2, 
         "missing"]]]], $CellContext`sym$229509[$CellContext`mxPH] = Part[
      $CellContext`sym$229509[$CellContext`mxPH, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229509[$CellContext`mxPH, 
         "missing"]]]], $CellContext`sym$229509[$CellContext`NH4] = Part[
      $CellContext`sym$229509[$CellContext`NH4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229509[$CellContext`NH4, 
         "missing"]]]], $CellContext`sym$229509[$CellContext`NO3] = Part[
      $CellContext`sym$229509[$CellContext`NO3, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229509[$CellContext`NO3, 
         "missing"]]]], $CellContext`sym$229509[$CellContext`oPO4] = Part[
      $CellContext`sym$229509[$CellContext`oPO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229509[$CellContext`oPO4, 
         "missing"]]]], $CellContext`sym$229509[$CellContext`PO4] = Part[
      $CellContext`sym$229509[$CellContext`PO4, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229509[$CellContext`PO4, 
         "missing"]]]], $CellContext`sym$229509[$CellContext`season] = Part[
      $CellContext`sym$229509[$CellContext`season, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229509[$CellContext`season, 
         "missing"]]]], $CellContext`sym$229509[$CellContext`size] = Part[
      $CellContext`sym$229509[$CellContext`size, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229509[$CellContext`size, 
         "missing"]]]], $CellContext`sym$229509[$CellContext`speed] = Part[
      $CellContext`sym$229509[$CellContext`speed, "raw"], 
      Complement[
       Range[
        Length[{{
          "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170.,
            50., 0., 0., 0., 0., 34.2, 8.3, 0.}, {
          "spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 
           558.75, 1.3, 1.4, 7.6, 4.8, 1.9, 6.7, 0., 2.1}, {
          "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 
           125.667, 187.05701, 15.6, 3.3, 53.6, 1.9, 0., 0., 0., 9.7}, {
          "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 
           61.182, 138.7, 1.4, 3.1, 41., 18.9, 0., 1.4, 0., 1.4}, {
          "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222,
            97.58, 10.5, 9.2, 2.9, 7.5, 0., 7.5, 4.1, 1.}, {
          "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 
           56.667, 28.4, 15.1, 14.6, 1.4, 0., 22.5, 12.6, 2.9}, {
          "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 
           111.75, 3.2, 2.4, 1.2, 3.2, 3.9, 5.8, 6.8, 0.}, {
          "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 
           44.667, 77.434, 6.9, 18.2, 1.6, 0., 0., 5.5, 8.7, 0.}, {
          "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 
           71., 5.544, 25.4, 5.4, 2.5, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 
           0.8, 17., 0., 0., 2.9, 0., 0., 1.7}, {
          "spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
           20.75, 0.8, 16.6, 0., 0., 0., 1.2, 0., 6.}, {
          "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 
           19., 0.6, 32.1, 0., 0., 0., 0., 0., 1.5}, {
          "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 
           41., 43.5, 0., 2.1, 0., 1.2, 0., 2.1}, {
          "summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5,
            31.1, 1., 3.4, 0., 1.9, 0., 4.1}, {
          "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 
           0.3, 52.2, 5., 7.8, 0., 4., 0., 0.}, {
          "autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
           98.25, 1.1, 69.9, 0., 1.7, 0., 0., 0., 0.}, {
          "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50.,
            1.1, 46.2, 0., 0., 1.2, 0., 0., 0.}, {
          "spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
           57.833, 0.4, 31.8, 0., 3.1, 4.8, 7.7, 1.4, 7.2}, {
          "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 
           0.8, 50.6, 0., 9.9, 4.3, 3.6, 8.2, 2.2}, {
          "spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
           564.59998, 771.59998, 4.5, 0., 0., 0., 44.6, 0., 0., 1.4}, {
          "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 
           586., 16., 0., 0., 0., 6.8, 6.1, 0., 0.}, {
          "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 
           0.5, 15.5, 0., 0., 2.3, 0., 0., 0.}, {
          "autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 
           7.6, 23.2, 0., 0., 0., 27.6, 11.1, 0.}, {
          "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 
           27.5, 1.7, 74.2, 0., 0., 3.7, 0., 0., 0.}, {
          "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 
           1.5, 13., 8.6, 1.2, 3.5, 1.2, 1.6, 1.9}, {
          "summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
           44.136, 3., 4.1, 0., 0., 0., 9.2, 10.1, 0.}, {
          "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 
           0.5, 29.7, 0., 0., 4.9, 0., 0., 0.}, {
          "autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
           Missing[], 2.7, 30.3, 1.9, 0., 0., 2.1, 1.4, 2.1}, {
          "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
           17.1, 0., 19.6, 0., 0., 0., 2.5}, {
          "spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5,
            33.9, 1., 14.6, 0., 0., 0., 0.}, {
          "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 
           4.9, 3.4, 16., 1.2, 0., 15.3, 15.8, 0.}, {
          "winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 
           2.8, 6.9, 17.1, 20.2, 0., 4., 0., 2.9}, {
          "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 
           130.75, 5.8, 0., 8., 1.9, 0., 11.2, 42.7, 1.2}, {
          "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47.,
            2.3, 13.6, 9.1, 0., 0., 1.4, 0., 0.}, {
          "winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23.,
            0.9, 5.3, 40.7, 3.3, 0., 0., 0., 1.9}, {
          "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 
           58.875, 84.46, 3.6, 18.3, 12.4, 1., 0., 0., 0., 1.}, {
          "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 
           0.2, 66., 0., 0., 0., 0., 0., 0.}, {"spring", "small", "high", 8., 
           Missing[], 1.45, 0.81, 10., 2.5, 3., 0.3, 75.8, 0., 0., 0., 0., 0.,
            0.}, {"winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 
           228.75, 196.62, 253.25, 12.32, 2., 38.5, 4.1, 2.2, 0., 0., 10.2}, {
          "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 
           182.42, 255.28, 8.957, 2.2, 2.7, 1., 3.7, 2.7, 0., 0.}, {
          "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001,
            296., 3.7, 0., 5.9, 10.6, 1.7, 0., 0., 7.1}, {
          "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 
           59.429, 175.04601, 13.2, 0., 0., 0., 5.7, 11.3, 17., 1.6}, {
          "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
           344.60001, 22.5, 0., 40.9, 7.5, 0., 2.4, 1.5, 0.}, {
          "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 
           276.85001, 326.85699, 11.84, 4.1, 3.1, 0., 0., 19.7, 17., 0.}, {
          "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 
           40.667, 3.9, 51.8, 4.1, 0., 0., 3.1, 5.5, 0.}, {
          "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 
           3.3, 29.5, 1., 2.7, 3.2, 2.9, 9.6, 0.}, {
          "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 
           0.8, 54.4, 3.4, 1.2, 0., 18.7, 2., 0.}, {"winter", "small", "low", 
           Missing[], 12.6, 9., 0.23, 10., 5., 6., 1.1, 35.5, 0., 0., 0., 0., 
           0., 0.}, {
          "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 
           2.8, 89.8, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 
           20.812, 12.1, 24.8, 7.4, 0., 2.5, 10.6, 17.1, 3.2}, {
          "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
           49.333, 7.9, 0., 0., 0., 4.6, 1.2, 0., 3.9}, {
          "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 
           22.9, 4.5, 39.1, 0., 1.2, 2.2, 5.4, 1.5, 3.2}, {
          "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 
           11.8, 0.5, 81.9, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818,
            0.8, 54., 0., 0., 2.4, 0., 0., 0.}, {
          "winter", "small", "high", 6.6, 10.8, 
           Missing[], 3.245, 10., 1., 6.5, 
           Missing[], 24.3, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "medium", 5.6, 11.8, 
           Missing[], 2.22, 5., 1., 1., 
           Missing[], 82.7, 0., 0., 0., 0., 0., 0.}, {
          "autumn", "small", "medium", 5.7, 10.8, 
           Missing[], 2.55, 10., 1., 4., 
           Missing[], 16.8, 4.6, 3.9, 11.5, 0., 0., 0.}, {
          "spring", "small", "high", 6.6, 9.5, 
           Missing[], 1.32, 20., 1., 6., 
           Missing[], 46.8, 0., 0., 28.8, 0., 0., 0.}, {
          "summer", "small", "high", 6.6, 10.8, 
           Missing[], 2.64, 10., 2., 11., 
           Missing[], 46.9, 0., 0., 13.4, 0., 0., 0.}, {
          "autumn", "small", "medium", 6.6, 11.3, 
           Missing[], 4.17, 10., 1., 6., 
           Missing[], 47.1, 0., 0., 0., 0., 1.2, 0.}, {
          "spring", "small", "medium", 6.5, 10.4, 
           Missing[], 5.97, 10., 2., 14., 
           Missing[], 66.9, 0., 0., 0., 0., 0., 0.}, {
          "summer", "small", "medium", 6.4, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 14., 
           Missing[], 19.4, 0., 0., 2., 0., 3.9, 1.7}, {
          "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 
           6.667, 
           Missing[], 14.4, 0., 0., 0., 0., 0., 0.}, {
          "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75,
            1., 20.3, 4.3, 5.5, 0., 0., 0., 1.4}, {
          "summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2,
            0.3, 15.8, 1.7, 7.8, 0., 0., 2.4, 1.4}, {
          "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 
           0.6, 55.5, 0., 1.7, 1.4, 0., 0., 0.}, {
          "spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
           10.75, 2.5, 10.3, 0., 42.8, 2.2, 0., 0., 0.}, {
          "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 
           0.5, 64.2, 0., 3., 0., 0., 0., 0.}, {
          "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75,
            351.60001, 10., 0., 0., 1.5, 7.6, 0., 0., 6.1}, {
          "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
           209.85699, 313.60001, 1., 1.9, 4.9, 2.6, 3., 0., 0., 1.9}, {
          "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 
           151.125, 279.06601, 13.1, 25.5, 3.9, 1., 11., 0., 0., 12.5}, {
          "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
           152.33299, 5.2, 11.3, 1.7, 2., 2.2, 13.3, 10.6, 0.}, {
          "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
           58.623, 11.6, 4.4, 4., 3.3, 0., 11.7, 21.4, 1.2}, {
          "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
           249.25, 20.87, 1.9, 5.8, 24.8, 4.6, 9.5, 5.1, 1.2}, {
          "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 
           100., 233.5, 13., 1.6, 8., 17.6, 3.7, 11.5, 7., 0.}, {
          "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 
           215.5, 18.37, 2.2, 9.6, 5., 1., 8.6, 7.9, 2.2}, {
          "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 
           25.167, 102.333, 3.6, 64.9, 1., 0., 1., 2.9, 1.4, 1.}, {
          "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
           105.727, 3., 15.1, 7.3, 23.2, 3.4, 4.1, 0., 0.}, {
          "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
           111.375, 3., 14.4, 0., 11.8, 11.3, 5.5, 0., 0.}, {
          "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 
           1.3, 6.7, 0., 5.4, 3.4, 4.9, 6.9, 10.8}, {
          "spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
           56.667, 2., 10.8, 0., 0., 4.6, 6.5, 2.2, 1.4}, {
          "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 
           4.3, 1.2, 0., 1.7, 0., 7.5, 17.7, 14.4}, {
          "winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 
           104., 21., 12.6, 4.3, 21.9, 1., 2.4, 3.3, 22.1}, {
          "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 
           69.93, 3.1, 14.7, 4.1, 1., 0., 7.7, 8.5, 31.2}, {
          "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 
           214., 2.9, 3.3, 0., 0., 5., 1.9, 6.2, 25.6}, {
          "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
           254.60001, 4.3, 0., 0., 0., 4.6, 9., 13.1, 30.1}, {
          "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 
           57.6, 169.00101, 3.2, 2.8, 0., 0., 2.6, 5.2, 13.2, 16.7}, {
          "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
           412.33301, 607.16699, 4.3, 0., 0., 2.6, 2.4, 5., 0., 2.4}, {
          "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
           282.16699, 624.73297, 6.8, 0., 0., 0., 1., 35.6, 9.9, 0.}, {
          "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 
           197.83299, 303.33301, 40., 0., 15.2, 8.8, 0., 8.6, 5.1, 2.7}, {
          "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 
           267.75, 391.75, 3.5, 0., 5.5, 3.3, 0., 20.8, 12.4, 0.}, {
          "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 
           191.75, 265.25, 7.3, 0., 2.1, 1.6, 0., 20.8, 32.9, 0.}, {
          "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
           232.83299, 31., 1.2, 5.6, 6.3, 1.7, 1.2, 0., 1.}, {
          "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 
           144.66701, 244., 9., 0., 3.1, 3.5, 1.6, 8.2, 9.9, 0.}, {
          "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 
           218., 6.5, 0., 5.2, 0., 0., 28.8, 20.4, 1.}, {
          "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 
           138.5, 20.829, 5.7, 0., 0., 4.4, 12.4, 8.3, 7.8}, {
          "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222,
            239., 72.478, 3.6, 31.9, 2.4, 0., 0., 0., 2.2}, {
          "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
           235.66701, 98.817, 1.2, 16.2, 0., 0., 0., 0., 1.}, {
          "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75,
            205.875, 2., 4., 2.1, 35.1, 6.8, 7.3, 0., 0.}, {
          "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 
           31.333, 211.66701, 21.9, 5.9, 3.4, 1., 1.2, 17.8, 49.4, 1.}, {
          "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625,
            186.5, 30., 16.5, 2.1, 19.5, 3.5, 5.3, 1.2, 3.2}, {
          "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 
           12.889, 154.125, 5.2, 7., 0., 13.5, 4.3, 8.7, 0., 4.3}, {
          "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 
           51.111, 183.66701, 17.2, 58.7, 0., 11.5, 6.6, 0., 0., 0.}, {
          "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
           292.625, 3., 8.7, 0., 3., 5.3, 9.4, 33.2, 0.}, {
          "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
           285.71399, 75., 17., 21.6, 1.6, 1.4, 10.2, 3.6, 1.1}, {
          "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
           201.778, 3., 12.3, 5.4, 1.9, 0., 1.4, 0., 1.9}, {
          "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
           275.14301, 65.7, 8.8, 19.6, 4.7, 0., 0., 0., 2.7}, {
          "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
           124.2, 13.1, 23.7, 13.7, 0., 1.7, 6.4, 2.6, 0.}, {
          "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 
           60.833, 141.83299, 25., 0., 6.4, 7.3, 12.7, 0., 0., 4.2}, {
          "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71.,
            132.54601, 15., 3.6, 38.8, 0., 0., 1.2, 0., 2.4}, {
          "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
           17.333, 1., 64.3, 1.5, 8., 0., 0., 0., 0.}, {
          "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 
           0.3, 46.6, 0., 2.5, 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
           8.692, 16.662, 2.1, 24., 0., 1., 0., 0., 0., 0.}, {
          "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 
           37.857, 102.571, 1.2, 3.7, 1.4, 1.1, 2.1, 3.2, 6.4, 0.}, {
          "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
           86.997, 3., 18.1, 14.5, 0., 0., 11.5, 22.3, 0.}, {
          "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 
           10.111, 
           Missing[], 41., 1.5, 0., 0., 0., 0., 0.}, {
          "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 
           16.833, 18.293, 1.4, 43.7, 0., 1.2, 0., 0., 4.7, 0.}, {
          "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545,
            13.2, 3.2, 86.6, 0., 0., 0., 0., 0., 0.}, {
          "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 
           261.60001, 432.909, 24.917, 1.9, 12.7, 25.9, 0., 0., 0., 6.8}, {
          "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
           320.39999, 6.8, 1.2, 1.9, 22.9, 0., 8.1, 0., 0.}, {
          "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 
           144., 287., 9.882, 1.4, 18.4, 0., 0., 20., 29.5, 0.}, {
          "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 
           166.72701, 262.72699, 17.2, 1.6, 8.9, 6.6, 0., 9.2, 1.6, 1.4}, {
          "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
           222.286, 6.429, 3.3, 11.6, 7., 0., 17.9, 4.7, 0.}, {
          "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 
           36.909, 122., 5.555, 14.6, 0., 0., 1.9, 22.1, 12.7, 1.4}, {
          "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556,
            127.222, 5.233, 1.7, 0., 10.3, 2.6, 8.9, 6.7, 0.}, {
          "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 
           89.625, 2.15, 3.3, 0., 0., 1.9, 34.3, 7.1, 6.}, {
          "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 
           55., 284., 88.255, 0., 36.6, 4.1, 0., 1.2, 16.7, 6.1}, {
          "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 
           102.333, 277.33301, 110.456, 0., 16.4, 10.1, 0., 0., 0., 6.6}, {
          "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 
           75.875, 177.625, 50.225, 1.5, 32.8, 1., 4.1, 0., 15.8, 2.4}, {
          "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 
           72.9, 11.1, 4.2, 0., 1.4, 1.9, 16.2, 0., 1.4}, {
          "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 
           48.667, 82.444, 2., 4.1, 0., 25.3, 2.1, 8., 0., 18.6}, {
          "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 
           48.625, 66.75, 3.3, 1.2, 0., 2.3, 0., 44.4, 7.5, 1.9}, {
          "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 
           23., 173.75, 15.3, 0., 0., 1., 0., 9., 64.6, 0.}, {
          "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 
           317., 5.5, 2.4, 1.7, 4.2, 8.3, 1.7, 0., 2.4}, {
          "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 
           84., 4.5, 7.8, 8.7, 2.1, 0., 14.9, 22.9, 2.4}, {
          "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 
           2., 10.3, 26.5, 6.1, 0., 5.6, 1.5, 2.2}, {
          "autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 
           88.5, 2.5, 1.5, 72.6, 0., 0., 3.4, 6.8, 3.4}, {
          "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115.,
            11.7, 9.2, 2.9, 2., 1.3, 2.5, 0., 0.}, {
          "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 
           98.143, 2., 28.1, 0., 0., 4., 1.2, 0., 0.}, {
          "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 
           143.75, 5.45, 2.1, 2.6, 0., 0., 15., 15.7, 0.}, {
          "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
           197.14301, 6.4, 1.4, 15.7, 1.4, 0., 3.5, 0., 1.6}, {
          "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 
           1., 19., 0., 22., 5., 1.1, 5.4, 0.}, {
          "autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
           10.583, 23.485, 2., 42.5, 0., 2.2, 1., 0., 0., 0.}, {
          "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 
           200.231, 19.4, 2.5, 1.4, 1.4, 6.2, 4.1, 1.8, 3.9}, {
          "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 
           77.333, 147.83299, 3., 4.4, 11.2, 6.8, 0., 1., 0., 31.6}, {
          "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5,
            276., 8.1, 6.5, 4.1, 0., 7.7, 9.9, 18.2, 7.}, {
          "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
           123.333, 30.4, 39.7, 12.7, 0., 1.1, 2.7, 0., 1.6}, {
          "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 
           75.207, 23.8, 32.8, 28., 2., 3.5, 1., 0., 1.5}, {
          "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 
           116.2, 7.3, 12.2, 16., 1., 1.4, 1.9, 1.2, 0.}, {
          "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
           188.66701, 32., 1.9, 25.4, 21.7, 0., 0., 1., 0.}, {
          "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 
           72.696, 22.7, 0., 5.6, 1.2, 0., 8., 2.7, 0.}, {
          "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 
           16., 0., 0., 0., 1.2, 5.7, 32.1, 0.}, {
          "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 
           34., 53.1, 2.2, 0., 0., 1.2, 5.9, 77.6, 0.}, {
          "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 
           27.5, 76.333, 2.1, 3.4, 21.5, 14., 1.8, 3.9, 0., 0.}, {
          "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
           58.374, 27.5, 2.8, 1.9, 0., 1.2, 19., 4.5, 0.}, {
          "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 
           175.66701, 361., 28.567, 24.8, 10.4, 0., 6.9, 0., 0., 2.7}, {
          "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 
           22.5, 32.5, 12., 0., 5., 0., 0., 1.9}, {
          "spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 
           26.8, 0., 28., 0., 0., 0., 0., 15.1}, {
          "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
           54.916, 20.6, 0., 11.3, 1.8, 0., 2.5, 0., 1.4}, {
          "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333,
            34.75, 0., 20.1, 0., 0., 0., 0., 0.}, {
          "spring", "large", "low", 9., 5.8, 
           Missing[], 0.9, 142., 102., 186., 68.05, 1.7, 20.6, 1.5, 2.2, 0., 
           0., 0.}, {
          "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 
           151.33299, 252.5, 93.683, 12.3, 21.7, 3.9, 0., 0., 0., 3.9}, {
          "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
           269.66699, 92.667, 7.2, 28.2, 0., 0., 0., 0., 3.3}, {
          "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 
           46.438, 81.54, 3.4, 21.5, 0., 0., 0., 0., 2.7}, {
          "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 
           85., 2., 0., 0., 0., 2.4, 0., 17.8, 3.6}, {
          "autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
           66.4, 171.272, 3.8, 1.1, 0., 1.4, 0., 6.6, 42.1, 5.2}, {
          "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 
           102.364, 232.89999, 54.367, 0., 6., 2.9, 0., 0., 0., 2.9}, {
          "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 
           84.3, 146.452, 21.22, 1.4, 14.7, 2.5, 0., 0., 0., 2.}, {
          "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
           246.66701, 14.7, 12.5, 2.1, 0., 1.2, 6.4, 4.5, 1.7}, {
          "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 
           205.636, 219.909, 6.209, 0., 0., 0., 0., 8.6, 52.5, 0.}, {
          "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 
           236.39999, 272.22198, 20.578, 2.5, 13.2, 0., 2., 7.4, 17.2, 0.}, {
          "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 
           1081.66003, 346.16699, 388.16699, 5.083, 1.7, 12., 4.9, 2.7, 0., 
           5.9, 1.7}, {
          "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 
           82.222, 167.89999, 5.609, 1.4, 4.6, 10.8, 2.2, 5.5, 42.4, 0.}, {
          "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 
           64.389, 137.778, 9.384, 0., 3.8, 16., 4., 0., 0., 3.3}, {
          "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 
           87.333, 194.10001, 27.618, 0., 1.2, 0., 0., 11.3, 11.5, 0.}, {
          "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
           159.16701, 221.278, 20.8, 0., 21.1, 3.7, 0., 0., 0., 1.9}, {
          "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 
           21.3, 1.1, 39.7, 0., 12.9, 0., 0., 0., 0.}, {
          "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 
           0.6, 37.3, 9.7, 13.6, 0., 2.2, 0., 1.2}, {
          "summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
           14.354, 0.8, 52.4, 7.5, 9.4, 0., 1.4, 1.9, 0.}, {
          "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222,
            7., 1.3, 48.3, 2., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 
           0.8, 50.4, 3.8, 0., 0., 0., 0., 0.}, {
          "winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
           7.654, 4., 56.8, 5., 0., 0., 0., 0., 0.}, {
          "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 
           2.86, 17.3, 6.7, 19.7, 0., 0., 0., 0.}, {
          "winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
           56.091, 
           Missing[], 16.8, 19.6, 4., 0., 0., 0., 0.}, {
          "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 
           52.875, 2., 18.1, 1.7, 2., 0., 1.7, 5.9, 0.}, {
          "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 
           104.727, 228.364, 46.075, 1.1, 3.9, 2.1, 0., 3.9, 4.6, 2.3}, {
          "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 
           85.4, 17.491, 0., 4.7, 0., 0., 2.6, 2.6, 0.}, {
          "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 
           87.125, 14.775, 0., 12., 1.7, 0., 2.7, 0., 0.}, {
          "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 
           101.455, 18.33, 1.7, 7., 1.2, 0., 4.8, 3.1, 0.}, {
          "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 
           50.889, 127., 24.556, 0., 0., 10.2, 1.7, 1.2, 0., 5.5}, {
          "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
           81.558, 5.62, 7.6, 0., 1.2, 0., 15.9, 31.8, 5.9}, {
          "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 
           19.727, 50.455, 8.155, 2.9, 4.6, 1., 0., 6.6, 16.6, 0.}, {
          "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111,
            120.889, 5.111, 2.2, 12.7, 8.8, 0., 0., 0., 1.2}, {
          "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 
           51.111, 91.111, 22.9, 3.8, 22., 2.9, 0., 3.1, 5.5, 0.}, {
          "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 
           19.111, 61.444, 6.167, 18.9, 13.2, 5., 0., 6.1, 0., 0.}, {
          "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625,
            79.75, 2.338, 12.7, 21.7, 5.6, 0., 1., 0., 0.}, {
          "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333,
            75.904, 4.667, 18., 7., 1.7, 0., 4.8, 10.3, 1.}, {
          "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333,
            140.22, 31.738, 0., 15.9, 2.4, 1., 0., 0., 0.}, {
          "winter", "large", "medium", 8., 7.6, 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 
           Missing[], 0., 12.5, 3.7, 1., 0., 0., 4.9}, {
          "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 
           140.517, 18.3, 2.4, 10.5, 9., 7.8, 0., 0., 5.8}}]], 
       Flatten[
        $CellContext`sym$229509[$CellContext`speed, 
         "missing"]]]], $CellContext`sym$229509[$CellContext`a1, 
      "factorized"] = 
    False, $CellContext`sym$229509[$CellContext`a1, 
      "missing"] = {}, $CellContext`sym$229509[$CellContext`a1, "raw"] = Part[
      $CellContext`sym$229509[All], 
      All, $CellContext`i$229521], $CellContext`sym$229509[$CellContext`a2, 
      "factorized"] = 
    False, $CellContext`sym$229509[$CellContext`a2, 
      "missing"] = {}, $CellContext`sym$229509[$CellContext`a2, "raw"] = Part[
      $CellContext`sym$229509[All], 
      All, $CellContext`i$229522], $CellContext`sym$229509[$CellContext`a3, 
      "factorized"] = 
    False, $CellContext`sym$229509[$CellContext`a3, 
      "missing"] = {}, $CellContext`sym$229509[$CellContext`a3, "raw"] = Part[
      $CellContext`sym$229509[All], 
      All, $CellContext`i$229523], $CellContext`sym$229509[$CellContext`a4, 
      "factorized"] = 
    False, $CellContext`sym$229509[$CellContext`a4, 
      "missing"] = {}, $CellContext`sym$229509[$CellContext`a4, "raw"] = Part[
      $CellContext`sym$229509[All], 
      All, $CellContext`i$229524], $CellContext`sym$229509[$CellContext`a5, 
      "factorized"] = 
    False, $CellContext`sym$229509[$CellContext`a5, 
      "missing"] = {}, $CellContext`sym$229509[$CellContext`a5, "raw"] = Part[
      $CellContext`sym$229509[All], 
      All, $CellContext`i$229525], $CellContext`sym$229509[$CellContext`a6, 
      "factorized"] = 
    False, $CellContext`sym$229509[$CellContext`a6, 
      "missing"] = {}, $CellContext`sym$229509[$CellContext`a6, "raw"] = Part[
      $CellContext`sym$229509[All], 
      All, $CellContext`i$229526], $CellContext`sym$229509[$CellContext`a7, 
      "factorized"] = 
    False, $CellContext`sym$229509[$CellContext`a7, 
      "missing"] = {}, $CellContext`sym$229509[$CellContext`a7, "raw"] = Part[
      $CellContext`sym$229509[All], 
      All, $CellContext`i$229527], $CellContext`sym$229509[
     All, "columns"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla, $CellContext`a1, $CellContext`a2, $CellContext`a3, \
$CellContext`a4, $CellContext`a5, $CellContext`a6, $CellContext`a7}, \
$CellContext`sym$229509[
     All, "nominals"] = {$CellContext`season, $CellContext`size, \
$CellContext`speed}, $CellContext`sym$229509[$CellContext`Chla, "factorized"] = 
    False, $CellContext`sym$229509[$CellContext`Chla, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {63}, {116}, {184}, {
     199}}, $CellContext`sym$229509[$CellContext`Chla, "raw"] = Part[
      $CellContext`sym$229509[All], 
      All, $CellContext`i$229520], $CellContext`sym$229509[$CellContext`Cl, 
      "factorized"] = 
    False, $CellContext`sym$229509[$CellContext`Cl, "missing"] = {{55}, {
     56}, {57}, {58}, {59}, {60}, {61}, {62}, {161}, {
     199}}, $CellContext`sym$229509[$CellContext`Cl, "raw"] = Part[
      $CellContext`sym$229509[All], 
      All, $CellContext`i$229515], $CellContext`sym$229509[$CellContext`mnO2, 
      "factorized"] = 
    False, $CellContext`sym$229509[$CellContext`mnO2, "missing"] = {{38}, {
     62}}, $CellContext`sym$229509[$CellContext`mnO2, "raw"] = Part[
      $CellContext`sym$229509[All], 
      All, $CellContext`i$229514], $CellContext`sym$229509[$CellContext`mxPH, 
      "factorized"] = 
    False, $CellContext`sym$229509[$CellContext`mxPH, "missing"] = {{
     48}}, $CellContext`sym$229509[$CellContext`mxPH, "raw"] = Part[
      $CellContext`sym$229509[All], 
      All, $CellContext`i$229513], $CellContext`sym$229509[$CellContext`NH4, 
      "factorized"] = 
    False, $CellContext`sym$229509[$CellContext`NH4, "missing"] = {{62}, {
     199}}, $CellContext`sym$229509[$CellContext`NH4, "raw"] = Part[
      $CellContext`sym$229509[All], 
      All, $CellContext`i$229517], $CellContext`sym$229509[$CellContext`NO3, 
      "factorized"] = 
    False, $CellContext`sym$229509[$CellContext`NO3, "missing"] = {{62}, {
     199}}, $CellContext`sym$229509[$CellContext`NO3, "raw"] = Part[
      $CellContext`sym$229509[All], 
      All, $CellContext`i$229516], $CellContext`sym$229509[$CellContext`oPO4, 
      "factorized"] = 
    False, $CellContext`sym$229509[$CellContext`oPO4, "missing"] = {{62}, {
     199}}, $CellContext`sym$229509[$CellContext`oPO4, "raw"] = Part[
      $CellContext`sym$229509[All], 
      All, $CellContext`i$229518], $CellContext`sym$229509[$CellContext`PO4, 
      "factorized"] = 
    False, $CellContext`sym$229509[$CellContext`PO4, "missing"] = {{28}, {
     199}}, $CellContext`sym$229509[$CellContext`PO4, "raw"] = Part[
      $CellContext`sym$229509[All], 
      All, $CellContext`i$229519], \
$CellContext`sym$229509[$CellContext`season, "factorized"] = 
    True, $CellContext`sym$229509[$CellContext`season, "factors"] = 
    Part[{"autumn", "spring", "summer", "winter"}, 
      $CellContext`fordering[$CellContext`sym$229509, $CellContext`season]], \
$CellContext`sym$229509[$CellContext`season, 
      "missing"] = {}, $CellContext`sym$229509[$CellContext`season, "raw"] = 
    Part[
      $CellContext`sym$229509[All], 
      All, $CellContext`i$229510], $CellContext`sym$229509[$CellContext`size, 
      "factorized"] = 
    True, $CellContext`sym$229509[$CellContext`size, "factors"] = 
    Part[{"large", "medium", "small"}, 
      $CellContext`fordering[$CellContext`sym$229509, $CellContext`size]], \
$CellContext`sym$229509[$CellContext`size, 
      "missing"] = {}, $CellContext`sym$229509[$CellContext`size, "raw"] = 
    Part[
      $CellContext`sym$229509[All], 
      All, $CellContext`i$229511], $CellContext`sym$229509[$CellContext`speed,
       "factorized"] = 
    True, $CellContext`sym$229509[$CellContext`speed, "factors"] = 
    Part[{"high", "low", "medium"}, 
      $CellContext`fordering[$CellContext`sym$229509, $CellContext`speed]], \
$CellContext`sym$229509[$CellContext`speed, 
      "missing"] = {}, $CellContext`sym$229509[$CellContext`speed, "raw"] = 
    Part[
      $CellContext`sym$229509[All], All, $CellContext`i$229512], 
    Attributes[$CellContext`i$229523] = {Temporary}, $CellContext`i$229523 = 
    14, Attributes[$CellContext`i$229521] = {
     Temporary}, $CellContext`i$229521 = 12, 
    Attributes[$CellContext`i$229510] = {Temporary}, $CellContext`i$229510 = 
    1, Attributes[$CellContext`i$229522] = {Temporary}, $CellContext`i$229522 = 
    13, Attributes[$CellContext`i$229517] = {
     Temporary}, $CellContext`i$229517 = 8, 
    Attributes[$CellContext`i$229515] = {Temporary}, $CellContext`i$229515 = 
    6, Attributes[$CellContext`i$229514] = {Temporary}, $CellContext`i$229514 = 
    5, Attributes[$CellContext`i$229518] = {Temporary}, $CellContext`i$229518 = 
    9, Attributes[$CellContext`i$229527] = {Temporary}, $CellContext`i$229527 = 
    18, Attributes[$CellContext`i$229512] = {
     Temporary}, $CellContext`i$229512 = 3, 
    Attributes[$CellContext`i$229511] = {Temporary}, $CellContext`i$229511 = 
    2, Attributes[$CellContext`i$229519] = {Temporary}, $CellContext`i$229519 = 
    10, Attributes[$CellContext`i$229516] = {
     Temporary}, $CellContext`i$229516 = 7, 
    Attributes[$CellContext`i$229520] = {Temporary}, $CellContext`i$229520 = 
    11, Attributes[$CellContext`i$229525] = {
     Temporary}, $CellContext`i$229525 = 16, 
    Attributes[$CellContext`i$229513] = {Temporary}, $CellContext`i$229513 = 
    4, Attributes[$CellContext`i$229526] = {Temporary}, $CellContext`i$229526 = 
    17, Attributes[$CellContext`i$229524] = {
     Temporary}, $CellContext`i$229524 = 15, 
    Attributes[$CellContext`i$236870] = {Temporary}, $CellContext`i$236870 = 
    8, Attributes[$CellContext`i$236866] = {Temporary}, $CellContext`i$236866 = 
    4, Attributes[$CellContext`i$236868] = {Temporary}, $CellContext`i$236868 = 
    6, Attributes[$CellContext`i$236877] = {Temporary}, $CellContext`i$236877 = 
    15, Attributes[$CellContext`i$236865] = {
     Temporary}, $CellContext`i$236865 = 3, 
    Attributes[$CellContext`i$236864] = {Temporary}, $CellContext`i$236864 = 
    2, Attributes[$CellContext`i$236871] = {Temporary}, $CellContext`i$236871 = 
    9, Attributes[$CellContext`i$236880] = {Temporary}, $CellContext`i$236880 = 
    18, Attributes[$CellContext`i$236873] = {
     Temporary}, $CellContext`i$236873 = 11, 
    Attributes[$CellContext`i$236876] = {Temporary}, $CellContext`i$236876 = 
    14, Attributes[$CellContext`i$236867] = {
     Temporary}, $CellContext`i$236867 = 5, 
    Attributes[$CellContext`i$236869] = {Temporary}, $CellContext`i$236869 = 
    7, Attributes[$CellContext`i$236863] = {Temporary}, $CellContext`i$236863 = 
    1, Attributes[$CellContext`i$236879] = {Temporary}, $CellContext`i$236879 = 
    17, Attributes[$CellContext`i$236874] = {
     Temporary}, $CellContext`i$236874 = 12, 
    Attributes[$CellContext`i$236875] = {Temporary}, $CellContext`i$236875 = 
    13, Attributes[$CellContext`i$236878] = {
     Temporary}, $CellContext`i$236878 = 16, 
    Attributes[$CellContext`i$236872] = {Temporary}, $CellContext`i$236872 = 
    10, $CellContext`columnize[
      Pattern[$CellContext`set, 
       Blank[]]] := 
    Module[{$CellContext`sym, $CellContext`registerCol}, $CellContext`sym[
        All] = $CellContext`set; $CellContext`sym[
        All, "nominals"] = {}; $CellContext`sym[
        All, "columns"] = $CellContext`columns; $CellContext`registerCol[
         Pattern[$CellContext`col, 
          Blank[]]] := 
       Module[{$CellContext`i = 
          ReplaceAll[$CellContext`col, $CellContext`numberedColumns]}, \
$CellContext`sym[$CellContext`col, "raw"] := Part[
            $CellContext`sym[All], 
            All, $CellContext`i]; $CellContext`sym[$CellContext`col, 
            "missing"] = Position[
            $CellContext`sym[$CellContext`col, "raw"], 
            Missing[]]; $CellContext`sym[$CellContext`col] := Part[
            $CellContext`sym[$CellContext`col, "raw"], 
            Complement[
             Range[
              Length[$CellContext`set]], 
             Flatten[
              $CellContext`sym[$CellContext`col, 
               "missing"]]]]; $CellContext`sym[$CellContext`col, 
            "factorized"] = If[
            MatchQ[
             $CellContext`sym[$CellContext`col], {
              Repeated[
               PatternTest[
                Blank[], NumericQ]]}], False, With[{$CellContext`u = Union[
                 $CellContext`sym[$CellContext`col]]}, \
$CellContext`fordering[$CellContext`sym, $CellContext`col] = Range[
                 Length[$CellContext`u]]; $CellContext`sym[$CellContext`col, 
                 "factors"] := Part[$CellContext`u, 
                 $CellContext`fordering[$CellContext`sym, $CellContext`col]]; 
              Null]; AppendTo[
              $CellContext`sym[All, "nominals"], $CellContext`col]; True]; 
         Null]; Map[$CellContext`registerCol, $CellContext`columns]; \
$CellContext`sym], $CellContext`columns = {$CellContext`season, \
$CellContext`size, $CellContext`speed, $CellContext`mxPH, $CellContext`mnO2, \
$CellContext`Cl, $CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, \
$CellContext`PO4, $CellContext`Chla, $CellContext`a1, $CellContext`a2, \
$CellContext`a3, $CellContext`a4, $CellContext`a5, $CellContext`a6, \
$CellContext`a7}, $CellContext`numberedColumns = {$CellContext`season -> 
      1, $CellContext`size -> 2, $CellContext`speed -> 3, $CellContext`mxPH -> 
      4, $CellContext`mnO2 -> 5, $CellContext`Cl -> 6, $CellContext`NO3 -> 
      7, $CellContext`NH4 -> 8, $CellContext`oPO4 -> 9, $CellContext`PO4 -> 
      10, $CellContext`Chla -> 11, $CellContext`a1 -> 12, $CellContext`a2 -> 
      13, $CellContext`a3 -> 14, $CellContext`a4 -> 15, $CellContext`a5 -> 
      16, $CellContext`a6 -> 17, $CellContext`a7 -> 18}}]], "Output",
 CellChangeTimes->{
  3.5859972914306107`*^9, 3.5860895702132683`*^9, {3.586089656273486*^9, 
   3.586089692416851*^9}, 3.58608974336438*^9}]
}, {2}]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Dynamic", "[", 
  RowBox[{"Length", "[", 
   RowBox[{"selected", "[", "All", "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5855016744391336`*^9, 3.585501687106505*^9}}],

Cell[BoxData[
 DynamicBox[ToBoxes[
   Length[
    $CellContext`selected[All]], StandardForm],
  ImageSizeCache->{23., {1., 9.}}]], "Output",
 CellChangeTimes->{3.585501688452984*^9}]
}, Open  ]],

Cell["\<\
We don\[CloseCurlyQuote]t have enough domain-specific knowledge to \
categorically reject certain measurements, so we will proceed without \
manually rejecting any outliers.\
\>", "Text",
 CellChangeTimes->{{3.586021530610837*^9, 3.5860215813305283`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Unknown Values: Basic Deletion", "Title",
 CellChangeTimes->{{3.585417299136742*^9, 3.585417302023638*^9}, {
  3.585486190840365*^9, 3.585486194479013*^9}, {3.5854955216795692`*^9, 
  3.585495536078971*^9}}],

Cell["\<\
We will now develop some techniques for handling missing values in the \
dataset.\
\>", "Text",
 CellChangeTimes->{{3.585409007360567*^9, 3.585409022125017*^9}, {
  3.585413920023147*^9, 3.585413990652582*^9}, {3.5854155138898907`*^9, 
  3.585415564335779*^9}, {3.5854817914031487`*^9, 3.585481799721176*^9}, {
  3.58548183960981*^9, 3.585481866751459*^9}, {3.58548621549551*^9, 
  3.585486233782075*^9}, {3.585486368100177*^9, 3.585486375659062*^9}, {
  3.585487812111656*^9, 3.58548781331898*^9}, {3.585495574847068*^9, 
  3.5854955843343363`*^9}, {3.585998663595963*^9, 3.585998684064237*^9}, {
  3.586021588751189*^9, 3.586021603735359*^9}}],

Cell["How many rows contain at least one missing value?", "Text",
 CellChangeTimes->{{3.585409007360567*^9, 3.585409022125017*^9}, {
  3.585413920023147*^9, 3.585413990652582*^9}, {3.5854155138898907`*^9, 
  3.585415564335779*^9}, {3.5854817914031487`*^9, 3.585481799721176*^9}, {
  3.58548183960981*^9, 3.585481866751459*^9}, {3.58548621549551*^9, 
  3.585486233782075*^9}, {3.585486368100177*^9, 3.585486375659062*^9}, {
  3.585487812111656*^9, 3.58548781331898*^9}, {3.585495574847068*^9, 
  3.5854955843343363`*^9}, {3.585998663595963*^9, 3.585998684064237*^9}, {
  3.586021588751189*^9, 3.5860215907751513`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Count", "[", 
  RowBox[{
   RowBox[{"med", "[", "All", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"__", ",", 
     RowBox[{"Missing", "[", "]"}], ",", "__"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5747638012595882`*^9, 3.574763852850539*^9}, {
  3.5747639366333313`*^9, 3.5747639474969525`*^9}, {3.585495618390387*^9, 
  3.585495646725402*^9}}],

Cell[BoxData["16"], "Output",
 CellChangeTimes->{3.58549564725148*^9, 3.58599868666035*^9, 
  3.5860217408124943`*^9}]
}, Open  ]],

Cell["Which rows are particularly problematic?", "Text",
 CellChangeTimes->{{3.5854956835565233`*^9, 3.585495689068082*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Count", "[", 
    RowBox[{"#", ",", 
     RowBox[{"Missing", "[", "]"}]}], "]"}], "&"}], "/@", 
  RowBox[{"med", "[", "All", "]"}]}]], "Input",
 CellChangeTimes->{{3.574764198536311*^9, 3.5747642152552676`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "1", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "1", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "1", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2", ",", 
   "2", ",", "6", ",", "1", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "1", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "1", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "1", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "6", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.574764211860073*^9, 3.5747642155082817`*^9}, 
   3.5747709987192593`*^9, 3.5747716012567225`*^9, 3.5747726949222765`*^9, 
   3.5750221357060957`*^9, 3.5751092818205204`*^9, 3.5752049439299603`*^9, 
   3.57580080841568*^9, 3.5854957748761797`*^9, 3.5859986914297543`*^9, 
   3.5860217443260612`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Histogram", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.585495786258079*^9, 3.5854957883399677`*^9}}],

Cell[BoxData[
 GraphicsBox[
  {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
   EdgeForm[Opacity[0.651]], {}, 
   {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
    EdgeForm[Opacity[0.651]], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{0., 0}, {1., 184}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{17.5, 66.2061224489796}, {-93.9012462484858, 
         96.28778676483911}}],
       StatusArea[#, 184]& ,
       TagBoxNote->"184"],
      StyleBox["184", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[184, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{1., 0}, {2., 7}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{65.2061224489796, 113.9122448979592}, {
         88.09037790020174, 96.28778676483911}}],
       StatusArea[#, 7]& ,
       TagBoxNote->"7"],
      StyleBox["7", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[7, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{2., 0}, {3., 7}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{112.9122448979592, 161.61836734693878`}, {
         88.09037790020174, 96.28778676483911}}],
       StatusArea[#, 7]& ,
       TagBoxNote->"7"],
      StyleBox["7", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[7, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{6., 0}, {7., 2}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{303.73673469387757`, 352.4428571428572}, {
         93.23138423208557, 96.28778676483911}}],
       StatusArea[#, 2]& ,
       TagBoxNote->"2"],
      StyleBox["2", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[2, {
        GrayLevel[0]}], "Tooltip"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  PlotRange->{{0., 7.}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.1]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.5854957887017927`*^9, 3.585998694331443*^9, 
  3.586021747764413*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tooBad", "=", 
  RowBox[{"Position", "[", 
   RowBox[{
    RowBox[{"med", "[", "All", "]"}], ",", 
    RowBox[{"x_", "/;", 
     RowBox[{
      RowBox[{"Count", "[", 
       RowBox[{"x", ",", 
        RowBox[{"Missing", "[", "]"}]}], "]"}], ">", "4"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.574764112217374*^9, 3.5747641431001406`*^9}, {
  3.5747643028452773`*^9, 3.5747643155390034`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", "62", "}"}], ",", 
   RowBox[{"{", "199", "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.574764135504706*^9, 3.574764143428159*^9}, {
   3.5747643061174645`*^9, 3.5747643160520325`*^9}, 3.5747709938189793`*^9, 
   3.5747716011687174`*^9, 3.5747726948582735`*^9, 3.574795299350169*^9, 
   3.575022132815931*^9, 3.5751092817545166`*^9, 3.575204943829719*^9, 
   3.5758008057462883`*^9, 3.5854957029493933`*^9, 3.5859987042081614`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"med", "[", "All", "]"}], "[", 
   RowBox[{"[", 
    RowBox[{"Flatten", "@", "tooBad"}], "]"}], "]"}], "//", 
  "TableForm"}]], "Input",
 CellChangeTimes->{{3.574764160630143*^9, 3.5747641642843523`*^9}, {
  3.585495732054504*^9, 3.585495748765522*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"summer\"\>", "\<\"small\"\>", "\<\"medium\"\>", "6.4`", 
     RowBox[{"Missing", "[", "]"}], 
     RowBox[{"Missing", "[", "]"}], 
     RowBox[{"Missing", "[", "]"}], 
     RowBox[{"Missing", "[", "]"}], 
     RowBox[{"Missing", "[", "]"}], "14.`", 
     RowBox[{"Missing", "[", "]"}], "19.4`", "0.`", "0.`", "2.`", "0.`", 
     "3.9`", "1.7`"},
    {"\<\"winter\"\>", "\<\"large\"\>", "\<\"medium\"\>", "8.`", "7.6`", 
     RowBox[{"Missing", "[", "]"}], 
     RowBox[{"Missing", "[", "]"}], 
     RowBox[{"Missing", "[", "]"}], 
     RowBox[{"Missing", "[", "]"}], 
     RowBox[{"Missing", "[", "]"}], 
     RowBox[{"Missing", "[", "]"}], "0.`", "12.5`", "3.7`", "1.`", "0.`", 
     "0.`", "4.9`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.5747641646363726`*^9, 3.5747709949740453`*^9, 3.57477160121072*^9, 
   3.574772694890275*^9, 3.5750221344230223`*^9, 3.5751092817915187`*^9, 
   3.5752049438776217`*^9, 3.5758008069809027`*^9, {3.585495736298585*^9, 
   3.585495749155376*^9}, 3.585998721102263*^9}]
}, Open  ]],

Cell["\<\
Visualize the dataset\[CloseCurlyQuote]s missing values (matrix is transposed \
to use less vertical space):\
\>", "Text",
 CellChangeTimes->{{3.585497331531107*^9, 3.585497342218532*^9}, {
  3.586016460510253*^9, 3.586016471110219*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MatrixPlot", "[", 
  RowBox[{"Transpose", "@", 
   RowBox[{"Replace", "[", 
    RowBox[{
     RowBox[{"med", "[", "All", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Except", "[", 
         RowBox[{"Missing", "[", "]"}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{"_", "\[Rule]", "1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"-", "1"}], "}"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.585497180624794*^9, 3.585497254733642*^9}, {
  3.585497297029014*^9, 3.585497298348521*^9}, {3.586016450887553*^9, 
  3.586016452864443*^9}}],

Cell[BoxData[
 GraphicsBox[RasterBox[CompressedData["
1:eJzt2rsNwyAQAFAkb+ANPIl3yAhWUnvljOARTGQXUQp3JsA9JPQQFZ+Do2Ba
1sdrSCmNuT5z/bSPss0kSZIkSZIkSZIkSZIkSZIkSZIkSZIkSZIka/d9+lvu
7v/3vNmn4o2Mc15aH39tWk+SJOk9wAiKc5JkSeUdRlCckyRLKu8wguKcJFlS
eYc16x87yWi6r/rQPvahfbzW+pAkyVb0biFJkiRJkiRJkiRJkiS/3QHEGL44

   "], {{0, 0}, {100, 18}}, {0, 1}],
  Frame->True,
  FrameLabel->{None, None},
  FrameTicks->{{{{17.5, 
       FormBox["1", TraditionalForm]}, {13.5, 
       FormBox["5", TraditionalForm]}, {8.5, 
       FormBox["10", TraditionalForm]}, {3.5, 
       FormBox["15", TraditionalForm]}, {0.5, 
       FormBox["18", TraditionalForm]}}, {{17.5, 
       FormBox["1", TraditionalForm]}, {13.5, 
       FormBox["5", TraditionalForm]}, {8.5, 
       FormBox["10", TraditionalForm]}, {3.5, 
       FormBox["15", TraditionalForm]}, {0.5, 
       FormBox["18", TraditionalForm]}}}, {{{0.25, 
       FormBox["1", TraditionalForm]}, {24.75, 
       FormBox["50", TraditionalForm]}, {49.75, 
       FormBox["100", TraditionalForm]}, {74.75, 
       FormBox["150", TraditionalForm]}, {99.75, 
       FormBox["200", TraditionalForm]}}, {{0.25, 
       FormBox["1", TraditionalForm]}, {24.75, 
       FormBox["50", TraditionalForm]}, {49.75, 
       FormBox["100", TraditionalForm]}, {74.75, 
       FormBox["150", TraditionalForm]}, {99.75, 
       FormBox["200", TraditionalForm]}}}}]], "Output",
 CellChangeTimes->{3.5854972195369463`*^9, 3.5854972554266872`*^9, 
  3.58549729905581*^9, 3.585998724967794*^9, 3.58601645466152*^9}]
}, Open  ]],

Cell["Construct a trimmed dataset with the problem rows deleted:", "Text",
 CellChangeTimes->{{3.585495812314445*^9, 3.585495844152849*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"trimmed", "=", 
   RowBox[{"columnize", "@", 
    RowBox[{"Delete", "[", 
     RowBox[{
      RowBox[{"med", "[", "All", "]"}], ",", "tooBad"}], "]"}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.5747642861633234`*^9, 3.5747643205202885`*^9}, 
   3.5747644187049046`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Filling in with Most Frequent Values", "Title",
 CellChangeTimes->{{3.585417299136742*^9, 3.585417302023638*^9}, {
  3.585486190840365*^9, 3.585486194479013*^9}, {3.5854955216795692`*^9, 
  3.585495536078971*^9}, {3.585495869960773*^9, 3.585495877024088*^9}}],

Cell["\<\
The idea here is to use a centrality measure on each column to fill in \
missing values.\
\>", "Text",
 CellChangeTimes->{{3.585409007360567*^9, 3.585409022125017*^9}, {
  3.585413920023147*^9, 3.585413990652582*^9}, {3.5854155138898907`*^9, 
  3.585415564335779*^9}, {3.5854817914031487`*^9, 3.585481799721176*^9}, {
  3.58548183960981*^9, 3.585481866751459*^9}, {3.58548621549551*^9, 
  3.585486233782075*^9}, {3.585486368100177*^9, 3.585486375659062*^9}, {
  3.585487812111656*^9, 3.58548781331898*^9}, {3.585495574847068*^9, 
  3.5854955843343363`*^9}, {3.585495980015123*^9, 3.585495996518042*^9}, {
  3.5854960393821917`*^9, 3.585496098612167*^9}, {3.585506977198782*^9, 
  3.585506977917441*^9}, {3.586021786322666*^9, 3.586021787779114*^9}}],

Cell["\<\
For example, given a row with a missing pH, fill in the hole with the mean pH \
of the column:\
\>", "Text",
 CellChangeTimes->{{3.585409007360567*^9, 3.585409022125017*^9}, {
  3.585413920023147*^9, 3.585413990652582*^9}, {3.5854155138898907`*^9, 
  3.585415564335779*^9}, {3.5854817914031487`*^9, 3.585481799721176*^9}, {
  3.58548183960981*^9, 3.585481866751459*^9}, {3.58548621549551*^9, 
  3.585486233782075*^9}, {3.585486368100177*^9, 3.585486375659062*^9}, {
  3.585487812111656*^9, 3.58548781331898*^9}, {3.585495574847068*^9, 
  3.5854955843343363`*^9}, {3.585495980015123*^9, 3.585495996518042*^9}, {
  3.5854960393821917`*^9, 3.585496098612167*^9}, {3.585506977198782*^9, 
  3.585506977917441*^9}, {3.586021786322666*^9, 3.586021787779114*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"trimmed", "[", "All", "]"}], "[", 
  RowBox[{"[", "48", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.574764521276771*^9, 3.574764527064102*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"winter\"\>", ",", "\<\"small\"\>", ",", "\<\"low\"\>", ",", 
   RowBox[{"Missing", "[", "]"}], ",", "12.6`", ",", "9.`", ",", "0.23`", ",",
    "10.`", ",", "5.`", ",", "6.`", ",", "1.1`", ",", "35.5`", ",", "0.`", 
   ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.574764527401121*^9, 3.5747715874429326`*^9, 
  3.5747716395899153`*^9, 3.574772701111631*^9, 3.5747902309922757`*^9, 
  3.575109355264721*^9, 3.575204948781221*^9, 3.575801829759947*^9, 
  3.5859989468191233`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"trimmedImputed", "=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"m", "=", 
        RowBox[{"Mean", "[", 
         RowBox[{"trimmed", "[", "mxPH", "]"}], "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"holes", "=", 
        RowBox[{"Flatten", "@", 
         RowBox[{"trimmed", "[", 
          RowBox[{"mxPH", ",", "\"\<missing\>\""}], "]"}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"dat", "=", 
        RowBox[{"trimmed", "[", "All", "]"}]}]}], "\[IndentingNewLine]", 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"dat", "[", 
        RowBox[{"[", 
         RowBox[{"holes", ",", 
          RowBox[{"mxPH", "/.", "numberedColumns"}]}], "]"}], "]"}], "=", 
       "m"}], ";", "\[IndentingNewLine]", 
      RowBox[{"columnize", "@", "dat"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.574764572851721*^9, 3.5747645793370914`*^9}, {
   3.5747646157971773`*^9, 3.574764616032191*^9}, {3.574764715411875*^9, 
   3.574764767041828*^9}, {3.574764854244816*^9, 3.5747648552078705`*^9}, {
   3.57476521360437*^9, 3.57476521431441*^9}, {3.5747717874993753`*^9, 
   3.574771795261819*^9}, {3.5747718274566603`*^9, 3.5747719034570074`*^9}, {
   3.5747720848653836`*^9, 3.5747720857374334`*^9}, {3.5747721223995304`*^9, 
   3.574772136274324*^9}, {3.5747721736294603`*^9, 3.574772190649434*^9}, {
   3.5747722412713294`*^9, 3.574772242100377*^9}, {3.574772274916254*^9, 
   3.5747722968735094`*^9}, {3.5747728718793983`*^9, 
   3.5747728799808617`*^9}, {3.5747731314162426`*^9, 
   3.5747731467641206`*^9}, {3.5747902360905676`*^9, 
   3.5747902443210382`*^9}, {3.5747903517821846`*^9, 3.5747903748685055`*^9}, 
   3.5747904172929316`*^9, {3.585496109079467*^9, 3.585496122671179*^9}, {
   3.585496273035371*^9, 3.585496277604342*^9}, {3.585496417527534*^9, 
   3.585496423496842*^9}}],

Cell["The missing value is filled in:", "Text",
 CellChangeTimes->{{3.585496174050476*^9, 3.585496182810536*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"trimmedImputed", "[", "All", "]"}], "[", 
  RowBox[{"[", "48", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.574772719434679*^9, 3.5747727463522186`*^9}, {
  3.57477379836539*^9, 3.574773799565459*^9}, {3.5747904307377005`*^9, 
  3.5747904321367807`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"winter\"\>", ",", "\<\"small\"\>", ",", "\<\"low\"\>", ",", 
   "8.01997461928934`", ",", "12.6`", ",", "9.`", ",", "0.23`", ",", "10.`", 
   ",", "5.`", ",", "6.`", ",", "1.1`", ",", "35.5`", ",", "0.`", ",", "0.`", 
   ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`"}], "}"}]], "Output",
 CellChangeTimes->{{3.574772731916393*^9, 3.574772747293272*^9}, 
   3.5747731637150903`*^9, 3.574773800248498*^9, 3.5747902196896296`*^9, 
   3.5747903927475276`*^9, 3.5747904325488043`*^9, 3.5751093553277245`*^9, 
   3.575204948861876*^9, 3.585496169916469*^9, 3.5854962826318283`*^9, 
   3.585496425835997*^9, 3.585998949439795*^9}]
}, Open  ]],

Cell["Some missing chlorophyll values:", "Text",
 CellChangeTimes->{{3.585496221321014*^9, 3.585496235832765*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"trimmed", "[", 
   RowBox[{"Chla", ",", "\"\<raw\>\""}], "]"}], "[", 
  RowBox[{"[", 
   RowBox[{"55", ";;", "60"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.574790544846227*^9, 3.5747905799832373`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Missing", "[", "]"}], ",", 
   RowBox[{"Missing", "[", "]"}], ",", 
   RowBox[{"Missing", "[", "]"}], ",", 
   RowBox[{"Missing", "[", "]"}], ",", 
   RowBox[{"Missing", "[", "]"}], ",", 
   RowBox[{"Missing", "[", "]"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.5747905698886595`*^9, 3.5747905803412576`*^9}, 
   3.575109355347726*^9, 3.575204948920526*^9, 3.585998950672073*^9}]
}, Open  ]],

Cell["\<\
As an exercise, try filling these in with the median chlorophyll value (copy \
and modify the module above).\
\>", "Text",
 CellChangeTimes->{{3.585496239624731*^9, 3.585496252424426*^9}, {
  3.5859110982465773`*^9, 3.585911101694034*^9}, {3.585998984260601*^9, 
  3.585998990067582*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"trimmedImputed", "[", 
   RowBox[{"Chla", ",", "\"\<raw\>\""}], "]"}], "[", 
  RowBox[{"[", 
   RowBox[{"55", ";;", "60"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5747905885407267`*^9, 3.574790592372946*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Central Imputation", "Title",
 CellChangeTimes->{{3.585417299136742*^9, 3.585417302023638*^9}, {
  3.585486190840365*^9, 3.585486194479013*^9}, {3.5854955216795692`*^9, 
  3.585495536078971*^9}, {3.585495869960773*^9, 3.585495877024088*^9}, {
  3.585496348406768*^9, 3.585496351222687*^9}}],

Cell["\<\
Construct a central imputation function that automates this task:\
\>", "Text",
 CellChangeTimes->{{3.585409007360567*^9, 3.585409022125017*^9}, {
  3.585413920023147*^9, 3.585413990652582*^9}, {3.5854155138898907`*^9, 
  3.585415564335779*^9}, {3.5854817914031487`*^9, 3.585481799721176*^9}, {
  3.58548183960981*^9, 3.585481866751459*^9}, {3.58548621549551*^9, 
  3.585486233782075*^9}, {3.585486368100177*^9, 3.585486375659062*^9}, {
  3.585487812111656*^9, 3.58548781331898*^9}, {3.585495574847068*^9, 
  3.5854955843343363`*^9}, {3.585495980015123*^9, 3.585495996518042*^9}, {
  3.5854960393821917`*^9, 3.585496098612167*^9}, {3.585496368558179*^9, 
  3.585496381862287*^9}, {3.5860218108577547`*^9, 3.5860218156729116`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"centralImpute", "[", 
   RowBox[{"set_", ",", "cols_"}], "]"}], ":=", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"m", ",", 
      RowBox[{"dat", "=", 
       RowBox[{"set", "[", "All", "]"}]}], ",", "holes"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Scan", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"holes", "=", 
           RowBox[{"Flatten", "@", 
            RowBox[{"set", "[", 
             RowBox[{"#", ",", "\"\<missing\>\""}], "]"}]}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"dat", "[", 
            RowBox[{"[", 
             RowBox[{"holes", ",", 
              RowBox[{"#", "/.", "numberedColumns"}]}], "]"}], "]"}], "=", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"set", "[", 
              RowBox[{"#", ",", "\"\<factorized\>\""}], "]"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"First", "@", 
              RowBox[{"Commonest", "[", 
               RowBox[{"set", "[", "#", "]"}], "]"}]}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"(*", " ", "else", " ", "*)"}], "\[IndentingNewLine]", 
             RowBox[{"Median", "[", 
              RowBox[{"set", "[", "#", "]"}], "]"}]}], "\[IndentingNewLine]", 
            "]"}]}], ";"}], ")"}], "&"}], ",", "\[IndentingNewLine]", 
       "cols"}], "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"columnize", "@", "dat"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->CompressedData["
1:eJwdzE8og3EAxvFx2UxtBytqOdBICodFxmlWi7WVvQdMRDSGRpkUN3/KSCFR
611ZZIlM2/D6V7jYvGrKn4gRsqklTRMxxfv8Dk+fy7cno6mLMibyeLx0blCr
pIeo+Yiy57h9GPYPflvhBj9hFEryzTNwqeqRhtZLnxM+OMNEXrX3HDrFLPHp
pyupivOs0SSEn/ZOEQzMvaVChZvOhyIbQ/zwa+VQ5RMUwjHZugLm+i9K4a4r
pwxqilTED329GrIxaQUUyH4nYXHz3xQM6s1uuGqp8cLpEekW6VoD29C1sngA
yzOzDmE3/5WFnpb9E1jriEdJpxLEoMkQS67mXB6YFcM9KkECbxoleZDtK5BD
T2iCGGVsOmhpF1NQGA4ZYK87pRbqEjtKGjifNbdl0CUVL7ObEWV2/Iv4Fkzz
wLb3l3V4dF+3A5nK8VPYucBcQaO69xrK9WsOO8P90HfEf9F0+Lg=
  "]],

Cell[BoxData[
 RowBox[{
  RowBox[{"test", "=", 
   RowBox[{"centralImpute", "[", 
    RowBox[{"trimmed", ",", "columns"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5747744220600634`*^9, 3.574774445307393*^9}, {
   3.574774486432745*^9, 3.5747744876428146`*^9}, 3.585496808622999*^9, {
   3.5854968623281918`*^9, 3.585496865556818*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"test", "[", 
   RowBox[{"Chla", ",", "\"\<raw\>\""}], "]"}], "[", 
  RowBox[{"[", 
   RowBox[{"55", ";;", "60"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5747744561890154`*^9, 3.574774458911171*^9}, 
   3.5747745126812468`*^9, {3.574790687495386*^9, 3.5747906955348463`*^9}, {
   3.58549679646994*^9, 3.5854968008381233`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "5.475`", ",", "5.475`", ",", "5.475`", ",", "5.475`", ",", "5.475`", ",", 
   "5.475`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.57479069578086*^9, 3.575109355442732*^9, 3.575204949201889*^9, 
   3.575801842778084*^9, {3.5854967790327873`*^9, 3.5854968011925917`*^9}, 
   3.585496867348983*^9, 3.585999011007567*^9}]
}, Open  ]],

Cell["\<\
There shouldn\[CloseCurlyQuote]t be any missing values left (matrix is \
transposed to use less vertical space):\
\>", "Text",
 CellChangeTimes->{{3.585497403096266*^9, 3.585497410265397*^9}, {
  3.5855070928604937`*^9, 3.585507100899304*^9}, {3.586021833528659*^9, 
  3.586021842640362*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MatrixPlot", "[", 
  RowBox[{"Transpose", "@", 
   RowBox[{"Replace", "[", 
    RowBox[{
     RowBox[{"test", "[", "All", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Except", "[", 
         RowBox[{"Missing", "[", "]"}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{"_", "\[Rule]", "1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"-", "1"}], "}"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.585497180624794*^9, 3.585497254733642*^9}, {
  3.585497297029014*^9, 3.585497298348521*^9}, {3.585498039911702*^9, 
  3.58549804138175*^9}, {3.586016437945079*^9, 3.5860164401602087`*^9}}],

Cell[BoxData[
 GraphicsBox[
  RasterBox[SparseArray[
   Automatic, {18, 99}, 1., {
    1, {{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0}, {}}, {}}], {{0, 0}, {99, 18}}, {0, 1}],
  Frame->True,
  FrameLabel->{None, None},
  FrameTicks->{{{{17.5, 
       FormBox["1", TraditionalForm]}, {13.5, 
       FormBox["5", TraditionalForm]}, {8.5, 
       FormBox["10", TraditionalForm]}, {3.5, 
       FormBox["15", TraditionalForm]}, {0.5, 
       FormBox["18", TraditionalForm]}}, {{17.5, 
       FormBox["1", TraditionalForm]}, {13.5, 
       FormBox["5", TraditionalForm]}, {8.5, 
       FormBox["10", TraditionalForm]}, {3.5, 
       FormBox["15", TraditionalForm]}, {0.5, 
       FormBox["18", TraditionalForm]}}}, {{{0.25, 
       FormBox["1", TraditionalForm]}, {24.75, 
       FormBox["50", TraditionalForm]}, {49.75, 
       FormBox["100", TraditionalForm]}, {74.75, 
       FormBox["150", TraditionalForm]}, {98.75, 
       FormBox["198", TraditionalForm]}}, {{0.25, 
       FormBox["1", TraditionalForm]}, {24.75, 
       FormBox["50", TraditionalForm]}, {49.75, 
       FormBox["100", TraditionalForm]}, {74.75, 
       FormBox["150", TraditionalForm]}, {98.75, 
       FormBox["198", TraditionalForm]}}}}]], "Output",
 CellChangeTimes->{3.5854972195369463`*^9, 3.5854972554266872`*^9, 
  3.58549729905581*^9, 3.585498041737479*^9, 3.585999023546681*^9, 
  3.586016440768551*^9}]
}, Open  ]],

Cell["\<\
This reset function will import the raw data from disk, delete problematic \
rows, and construct columnized trimmed and centrally imputed representations. \
The function is also defined in the initialization section of this notebook.\
\>", "Text",
 CellChangeTimes->{{3.585497426609527*^9, 3.585497477495833*^9}, {
  3.585497897535706*^9, 3.585497915151105*^9}, {3.5854983844872437`*^9, 
  3.5854983857332478`*^9}, {3.5854984930133142`*^9, 3.585498497179017*^9}, {
  3.5859990409802303`*^9, 3.585999052268121*^9}, {3.58609652648591*^9, 
  3.5860965275576153`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "@", "reset"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"reset", "[", 
   RowBox[{"n_:", "4"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"raw", ",", "tooBad"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"raw", "=", 
      RowBox[{
       RowBox[{"Import", "[", 
        RowBox[{
         RowBox[{"FileNameJoin", "[", 
          RowBox[{"{", 
           RowBox[{"\"\<algae\>\"", ",", "\"\<Analysis.txt\>\""}], "}"}], 
          "]"}], ",", "\"\<Data\>\""}], "]"}], "/.", 
       RowBox[{"\"\<XXXXXXX\>\"", "\[Rule]", 
        RowBox[{"Missing", "[", "]"}]}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"med", "=", 
      RowBox[{"columnize", "@", "raw"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"tooBad", "=", 
      RowBox[{"Position", "[", 
       RowBox[{
        RowBox[{"med", "[", "All", "]"}], ",", 
        RowBox[{"x_", "/;", 
         RowBox[{
          RowBox[{"Count", "[", 
           RowBox[{"x", ",", 
            RowBox[{"Missing", "[", "]"}]}], "]"}], ">", "n"}]}]}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"trimmed", "=", 
      RowBox[{"columnize", "@", 
       RowBox[{"Delete", "[", 
        RowBox[{
         RowBox[{"med", "[", "All", "]"}], ",", "tooBad"}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"imputed", "=", 
      RowBox[{"centralImpute", "[", 
       RowBox[{"trimmed", ",", "featureColumns"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"applyForderings", "[", "#", "]"}], "&"}], "/@", 
      RowBox[{"{", 
       RowBox[{"med", ",", "trimmed", ",", "imputed"}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Print", "[", 
      RowBox[{"StringForm", "[", 
       RowBox[{"\"\<med dataset defined, `` rows\>\"", ",", " ", 
        RowBox[{"Length", "@", 
         RowBox[{"med", "[", "All", "]"}]}]}], "]"}], "]"}], ";", 
     RowBox[{"Print", "[", 
      RowBox[{"StringForm", "[", 
       RowBox[{"\"\<trimmed dataset defined, `` rows\>\"", ",", " ", 
        RowBox[{"Length", "@", 
         RowBox[{"trimmed", "[", "All", "]"}]}]}], "]"}], "]"}], ";", 
     RowBox[{"Print", "[", 
      RowBox[{"StringForm", "[", 
       RowBox[{"\"\<centrally imputed dataset defined, `` rows\>\"", ",", " ", 
        RowBox[{"Length", "@", 
         RowBox[{"imputed", "[", "All", "]"}]}]}], "]"}], "]"}], ";"}]}], 
   "\[IndentingNewLine]", "]"}]}]}], "Input",
 CellChangeTimes->{{3.574774280013939*^9, 3.5747742819520493`*^9}, {
  3.574774319694208*^9, 3.5747743761854396`*^9}, {3.5747745214527483`*^9, 
  3.5747745526075306`*^9}, {3.5747747470306506`*^9, 3.5747747961084576`*^9}, {
  3.5854977459236393`*^9, 3.585497770532607*^9}, {3.585497827036298*^9, 
  3.585497870755597*^9}, {3.585497924583564*^9, 3.585497930536949*^9}, {
  3.585498204923811*^9, 3.585498205646285*^9}, {3.585498502006689*^9, 
  3.585498526750547*^9}, {3.5855756277089376`*^9, 3.585575628876481*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"reset", "[", "]"}]], "Input",
 CellChangeTimes->{{3.5747747838307557`*^9, 3.5747747849728208`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox["\<\"med dataset defined, \\!\\(200\\) rows\"\>",
  StringForm["med dataset defined, `` rows", 200],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.585497878642542*^9, 3.58549828990025*^9, 3.585498323282619*^9, {
   3.585498363690699*^9, 3.585498372167289*^9}, 3.585498528875642*^9, 
   3.585999063455803*^9}],

Cell[BoxData[
 InterpretationBox["\<\"trimmed dataset defined, \\!\\(198\\) rows\"\>",
  StringForm["trimmed dataset defined, `` rows", 198],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.585497878642542*^9, 3.58549828990025*^9, 3.585498323282619*^9, {
   3.585498363690699*^9, 3.585498372167289*^9}, 3.585498528875642*^9, 
   3.585999063462656*^9}],

Cell[BoxData[
 InterpretationBox["\<\"centrally imputed dataset defined, \\!\\(198\\) \
rows\"\>",
  StringForm["centrally imputed dataset defined, `` rows", 198],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.585497878642542*^9, 3.58549828990025*^9, 3.585498323282619*^9, {
   3.585498363690699*^9, 3.585498372167289*^9}, 3.585498528875642*^9, 
   3.585999063468176*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Length", "@", 
    RowBox[{"#", "[", "All", "]"}]}], "&"}], "/@", 
  RowBox[{"{", 
   RowBox[{"med", ",", "trimmed", ",", "imputed"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.5747748020697985`*^9, 3.5747748060030236`*^9}, 
   3.574774908555889*^9, {3.585497882344165*^9, 3.5854978849542227`*^9}, {
   3.5859990764277678`*^9, 3.585999099076703*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"200", ",", "198", ",", "198"}], "}"}]], "Output",
 CellChangeTimes->{
  3.585497885215845*^9, 3.585498291088292*^9, {3.5854983638382893`*^9, 
   3.5854983733119183`*^9}, {3.585999069929122*^9, 3.5859990994705133`*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Using Correlations", "Title",
 CellChangeTimes->{{3.585417299136742*^9, 3.585417302023638*^9}, {
  3.585486190840365*^9, 3.585486194479013*^9}, {3.5854955216795692`*^9, 
  3.585495536078971*^9}, {3.585495869960773*^9, 3.585495877024088*^9}, {
  3.5854984265503893`*^9, 3.585498429740182*^9}}],

Cell["\<\
Another way to fill in missing data is to use similarities between rows \
rather than columns.  Consider the raw matrix of numerical values with \
missing values excised:\
\>", "Text",
 CellChangeTimes->{{3.585409007360567*^9, 3.585409022125017*^9}, {
  3.585413920023147*^9, 3.585413990652582*^9}, {3.5854155138898907`*^9, 
  3.585415564335779*^9}, {3.5854817914031487`*^9, 3.585481799721176*^9}, {
  3.58548183960981*^9, 3.585481866751459*^9}, {3.58548621549551*^9, 
  3.585486233782075*^9}, {3.585486368100177*^9, 3.585486375659062*^9}, {
  3.585487812111656*^9, 3.58548781331898*^9}, {3.585495574847068*^9, 
  3.5854955843343363`*^9}, {3.585495980015123*^9, 3.585495996518042*^9}, {
  3.5854960393821917`*^9, 3.585496098612167*^9}, {3.585498436684367*^9, 
  3.585498451987658*^9}, {3.585498681192321*^9, 3.58549869956702*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"completeMat", "=", 
   RowBox[{
    RowBox[{"DeleteCases", "[", 
     RowBox[{
      RowBox[{"med", "[", "All", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"__", ",", 
        RowBox[{"Missing", "[", "]"}], ",", "__"}], "}"}]}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", 
      RowBox[{"4", ";;"}]}], "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5747753817519546`*^9, 3.5747754004390235`*^9}, {
  3.574775604827714*^9, 3.5747756213456583`*^9}}],

Cell["Compute the correlation matrix:", "Text",
 CellChangeTimes->{{3.585498738701859*^9, 3.5854987439337378`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"corrMat", "=", 
   RowBox[{"Correlation", "[", "completeMat", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5747756301951647`*^9, 3.5747756431579065`*^9}, {
  3.5747757114038095`*^9, 3.5747757285267887`*^9}, {3.585498736070669*^9, 
  3.585498736793354*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Column", "[", 
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"GraphicsRow", "[", 
      RowBox[{
       RowBox[{"columns", "[", 
        RowBox[{"[", 
         RowBox[{"4", ";;"}], "]"}], "]"}], ",", 
       RowBox[{"ImageSize", "\[Rule]", "500"}], ",", 
       RowBox[{"Frame", "\[Rule]", "All"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Row", "[", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"GraphicsColumn", "[", 
         RowBox[{
          RowBox[{"columns", "[", 
           RowBox[{"[", 
            RowBox[{"4", ";;"}], "]"}], "]"}], ",", 
          RowBox[{"ImageSize", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"34", ",", "500"}], "}"}]}], ",", 
          RowBox[{"Frame", "\[Rule]", "All"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Overlay", "[", 
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"ArrayPlot", "[", 
            RowBox[{"corrMat", ",", 
             RowBox[{"ColorFunction", "\[Rule]", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"ColorData", "[", "\"\<TemperatureMap\>\"", "]"}], 
                 "[", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"1", "+", "#"}], ")"}], "/", "2"}], "]"}], "&"}], 
               ")"}]}], ",", 
             RowBox[{"Frame", "\[Rule]", "None"}], ",", 
             RowBox[{"Mesh", "\[Rule]", "True"}], ",", 
             RowBox[{"PlotRangePadding", "\[Rule]", "0"}], ",", 
             RowBox[{"ImageSize", "\[Rule]", "500"}], ",", 
             RowBox[{"ColorFunctionScaling", "\[Rule]", "False"}]}], "]"}], 
           ",", "\[IndentingNewLine]", 
           RowBox[{"GraphicsGrid", "[", 
            RowBox[{
             RowBox[{"Map", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"NumberForm", "[", 
                 RowBox[{"#", ",", "2"}], "]"}], "&"}], ",", "corrMat", ",", 
               RowBox[{"{", "2", "}"}]}], "]"}], ",", 
             RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}]}], 
          "\[IndentingNewLine]", "}"}], "]"}]}], "\[IndentingNewLine]", "}"}],
       "]"}]}], "\[IndentingNewLine]", "}"}], ",", 
   RowBox[{"Alignment", "\[Rule]", "Right"}], ",", 
   RowBox[{"Spacings", "\[Rule]", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.574775647696166*^9, 3.574775701253229*^9}, {
   3.5747757322850037`*^9, 3.574775769652141*^9}, {3.574775812338583*^9, 
   3.574775844408417*^9}, {3.5747759175506005`*^9, 3.5747759328764772`*^9}, {
   3.574776105087327*^9, 3.5747761581093597`*^9}, {3.585498727686088*^9, 
   3.585498731961906*^9}, {3.5854987683594627`*^9, 3.585498903924493*^9}, 
   3.585911171791112*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     GraphicsBox[{{}, {
        InsetBox["mxPH", {196.875, -189.}, {Center, Center}, {360., 360.}], 
        InsetBox["mnO2", {590.625, -189.}, {Center, Center}, {360., 360.}], 
        InsetBox["Cl", {984.375, -189.}, {Center, Center}, {360., 360.}], 
        InsetBox["NO3", {1378.125, -189.}, {Center, Center}, {360., 360.}], 
        InsetBox["NH4", {1771.875, -189.}, {Center, Center}, {360., 360.}], 
        InsetBox["oPO4", {2165.625, -189.}, {Center, Center}, {360., 360.}], 
        InsetBox["PO4", {2559.375, -189.}, {Center, Center}, {360., 360.}], 
        InsetBox["Chla", {2953.125, -189.}, {Center, Center}, {360., 360.}], 
        InsetBox["a1", {3346.875, -189.}, {Center, Center}, {360., 360.}], 
        InsetBox["a2", {3740.625, -189.}, {Center, Center}, {360., 360.}], 
        InsetBox["a3", {4134.375, -189.}, {Center, Center}, {360., 360.}], 
        InsetBox["a4", {4528.125, -189.}, {Center, Center}, {360., 360.}], 
        InsetBox["a5", {4921.875, -189.}, {Center, Center}, {360., 360.}], 
        InsetBox["a6", {5315.625, -189.}, {Center, Center}, {360., 360.}], 
        InsetBox["a7", {5709.375, -189.}, {Center, Center}, {360., 360.}]}, 
       StyleBox[{{}, {LineBox[{{0, 0}, {0, -378.}}], 
          LineBox[{{393.75, 0}, {393.75, -378.}}], 
          LineBox[{{787.5, 0}, {787.5, -378.}}], 
          LineBox[{{1181.25, 0}, {1181.25, -378.}}], 
          LineBox[{{1575., 0}, {1575., -378.}}], 
          LineBox[{{1968.75, 0}, {1968.75, -378.}}], 
          LineBox[{{2362.5, 0}, {2362.5, -378.}}], 
          LineBox[{{2756.25, 0}, {2756.25, -378.}}], 
          LineBox[{{3150., 0}, {3150., -378.}}], 
          LineBox[{{3543.75, 0}, {3543.75, -378.}}], 
          LineBox[{{3937.5, 0}, {3937.5, -378.}}], 
          LineBox[{{4331.25, 0}, {4331.25, -378.}}], 
          LineBox[{{4725., 0}, {4725., -378.}}], 
          LineBox[{{5118.75, 0}, {5118.75, -378.}}], 
          LineBox[{{5512.5, 0}, {5512.5, -378.}}], 
          LineBox[{{5906.25, 0}, {5906.25, -378.}}], 
          LineBox[{{0, 0}, {393.75, 0}}], LineBox[{{393.75, 0}, {787.5, 0}}], 
          LineBox[{{787.5, 0}, {1181.25, 0}}], 
          LineBox[{{1181.25, 0}, {1575., 0}}], 
          LineBox[{{1575., 0}, {1968.75, 0}}], 
          LineBox[{{1968.75, 0}, {2362.5, 0}}], 
          LineBox[{{2362.5, 0}, {2756.25, 0}}], 
          LineBox[{{2756.25, 0}, {3150., 0}}], 
          LineBox[{{3150., 0}, {3543.75, 0}}], 
          LineBox[{{3543.75, 0}, {3937.5, 0}}], 
          LineBox[{{3937.5, 0}, {4331.25, 0}}], 
          LineBox[{{4331.25, 0}, {4725., 0}}], 
          LineBox[{{4725., 0}, {5118.75, 0}}], 
          LineBox[{{5118.75, 0}, {5512.5, 0}}], 
          LineBox[{{5512.5, 0}, {5906.25, 0}}], 
          LineBox[{{0, -378.}, {393.75, -378.}}], 
          LineBox[{{393.75, -378.}, {787.5, -378.}}], 
          LineBox[{{787.5, -378.}, {1181.25, -378.}}], 
          LineBox[{{1181.25, -378.}, {1575., -378.}}], 
          LineBox[{{1575., -378.}, {1968.75, -378.}}], 
          LineBox[{{1968.75, -378.}, {2362.5, -378.}}], 
          LineBox[{{2362.5, -378.}, {2756.25, -378.}}], 
          LineBox[{{2756.25, -378.}, {3150., -378.}}], 
          LineBox[{{3150., -378.}, {3543.75, -378.}}], 
          LineBox[{{3543.75, -378.}, {3937.5, -378.}}], 
          LineBox[{{3937.5, -378.}, {4331.25, -378.}}], 
          LineBox[{{4331.25, -378.}, {4725., -378.}}], 
          LineBox[{{4725., -378.}, {5118.75, -378.}}], 
          LineBox[{{5118.75, -378.}, {5512.5, -378.}}], 
          LineBox[{{5512.5, -378.}, {5906.25, -378.}}]}},
        Antialiasing->False]},
      ContentSelectable->True,
      ImageSize->500,
      PlotRangePadding->{6, 5}]},
    {
     TemplateBox[{GraphicsBox[{{}, {
          InsetBox["mxPH", {189., -196.875}, {Center, Center}, {360., 360.}], 
          InsetBox["mnO2", {189., -590.625}, {Center, Center}, {360., 360.}], 
          InsetBox["Cl", {189., -984.375}, {Center, Center}, {360., 360.}], 
          InsetBox["NO3", {189., -1378.125}, {Center, Center}, {360., 360.}], 
          InsetBox["NH4", {189., -1771.875}, {Center, Center}, {360., 360.}], 
          InsetBox["oPO4", {189., -2165.625}, {Center, Center}, {360., 360.}], 
          InsetBox["PO4", {189., -2559.375}, {Center, Center}, {360., 360.}], 
          InsetBox["Chla", {189., -2953.125}, {Center, Center}, {360., 360.}], 
          InsetBox["a1", {189., -3346.875}, {Center, Center}, {360., 360.}], 
          InsetBox["a2", {189., -3740.625}, {Center, Center}, {360., 360.}], 
          InsetBox["a3", {189., -4134.375}, {Center, Center}, {360., 360.}], 
          InsetBox["a4", {189., -4528.125}, {Center, Center}, {360., 360.}], 
          InsetBox["a5", {189., -4921.875}, {Center, Center}, {360., 360.}], 
          InsetBox["a6", {189., -5315.625}, {Center, Center}, {360., 360.}], 
          InsetBox["a7", {189., -5709.375}, {Center, Center}, {360., 360.}]}, 
         StyleBox[{{}, {
            LineBox[{{0, 0}, {0, -393.75}}], 
            LineBox[{{0, -393.75}, {0, -787.5}}], 
            LineBox[{{0, -787.5}, {0, -1181.25}}], 
            LineBox[{{0, -1181.25}, {0, -1575.}}], 
            LineBox[{{0, -1575.}, {0, -1968.75}}], 
            LineBox[{{0, -1968.75}, {0, -2362.5}}], 
            LineBox[{{0, -2362.5}, {0, -2756.25}}], 
            LineBox[{{0, -2756.25}, {0, -3150.}}], 
            LineBox[{{0, -3150.}, {0, -3543.75}}], 
            LineBox[{{0, -3543.75}, {0, -3937.5}}], 
            LineBox[{{0, -3937.5}, {0, -4331.25}}], 
            LineBox[{{0, -4331.25}, {0, -4725.}}], 
            LineBox[{{0, -4725.}, {0, -5118.75}}], 
            LineBox[{{0, -5118.75}, {0, -5512.5}}], 
            LineBox[{{0, -5512.5}, {0, -5906.25}}], 
            LineBox[{{378., 0}, {378., -393.75}}], 
            LineBox[{{378., -393.75}, {378., -787.5}}], 
            LineBox[{{378., -787.5}, {378., -1181.25}}], 
            LineBox[{{378., -1181.25}, {378., -1575.}}], 
            LineBox[{{378., -1575.}, {378., -1968.75}}], 
            LineBox[{{378., -1968.75}, {378., -2362.5}}], 
            LineBox[{{378., -2362.5}, {378., -2756.25}}], 
            LineBox[{{378., -2756.25}, {378., -3150.}}], 
            LineBox[{{378., -3150.}, {378., -3543.75}}], 
            LineBox[{{378., -3543.75}, {378., -3937.5}}], 
            LineBox[{{378., -3937.5}, {378., -4331.25}}], 
            LineBox[{{378., -4331.25}, {378., -4725.}}], 
            LineBox[{{378., -4725.}, {378., -5118.75}}], 
            LineBox[{{378., -5118.75}, {378., -5512.5}}], 
            LineBox[{{378., -5512.5}, {378., -5906.25}}], 
            LineBox[{{0, 0}, {378., 0}}], 
            LineBox[{{0, -393.75}, {378., -393.75}}], 
            LineBox[{{0, -787.5}, {378., -787.5}}], 
            LineBox[{{0, -1181.25}, {378., -1181.25}}], 
            LineBox[{{0, -1575.}, {378., -1575.}}], 
            LineBox[{{0, -1968.75}, {378., -1968.75}}], 
            LineBox[{{0, -2362.5}, {378., -2362.5}}], 
            LineBox[{{0, -2756.25}, {378., -2756.25}}], 
            LineBox[{{0, -3150.}, {378., -3150.}}], 
            LineBox[{{0, -3543.75}, {378., -3543.75}}], 
            LineBox[{{0, -3937.5}, {378., -3937.5}}], 
            LineBox[{{0, -4331.25}, {378., -4331.25}}], 
            LineBox[{{0, -4725.}, {378., -4725.}}], 
            LineBox[{{0, -5118.75}, {378., -5118.75}}], 
            LineBox[{{0, -5512.5}, {378., -5512.5}}], 
            LineBox[{{0, -5906.25}, {378., -5906.25}}]}}, Antialiasing -> 
          False]}, ContentSelectable -> True, ImageSize -> {34, 500}, 
        PlotRangePadding -> {6, 5}],OverlayBox[{
         GraphicsBox[{
           RasterBox[CompressedData["
1:eJx9mHs01VkfxgndGI1LF+lyTCG3biaX0DPMoKamC0mN8KbIVEqlxBilmyGm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            "], {{0, 0}, {15, 15}}, {0, 1}], {{
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              
              LineBox[{{{0, 15}, {15, 15}}, {{0, 14}, {15, 14}}, {{0, 13}, {
               15, 13}}, {{0, 12}, {15, 12}}, {{0, 11}, {15, 11}}, {{0, 10}, {
               15, 10}}, {{0, 9}, {15, 9}}, {{0, 8}, {15, 8}}, {{0, 7}, {15, 
               7}}, {{0, 6}, {15, 6}}, {{0, 5}, {15, 5}}, {{0, 4}, {15, 
               4}}, {{0, 3}, {15, 3}}, {{0, 2}, {15, 2}}, {{0, 1}, {15, 
               1}}, {{0, 0}, {15, 0}}}], Antialiasing -> False]}, {
             GrayLevel[
              NCache[-1 + GoldenRatio, 0.6180339887498949]], 
             StyleBox[
              
              LineBox[{{{0, 0}, {0, 15}}, {{1, 0}, {1, 15}}, {{2, 0}, {2, 
               15}}, {{3, 0}, {3, 15}}, {{4, 0}, {4, 15}}, {{5, 0}, {5, 
               15}}, {{6, 0}, {6, 15}}, {{7, 0}, {7, 15}}, {{8, 0}, {8, 
               15}}, {{9, 0}, {9, 15}}, {{10, 0}, {10, 15}}, {{11, 0}, {11, 
               15}}, {{12, 0}, {12, 15}}, {{13, 0}, {13, 15}}, {{14, 0}, {14, 
               15}}, {{15, 0}, {15, 15}}}], Antialiasing -> False]}}}, Frame -> 
          None, FrameLabel -> {None, None}, 
          FrameTicks -> {{None, None}, {None, None}}, ImageSize -> 500, 
          PlotRangePadding -> 0], 
         GraphicsBox[{{}, {{
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"1.\"", 0.9999999999999996, AutoDelete -> True], 
               NumberForm[#, 2]& ], {196.875, -196.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.1\"", -0.10269373764110042`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {590.625, -196.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.15\"", 0.1470953900023518, AutoDelete -> True], 
               NumberForm[#, 2]& ], {984.375, -196.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.17\"", -0.17213023813255016`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {1378.125, -196.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.15\"", -0.1542975680453901, AutoDelete -> True], 
               NumberForm[#, 2]& ], {1771.875, -196.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.09\"", 0.09022908521564946, AutoDelete -> True], 
               NumberForm[#, 2]& ], {2165.625, -196.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.1\"", 0.10132957240378201`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {2559.375, -196.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.43\"", 0.4318237689502275, AutoDelete -> True], 
               NumberForm[#, 2]& ], {2953.125, -196.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.16\"", -0.16262985851256256`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {3346.875, -196.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.34\"", 0.33501740134845226`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {3740.625, -196.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.027\"", -0.02716033595355083, AutoDelete -> True], 
               NumberForm[#, 2]& ], {4134.375, -196.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.18\"", -0.18435347516440556`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {4528.125, -196.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.11\"", -0.10731229516150159`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {4921.875, -196.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.17\"", -0.1727379465696265, AutoDelete -> True], 
               NumberForm[#, 2]& ], {5315.625, -196.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.17\"", -0.1702708808314493, AutoDelete -> True], 
               NumberForm[#, 2]& ], {5709.375, -196.875}, {Center, Center}, {
              360., 360.}]}, {
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.1\"", -0.10269373764110042`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {196.875, -590.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox["\"1.\"", 1., AutoDelete -> True], 
               NumberForm[#, 2]& ], {590.625, -590.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.26\"", -0.2632453576802413, AutoDelete -> True], 
               NumberForm[#, 2]& ], {984.375, -590.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.12\"", 0.11790768840355514`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {1378.125, -590.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.078\"", -0.07826815534792383, AutoDelete -> True], 
               NumberForm[#, 2]& ], {1771.875, -590.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.39\"", -0.3937526882844783, AutoDelete -> True], 
               NumberForm[#, 2]& ], {2165.625, -590.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.46\"", -0.46396073291635087`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {2559.375, -590.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.13\"", -0.1312167106230113, AutoDelete -> True], 
               NumberForm[#, 2]& ], {2953.125, -590.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.25\"", 0.24998371946682332`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {3346.875, -590.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.068\"", -0.06848198894702665, AutoDelete -> True], 
               NumberForm[#, 2]& ], {3740.625, -590.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.24\"", -0.23522830668982778`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {4134.375, -590.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.38\"", -0.37982998959721687`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {4528.125, -590.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.21\"", 0.21001174373712214`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {4921.875, -590.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.19\"", 0.1886265552394863, AutoDelete -> True], 
               NumberForm[#, 2]& ], {5315.625, -590.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.1\"", -0.10455105663096541`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {5709.375, -590.625}, {Center, Center}, {
              360., 360.}]}, {
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.15\"", 0.1470953900023518, AutoDelete -> True], 
               NumberForm[#, 2]& ], {196.875, -984.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.26\"", -0.2632453576802413, AutoDelete -> True], 
               NumberForm[#, 2]& ], {590.625, -984.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"1.\"", 0.9999999999999999, AutoDelete -> True], 
               NumberForm[#, 2]& ], {984.375, -984.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.21\"", 0.21095831384379604`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {1378.125, -984.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.066\"", 0.06598336081181684, AutoDelete -> True], 
               NumberForm[#, 2]& ], {1771.875, -984.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.38\"", 0.3792559584596902, AutoDelete -> True], 
               NumberForm[#, 2]& ], {2165.625, -984.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.45\"", 0.44519117914681616`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {2559.375, -984.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.14\"", 0.14295775727663615`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {2953.125, -984.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.36\"", -0.3592394625241735, AutoDelete -> True], 
               NumberForm[#, 2]& ], {3346.875, -984.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.078\"", 0.07845401933198953, AutoDelete -> True], 
               NumberForm[#, 2]& ], {3740.625, -984.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.077\"", 0.07653026913356498, AutoDelete -> True], 
               NumberForm[#, 2]& ], {4134.375, -984.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.14\"", 0.14147281498402975`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {4528.125, -984.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.15\"", 0.14534877148941153`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {4921.875, -984.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.17\"", 0.16904394478595097`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {5315.625, -984.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.045\"", -0.04494523878070061, AutoDelete -> True], 
               NumberForm[#, 2]& ], {5709.375, -984.375}, {Center, Center}, {
              360., 360.}]}, {
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.17\"", -0.17213023813255016`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {196.875, -1378.125}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.12\"", 0.11790768840355514`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {590.625, -1378.125}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.21\"", 0.21095831384379604`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {984.375, -1378.125}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox["\"1.\"", 1., AutoDelete -> True], 
               NumberForm[#, 2]& ], {1378.125, -1378.125}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.72\"", 0.7246776638939985, AutoDelete -> True], 
               NumberForm[#, 2]& ], {1771.875, -1378.125}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.13\"", 0.13301451666556982`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {2165.625, -1378.125}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.16\"", 0.15702971476225328`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {2559.375, -1378.125}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.15\"", 0.14549290051709365`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {2953.125, -1378.125}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.25\"", -0.24723920846432587`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {3346.875, -1378.125}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.02\"", 0.01997078620647075, AutoDelete -> True], 
               NumberForm[#, 2]& ], {3740.625, -1378.125}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.092\"", -0.09182235816537995, AutoDelete -> True], 
               NumberForm[#, 2]& ], {4134.375, -1378.125}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.014\"", -0.014488749534123647`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {4528.125, -1378.125}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.21\"", 0.21213579457349596`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {4921.875, -1378.125}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.54\"", 0.5440445529021033, AutoDelete -> True], 
               NumberForm[#, 2]& ], {5315.625, -1378.125}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.075\"", 0.07505030107028399, AutoDelete -> True], 
               NumberForm[#, 2]& ], {5709.375, -1378.125}, {Center, Center}, {
              360., 360.}]}, {
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.15\"", -0.1542975680453901, AutoDelete -> True], 
               NumberForm[#, 2]& ], {196.875, -1771.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.078\"", -0.07826815534792383, AutoDelete -> True], 
               NumberForm[#, 2]& ], {590.625, -1771.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.066\"", 0.06598336081181684, AutoDelete -> True], 
               NumberForm[#, 2]& ], {984.375, -1771.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.72\"", 0.7246776638939985, AutoDelete -> True], 
               NumberForm[#, 2]& ], {1378.125, -1771.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"1.\"", 1.0000000000000002`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {1771.875, -1771.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.22\"", 0.21931120616819727`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {2165.625, -1771.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.2\"", 0.19939575217419855`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {2559.375, -1771.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.091\"", 0.09120406430457663, AutoDelete -> True], 
               NumberForm[#, 2]& ], {2953.125, -1771.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.12\"", -0.12360578411825932`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {3346.875, -1771.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.038\"", -0.03790295790924063, AutoDelete -> True], 
               NumberForm[#, 2]& ], {3740.625, -1771.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.11\"", -0.11290466552608752`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {4134.375, -1771.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.27\"", 0.2745200025313501, AutoDelete -> True], 
               NumberForm[#, 2]& ], {4528.125, -1771.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.015\"", 0.015444577764267898`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {4921.875, -1771.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.4\"", 0.4011927489401661, AutoDelete -> True], 
               NumberForm[#, 2]& ], {5315.625, -1771.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.025\"", -0.0253927905604893, AutoDelete -> True], 
               NumberForm[#, 2]& ], {5709.375, -1771.875}, {Center, Center}, {
              360., 360.}]}, {
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.09\"", 0.09022908521564946, AutoDelete -> True], 
               NumberForm[#, 2]& ], {196.875, -2165.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.39\"", -0.3937526882844783, AutoDelete -> True], 
               NumberForm[#, 2]& ], {590.625, -2165.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.38\"", 0.3792559584596902, AutoDelete -> True], 
               NumberForm[#, 2]& ], {984.375, -2165.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.13\"", 0.13301451666556982`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {1378.125, -2165.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.22\"", 0.21931120616819727`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {1771.875, -2165.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"1.\"", 1.0000000000000002`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {2165.625, -2165.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.91\"", 0.9119646020986052, AutoDelete -> True], 
               NumberForm[#, 2]& ], {2559.375, -2165.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.11\"", 0.10691478414084316`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {2953.125, -2165.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.39\"", -0.3945744794289791, AutoDelete -> True], 
               NumberForm[#, 2]& ], {3346.875, -2165.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.12\"", 0.12381106845822372`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {3740.625, -2165.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.0057\"", 0.005704556732967764, AutoDelete -> True], 
               NumberForm[#, 2]& ], {4134.375, -2165.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.38\"", 0.3824814330610736, AutoDelete -> True], 
               NumberForm[#, 2]& ], {4528.125, -2165.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.12\"", 0.12202748175725525`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {4921.875, -2165.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.0033\"", 0.0033403662962000723`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {5315.625, -2165.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.026\"", 0.026150419750380606`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {5709.375, -2165.625}, {Center, Center}, {
              360., 360.}]}, {
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.1\"", 0.10132957240378201`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {196.875, -2559.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.46\"", -0.46396073291635087`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {590.625, -2559.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.45\"", 0.44519117914681616`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {984.375, -2559.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.16\"", 0.15702971476225328`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {1378.125, -2559.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.2\"", 0.19939575217419855`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {1771.875, -2559.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.91\"", 0.9119646020986052, AutoDelete -> True], 
               NumberForm[#, 2]& ], {2165.625, -2559.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"1.\"", 0.9999999999999999, AutoDelete -> True], 
               NumberForm[#, 2]& ], {2559.375, -2559.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.25\"", 0.24849222522904624`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {2953.125, -2559.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.46\"", -0.4581678143787641, AutoDelete -> True], 
               NumberForm[#, 2]& ], {3346.875, -2559.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.13\"", 0.13266789085100136`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {3740.625, -2559.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.032\"", 0.032193980781312435`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {4134.375, -2559.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.41\"", 0.40883951219756254`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {4528.125, -2559.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.16\"", 0.1554889955878227, AutoDelete -> True], 
               NumberForm[#, 2]& ], {4921.875, -2559.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.053\"", 0.05320294207673824, AutoDelete -> True], 
               NumberForm[#, 2]& ], {5315.625, -2559.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.08\"", 0.07978353427928886, AutoDelete -> True], 
               NumberForm[#, 2]& ], {5709.375, -2559.375}, {Center, Center}, {
              360., 360.}]}, {
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.43\"", 0.4318237689502275, AutoDelete -> True], 
               NumberForm[#, 2]& ], {196.875, -2953.125}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.13\"", -0.1312167106230113, AutoDelete -> True], 
               NumberForm[#, 2]& ], {590.625, -2953.125}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.14\"", 0.14295775727663615`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {984.375, -2953.125}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.15\"", 0.14549290051709365`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {1378.125, -2953.125}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.091\"", 0.09120406430457663, AutoDelete -> True], 
               NumberForm[#, 2]& ], {1771.875, -2953.125}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.11\"", 0.10691478414084316`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {2165.625, -2953.125}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.25\"", 0.24849222522904624`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {2559.375, -2953.125}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"1.\"", 0.9999999999999997, AutoDelete -> True], 
               NumberForm[#, 2]& ], {2953.125, -2953.125}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.27\"", -0.2660108846592096, AutoDelete -> True], 
               NumberForm[#, 2]& ], {3346.875, -2953.125}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.37\"", 0.36672464706931746`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {3740.625, -2953.125}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.063\"", -0.06330112758808004, AutoDelete -> True], 
               NumberForm[#, 2]& ], {4134.375, -2953.125}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.086\"", -0.08600540230979055, AutoDelete -> True], 
               NumberForm[#, 2]& ], {4528.125, -2953.125}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.073\"", -0.07342836891715476, AutoDelete -> True], 
               NumberForm[#, 2]& ], {4921.875, -2953.125}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.01\"", 0.010325497084564959`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {5315.625, -2953.125}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.018\"", 0.01760782280767119, AutoDelete -> True], 
               NumberForm[#, 2]& ], {5709.375, -2953.125}, {Center, Center}, {
              360., 360.}]}, {
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.16\"", -0.16262985851256256`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {196.875, -3346.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.25\"", 0.24998371946682332`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {590.625, -3346.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.36\"", -0.3592394625241735, AutoDelete -> True], 
               NumberForm[#, 2]& ], {984.375, -3346.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.25\"", -0.24723920846432587`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {1378.125, -3346.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.12\"", -0.12360578411825932`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {1771.875, -3346.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.39\"", -0.3945744794289791, AutoDelete -> True], 
               NumberForm[#, 2]& ], {2165.625, -3346.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.46\"", -0.4581678143787641, AutoDelete -> True], 
               NumberForm[#, 2]& ], {2559.375, -3346.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.27\"", -0.2660108846592096, AutoDelete -> True], 
               NumberForm[#, 2]& ], {2953.125, -3346.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"1.\"", 1.0000000000000013`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {3346.875, -3346.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.26\"", -0.26266548510258386`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {3740.625, -3346.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.11\"", -0.108177581325717, AutoDelete -> True], 
               NumberForm[#, 2]& ], {4134.375, -3346.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.093\"", -0.0933807201300904, AutoDelete -> True], 
               NumberForm[#, 2]& ], {4528.125, -3346.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.27\"", -0.2697270871130358, AutoDelete -> True], 
               NumberForm[#, 2]& ], {4921.875, -3346.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.26\"", -0.26156402294384273`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {5315.625, -3346.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.19\"", -0.19306384237317084`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {5709.375, -3346.875}, {Center, Center}, {
              360., 360.}]}, {
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.34\"", 0.33501740134845226`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {196.875, -3740.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.068\"", -0.06848198894702665, AutoDelete -> True], 
               NumberForm[#, 2]& ], {590.625, -3740.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.078\"", 0.07845401933198953, AutoDelete -> True], 
               NumberForm[#, 2]& ], {984.375, -3740.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.02\"", 0.01997078620647075, AutoDelete -> True], 
               NumberForm[#, 2]& ], {1378.125, -3740.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.038\"", -0.03790295790924063, AutoDelete -> True], 
               NumberForm[#, 2]& ], {1771.875, -3740.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.12\"", 0.12381106845822372`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {2165.625, -3740.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.13\"", 0.13266789085100136`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {2559.375, -3740.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.37\"", 0.36672464706931746`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {2953.125, -3740.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.26\"", -0.26266548510258386`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {3346.875, -3740.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"1.\"", 1.0000000000000002`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {3740.625, -3740.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.0098\"", 0.009759915004767908, AutoDelete -> True], 
               NumberForm[#, 2]& ], {4134.375, -3740.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.18\"", -0.1762870376194998, AutoDelete -> True], 
               NumberForm[#, 2]& ], {4528.125, -3740.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.19\"", -0.18675893959918863`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {4921.875, -3740.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.13\"", -0.1335184796048172, AutoDelete -> True], 
               NumberForm[#, 2]& ], {5315.625, -3740.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.036\"", 0.03620620510864372, AutoDelete -> True], 
               NumberForm[#, 2]& ], {5709.375, -3740.625}, {Center, Center}, {
              360., 360.}]}, {
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.027\"", -0.02716033595355083, AutoDelete -> True], 
               NumberForm[#, 2]& ], {196.875, -4134.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.24\"", -0.23522830668982778`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {590.625, -4134.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.077\"", 0.07653026913356498, AutoDelete -> True], 
               NumberForm[#, 2]& ], {984.375, -4134.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.092\"", -0.09182235816537995, AutoDelete -> True], 
               NumberForm[#, 2]& ], {1378.125, -4134.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.11\"", -0.11290466552608752`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {1771.875, -4134.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.0057\"", 0.005704556732967764, AutoDelete -> True], 
               NumberForm[#, 2]& ], {2165.625, -4134.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.032\"", 0.032193980781312435`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {2559.375, -4134.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.063\"", -0.06330112758808004, AutoDelete -> True], 
               NumberForm[#, 2]& ], {2953.125, -4134.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.11\"", -0.108177581325717, AutoDelete -> True], 
               NumberForm[#, 2]& ], {3346.875, -4134.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.0098\"", 0.009759915004767908, AutoDelete -> True], 
               NumberForm[#, 2]& ], {3740.625, -4134.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"1.\"", 0.9999999999999991, AutoDelete -> True], 
               NumberForm[#, 2]& ], {4134.375, -4134.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.033\"", 0.03336910166307198, AutoDelete -> True], 
               NumberForm[#, 2]& ], {4528.125, -4134.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.14\"", -0.14161094759426504`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {4921.875, -4134.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.2\"", -0.19690005139062736`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {5315.625, -4134.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.039\"", 0.03906024761143982, AutoDelete -> True], 
               NumberForm[#, 2]& ], {5709.375, -4134.375}, {Center, Center}, {
              360., 360.}]}, {
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.18\"", -0.18435347516440556`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {196.875, -4528.125}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.38\"", -0.37982998959721687`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {590.625, -4528.125}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.14\"", 0.14147281498402975`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {984.375, -4528.125}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.014\"", -0.014488749534123647`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {1378.125, -4528.125}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.27\"", 0.2745200025313501, AutoDelete -> True], 
               NumberForm[#, 2]& ], {1771.875, -4528.125}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.38\"", 0.3824814330610736, AutoDelete -> True], 
               NumberForm[#, 2]& ], {2165.625, -4528.125}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.41\"", 0.40883951219756254`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {2559.375, -4528.125}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.086\"", -0.08600540230979055, AutoDelete -> True], 
               NumberForm[#, 2]& ], {2953.125, -4528.125}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.093\"", -0.0933807201300904, AutoDelete -> True], 
               NumberForm[#, 2]& ], {3346.875, -4528.125}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.18\"", -0.1762870376194998, AutoDelete -> True], 
               NumberForm[#, 2]& ], {3740.625, -4528.125}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.033\"", 0.03336910166307198, AutoDelete -> True], 
               NumberForm[#, 2]& ], {4134.375, -4528.125}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"1.\"", 1.0000000000000029`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {4528.125, -4528.125}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.1\"", -0.10131827241808015`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {4921.875, -4528.125}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.085\"", -0.08488425900758363, AutoDelete -> True], 
               NumberForm[#, 2]& ], {5315.625, -4528.125}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.071\"", 0.07114637937583271, AutoDelete -> True], 
               NumberForm[#, 2]& ], {5709.375, -4528.125}, {Center, Center}, {
              360., 360.}]}, {
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.11\"", -0.10731229516150159`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {196.875, -4921.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.21\"", 0.21001174373712214`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {590.625, -4921.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.15\"", 0.14534877148941153`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {984.375, -4921.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.21\"", 0.21213579457349596`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {1378.125, -4921.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.015\"", 0.015444577764267898`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {1771.875, -4921.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.12\"", 0.12202748175725525`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {2165.625, -4921.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.16\"", 0.1554889955878227, AutoDelete -> True], 
               NumberForm[#, 2]& ], {2559.375, -4921.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.073\"", -0.07342836891715476, AutoDelete -> True], 
               NumberForm[#, 2]& ], {2953.125, -4921.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.27\"", -0.2697270871130358, AutoDelete -> True], 
               NumberForm[#, 2]& ], {3346.875, -4921.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.19\"", -0.18675893959918863`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {3740.625, -4921.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.14\"", -0.14161094759426504`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {4134.375, -4921.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.1\"", -0.10131827241808015`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {4528.125, -4921.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"1.\"", 0.9999999999999981, AutoDelete -> True], 
               NumberForm[#, 2]& ], {4921.875, -4921.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.39\"", 0.38860895539977613`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {5315.625, -4921.875}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.051\"", -0.05149345883989447, AutoDelete -> True], 
               NumberForm[#, 2]& ], {5709.375, -4921.875}, {Center, Center}, {
              360., 360.}]}, {
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.17\"", -0.1727379465696265, AutoDelete -> True], 
               NumberForm[#, 2]& ], {196.875, -5315.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.19\"", 0.1886265552394863, AutoDelete -> True], 
               NumberForm[#, 2]& ], {590.625, -5315.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.17\"", 0.16904394478595097`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {984.375, -5315.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.54\"", 0.5440445529021033, AutoDelete -> True], 
               NumberForm[#, 2]& ], {1378.125, -5315.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.4\"", 0.4011927489401661, AutoDelete -> True], 
               NumberForm[#, 2]& ], {1771.875, -5315.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.0033\"", 0.0033403662962000723`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {2165.625, -5315.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.053\"", 0.05320294207673824, AutoDelete -> True], 
               NumberForm[#, 2]& ], {2559.375, -5315.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.01\"", 0.010325497084564959`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {2953.125, -5315.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.26\"", -0.26156402294384273`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {3346.875, -5315.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.13\"", -0.1335184796048172, AutoDelete -> True], 
               NumberForm[#, 2]& ], {3740.625, -5315.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.2\"", -0.19690005139062736`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {4134.375, -5315.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.085\"", -0.08488425900758363, AutoDelete -> True], 
               NumberForm[#, 2]& ], {4528.125, -5315.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.39\"", 0.38860895539977613`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {4921.875, -5315.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"1.\"", 0.9999999999999996, AutoDelete -> True], 
               NumberForm[#, 2]& ], {5315.625, -5315.625}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.03\"", -0.030334277118888454`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {5709.375, -5315.625}, {Center, Center}, {
              360., 360.}]}, {
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.17\"", -0.1702708808314493, AutoDelete -> True], 
               NumberForm[#, 2]& ], {196.875, -5709.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.1\"", -0.10455105663096541`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {590.625, -5709.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.045\"", -0.04494523878070061, AutoDelete -> True], 
               NumberForm[#, 2]& ], {984.375, -5709.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.075\"", 0.07505030107028399, AutoDelete -> True], 
               NumberForm[#, 2]& ], {1378.125, -5709.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.025\"", -0.0253927905604893, AutoDelete -> True], 
               NumberForm[#, 2]& ], {1771.875, -5709.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.026\"", 0.026150419750380606`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {2165.625, -5709.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.08\"", 0.07978353427928886, AutoDelete -> True], 
               NumberForm[#, 2]& ], {2559.375, -5709.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.018\"", 0.01760782280767119, AutoDelete -> True], 
               NumberForm[#, 2]& ], {2953.125, -5709.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.19\"", -0.19306384237317095`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {3346.875, -5709.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.036\"", 0.03620620510864371, AutoDelete -> True], 
               NumberForm[#, 2]& ], {3740.625, -5709.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.039\"", 0.03906024761143976, AutoDelete -> True], 
               NumberForm[#, 2]& ], {4134.375, -5709.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"0.071\"", 0.07114637937583275, AutoDelete -> True], 
               NumberForm[#, 2]& ], {4528.125, -5709.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.051\"", -0.05149345883989446, AutoDelete -> True], 
               NumberForm[#, 2]& ], {4921.875, -5709.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"-0.03\"", -0.030334277118888437`, AutoDelete -> True], 
               NumberForm[#, 2]& ], {5315.625, -5709.375}, {Center, Center}, {
              360., 360.}], 
             InsetBox[
              TagBox[
               InterpretationBox[
               "\"1.\"", 0.9999999999999993, AutoDelete -> True], 
               NumberForm[#, 2]& ], {5709.375, -5709.375}, {Center, Center}, {
              360., 360.}]}}, {}}, ContentSelectable -> True, ImageSize -> 
          500, PlotRangePadding -> {6, 5}]}]},
      "RowDefault"]}
   },
   DefaultBaseStyle->"Column",
   GridBoxAlignment->{"Columns" -> {{Right}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{0}}}],
  "Column"]], "Output",
 CellChangeTimes->{{3.5854988050807543`*^9, 3.585498904984374*^9}, 
   3.585911175357383*^9, 3.585999138172324*^9}]
}, {2}]],

Cell["\<\
Note the relatively strong correlation between nitrate and ammonia, and \
between phosphate and orthophosphate (this last one is expected on domain \
grounds).\
\>", "Text",
 CellChangeTimes->{{3.585499035256184*^9, 3.5854990618474913`*^9}, {
  3.586022129443694*^9, 3.5860221404580297`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Applying Correlations", "Title",
 CellChangeTimes->{{3.585417299136742*^9, 3.585417302023638*^9}, {
  3.585486190840365*^9, 3.585486194479013*^9}, {3.5854955216795692`*^9, 
  3.585495536078971*^9}, {3.585495869960773*^9, 3.585495877024088*^9}, {
  3.5854984265503893`*^9, 3.585498429740182*^9}, {3.585499094894772*^9, 
  3.585499097542303*^9}}],

Cell["\<\
Unfortunately there are no missing values for which we could exploit the \
nitrate-ammonia correlation:\
\>", "Text",
 CellChangeTimes->{{3.5859993371642847`*^9, 3.585999355427636*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"trimmed", "[", 
    RowBox[{"NO3", ",", "\"\<missing\>\""}], "]"}], ",", 
   RowBox[{"trimmed", "[", 
    RowBox[{"NH4", ",", "\"\<missing\>\""}], "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.574776456588432*^9, 3.5747764579065075`*^9}, {
  3.574789225987793*^9, 3.5747892425767417`*^9}, {3.5854991355972357`*^9, 
  3.5854991428784103`*^9}, {3.585499181927496*^9, 3.5854992098185596`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", "}"}], ",", 
   RowBox[{"{", "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5854992106145144`*^9, 3.585999236874363*^9}]
}, Open  ]],

Cell["But there is a missing phosphate value:", "Text",
 CellChangeTimes->{{3.585999364363592*^9, 3.585999370427465*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"trimmed", "[", 
    RowBox[{"PO4", ",", "\"\<missing\>\""}], "]"}], ",", 
   RowBox[{"trimmed", "[", 
    RowBox[{"oPO4", ",", "\"\<missing\>\""}], "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.574776456588432*^9, 3.5747764579065075`*^9}, {
  3.574789225987793*^9, 3.5747892425767417`*^9}, {3.5854991355972357`*^9, 
  3.5854991428784103`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"{", "28", "}"}], "}"}], ",", 
   RowBox[{"{", "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.574776451732154*^9, 3.57477645830153*^9}, 
   3.5747892431167727`*^9, 3.5758008496292887`*^9, 3.585499143544156*^9, 
   3.585999237781467*^9}]
}, Open  ]],

Cell["\<\
Build a linear model to fill in a missing phosphate value. Note we work with \
ordered pairs in which neither value is missing:\
\>", "Text",
 CellChangeTimes->{{3.585499152813651*^9, 3.585499178333126*^9}, {
  3.585499243166008*^9, 3.585499269755247*^9}, {3.5854993071552677`*^9, 
  3.585499309794592*^9}, {3.5854993691371613`*^9, 3.585499385625112*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lm", "=", 
  RowBox[{"LinearModelFit", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DeleteCases", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"trimmed", "[", 
          RowBox[{"oPO4", ",", "\"\<raw\>\""}], "]"}], ",", 
         RowBox[{"trimmed", "[", 
          RowBox[{"PO4", ",", "\"\<raw\>\""}], "]"}]}], "}"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"___", ",", 
        RowBox[{"Missing", "[", "]"}], ",", "___"}], "}"}]}], "]"}], ",", 
    "oPO4", ",", "oPO4"}], "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.58549938881157*^9, 3.585499398226409*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"FittedModel", "[", 
   TagBox[
    PanelBox[
     TagBox[
      RowBox[{"42.897046403408034`", "\[VeryThinSpace]", "+", 
       RowBox[{"1.2930608923116587`", " ", "oPO4"}]}],
      Short[#, 2]& ],
     FrameMargins->5],
    Editable -> False], "]"}],
  InterpretTemplate[
  FittedModel[{
    "Linear", {42.897046403408034`, 
     1.2930608923116587`}, {{$CellContext`oPO4}, {1, $CellContext`oPO4}}, {0, 
     0}}, CompressedData["
1:eJxTTMoPSmViYGBgBOKjDDDwwX6UHqVH6VF6lB6lsdEACeTrnQ==
    "], CompressedData["
1:eJyFVmtMk2cUbpAwhoTgHEoYKF5QBC8IqFzmOFzk3looJYViKbdSLqUtCsHb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    "], CompressedData["
1:eJyllmtI1EEQwP+YhJVIL0vC6rQsU8zqskwrLxPz3fm48IWdl152mZ5SklFx
0YeIogcRaVGJHZoaISIVJnFIWsQVFoqURH3QXiAZaVkpdLcLM86E3If+8Gf5
Mbuzs/Pa9TOUphW6KYrS6fido/yGo8SgydYQth8Brrv2WNVs2g1842t9V+KV
FOBl/b+Om3yT6XrNOso1OD9p4+ltel0ssNH5rYhm6yMpW1YBh75dPv2ELoDK
lUDGaxgHMZ4DXFUy96StkdmrrKdsiwH2KNd22K0nqDz8GLBafKEu7PFwwf6M
ZzOOYMzPn8bsL6FsSZjyvFernd9iKjez+Cq/oyi7g9xq3jKz71IRsINumZ8b
gW9HDBgf/MgHHpnoOfz5HuqvnfUlx3jODJw34m2tTi5j+y9nzPLlH3/PdzGf
5cekfJPxZP5QljL2Z/y/o+JCH8pjzhR//NMwUzOVXI4Yn1MLXr/4mT7K9I0A
P7c7v3Eqr9oP68feJVQUR5qo/gEDZUss40TKPvmUlSzKeh2wqM+gTWx+NOVm
ZJm/rD7025kc+4esf54PGsrdOcDtn4Lj1Gq0X/orCbhfneiW0VkJHGBvnWiq
xfy1jlvf1LdhfYih3Ux5bC9lVR5w7rScgExvA5UP72H2bwS+OHQ0KswL+3t2
QeS7nbpMOv99PHCRc4EuisprNgO3xXu6BT/B+hD6z8XT+Sp2n2jR/9Lf4cxe
lh8WnN/6tOLRTVMKldtSgeV9sIzpWwQ83vDtVbLBD9h9l1dIy1A02w9ZlFPZ
BuqPXuwnuec7RgNzPYFFf8rC+In7rOsAs8cAfPdhZeP2vgIqr8H+uNbjjm/2
QbRH+pudX7uT2Y/+E/G9zOppDO+DTlVzeVHqNmB5H8cx/Ywn5ZO0t5Cyjd03
epa/FqZPw+pLYed7r6V8QQ8s6w3j8dLf8QAJYu8BC+aHzPd0Zu8Odn5kEb8P
3D5ufw7lSfkq74sNbD3vh7zfYD2I+h5l/tViPonze2K8ZT3x98pWth/mg+g/
Xwx0v8uYf9J+rBdZXyHAsn9ifOR7MIuun4f9O2Zhz317O94fIr9b91H5WTyf
7JeHgGV/yQB2hmvQB/cX8e3F/cR5Bnk/ZO+BSfd7nrPAmpYAh7Rcd5xoBrDI
B6MX08ffYz7Aol94h1F5Dd5HCY5yPrUa+6NQXxdD51/Afir8+R3zp9QR7mdl
rN9qsJ5XOh3cpgaW73Nk3q+5XAzd+D4U/bcR9cv+wupJ0Wr+Ag/6ehg=
    "], 
    Function[Null, 
     Internal`LocalizedBlock[{$CellContext`oPO4}, #], {HoldAll}]]& ],
  Editable->False,
  SelectWithContents->True,
  Selectable->True]], "Output",
 CellChangeTimes->{{3.585499392879683*^9, 3.5854993987466297`*^9}, 
   3.585499436380658*^9, 3.585999239386166*^9, 3.585999389395596*^9}]
}, Open  ]],

Cell["Visualized:", "Text",
 CellChangeTimes->{{3.5854996044375553`*^9, 3.585499606644335*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"pairs", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"trimmed", "[", 
         RowBox[{"oPO4", ",", "\"\<raw\>\""}], "]"}], ",", 
        RowBox[{"trimmed", "[", 
         RowBox[{"PO4", ",", "\"\<raw\>\""}], "]"}]}], "}"}], "]"}]}], "}"}], 
   ",", "\[IndentingNewLine]", 
   RowBox[{"Show", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ListPlot", "[", 
      RowBox[{"pairs", ",", "\[IndentingNewLine]", 
       RowBox[{"Epilog", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"PointSize", "[", "0.04", "]"}], ",", "Pink", ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"pairs", "[", 
              RowBox[{"[", 
               RowBox[{"28", ",", "1"}], "]"}], "]"}], ",", 
             RowBox[{"lm", "@", 
              RowBox[{"pairs", "[", 
               RowBox[{"[", 
                RowBox[{"28", ",", "1"}], "]"}], "]"}]}]}], "}"}], "]"}]}], 
         "}"}]}]}], "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"lm", "[", "oPO4", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"oPO4", ",", "0", ",", "350"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Pink"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"oPO4", ",", "PO4"}], "}"}]}]}], "\[IndentingNewLine]", 
    "]"}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.58549960962674*^9, 3.585499699924831*^9}, {
  3.585499740290786*^9, 3.585499931545396*^9}, {3.5854999874456873`*^9, 
  3.585500021824402*^9}, {3.5855071393169937`*^9, 3.585507139900077*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, 
     {RGBColor[0.24720000000000014`, 0.24, 0.6], PointBox[CompressedData["
1:eJyFVmtMk2cUbpAwhoTgHEoYKF5QBC8IqFzmOFzk3looJYViKbdSLqUtCsHb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       "]]}, {}}, {}}, {{}, {}, 
    {RGBColor[1, 0.5, 0.5], LineBox[CompressedData["
1:eJwVz3k41HkAx3GJ2tEeSi3yRGKzpZ4oish8OmaSJDcNU5NjEuOYMV8zzPhF
plrpoJZI0SFJzkKS2nQspdxFB5JNwjSiYTtk2z/ez/vvl6FfuGugqoqKypbv
/X9p1ZesVGWn3ZnN8ypbBAycebteskNyg96g0T6ZJmPg0iWdZCNJPf3rg+SN
PmkMFGoknFSXvKBvs1dr773OwDKbyuyxmEH6LMag8qMKExGtrgsUMV/oMrvr
K7SPMpFicMZ/MGYGgsw9in0ub8TZ+0zZuxg9mGkfzv2ndxNM0vU1a88tAcND
i8oscwKr07buCsMS7jdLXzZluOBDC+mYo22Lnufz5bQGNxjLrLQsbq1Fqbme
YM5yT8yb28AsMWfgd+nnPPtQb4w1btA1Vtjj9WSAu1MHC+OraloNMx0hPpI2
QrNi4/zj4C2fpjqjTLNwnTxsB1YfDYxjd7tAl3sxoXmAA5FTgbVpphsKbg7Y
3ab54UGfsm+NkwcKTqaM0oz8ofFLib/jQi84zaZe27oHYMSignuvyxt3p7Pz
p/ID8XBgibVVNQvPT8QXXL3ARUV07uRwsi+2F9LybrXtwqZpPEct5nZU2Mqk
bEUQuDNdynQ0OSgO2pD0xjAYEv1j+3zlHEh/HhdMQQj+iEyy0+/ciUFnxZ/T
ongwsNzP31vnh1qdzSXc3FAkKnN36eX4I4qVkcO6E4bBiT2M5ccCUGu1tHXV
WDjmq+/pi40IBKnbFtp2MALd4j1TeA5c2F1rCK3S5iPNwkqtY+UueAm5M1JL
+DBU/PpQrBUEnzBRqjVdgJwPhaITqrtRvPJydcszAUo5zGxv+W5U1SRzMviR
SGlQO+hUF4yiRMXwoslI7JZJfO+Uh+CjAV+/OF2I2dY6I8HHeTAaDbH6ZkLg
wKqYUsELBS1RpzGmjEB098dPlHcY6PK3qkOOURCbJl6VWoSDc8TMyORFFK7L
uxZLZ0agZSLzlScRwYBxiN0WF4Gl+XEHndXFqHdd/XhCHgHoapeKjokRKbtn
xg3g47xnk/C4aTRk5T3K/hY+hptUf4uuikaKxouifAcBDut6C9w8YtA750nO
mtsC9BjvsPWRxyB7vt/XgaWRMAjtHlkikcBra/3G9pxIFCXsZY7OlkIcW/ux
U0uIhe1Z+xNypOjeea+rPE4ITzlv/VrzWKwLPl39aEyI9mb26dEHsfhZQPs6
EUCA0drecG8KJZ5fpg5wCfj9efOGWBRcbeQzngYRnO9M9ApiU0hTa9Yr4hGo
122u5/hRMDiRbrNdSFB/qvGKC4+CWbWJ5FYCgRezPX5FHAW3aczP1DmC8Iw+
g/GLFMYGVqmG5BCcPVK7LTKfQnrjIg2vXILWhLzjigIKL9N/mrssn8AyLHh6
fymFANMn1t2lBJ/XvX/fcYNClHNANL2G4MCQ8mZVIwUdS89407sElT1Px1e2
UKjStU/Uvk/w7uk186ttFL69Ns1Q1BE41kRfuPyMwgEyWpndRDArbeLQqV4K
i1lvbie1EDCSuv7W6aPwyK69TtRGEBX3l0pqPwXNH250bO0geBYcLzwsp3Bl
qOCVzXMCDY5fEW2YgntzVr/JSwIbj/X9+0a++8qTh7W6CHgOxgtUld99J/f+
O9lNkEVX96XGKfwHQypKSw==
      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["oPO4", TraditionalForm], 
    FormBox["PO4", TraditionalForm]},
  AxesOrigin->{0, 0},
  Epilog->{
    PointSize[0.04], 
    RGBColor[1, 0.5, 0.5], 
    PointBox[{4., 48.069289972654666`}]},
  Method->{"ScalingFunctions" -> None},
  PlotRange->{{0, 344.77452500000004`}, {0, 771.59998}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.5854999048013983`*^9, 3.585499932961707*^9}, {
   3.5854999904638357`*^9, 3.5855000233050537`*^9}, 3.585507140180665*^9, 
   3.585999241586088*^9, 3.58599928134601*^9, 3.585999396540854*^9}]
}, {2}]],

Cell["\<\
Here is a function for applying a model to a column in a dataset (yielding a \
fresh dataset):\
\>", "Text",
 CellChangeTimes->{{3.585499511414748*^9, 3.5854995136543016`*^9}, {
  3.585999418674457*^9, 3.585999454417274*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"modelFill", "[", 
   RowBox[{"set_", ",", "to_", ",", "from_", ",", "model_"}], "]"}], ":=", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"dat", "=", 
       RowBox[{"set", "[", "All", "]"}]}], ",", 
      RowBox[{"holes", "=", 
       RowBox[{"Flatten", "@", 
        RowBox[{"set", "[", 
         RowBox[{"to", ",", "\"\<missing\>\""}], "]"}]}]}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Scan", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"dat", "[", 
           RowBox[{"[", 
            RowBox[{"#", ",", 
             RowBox[{"to", "/.", "numberedColumns"}]}], "]"}], "]"}], "=", 
          RowBox[{"model", "[", 
           RowBox[{"dat", "[", 
            RowBox[{"[", 
             RowBox[{"#", ",", 
              RowBox[{"from", "/.", "numberedColumns"}]}], "]"}], "]"}], 
           "]"}]}], ")"}], "&"}], ",", "\[IndentingNewLine]", "holes"}], 
      "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"columnize", "@", "dat"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.5747892866442623`*^9, 3.574789302327159*^9}, {
  3.5747893987896767`*^9, 3.5747894022198725`*^9}, {3.5747894597221613`*^9, 
  3.5747894783382263`*^9}, {3.574789734289866*^9, 3.574789744528452*^9}, {
  3.5747897996246033`*^9, 3.5747899768957424`*^9}, {3.5747908026089706`*^9, 
  3.574790826781353*^9}, {3.5854994624171753`*^9, 3.585499501023966*^9}, {
  3.585999457365287*^9, 3.585999458030615*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"filled", "=", 
   RowBox[{"modelFill", "[", 
    RowBox[{"trimmed", ",", "PO4", ",", "oPO4", ",", "lm"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.585499516166904*^9, 3.585499535342174*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"trimmed", "[", 
       RowBox[{"PO4", ",", "\"\<raw\>\""}], "]"}], "[", 
      RowBox[{"[", "#", "]"}], "]"}], ",", 
     RowBox[{
      RowBox[{"filled", "[", 
       RowBox[{"PO4", ",", "\"\<raw\>\""}], "]"}], "[", 
      RowBox[{"[", "#", "]"}], "]"}]}], "}"}], "&"}], "@", "28"}]], "Input",
 CellChangeTimes->{{3.5854995374449997`*^9, 3.585499573285822*^9}, {
  3.585503765883704*^9, 3.5855037742156*^9}, {3.585999473284136*^9, 
  3.585999475650875*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Missing", "[", "]"}], ",", "48.069289972654666`"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.585499564741584*^9, 3.5854995737454777`*^9}, 
   3.585503774701483*^9, {3.585999460414022*^9, 3.58599947652842*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Conditional Distributions", "Title",
 CellChangeTimes->{{3.585417299136742*^9, 3.585417302023638*^9}, {
  3.585486190840365*^9, 3.585486194479013*^9}, {3.5854955216795692`*^9, 
  3.585495536078971*^9}, {3.585495869960773*^9, 3.585495877024088*^9}, {
  3.5854984265503893`*^9, 3.585498429740182*^9}, {3.585499094894772*^9, 
  3.585499097542303*^9}, {3.58550056152886*^9, 3.585500572056347*^9}, {
  3.5855041255687923`*^9, 3.585504130967813*^9}}],

Cell["\<\
It is also possible to impute based on correlations with nominal variables. \
For example, if we noticed a strong relationship between phosphate values and \
small rivers, we could impute using a centrality measure of the phosphate \
values corresponding to small rivers.  To do this we need some machinery for \
generating distributions conditioned on factorized variables.\
\>", "Text",
 CellChangeTimes->{{3.5855041517351713`*^9, 3.5855041931581917`*^9}, {
  3.585505188786007*^9, 3.58550520123384*^9}, {3.585911365256357*^9, 
  3.585911427319317*^9}, {3.585999497522667*^9, 3.585999514177639*^9}, {
  3.5860966967554827`*^9, 3.5860967015219183`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"condition", ",", "pivot"}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"pivot", "[", 
    RowBox[{"set_", ",", "on_"}], "]"}], ":=", 
   RowBox[{"Module", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"trans", "=", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"set", "[", "All", "]"}], ",", 
           RowBox[{"set", "[", "on", "]"}]}], "}"}], "\[Transpose]"}]}], ",", 
       "med"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"med", "=", 
       RowBox[{"SortBy", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Rule", "[", 
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", 
                RowBox[{"-", "1"}]}], "]"}], "]"}], ",", 
             RowBox[{"columnize", "@", 
              RowBox[{"#", "[", 
               RowBox[{"[", 
                RowBox[{"All", ",", "1"}], "]"}], "]"}]}]}], "]"}], "&"}], "/@", 
          RowBox[{"GatherBy", "[", 
           RowBox[{"trans", ",", "Last"}], "]"}]}], ",", "First"}], "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "Copy", " ", "factor", " ", "orderings", " ", "to", " ", "new", " ", 
        "sets"}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"Map", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Function", "[", 
           RowBox[{
            RowBox[{"{", "nominal", "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"fordering", "[", 
              RowBox[{"#", ",", "nominal"}], "]"}], "=", 
             RowBox[{"fordering", "[", 
              RowBox[{"set", ",", "nominal"}], "]"}]}]}], 
           "\[IndentingNewLine]", "]"}], ",", 
          RowBox[{"set", "[", 
           RowBox[{"All", ",", "\"\<nominals\>\""}], "]"}]}], 
         "\[IndentingNewLine]", "]"}], "&"}], "/@", 
       RowBox[{"med", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"set", "[", 
         RowBox[{"on", ",", "\"\<factorized\>\""}], "]"}], ",", 
        RowBox[{"med", "[", 
         RowBox[{"[", 
          RowBox[{"fordering", "[", 
           RowBox[{"set", ",", "on"}], "]"}], "]"}], "]"}], ",", "med"}], 
       "]"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"condition", "[", 
    RowBox[{"set_", ",", "col_", ",", 
     RowBox[{"{", "}"}]}], "]"}], ":=", 
   RowBox[{"set", "[", "col", "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"condition", "[", 
   RowBox[{"set_", ",", "col_", ",", "conds_List"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"pivot", "[", 
    RowBox[{"set", ",", 
     RowBox[{"First", "@", "conds"}]}], "]"}], "/.", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Rule", "[", 
     RowBox[{"cat_", ",", "subset_"}], "]"}], "\[RuleDelayed]", 
    RowBox[{"Rule", "[", 
     RowBox[{"cat", ",", 
      RowBox[{"condition", "[", 
       RowBox[{"subset", ",", "col", ",", 
        RowBox[{"Rest", "@", "conds"}]}], "]"}]}], "]"}]}]}]}]}], "Input",
 CellChangeTimes->{{3.5747107211921825`*^9, 3.5747107240973487`*^9}, {
   3.5747128386022916`*^9, 3.5747128480458317`*^9}, {3.5747130146243596`*^9, 
   3.5747130304442644`*^9}, {3.5747130628731194`*^9, 
   3.5747130630231276`*^9}, {3.5747225962010665`*^9, 
   3.5747225971411204`*^9}, {3.5747935534873114`*^9, 3.574793571605348*^9}, {
   3.5747938930677347`*^9, 3.5747939597625494`*^9}, {3.574794016354786*^9, 
   3.5747940271804056`*^9}, {3.5747940809594812`*^9, 
   3.5747941769309707`*^9}, {3.574794802512752*^9, 3.574794803617815*^9}, {
   3.575025380071663*^9, 3.5750253852709603`*^9}, 3.575025445720418*^9, {
   3.575025737403101*^9, 3.5750257851258307`*^9}, {3.5750259768527975`*^9, 
   3.575025978269878*^9}, {3.575026113552616*^9, 3.5750261469675274`*^9}, {
   3.5750261861897707`*^9, 3.5750262130643077`*^9}, {3.5750262785940557`*^9, 
   3.5750262798751287`*^9}, {3.57502631066689*^9, 3.575026400040002*^9}, {
   3.5750264367491016`*^9, 3.5750265014888043`*^9}, {3.5855042435936832`*^9, 
   3.585504268321398*^9}, {3.585504319737174*^9, 3.5855043774694138`*^9}, {
   3.585504441126053*^9, 3.5855045228114*^9}, {3.585504556170137*^9, 
   3.585504607097177*^9}, {3.5859995177170773`*^9, 3.585999518430896*^9}, 
   3.585999645650237*^9}],

Cell["What is the distribution of a1 conditioned on river size?", "Text",
 CellChangeTimes->{{3.585504794666568*^9, 3.5855048079950247`*^9}}],

Cell[BoxData[
 RowBox[{"condition", "[", 
  RowBox[{"med", ",", "a1", ",", 
   RowBox[{"{", "size", "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.574618985007961*^9, 3.5746189932422266`*^9}, 
   3.5746192547951603`*^9, {3.5747070320211744`*^9, 3.574707035655382*^9}, {
   3.574707088221389*^9, 3.574707092701645*^9}, {3.5747201506751904`*^9, 
   3.574720167614159*^9}, {3.574762581533824*^9, 3.574762586142088*^9}, {
   3.574770927384179*^9, 3.574770930736371*^9}, 3.574794182251275*^9, 
   3.574795164512457*^9, {3.575216572727028*^9, 3.5752165738063993`*^9}}],

Cell["Visualized:", "Text",
 CellChangeTimes->{{3.585504831912891*^9, 3.585504836904928*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"dat", "=", 
     RowBox[{"condition", "[", 
      RowBox[{"med", ",", "a1", ",", 
       RowBox[{"{", "size", "}"}]}], "]"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"BoxWhiskerChart", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Reverse", "@", 
      RowBox[{"dat", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2"}], "]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<Outliers\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"\"\<MedianMarker\>\"", ",", "White"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"BarOrigin", "\[Rule]", "Left"}], ",", "\[IndentingNewLine]", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<River Size\>\"", ",", "\"\<A1\>\""}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"ChartLabels", "\[Rule]", 
      RowBox[{"Reverse", "@", 
       RowBox[{"dat", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "1"}], "]"}], "]"}]}]}]}], "\[IndentingNewLine]",
     "]"}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.5746190644535785`*^9, 3.5746190679005814`*^9}, {
  3.5746191888876953`*^9, 3.5746192080582523`*^9}, {3.574619257601432*^9, 
  3.5746193337931733`*^9}, {3.5747070952837925`*^9, 3.5747070981639576`*^9}, {
  3.574708635731901*^9, 3.5747086361179233`*^9}, {3.5747201819629803`*^9, 
  3.574720183448065*^9}}],

Cell[BoxData[
 GraphicsBox[{
   {Opacity[0], 
    PointBox[{{-4.49, 0.4990857618568485}, {94.28999999999999, 
     3.5009142381431513`}}]}, 
   {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], {}, 
    {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
     {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
      TagBox[
       TooltipBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          GraphicsGroupBox[{Antialiasing -> False, 
            
            PolygonBox[{{17.3, 0.7509076238812251}, {17.3, 
             1.2490923761187749`}, {0., 1.2490923761187749`}, {0., 
             0.7509076238812251}}], {}, {{
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox["\"\[FilledSmallCircle]\"", 10, 
                  GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
               52.4, 1.}], 
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox["\"\[FilledSmallCircle]\"", 10, 
                  GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
               48.3, 1.}], 
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox["\"\[FilledSmallCircle]\"", 10, 
                  GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
               50.4, 1.}], 
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox["\"\[FilledSmallCircle]\"", 10, 
                  GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
               56.8, 1.}]}, {}}, {}, {
             GrayLevel[0], 
             GrayLevel[1], 
             
             LineBox[{{2.4, 1.2490923761187749`}, {2.4, 
              0.7509076238812251}}]}, {}, {
             GrayLevel[0], 
             GrayLevel[0.5], 
             LineBox[{{{0., 1.}, {0., 1.}}, {{17.3, 1.}, {39.7, 1.}}}]}, {
             GrayLevel[0], 
             GrayLevel[0.5], 
             
             LineBox[{{{0., 1.1245461880593874`}, {0., 
              0.8754538119406126}}, {{39.7, 1.1245461880593874`}, {39.7, 
              0.8754538119406126}}}]}, {}}]},
         ImageSizeCache->{{69.5857864376269, 242.45644883267076`}, {
          26.585786437626894`, 59.41421356237312}}],
        StyleBox[
         TagBox[
          GridBox[{{
             StyleBox["\"max\"", Bold, StripOnInput -> False], "56.8`"}, {
             StyleBox["\"75%\"", Bold, StripOnInput -> False], "17.3`"}, {
             StyleBox["\"median\"", Bold, StripOnInput -> False], "2.4`"}, {
             StyleBox["\"25%\"", Bold, StripOnInput -> False], "0.`"}, {
             StyleBox["\"min\"", Bold, StripOnInput -> False], "0.`"}}, 
           GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
           AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}, "Rows" -> {
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}}, 
           GridBoxFrame -> {
            "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, BaseStyle -> 
           Directive[
             AbsoluteThickness[1], 
             Dashing[{}]]], "Grid"], {
          GrayLevel[0]}, StripOnInput -> False]],
       Annotation[#, 
        Style[
         Grid[{{
            Style["max", Bold], 56.8}, {
            Style["75%", Bold], 17.3}, {
            Style["median", Bold], 2.4}, {
            Style["25%", Bold], 0.}, {
            Style["min", Bold], 0.}}, Dividers -> {{
             Directive[
              GrayLevel[0.3]], {
              Directive[
               GrayLevel[0.3]]}, 
             Directive[
              GrayLevel[0.3]]}, {
             Directive[
              GrayLevel[0.3]], {
              Directive[
               GrayLevel[0.3]]}, 
             Directive[
              GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, Frame -> 
          GrayLevel[0], BaseStyle -> Directive[
            AbsoluteThickness[1], 
            Dashing[{}]]], {
          GrayLevel[0]}], "Tooltip"]& ]}, 
     {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
      TagBox[
       TooltipBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          GraphicsGroupBox[{Antialiasing -> False, 
            
            PolygonBox[{{12.6, 1.7509076238812251`}, {12.6, 
             2.249092376118775}, {1.4, 2.249092376118775}, {1.4, 
             1.7509076238812251`}}], {}, {{
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox["\"\[FilledSmallCircle]\"", 10, 
                  GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
               41., 2.}], 
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox["\"\[FilledSmallCircle]\"", 10, 
                  GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
               43.7, 2.}], 
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox["\"\[FilledSmallCircle]\"", 10, 
                  GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
               42.5, 2.}], 
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox["\"\[FilledSmallCircle]\"", 10, 
                  GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
               39.7, 2.}], 
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox["\"\[FilledSmallCircle]\"", 10, 
                  GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
               32.8, 2.}]}, {
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox["\"\[FilledSmallCircle]\"", 10, 
                  GrayLevel[0.5], StripOnInput -> False], TraditionalForm]], {
               64.9, 2.}], 
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox["\"\[FilledSmallCircle]\"", 10, 
                  GrayLevel[0.5], StripOnInput -> False], TraditionalForm]], {
               58.7, 2.}], 
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox["\"\[FilledSmallCircle]\"", 10, 
                  GrayLevel[0.5], StripOnInput -> False], TraditionalForm]], {
               64.3, 2.}], 
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox["\"\[FilledSmallCircle]\"", 10, 
                  GrayLevel[0.5], StripOnInput -> False], TraditionalForm]], {
               46.6, 2.}], 
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox["\"\[FilledSmallCircle]\"", 10, 
                  GrayLevel[0.5], StripOnInput -> False], TraditionalForm]], {
               86.6, 2.}]}}, {}, {
             GrayLevel[0], 
             GrayLevel[1], 
             
             LineBox[{{3.6, 2.249092376118775}, {3.6, 
              1.7509076238812251`}}]}, {}, {
             GrayLevel[0], 
             GrayLevel[0.5], 
             LineBox[{{{1.4, 2.}, {0., 2.}}, {{12.6, 2.}, {28.1, 2.}}}]}, {
             GrayLevel[0], 
             GrayLevel[0.5], 
             
             LineBox[{{{0., 2.124546188059387}, {0., 1.8754538119406126`}}, {{
              28.1, 2.124546188059387}, {28.1, 1.8754538119406126`}}}]}, {}}]},
         ImageSizeCache->{{69.5857864376269, 
          330.20927329106314`}, {-33.414213562373114`, -0.5857864376268935}}],
        StyleBox[
         TagBox[
          GridBox[{{
             StyleBox["\"max\"", Bold, StripOnInput -> False], "86.6`"}, {
             StyleBox["\"75%\"", Bold, StripOnInput -> False], "12.6`"}, {
             StyleBox["\"median\"", Bold, StripOnInput -> False], "3.6`"}, {
             StyleBox["\"25%\"", Bold, StripOnInput -> False], "1.4`"}, {
             StyleBox["\"min\"", Bold, StripOnInput -> False], "0.`"}}, 
           GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
           AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}, "Rows" -> {
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}}, 
           GridBoxFrame -> {
            "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, BaseStyle -> 
           Directive[
             AbsoluteThickness[1], 
             Dashing[{}]]], "Grid"], {
          GrayLevel[0]}, StripOnInput -> False]],
       Annotation[#, 
        Style[
         Grid[{{
            Style["max", Bold], 86.6}, {
            Style["75%", Bold], 12.6}, {
            Style["median", Bold], 3.6}, {
            Style["25%", Bold], 1.4}, {
            Style["min", Bold], 0.}}, Dividers -> {{
             Directive[
              GrayLevel[0.3]], {
              Directive[
               GrayLevel[0.3]]}, 
             Directive[
              GrayLevel[0.3]]}, {
             Directive[
              GrayLevel[0.3]], {
              Directive[
               GrayLevel[0.3]]}, 
             Directive[
              GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, Frame -> 
          GrayLevel[0], BaseStyle -> Directive[
            AbsoluteThickness[1], 
            Dashing[{}]]], {
          GrayLevel[0]}], "Tooltip"]& ]}, 
     {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
      TagBox[
       TooltipBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          GraphicsGroupBox[{Antialiasing -> False, 
            
            PolygonBox[{{46.8, 2.750907623881225}, {46.8, 
             3.249092376118775}, {4.1, 3.249092376118775}, {4.1, 
             2.750907623881225}}], {}, {{}, {}}, {}, {
             GrayLevel[0], 
             GrayLevel[1], 
             
             LineBox[{{19.4, 3.249092376118775}, {19.4, 
              2.750907623881225}}]}, {}, {
             GrayLevel[0], 
             GrayLevel[0.5], 
             LineBox[{{{4.1, 3.}, {0., 3.}}, {{46.8, 3.}, {89.8, 3.}}}]}, {
             GrayLevel[0], 
             GrayLevel[0.5], 
             
             LineBox[{{{0., 3.124546188059387}, {0., 2.875453811940613}}, {{
              89.8, 3.124546188059387}, {89.8, 2.875453811940613}}}]}, {}}]},
         ImageSizeCache->{{69.5857864376269, 
          337.4142135623731}, {-93.41421356237312, -60.58578643762689}}],
        StyleBox[
         TagBox[
          GridBox[{{
             StyleBox["\"max\"", Bold, StripOnInput -> False], "89.8`"}, {
             StyleBox["\"75%\"", Bold, StripOnInput -> False], "46.8`"}, {
             StyleBox["\"median\"", Bold, StripOnInput -> False], "19.4`"}, {
             StyleBox["\"25%\"", Bold, StripOnInput -> False], "4.1`"}, {
             StyleBox["\"min\"", Bold, StripOnInput -> False], "0.`"}}, 
           GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
           AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}, "Rows" -> {
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}}, 
           GridBoxFrame -> {
            "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, BaseStyle -> 
           Directive[
             AbsoluteThickness[1], 
             Dashing[{}]]], "Grid"], {
          GrayLevel[0]}, StripOnInput -> False]],
       Annotation[#, 
        Style[
         Grid[{{
            Style["max", Bold], 89.8}, {
            Style["75%", Bold], 46.8}, {
            Style["median", Bold], 19.4}, {
            Style["25%", Bold], 4.1}, {
            Style["min", Bold], 0.}}, Dividers -> {{
             Directive[
              GrayLevel[0.3]], {
              Directive[
               GrayLevel[0.3]]}, 
             Directive[
              GrayLevel[0.3]]}, {
             Directive[
              GrayLevel[0.3]], {
              Directive[
               GrayLevel[0.3]]}, 
             Directive[
              GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, Frame -> 
          GrayLevel[0], BaseStyle -> Directive[
            AbsoluteThickness[1], 
            Dashing[{}]]], {
          GrayLevel[0]}], 
        "Tooltip"]& ]}}, {}, {}}, {{{{{{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, \
{}}, {}}}, {}}, {}}, {}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  Frame->True,
  FrameLabel->{{
     FormBox["\"River Size\"", TraditionalForm], None}, {
     FormBox["\"A1\"", TraditionalForm], None}},
  FrameTicks->{{{{0.7509076238812251, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0, 0}}, {3.249092376118775, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0, 0}}, {1., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.008, 0}}, {1., 
       FormBox["\"large\"", TraditionalForm], 0}, {2., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.008, 0}}, {2., 
       FormBox["\"medium\"", TraditionalForm], 0}, {3., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.008, 0}}, {3., 
       FormBox["\"small\"", TraditionalForm], 0}}, {{0.7509076238812251, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0, 0}}, {3.249092376118775, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0, 0}}, {1., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.008, 0}}, {2., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.008, 0}}, {3., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.008, 0}}}}, {Automatic, Automatic}},
  PlotRangePadding->Scaled[0.02],
  Ticks->{Automatic, None}]], "Output",
 CellChangeTimes->{3.585504839434875*^9, 3.585999698113154*^9}]
}, {2}]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Multiple Conditions", "Title",
 CellChangeTimes->{{3.585417299136742*^9, 3.585417302023638*^9}, {
  3.585486190840365*^9, 3.585486194479013*^9}, {3.5854955216795692`*^9, 
  3.585495536078971*^9}, {3.585495869960773*^9, 3.585495877024088*^9}, {
  3.5854984265503893`*^9, 3.585498429740182*^9}, {3.585499094894772*^9, 
  3.585499097542303*^9}, {3.58550056152886*^9, 3.585500572056347*^9}, {
  3.5855041255687923`*^9, 3.585504130967813*^9}, {3.58550491005755*^9, 
  3.5855049179996977`*^9}, {3.585505127301998*^9, 3.585505130595188*^9}}],

Cell["\<\
Our conditional distribution machinery can handle multiple conditions:\
\>", "Text",
 CellChangeTimes->{{3.585505137570664*^9, 3.585505151210739*^9}}],

Cell[BoxData[
 RowBox[{"mxPHss", "=", 
  RowBox[{"condition", "[", 
   RowBox[{"med", ",", "mxPH", ",", 
    RowBox[{"{", 
     RowBox[{"speed", ",", "size"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.574618985007961*^9, 3.5746189932422266`*^9}, 
   3.5746192547951603`*^9, {3.5747070320211744`*^9, 3.574707035655382*^9}, {
   3.574707088221389*^9, 3.574707092701645*^9}, {3.5747201506751904`*^9, 
   3.574720167614159*^9}, {3.574762581533824*^9, 3.574762586142088*^9}, {
   3.574770927384179*^9, 3.574770930736371*^9}, 3.574794182251275*^9, 
   3.574795164512457*^9, {3.575216572727028*^9, 3.5752165738063993`*^9}, {
   3.585505165747299*^9, 3.585505166491193*^9}, {3.5855052401255074`*^9, 
   3.58550527797086*^9}, {3.58550533514071*^9, 3.5855053367156067`*^9}, {
   3.585505466577039*^9, 3.58550546789356*^9}, {3.585505550068266*^9, 
   3.585505552451294*^9}}],

Cell["Histogram each combination:", "Text",
 CellChangeTimes->{{3.58602221541674*^9, 3.5860222243844748`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Reverse", "@", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Histogram", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"size", "/.", 
        RowBox[{"(", 
         RowBox[{"speed", "/.", "mxPHss"}], ")"}]}], "\[IndentingNewLine]", 
       ",", 
       RowBox[{"PlotLabel", "\[Rule]", 
        RowBox[{"Column", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"speed", ",", "size"}], "}"}], ",", "Center"}], "]"}]}]}], 
      "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"size", ",", 
       RowBox[{"med", "[", 
        RowBox[{"size", ",", "\"\<factors\>\""}], "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"speed", ",", 
       RowBox[{"med", "[", 
        RowBox[{"speed", ",", "\"\<factors\>\""}], "]"}]}], "}"}]}], 
    "\[IndentingNewLine]", "]"}]}], "//", "Grid"}]], "Input",
 CellChangeTimes->{{3.585505630321286*^9, 3.5855057412877197`*^9}, {
  3.585505772055212*^9, 3.585505781830653*^9}, {3.585505842174966*^9, 
  3.585505857990263*^9}, {3.5855060166353683`*^9, 3.5855060557850447`*^9}, {
  3.5855060873139477`*^9, 3.58550613004008*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     GraphicsBox[
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.6649999999999999]], {}, 
       {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
        EdgeForm[Opacity[0.6649999999999999]], 
        TagBox[
         TooltipBox[
          TagBox[
           DynamicBox[{
             FEPrivate`If[
              CurrentValue["MouseOver"], 
              EdgeForm[{
                GrayLevel[0.5], 
                AbsoluteThickness[1.5], 
                Opacity[0.66]}], {}, {}], 
             RectangleBox[{7.5, 0}, {8., 2}, "RoundingRadius" -> 0]},
            
            ImageSizeCache->{{7.5, 40.89999999999998}, {33.86285905717402, 
             57.80737088951388}}],
           StatusArea[#, 2]& ,
           TagBoxNote->"2"],
          StyleBox["2", {
            GrayLevel[0]}, StripOnInput -> False]],
         Annotation[#, 
          Style[2, {
            GrayLevel[0]}], "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          TagBox[
           DynamicBox[{
             FEPrivate`If[
              CurrentValue["MouseOver"], 
              EdgeForm[{
                GrayLevel[0.5], 
                AbsoluteThickness[1.5], 
                Opacity[0.66]}], {}, {}], 
             RectangleBox[{8., 0}, {8.5, 4}, "RoundingRadius" -> 0]},
            
            ImageSizeCache->{{39.89999999999998, 73.29999999999995}, {
             10.918347224834172`, 57.80737088951388}}],
           StatusArea[#, 4]& ,
           TagBoxNote->"4"],
          StyleBox["4", {
            GrayLevel[0]}, StripOnInput -> False]],
         Annotation[#, 
          Style[4, {
            GrayLevel[0]}], "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          TagBox[
           DynamicBox[{
             FEPrivate`If[
              CurrentValue["MouseOver"], 
              EdgeForm[{
                GrayLevel[0.5], 
                AbsoluteThickness[1.5], 
                Opacity[0.66]}], {}, {}], 
             RectangleBox[{8.5, 0}, {9., 8}, "RoundingRadius" -> 0]},
            
            ImageSizeCache->{{72.29999999999995, 
             105.69999999999993`}, {-34.97067643984553, 57.80737088951388}}],
           StatusArea[#, 8]& ,
           TagBoxNote->"8"],
          StyleBox["8", {
            GrayLevel[0]}, StripOnInput -> False]],
         Annotation[#, 
          Style[8, {
            GrayLevel[0]}], "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          TagBox[
           DynamicBox[{
             FEPrivate`If[
              CurrentValue["MouseOver"], 
              EdgeForm[{
                GrayLevel[0.5], 
                AbsoluteThickness[1.5], 
                Opacity[0.66]}], {}, {}], 
             RectangleBox[{9., 0}, {9.5, 2}, "RoundingRadius" -> 0]},
            
            ImageSizeCache->{{104.69999999999993`, 138.10000000000002`}, {
             33.86285905717402, 57.80737088951388}}],
           StatusArea[#, 2]& ,
           TagBoxNote->"2"],
          StyleBox["2", {
            GrayLevel[0]}, StripOnInput -> False]],
         Annotation[#, 
          Style[2, {
            GrayLevel[0]}], "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          TagBox[
           DynamicBox[{
             FEPrivate`If[
              CurrentValue["MouseOver"], 
              EdgeForm[{
                GrayLevel[0.5], 
                AbsoluteThickness[1.5], 
                Opacity[0.66]}], {}, {}], 
             RectangleBox[{9.5, 0}, {10., 1}, "RoundingRadius" -> 0]},
            
            ImageSizeCache->{{137.10000000000002`, 170.5}, {45.33511497334395,
              57.80737088951388}}],
           StatusArea[#, 1]& ,
           TagBoxNote->"1"],
          StyleBox["1", {
            GrayLevel[0]}, StripOnInput -> False]],
         Annotation[#, 
          Style[1, {
            GrayLevel[0]}], "Tooltip"]& ]}, {}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{7.5, 0},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      PlotLabel->FormBox[
        TagBox[
         GridBox[{{"\"low\""}, {"\"large\""}}, 
          GridBoxAlignment -> {"Columns" -> {{Center}}}, DefaultBaseStyle -> 
          "Column", 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Column"], 
        TraditionalForm],
      PlotRange->{{7.5, 10.}, {All, All}},
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.1]}},
      Ticks->{Automatic, Automatic},
      ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]], 
     GraphicsBox[
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.651]], {}, 
       {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
        EdgeForm[Opacity[0.651]], 
        TagBox[
         TooltipBox[
          TagBox[
           DynamicBox[{
             FEPrivate`If[
              CurrentValue["MouseOver"], 
              EdgeForm[{
                GrayLevel[0.5], 
                AbsoluteThickness[1.5], 
                Opacity[0.66]}], {}, {}], 
             RectangleBox[{7.8, 0}, {8., 1}, "RoundingRadius" -> 0]},
            
            ImageSizeCache->{{7.500000000000114, 32.000000000000114`}, {
             45.73534822910531, 58.384645131635864`}}],
           StatusArea[#, 1]& ,
           TagBoxNote->"1"],
          StyleBox["1", {
            GrayLevel[0]}, StripOnInput -> False]],
         Annotation[#, 
          Style[1, {
            GrayLevel[0]}], "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          TagBox[
           DynamicBox[{
             FEPrivate`If[
              CurrentValue["MouseOver"], 
              EdgeForm[{
                GrayLevel[0.5], 
                AbsoluteThickness[1.5], 
                Opacity[0.66]}], {}, {}], 
             RectangleBox[{8., 0}, {8.2, 1}, "RoundingRadius" -> 0]},
            
            ImageSizeCache->{{31.000000000000114`, 55.5}, {45.73534822910531, 
             58.384645131635864`}}],
           StatusArea[#, 1]& ,
           TagBoxNote->"1"],
          StyleBox["1", {
            GrayLevel[0]}, StripOnInput -> False]],
         Annotation[#, 
          Style[1, {
            GrayLevel[0]}], "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          TagBox[
           DynamicBox[{
             FEPrivate`If[
              CurrentValue["MouseOver"], 
              EdgeForm[{
                GrayLevel[0.5], 
                AbsoluteThickness[1.5], 
                Opacity[0.66]}], {}, {}], 
             RectangleBox[{8.2, 0}, {8.4, 7}, "RoundingRadius" -> 0]},
            
            ImageSizeCache->{{54.5, 79.00000000000011}, {-24.160433186078023`,
              58.384645131635864`}}],
           StatusArea[#, 7]& ,
           TagBoxNote->"7"],
          StyleBox["7", {
            GrayLevel[0]}, StripOnInput -> False]],
         Annotation[#, 
          Style[7, {
            GrayLevel[0]}], "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          TagBox[
           DynamicBox[{
             FEPrivate`If[
              CurrentValue["MouseOver"], 
              EdgeForm[{
                GrayLevel[0.5], 
                AbsoluteThickness[1.5], 
                Opacity[0.66]}], {}, {}], 
             RectangleBox[{8.4, 0}, {8.6, 8}, "RoundingRadius" -> 0]},
            
            ImageSizeCache->{{78.00000000000011, 
             102.5}, {-35.809730088608575`, 58.384645131635864`}}],
           StatusArea[#, 8]& ,
           TagBoxNote->"8"],
          StyleBox["8", {
            GrayLevel[0]}, StripOnInput -> False]],
         Annotation[#, 
          Style[8, {
            GrayLevel[0]}], "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          TagBox[
           DynamicBox[{
             FEPrivate`If[
              CurrentValue["MouseOver"], 
              EdgeForm[{
                GrayLevel[0.5], 
                AbsoluteThickness[1.5], 
                Opacity[0.66]}], {}, {}], 
             RectangleBox[{8.6, 0}, {8.8, 3}, "RoundingRadius" -> 0]},
            
            ImageSizeCache->{{101.5, 126.00000000000023`}, {
             22.436754424044196`, 58.384645131635864`}}],
           StatusArea[#, 3]& ,
           TagBoxNote->"3"],
          StyleBox["3", {
            GrayLevel[0]}, StripOnInput -> False]],
         Annotation[#, 
          Style[3, {
            GrayLevel[0]}], "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          TagBox[
           DynamicBox[{
             FEPrivate`If[
              CurrentValue["MouseOver"], 
              EdgeForm[{
                GrayLevel[0.5], 
                AbsoluteThickness[1.5], 
                Opacity[0.66]}], {}, {}], 
             RectangleBox[{9., 0}, {9.2, 1}, "RoundingRadius" -> 0]},
            
            ImageSizeCache->{{148.5, 173.}, {45.73534822910531, 
             58.384645131635864`}}],
           StatusArea[#, 1]& ,
           TagBoxNote->"1"],
          StyleBox["1", {
            GrayLevel[0]}, StripOnInput -> False]],
         Annotation[#, 
          Style[1, {
            GrayLevel[0]}], "Tooltip"]& ]}, {}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{7.8, 0},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      PlotLabel->FormBox[
        TagBox[
         GridBox[{{"\"medium\""}, {"\"large\""}}, 
          GridBoxAlignment -> {"Columns" -> {{Center}}}, DefaultBaseStyle -> 
          "Column", 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Column"], 
        TraditionalForm],
      PlotRange->{{7.8, 9.2}, {All, All}},
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.1]}},
      Ticks->{Automatic, Automatic},
      ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]], 
     GraphicsBox[
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.6859999999999999]], {}, 
       {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
        EdgeForm[Opacity[0.6859999999999999]], 
        TagBox[
         TooltipBox[
          TagBox[
           DynamicBox[{
             FEPrivate`If[
              CurrentValue["MouseOver"], 
              EdgeForm[{
                GrayLevel[0.5], 
                AbsoluteThickness[1.5], 
                Opacity[0.66]}], {}, {}], 
             RectangleBox[{7., 0}, {8., 2}, "RoundingRadius" -> 0]},
            
            ImageSizeCache->{{7.5, 90.75}, {20.106895043538167`, 
             58.384645131635985`}}],
           StatusArea[#, 2]& ,
           TagBoxNote->"2"],
          StyleBox["2", {
            GrayLevel[0]}, StripOnInput -> False]],
         Annotation[#, 
          Style[2, {
            GrayLevel[0]}], "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          TagBox[
           DynamicBox[{
             FEPrivate`If[
              CurrentValue["MouseOver"], 
              EdgeForm[{
                GrayLevel[0.5], 
                AbsoluteThickness[1.5], 
                Opacity[0.66]}], {}, {}], 
             RectangleBox[{8., 0}, {9., 5}, "RoundingRadius" -> 0]},
            
            ImageSizeCache->{{89.75, 173.}, {-35.80973008860857, 
             58.384645131635985`}}],
           StatusArea[#, 5]& ,
           TagBoxNote->"5"],
          StyleBox["5", {
            GrayLevel[0]}, StripOnInput -> False]],
         Annotation[#, 
          Style[5, {
            GrayLevel[0]}], "Tooltip"]& ]}, {}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{7., 0},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      PlotLabel->FormBox[
        TagBox[
         GridBox[{{"\"high\""}, {"\"large\""}}, 
          GridBoxAlignment -> {"Columns" -> {{Center}}}, DefaultBaseStyle -> 
          "Column", 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Column"], 
        TraditionalForm],
      PlotRange->{{7., 9.}, {All, All}},
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.1]}},
      Ticks->{Automatic, Automatic},
      ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]},
    {
     GraphicsBox[
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.6719999999999999]], {}, 
       {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
        EdgeForm[Opacity[0.6719999999999999]], 
        TagBox[
         TooltipBox[
          TagBox[
           DynamicBox[{
             FEPrivate`If[
              CurrentValue["MouseOver"], 
              EdgeForm[{
                GrayLevel[0.5], 
                AbsoluteThickness[1.5], 
                Opacity[0.66]}], {}, {}], 
             RectangleBox[{7.5, 0}, {8., 6}, "RoundingRadius" -> 0]},
            
            ImageSizeCache->{{7.5, 49.625}, {-35.80973008860856, 
             58.38464513163598}}],
           StatusArea[#, 6]& ,
           TagBoxNote->"6"],
          StyleBox["6", {
            GrayLevel[0]}, StripOnInput -> False]],
         Annotation[#, 
          Style[6, {
            GrayLevel[0]}], "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          TagBox[
           DynamicBox[{
             FEPrivate`If[
              CurrentValue["MouseOver"], 
              EdgeForm[{
                GrayLevel[0.5], 
                AbsoluteThickness[1.5], 
                Opacity[0.66]}], {}, {}], 
             RectangleBox[{8., 0}, {8.5, 5}, "RoundingRadius" -> 0]},
            
            ImageSizeCache->{{48.625, 90.75}, {-20.277334218567802`, 
             58.38464513163598}}],
           StatusArea[#, 5]& ,
           TagBoxNote->"5"],
          StyleBox["5", {
            GrayLevel[0]}, StripOnInput -> False]],
         Annotation[#, 
          Style[5, {
            GrayLevel[0]}], "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          TagBox[
           DynamicBox[{
             FEPrivate`If[
              CurrentValue["MouseOver"], 
              EdgeForm[{
                GrayLevel[0.5], 
                AbsoluteThickness[1.5], 
                Opacity[0.66]}], {}, {}], 
             RectangleBox[{8.5, 0}, {9., 3}, "RoundingRadius" -> 0]},
            
            ImageSizeCache->{{89.75, 131.875}, {10.787457521513709`, 
             58.38464513163598}}],
           StatusArea[#, 3]& ,
           TagBoxNote->"3"],
          StyleBox["3", {
            GrayLevel[0]}, StripOnInput -> False]],
         Annotation[#, 
          Style[3, {
            GrayLevel[0]}], "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          TagBox[
           DynamicBox[{
             FEPrivate`If[
              CurrentValue["MouseOver"], 
              EdgeForm[{
                GrayLevel[0.5], 
                AbsoluteThickness[1.5], 
                Opacity[0.66]}], {}, {}], 
             RectangleBox[{9., 0}, {9.5, 1}, "RoundingRadius" -> 0]},
            
            ImageSizeCache->{{130.875, 173.}, {41.85224926159522, 
             58.38464513163598}}],
           StatusArea[#, 1]& ,
           TagBoxNote->"1"],
          StyleBox["1", {
            GrayLevel[0]}, StripOnInput -> False]],
         Annotation[#, 
          Style[1, {
            GrayLevel[0]}], "Tooltip"]& ]}, {}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{7.5, 0},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      PlotLabel->FormBox[
        TagBox[
         GridBox[{{"\"low\""}, {"\"medium\""}}, 
          GridBoxAlignment -> {"Columns" -> {{Center}}}, DefaultBaseStyle -> 
          "Column", 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Column"], 
        TraditionalForm],
      PlotRange->{{7.5, 9.5}, {All, All}},
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.1]}},
      Ticks->{Automatic, Automatic},
      ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]], 
     GraphicsBox[
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.6649999999999999]], {}, 
       {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
        EdgeForm[Opacity[0.6649999999999999]], 
        TagBox[
         TooltipBox[
          TagBox[
           DynamicBox[{
             FEPrivate`If[
              CurrentValue["MouseOver"], 
              EdgeForm[{
                GrayLevel[0.5], 
                AbsoluteThickness[1.5], 
                Opacity[0.66]}], {}, {}], 
             RectangleBox[{7., 0}, {7.5, 1}, "RoundingRadius" -> 0]},
            
            ImageSizeCache->{{12.5, 45.400000000000034`}, {50.58248918248706, 
             57.2300966473917}}],
           StatusArea[#, 1]& ,
           TagBoxNote->"1"],
          StyleBox["1", {
            GrayLevel[0]}, StripOnInput -> False]],
         Annotation[#, 
          Style[1, {
            GrayLevel[0]}], "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          TagBox[
           DynamicBox[{
             FEPrivate`If[
              CurrentValue["MouseOver"], 
              EdgeForm[{
                GrayLevel[0.5], 
                AbsoluteThickness[1.5], 
                Opacity[0.66]}], {}, {}], 
             RectangleBox[{7.5, 0}, {8., 13}, "RoundingRadius" -> 0]},
            
            ImageSizeCache->{{44.400000000000034`, 
             77.30000000000001}, {-17.188800396368585`, 57.2300966473917}}],
           StatusArea[#, 13]& ,
           TagBoxNote->"13"],
          StyleBox["13", {
            GrayLevel[0]}, StripOnInput -> False]],
         Annotation[#, 
          Style[13, {
            GrayLevel[0]}], "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          TagBox[
           DynamicBox[{
             FEPrivate`If[
              CurrentValue["MouseOver"], 
              EdgeForm[{
                GrayLevel[0.5], 
                AbsoluteThickness[1.5], 
                Opacity[0.66]}], {}, {}], 
             RectangleBox[{8., 0}, {8.5, 16}, "RoundingRadius" -> 0]},
            
            ImageSizeCache->{{76.30000000000001, 
             109.19999999999999`}, {-34.1316227910825, 57.2300966473917}}],
           StatusArea[#, 16]& ,
           TagBoxNote->"16"],
          StyleBox["16", {
            GrayLevel[0]}, StripOnInput -> False]],
         Annotation[#, 
          Style[16, {
            GrayLevel[0]}], "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          TagBox[
           DynamicBox[{
             FEPrivate`If[
              CurrentValue["MouseOver"], 
              EdgeForm[{
                GrayLevel[0.5], 
                AbsoluteThickness[1.5], 
                Opacity[0.66]}], {}, {}], 
             RectangleBox[{8.5, 0}, {9., 3}, "RoundingRadius" -> 0]},
            
            ImageSizeCache->{{108.19999999999999`, 141.09999999999997`}, {
             39.28727425267779, 57.2300966473917}}],
           StatusArea[#, 3]& ,
           TagBoxNote->"3"],
          StyleBox["3", {
            GrayLevel[0]}, StripOnInput -> False]],
         Annotation[#, 
          Style[3, {
            GrayLevel[0]}], "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          TagBox[
           DynamicBox[{
             FEPrivate`If[
              CurrentValue["MouseOver"], 
              EdgeForm[{
                GrayLevel[0.5], 
                AbsoluteThickness[1.5], 
                Opacity[0.66]}], {}, {}], 
             RectangleBox[{9., 0}, {9.5, 2}, "RoundingRadius" -> 0]},
            
            ImageSizeCache->{{140.09999999999997`, 173.00000000000006`}, {
             44.93488171758242, 57.2300966473917}}],
           StatusArea[#, 2]& ,
           TagBoxNote->"2"],
          StyleBox["2", {
            GrayLevel[0]}, StripOnInput -> False]],
         Annotation[#, 
          Style[2, {
            GrayLevel[0]}], "Tooltip"]& ]}, {}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{7., 0},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      PlotLabel->FormBox[
        TagBox[
         GridBox[{{"\"medium\""}, {"\"medium\""}}, 
          GridBoxAlignment -> {"Columns" -> {{Center}}}, DefaultBaseStyle -> 
          "Column", 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Column"], 
        TraditionalForm],
      PlotRange->{{7., 9.5}, {All, All}},
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.1]}},
      Ticks->{Automatic, Automatic},
      ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztWj2I5MgV1uzM7No+X2LvYg7f+daBvY4Ezu1A+H5wYAT2RbaS5bC4C4zF
+RKlyhSKSxQcKLHsQJHgoLmgk46aw0qUCEwHjUGJAhkqUaDg86tXJY26t/e6
Z2d68TDd0K1WVb33vffq1au/97vnn3/y5788//zTj58//fCz594nn378t6cf
/PUzKjo/MwzjK/p+8dSQ/0F/9c9XoA9V7no848c5/fToup7fLiZlQgj6hfEj
XSbaFoKbTdr1Am3b8duTCW3btEx71a5jftN2olmj1rQPdVkvWqgiGI93tLvc
we98S52+hGP6qOntgWae2QasL7+GK+3iBgh8H3klFML36adGZFvwkwyR5yBe
NiwCkyUV2iKB7YRIQxdeWg1kfbMgJAdJlsJzPCxbqfsKDqF8ufiH7AE4QQjf
i1B1GMhEXRInD5YTYaV0HckSKigTD26YIHRspFV3CNkONKW68Qt+vIGZR8xW
PYZP19ZoiItohS5ZwzM9VD2MHzLNmxBFSNaaqepVDMNK0I201J4Qc7ZUi8Aw
MWv6kbYILbh5rUlt2GRGblnXxKMbnIYsn5NGGTvLEy2rKCKSPECjJWMaamcY
HpijmMOk+nofzUtwzqamOUe7DGFH5aZ/EWlkWpi3gzmoppGwIZq+QeKQIwXL
0cHQzmGN8IJoDQTLdiBt5j5Mf0GWK7i/qGriygVsMyQbTqCIxSKLEScxbGrv
zeoRql0EzEt1Y0GwJpYC30a6C2rLCDxqrFAqoAet/O1R5T61cqVfPNbFay4i
/c1IdsEgF3uLEWHwp2VgTU0gmeWeyZRmuJhEB/rtW+Q+1TmpdLCBpIwt8jny
9maF2JZkVwYvQpPeC43VIDRtLMS3kr4EbdsQUk7XRl73OrJcoMq0xvSl2PB4
UKmvOKK4UQzfdjEnktEhxGLDIeJNh+hWKXEzESURHBrQ634IVqoHM8/SiA4W
47B6OPpWWCgzr1IHZrAc+4Bc2fTn277xg0OodwPrMPLzwa55irJVYaQmp3aS
SluJ4nRJHufnaESnhyXpWSXkJ4kSqJDCTcYMmc8ZQ0itwkndDyaqEhtWrKJG
Sb7kL9oRqoxd+HkJ0fUj1IK61F8K7XuGjDgjVLdKOHowUqMiyfrK0XaR7oI6
nxrjIfp1NroFf8mhxDAglDk5Tmhzlt10gFMMcV1ENHX4to2sEqO3iZJmGzdC
Gk1mGxl+ljTL+EhpcDu2L2O8JqG6rlRz25UUI1Rfz+HaHpIk4Lmj7jFC8VQT
pYhch6Ya8XgvyW4oPYR+OQwhmpw7vVAYJ3FaPHTbi4eOFg9qRbG5eGjV4uGR
Luu7Dnrm0lqpAN2quWsMb524WqA82dGO+Z1JdmeSn5b6Td1SKqQ/xt/3Vn1X
Pv4pay5ebPsv6mr60pv63Vd2cWC7m9C+Doz7LN/gH5cvd4e3d7B455bKrgH/
3ge/f4HFTcv+D+EfSPSfyOp3j6/kUPW2LnvNNj7B30N4dvB3bgr6U1n06Pha
Dfx+doK6k1DX9zb2rGe3K+1A+/6J7SbbVw4Gd1r14diwE+KFo8lbhrrUzHPX
4AORMPAR5tVR0S55SzOc9clTiXQlCY4C+R3NogxtudfmN97KMtItAAzbubbK
YZLsR9Rl6KyuymDpzaoTL4/sGhAFbZsDlA0fnB8J7aFGKxN3PHlISnFkr5he
Ejw4DtQ9jmN3kO2po+4321P/3xG297Oj1DIQfa9WhX3XD7PWruvp2wb/Hr9W
s5A5h9lS3YrR+sCzXCRpCNvL5MLuSLO2FkDeQMiLsSUvIXvMaO3qztSlLN95
zOpjC9AisvhmDvLKI1BXqvwpI1NeobIAt7XE3AUrlrTatKCvvPj61NKwRzX8
ld4tdQLp3Qx6W6PeRxKAHLympahhQ11qdUht2fNKAuUF62MK0KGaJ7TyHgSA
9n0PaaZ8XxzN94c94fTm50jj/B7H1zvI9tRR95vtVf/zyeS715PiV3ukOLE4
wPq/fu3YL18H7jszvC4QZwS8sObbOi68FaRdizvsOircNcO+mv0mK6pBg93n
hDdmP8i875Tw1bpnc2GG7QPCW3OE7RUYtg8HbwVJ8thYainfPuhs8JpYh54D
3iw0cGD+cFK1xX1/Xs5xqljC9PWDbyZsf6Qbcp7TVh9wQrQuu1oB92OZrVj8
lh9voEhVRqOXzFEtUx4DlhujrBbwLXIcy8ey+S/ywDJYeePHcnywcPUy1s5l
8gg1KAjFixKpTh30koITk31TOaBtW9zWT5YH4vbGb6biPuPsVEtu4liZjrMp
o1JFuyq2YEYlulKJFc1XFO4FZoGNcPENpxVaocqJrGcSPpAJbehlaiLxLHuo
NEUSUYaztojH/wfgGu9tWlalXVp63A/5lmrPW9DWTyatcnaqm+u49hbqfy/Y
Enmt5iNRymRmlUorWC21f53+H0RjnP2Ym2I+G0mKbqqZilWlFnOde5CJi1EU
IQxD+iYo/yO30+YY1rpDRJ2Ktx93W9SWYrT0My+r0AuVfWj6MyIWyFzO7UW/
TnmarcjdV5kKfou2Q+bQXjdfq86X6phK1NUsGMXrKyXqcsuqB+Bui1rOYjg0
vfihD5s0M8m1FxSebXPMqGVR1nNq5ziwTAtBVqjsxq5CaNvwgoDTYg0rJqAW
sySAbbkkaoMscEgFHxX9z0NS03RZhQNwB1H/xI9LrfVVurYQnQ4wxh/58YiM
sUbkqERv6UyiCJjbqofxB9XU4ccFp3eyEj2n3H+0K3wd8DhFuFOEO0W4U4S7
oxHOOPsfcGzJMg==\
\>"]], 
     GraphicsBox[
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.6579999999999999]], {}, 
       {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
        EdgeForm[Opacity[0.6579999999999999]], 
        TagBox[
         TooltipBox[
          TagBox[
           DynamicBox[{
             FEPrivate`If[
              CurrentValue["MouseOver"], 
              EdgeForm[{
                GrayLevel[0.5], 
                AbsoluteThickness[1.5], 
                Opacity[0.66]}], {}, {}], 
             RectangleBox[{7., 0}, {7.5, 7}, "RoundingRadius" -> 0]},
            
            ImageSizeCache->{{12.5, 39.66666666666663}, {-6.6089516780427005`,
              56.65282240526962}}],
           StatusArea[#, 7]& ,
           TagBoxNote->"7"],
          StyleBox["7", {
            GrayLevel[0]}, StripOnInput -> False]],
         Annotation[#, 
          Style[7, {
            GrayLevel[0]}], "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          TagBox[
           DynamicBox[{
             FEPrivate`If[
              CurrentValue["MouseOver"], 
              EdgeForm[{
                GrayLevel[0.5], 
                AbsoluteThickness[1.5], 
                Opacity[0.66]}], {}, {}], 
             RectangleBox[{7.5, 0}, {8., 8}, "RoundingRadius" -> 0]},
            
            ImageSizeCache->{{38.66666666666663, 
             65.83333333333331}, {-15.503490832801603`, 56.65282240526962}}],
           StatusArea[#, 8]& ,
           TagBoxNote->"8"],
          StyleBox["8", {
            GrayLevel[0]}, StripOnInput -> False]],
         Annotation[#, 
          Style[8, {
            GrayLevel[0]}], "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          TagBox[
           DynamicBox[{
             FEPrivate`If[
              CurrentValue["MouseOver"], 
              EdgeForm[{
                GrayLevel[0.5], 
                AbsoluteThickness[1.5], 
                Opacity[0.66]}], {}, {}], 
             RectangleBox[{8., 0}, {8.5, 10}, "RoundingRadius" -> 0]},
            
            ImageSizeCache->{{64.83333333333331, 92.}, {-33.29256914231941, 
             56.65282240526962}}],
           StatusArea[#, 10]& ,
           TagBoxNote->"10"],
          StyleBox["10", {
            GrayLevel[0]}, StripOnInput -> False]],
         Annotation[#, 
          Style[10, {
            GrayLevel[0]}], "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          TagBox[
           DynamicBox[{
             FEPrivate`If[
              CurrentValue["MouseOver"], 
              EdgeForm[{
                GrayLevel[0.5], 
                AbsoluteThickness[1.5], 
                Opacity[0.66]}], {}, {}], 
             RectangleBox[{8.5, 0}, {9., 7}, "RoundingRadius" -> 0]},
            
            ImageSizeCache->{{91., 
             118.16666666666663`}, {-6.6089516780427005`, 56.65282240526962}}],
           StatusArea[#, 7]& ,
           TagBoxNote->"7"],
          StyleBox["7", {
            GrayLevel[0]}, StripOnInput -> False]],
         Annotation[#, 
          Style[7, {
            GrayLevel[0]}], "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          TagBox[
           DynamicBox[{
             FEPrivate`If[
              CurrentValue["MouseOver"], 
              EdgeForm[{
                GrayLevel[0.5], 
                AbsoluteThickness[1.5], 
                Opacity[0.66]}], {}, {}], 
             RectangleBox[{9., 0}, {9.5, 1}, "RoundingRadius" -> 0]},
            
            ImageSizeCache->{{117.16666666666663`, 144.33333333333331`}, {
             46.758283250510715`, 56.65282240526962}}],
           StatusArea[#, 1]& ,
           TagBoxNote->"1"],
          StyleBox["1", {
            GrayLevel[0]}, StripOnInput -> False]],
         Annotation[#, 
          Style[1, {
            GrayLevel[0]}], "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          TagBox[
           DynamicBox[{
             FEPrivate`If[
              CurrentValue["MouseOver"], 
              EdgeForm[{
                GrayLevel[0.5], 
                AbsoluteThickness[1.5], 
                Opacity[0.66]}], {}, {}], 
             RectangleBox[{9.5, 0}, {10., 1}, "RoundingRadius" -> 0]},
            
            ImageSizeCache->{{143.33333333333331`, 170.5}, {
             46.758283250510715`, 56.65282240526962}}],
           StatusArea[#, 1]& ,
           TagBoxNote->"1"],
          StyleBox["1", {
            GrayLevel[0]}, StripOnInput -> False]],
         Annotation[#, 
          Style[1, {
            GrayLevel[0]}], "Tooltip"]& ]}, {}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{7., 0},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      PlotLabel->FormBox[
        TagBox[
         GridBox[{{"\"high\""}, {"\"medium\""}}, 
          GridBoxAlignment -> {"Columns" -> {{Center}}}, DefaultBaseStyle -> 
          "Column", 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Column"], 
        TraditionalForm],
      PlotRange->{{7., 10.}, {All, All}},
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.1]}},
      Ticks->{Automatic, Automatic},
      ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]},
    {
     GraphicsBox[
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.7]]},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      PlotLabel->FormBox[
        TagBox[
         GridBox[{{"\"low\""}, {"\"small\""}}, 
          GridBoxAlignment -> {"Columns" -> {{Center}}}, DefaultBaseStyle -> 
          "Column", 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Column"], 
        TraditionalForm],
      PlotRange->{{All, All}, {All, All}},
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.1]}},
      Ticks->{Automatic, Automatic}], 
     GraphicsBox[
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.6719999999999999]], {}, 
       {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
        EdgeForm[Opacity[0.6719999999999999]], 
        TagBox[
         TooltipBox[
          TagBox[
           DynamicBox[{
             FEPrivate`If[
              CurrentValue["MouseOver"], 
              EdgeForm[{
                GrayLevel[0.5], 
                AbsoluteThickness[1.5], 
                Opacity[0.66]}], {}, {}], 
             RectangleBox[{5., 0}, {6., 2}, "RoundingRadius" -> 0]},
            
            ImageSizeCache->{{12.499999999999972`, 54.12857142857138}, {
             43.979066417926106`, 58.13183873360754}}],
           StatusArea[#, 2]& ,
           TagBoxNote->"2"],
          StyleBox["2", {
            GrayLevel[0]}, StripOnInput -> False]],
         Annotation[#, 
          Style[2, {
            GrayLevel[0]}], "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          TagBox[
           DynamicBox[{
             FEPrivate`If[
              CurrentValue["MouseOver"], 
              EdgeForm[{
                GrayLevel[0.5], 
                AbsoluteThickness[1.5], 
                Opacity[0.66]}], {}, {}], 
             RectangleBox[{6., 0}, {7., 3}, "RoundingRadius" -> 0]},
            
            ImageSizeCache->{{53.12857142857138, 94.75714285714278}, {
             37.40268026008539, 58.13183873360754}}],
           StatusArea[#, 3]& ,
           TagBoxNote->"3"],
          StyleBox["3", {
            GrayLevel[0]}, StripOnInput -> False]],
         Annotation[#, 
          Style[3, {
            GrayLevel[0]}], "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          TagBox[
           DynamicBox[{
             FEPrivate`If[
              CurrentValue["MouseOver"], 
              EdgeForm[{
                GrayLevel[0.5], 
                AbsoluteThickness[1.5], 
                Opacity[0.66]}], {}, {}], 
             RectangleBox[{7., 0}, {8., 8}, "RoundingRadius" -> 0]},
            
            ImageSizeCache->{{93.75714285714278, 135.38571428571422`}, {
             4.52074947088181, 58.13183873360754}}],
           StatusArea[#, 8]& ,
           TagBoxNote->"8"],
          StyleBox["8", {
            GrayLevel[0]}, StripOnInput -> False]],
         Annotation[#, 
          Style[8, {
            GrayLevel[0]}], "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          TagBox[
           DynamicBox[{
             FEPrivate`If[
              CurrentValue["MouseOver"], 
              EdgeForm[{
                GrayLevel[0.5], 
                AbsoluteThickness[1.5], 
                Opacity[0.66]}], {}, {}], 
             RectangleBox[{8., 0}, {9., 14}, "RoundingRadius" -> 0]},
            
            ImageSizeCache->{{134.38571428571422`, 
             176.01428571428565`}, {-34.937567476162485`, 58.13183873360754}}],
           StatusArea[#, 14]& ,
           TagBoxNote->"14"],
          StyleBox["14", {
            GrayLevel[0]}, StripOnInput -> False]],
         Annotation[#, 
          Style[14, {
            GrayLevel[0]}], "Tooltip"]& ]}, {}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{5., 0},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      PlotLabel->FormBox[
        TagBox[
         GridBox[{{"\"medium\""}, {"\"small\""}}, 
          GridBoxAlignment -> {"Columns" -> {{Center}}}, DefaultBaseStyle -> 
          "Column", 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Column"], 
        TraditionalForm],
      PlotRange->{{5., 9.}, {All, All}},
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.1]}},
      Ticks->{Automatic, Automatic}], 
     GraphicsBox[
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.6719999999999999]], {}, 
       {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
        EdgeForm[Opacity[0.6719999999999999]], 
        TagBox[
         TooltipBox[
          TagBox[
           DynamicBox[{
             FEPrivate`If[
              CurrentValue["MouseOver"], 
              EdgeForm[{
                GrayLevel[0.5], 
                AbsoluteThickness[1.5], 
                Opacity[0.66]}], {}, {}], 
             RectangleBox[{6.5, 0}, {7., 4}, "RoundingRadius" -> 0]},
            
            ImageSizeCache->{{12.499999999999943`, 53.37499999999994}, {
             34.96851560304482, 57.23009664739168}}],
           StatusArea[#, 4]& ,
           TagBoxNote->"4"],
          StyleBox["4", {
            GrayLevel[0]}, StripOnInput -> False]],
         Annotation[#, 
          Style[4, {
            GrayLevel[0]}], "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          TagBox[
           DynamicBox[{
             FEPrivate`If[
              CurrentValue["MouseOver"], 
              EdgeForm[{
                GrayLevel[0.5], 
                AbsoluteThickness[1.5], 
                Opacity[0.66]}], {}, {}], 
             RectangleBox[{7., 0}, {7.5, 10}, "RoundingRadius" -> 0]},
            
            ImageSizeCache->{{52.37499999999994, 93.24999999999994}, {
             3.076144036524518, 57.23009664739168}}],
           StatusArea[#, 10]& ,
           TagBoxNote->"10"],
          StyleBox["10", {
            GrayLevel[0]}, StripOnInput -> False]],
         Annotation[#, 
          Style[10, {
            GrayLevel[0]}], "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          TagBox[
           DynamicBox[{
             FEPrivate`If[
              CurrentValue["MouseOver"], 
              EdgeForm[{
                GrayLevel[0.5], 
                AbsoluteThickness[1.5], 
                Opacity[0.66]}], {}, {}], 
             RectangleBox[{7.5, 0}, {8., 17}, "RoundingRadius" -> 0]},
            
            ImageSizeCache->{{92.24999999999994, 
             133.12499999999994`}, {-34.1316227910825, 57.23009664739168}}],
           StatusArea[#, 17]& ,
           TagBoxNote->"17"],
          StyleBox["17", {
            GrayLevel[0]}, StripOnInput -> False]],
         Annotation[#, 
          Style[17, {
            GrayLevel[0]}], "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          TagBox[
           DynamicBox[{
             FEPrivate`If[
              CurrentValue["MouseOver"], 
              EdgeForm[{
                GrayLevel[0.5], 
                AbsoluteThickness[1.5], 
                Opacity[0.66]}], {}, {}], 
             RectangleBox[{8., 0}, {8.5, 12}, "RoundingRadius" -> 0]},
            ImageSizeCache->{{132.12499999999994`, 
             172.99999999999994`}, {-7.5546464856489095`, 57.23009664739168}}],
           StatusArea[#, 12]& ,
           TagBoxNote->"12"],
          StyleBox["12", {
            GrayLevel[0]}, StripOnInput -> False]],
         Annotation[#, 
          Style[12, {
            GrayLevel[0]}], "Tooltip"]& ]}, {}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{6.5, 0},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      PlotLabel->FormBox[
        TagBox[
         GridBox[{{"\"high\""}, {"\"small\""}}, 
          GridBoxAlignment -> {"Columns" -> {{Center}}}, DefaultBaseStyle -> 
          "Column", 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Column"], 
        TraditionalForm],
      PlotRange->{{6.5, 8.5}, {All, All}},
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.1]}},
      Ticks->{Automatic, Automatic}]}
   },
   AutoDelete->False,
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellChangeTimes->{
  3.585505679075221*^9, {3.5855057155160103`*^9, 3.585505741781652*^9}, {
   3.585505774950279*^9, 3.585505782319422*^9}, 3.585505859461093*^9, {
   3.585506018641458*^9, 3.5855060562998247`*^9}, 3.5855060879119864`*^9, {
   3.585506121034933*^9, 3.58550613095373*^9}, 3.5859997383803864`*^9}]
}, {2}]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[TextData[{
 "Multiple Conditions, ",
 StyleBox["BoxWhiskerChart", "Input",
  FontSize->36]
}], "Title",
 CellChangeTimes->{{3.585417299136742*^9, 3.585417302023638*^9}, {
  3.585486190840365*^9, 3.585486194479013*^9}, {3.5854955216795692`*^9, 
  3.585495536078971*^9}, {3.585495869960773*^9, 3.585495877024088*^9}, {
  3.5854984265503893`*^9, 3.585498429740182*^9}, {3.585499094894772*^9, 
  3.585499097542303*^9}, {3.58550056152886*^9, 3.585500572056347*^9}, {
  3.5855041255687923`*^9, 3.585504130967813*^9}, {3.58550491005755*^9, 
  3.5855049179996977`*^9}, {3.585505127301998*^9, 3.585505130595188*^9}, {
  3.585506505509509*^9, 3.585506509199935*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Partition", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"With", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"dat", "=", 
           RowBox[{"speed", "/.", "mxPHss"}]}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"BoxWhiskerChart", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"dat", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "2"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"\"\<Outliers\>\"", ",", 
             RowBox[{"{", 
              RowBox[{"\"\<MedianMarker\>\"", ",", "White"}], "}"}]}], "}"}], 
           ",", "\[IndentingNewLine]", 
           RowBox[{"BarOrigin", "\[Rule]", "Left"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"ChartLabels", "\[Rule]", 
            RowBox[{"dat", "[", 
             RowBox[{"[", 
              RowBox[{"All", ",", "1"}], "]"}], "]"}]}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"PlotLabel", "\[Rule]", "speed"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"ImageSize", "\[Rule]", "250"}]}], "\[IndentingNewLine]", 
          "]"}]}], "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"speed", ",", 
         RowBox[{"med", "[", 
          RowBox[{"speed", ",", "\"\<factors\>\""}], "]"}]}], "}"}]}], 
      "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", "2", ",", "2",
      ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", "}"}]}], "]"}], "//", "Reverse"}], "//", "Grid"}]], "Input",
 CellChangeTimes->{{3.585505630321286*^9, 3.5855057412877197`*^9}, {
  3.585505772055212*^9, 3.585505781830653*^9}, {3.585505842174966*^9, 
  3.585505857990263*^9}, {3.5855060166353683`*^9, 3.5855060557850447`*^9}, {
  3.5855060873139477`*^9, 3.585506141717018*^9}, {3.585506174727777*^9, 
  3.5855062505480013`*^9}, {3.585506285085061*^9, 3.585506288950142*^9}, {
  3.585506339807251*^9, 3.5855064245302343`*^9}, {3.585506461500578*^9, 
  3.585506463744803*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     GraphicsBox[{
       {Opacity[0], 
        PointBox[{{6.444999999999999, 0.4990857618568485}, {9.854999999999999,
          3.5009142381431513`}}]}, 
       {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], {}, 
        {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
         {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
          TagBox[
           TooltipBox[
            DynamicBox[{
              FEPrivate`If[
               CurrentValue["MouseOver"], 
               EdgeForm[{
                 GrayLevel[0.5], 
                 AbsoluteThickness[1.5], 
                 Opacity[0.66]}], {}, {}], 
              GraphicsGroupBox[{Antialiasing -> False, 
                
                PolygonBox[{{8., 0.7509076238812251}, {8., 
                 1.2490923761187749`}, {7.35, 1.2490923761187749`}, {7.35, 
                 0.7509076238812251}}], {}, {{}, {}}, {}, {
                 GrayLevel[0], 
                 GrayLevel[1], 
                 
                 LineBox[{{7.75, 1.2490923761187749`}, {7.75, 
                  0.7509076238812251}}]}, {}, {
                 GrayLevel[0], 
                 GrayLevel[0.5], 
                 LineBox[{{{7.35, 1.}, {6.6, 1.}}, {{8., 1.}, {8.4, 1.}}}]}, {
                 GrayLevel[0], 
                 GrayLevel[0.5], 
                 
                 LineBox[{{{6.6, 1.1245461880593874`}, {6.6, 
                  0.8754538119406126}}, {{8.4, 1.1245461880593874`}, {8.4, 
                  0.8754538119406126}}}]}, {}}]},
             
             ImageSizeCache->{{47.58578643762689, 156.4142135623731}, {
              26.585786437626886`, 50.41421356237311}}],
            StyleBox[
             TagBox[
              GridBox[{{
                 StyleBox["\"max\"", Bold, StripOnInput -> False], "8.4`"}, {
                 StyleBox["\"75%\"", Bold, StripOnInput -> False], "8.`"}, {
                 StyleBox["\"median\"", Bold, StripOnInput -> False], 
                 "7.75`"}, {
                 StyleBox["\"25%\"", Bold, StripOnInput -> False], "7.35`"}, {
                 StyleBox["\"min\"", Bold, StripOnInput -> False], "6.6`"}}, 
               GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
               AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, 
               GridBoxFrame -> {
                "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> Directive[
                 AbsoluteThickness[1], 
                 Dashing[{}]]], "Grid"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Grid[{{
                Style["max", Bold], 8.4}, {
                Style["75%", Bold], 8.}, {
                Style["median", Bold], 7.75}, {
                Style["25%", Bold], 7.35}, {
                Style["min", Bold], 6.6}}, Dividers -> {{
                 Directive[
                  GrayLevel[0.3]], {
                  Directive[
                   GrayLevel[0.3]]}, 
                 Directive[
                  GrayLevel[0.3]]}, {
                 Directive[
                  GrayLevel[0.3]], {
                  Directive[
                   GrayLevel[0.3]]}, 
                 Directive[
                  GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
              Frame -> GrayLevel[0], BaseStyle -> Directive[
                AbsoluteThickness[1], 
                Dashing[{}]]], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
          TagBox[
           TooltipBox[
            DynamicBox[{
              FEPrivate`If[
               CurrentValue["MouseOver"], 
               EdgeForm[{
                 GrayLevel[0.5], 
                 AbsoluteThickness[1.5], 
                 Opacity[0.66]}], {}, {}], 
              GraphicsGroupBox[{Antialiasing -> False, 
                
                PolygonBox[{{8.5, 1.7509076238812251`}, {8.5, 
                 2.249092376118775}, {7.7, 2.249092376118775}, {7.7, 
                 1.7509076238812251`}}], {}, {{}, {}}, {}, {
                 GrayLevel[0], 
                 GrayLevel[1], 
                 
                 LineBox[{{8.2, 2.249092376118775}, {8.2, 
                  1.7509076238812251`}}]}, {}, {
                 GrayLevel[0], 
                 GrayLevel[0.5], 
                 LineBox[{{{7.7, 2.}, {7.3, 2.}}, {{8.5, 2.}, {9.7, 2.}}}]}, {
                 GrayLevel[0], 
                 GrayLevel[0.5], 
                 
                 LineBox[{{{7.3, 2.124546188059387}, {7.3, 
                  1.8754538119406126`}}, {{9.7, 2.124546188059387}, {9.7, 
                  1.8754538119406126`}}}]}, {}}]},
             
             ImageSizeCache->{{88.5857864376269, 
              233.4142135623731}, {-15.414213562373106`, 8.414213562373106}}],
            StyleBox[
             TagBox[
              GridBox[{{
                 StyleBox["\"max\"", Bold, StripOnInput -> False], "9.7`"}, {
                 StyleBox["\"75%\"", Bold, StripOnInput -> False], "8.5`"}, {
                 StyleBox["\"median\"", Bold, StripOnInput -> False], 
                 "8.2`"}, {
                 StyleBox["\"25%\"", Bold, StripOnInput -> False], "7.7`"}, {
                 StyleBox["\"min\"", Bold, StripOnInput -> False], "7.3`"}}, 
               GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
               AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, 
               GridBoxFrame -> {
                "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> Directive[
                 AbsoluteThickness[1], 
                 Dashing[{}]]], "Grid"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Grid[{{
                Style["max", Bold], 9.7}, {
                Style["75%", Bold], 8.5}, {
                Style["median", Bold], 8.2}, {
                Style["25%", Bold], 7.7}, {
                Style["min", Bold], 7.3}}, Dividers -> {{
                 Directive[
                  GrayLevel[0.3]], {
                  Directive[
                   GrayLevel[0.3]]}, 
                 Directive[
                  GrayLevel[0.3]]}, {
                 Directive[
                  GrayLevel[0.3]], {
                  Directive[
                   GrayLevel[0.3]]}, 
                 Directive[
                  GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
              Frame -> GrayLevel[0], BaseStyle -> Directive[
                AbsoluteThickness[1], 
                Dashing[{}]]], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
          TagBox[
           TooltipBox[
            DynamicBox[{
              FEPrivate`If[
               CurrentValue["MouseOver"], 
               EdgeForm[{
                 GrayLevel[0.5], 
                 AbsoluteThickness[1.5], 
                 Opacity[0.66]}], {}, {}], 
              GraphicsGroupBox[{Antialiasing -> False, 
                
                PolygonBox[{{8.4, 2.750907623881225}, {8.4, 
                 3.249092376118775}, {7.4, 3.249092376118775}, {7.4, 
                 2.750907623881225}}], {}, {{}, {}}, {}, {
                 GrayLevel[0], 
                 GrayLevel[1], 
                 
                 LineBox[{{8.1, 3.249092376118775}, {8.1, 
                  2.750907623881225}}]}, {}, {
                 GrayLevel[0], 
                 GrayLevel[0.5], 
                 LineBox[{{{7.4, 3.}, {7.3, 3.}}, {{8.4, 3.}, {8.7, 3.}}}]}, {
                 GrayLevel[0], 
                 GrayLevel[0.5], 
                 
                 LineBox[{{{7.3, 3.124546188059387}, {7.3, 
                  2.875453811940613}}, {{8.7, 3.124546188059387}, {8.7, 
                  2.875453811940613}}}]}, {}}]},
             
             ImageSizeCache->{{88.5857864376269, 
              174.4142135623731}, {-56.414213562373114`, -32.58578643762689}}],
            StyleBox[
             TagBox[
              GridBox[{{
                 StyleBox["\"max\"", Bold, StripOnInput -> False], "8.7`"}, {
                 StyleBox["\"75%\"", Bold, StripOnInput -> False], "8.4`"}, {
                 StyleBox["\"median\"", Bold, StripOnInput -> False], 
                 "8.1`"}, {
                 StyleBox["\"25%\"", Bold, StripOnInput -> False], "7.4`"}, {
                 StyleBox["\"min\"", Bold, StripOnInput -> False], "7.3`"}}, 
               GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
               AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, 
               GridBoxFrame -> {
                "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> Directive[
                 AbsoluteThickness[1], 
                 Dashing[{}]]], "Grid"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Grid[{{
                Style["max", Bold], 8.7}, {
                Style["75%", Bold], 8.4}, {
                Style["median", Bold], 8.1}, {
                Style["25%", Bold], 7.4}, {
                Style["min", Bold], 7.3}}, Dividers -> {{
                 Directive[
                  GrayLevel[0.3]], {
                  Directive[
                   GrayLevel[0.3]]}, 
                 Directive[
                  GrayLevel[0.3]]}, {
                 Directive[
                  GrayLevel[0.3]], {
                  Directive[
                   GrayLevel[0.3]]}, 
                 Directive[
                  GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
              Frame -> GrayLevel[0], BaseStyle -> Directive[
                AbsoluteThickness[1], 
                Dashing[{}]]], {
              GrayLevel[0]}], 
            "Tooltip"]& ]}}, {}, {}}, {{{{{{{}, {}}, {}}, {{{}, {}}, {}}, \
{{{}, {}}, {}}}, {}}, {}}, {}}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{False, False},
      Frame->True,
      FrameLabel->{None, None},
      FrameTicks->{{{{0.7509076238812251, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[0]], TraditionalForm], {0, 0}}, {3.249092376118775, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[0]], TraditionalForm], {0, 0}}, {1., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[0]], TraditionalForm], {0.008, 0}}, {1., 
           FormBox["\"small\"", TraditionalForm], 0}, {2., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[0]], TraditionalForm], {0.008, 0}}, {2., 
           FormBox["\"medium\"", TraditionalForm], 0}, {3., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[0]], TraditionalForm], {0.008, 0}}, {3., 
           FormBox["\"large\"", TraditionalForm], 0}}, {{0.7509076238812251, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[0]], TraditionalForm], {0, 0}}, {3.249092376118775, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[0]], TraditionalForm], {0, 0}}, {1., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[0]], TraditionalForm], {0.008, 0}}, {2., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[0]], TraditionalForm], {0.008, 0}}, {3., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[0]], TraditionalForm], {0.008, 0}}}}, {
        Automatic, Automatic}},
      ImageSize->250,
      PlotLabel->FormBox["\"high\"", TraditionalForm],
      PlotRangePadding->Scaled[0.02],
      Ticks->{Automatic, None}], ""},
    {
     GraphicsBox[{
       {Opacity[0], 
        PointBox[{{7.4, 0.4990857618568485}, {9.6, 3.5009142381431513`}}]}, 
       {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], {}, 
        {RGBColor[
         0.798413061722744, 0.824719615472648, 0.968322270542458], {}, 
         {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
          TagBox[
           TooltipBox[
            DynamicBox[{
              FEPrivate`If[
               CurrentValue["MouseOver"], 
               EdgeForm[{
                 GrayLevel[0.5], 
                 AbsoluteThickness[1.5], 
                 Opacity[0.66]}], {}, {}], 
              GraphicsGroupBox[{Antialiasing -> False, 
                
                PolygonBox[{{8.5, 1.7509076238812251`}, {8.5, 
                 2.249092376118775}, {7.7, 2.249092376118775}, {7.7, 
                 1.7509076238812251`}}], {}, {{}, {}}, {}, {
                 GrayLevel[0], 
                 GrayLevel[1], 
                 LineBox[{{8.1, 2.249092376118775}, {8.1, 
                  1.7509076238812251`}}]}, {}, {
                 GrayLevel[0], 
                 GrayLevel[0.5], 
                 LineBox[{{{7.7, 2.}, {7.5, 2.}}, {{8.5, 2.}, {9.1, 2.}}}]}, {
                 GrayLevel[0], 
                 GrayLevel[0.5], 
                 
                 LineBox[{{{7.5, 2.124546188059387}, {7.5, 
                  1.8754538119406126`}}, {{9.1, 2.124546188059387}, {9.1, 
                  1.8754538119406126`}}}]}, {}}]},
             
             ImageSizeCache->{{47.58578643762689, 
              196.4142135623731}, {-15.414213562373106`, 8.414213562373106}}],
            StyleBox[
             TagBox[
              GridBox[{{
                 StyleBox["\"max\"", Bold, StripOnInput -> False], "9.1`"}, {
                 StyleBox["\"75%\"", Bold, StripOnInput -> False], "8.5`"}, {
                 StyleBox["\"median\"", Bold, StripOnInput -> False], 
                 "8.1`"}, {
                 StyleBox["\"25%\"", Bold, StripOnInput -> False], "7.7`"}, {
                 StyleBox["\"min\"", Bold, StripOnInput -> False], "7.5`"}}, 
               GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
               AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, 
               GridBoxFrame -> {
                "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> Directive[
                 AbsoluteThickness[1], 
                 Dashing[{}]]], "Grid"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Grid[{{
                Style["max", Bold], 9.1}, {
                Style["75%", Bold], 8.5}, {
                Style["median", Bold], 8.1}, {
                Style["25%", Bold], 7.7}, {
                Style["min", Bold], 7.5}}, Dividers -> {{
                 Directive[
                  GrayLevel[0.3]], {
                  Directive[
                   GrayLevel[0.3]]}, 
                 Directive[
                  GrayLevel[0.3]]}, {
                 Directive[
                  GrayLevel[0.3]], {
                  Directive[
                   GrayLevel[0.3]]}, 
                 Directive[
                  GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
              Frame -> GrayLevel[0], BaseStyle -> Directive[
                AbsoluteThickness[1], 
                Dashing[{}]]], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
          TagBox[
           TooltipBox[
            DynamicBox[{
              FEPrivate`If[
               CurrentValue["MouseOver"], 
               EdgeForm[{
                 GrayLevel[0.5], 
                 AbsoluteThickness[1.5], 
                 Opacity[0.66]}], {}, {}], 
              GraphicsGroupBox[{Antialiasing -> False, 
                
                PolygonBox[{{8.8, 2.750907623881225}, {8.8, 
                 3.249092376118775}, {8.4, 3.249092376118775}, {8.4, 
                 2.750907623881225}}], {}, {{
                  InsetBox[
                   BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                   7.6, 3.}], 
                  InsetBox[
                   BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                   9.5, 3.}]}, {}}, {}, {
                 GrayLevel[0], 
                 GrayLevel[1], 
                 
                 LineBox[{{8.56, 3.249092376118775}, {8.56, 
                  2.750907623881225}}]}, {}, {
                 GrayLevel[0], 
                 GrayLevel[0.5], 
                 LineBox[{{{8.4, 3.}, {7.8, 3.}}, {{8.8, 3.}, {9.1, 3.}}}]}, {
                 GrayLevel[0], 
                 GrayLevel[0.5], 
                 
                 LineBox[{{{7.8, 3.124546188059387}, {7.8, 
                  2.875453811940613}}, {{9.1, 3.124546188059387}, {9.1, 
                  2.875453811940613}}}]}, {}}]},
             
             ImageSizeCache->{{54.505786437626966`, 
              235.61421356237327`}, {-56.414213562373114`, \
-32.58578643762689}}],
            StyleBox[
             TagBox[
              GridBox[{{
                 StyleBox["\"max\"", Bold, StripOnInput -> False], "9.5`"}, {
                 StyleBox["\"75%\"", Bold, StripOnInput -> False], "8.8`"}, {
                 StyleBox["\"median\"", Bold, StripOnInput -> False], 
                 "8.56`"}, {
                 StyleBox["\"25%\"", Bold, StripOnInput -> False], "8.4`"}, {
                 StyleBox["\"min\"", Bold, StripOnInput -> False], "7.6`"}}, 
               GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
               AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, 
               GridBoxFrame -> {
                "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> Directive[
                 AbsoluteThickness[1], 
                 Dashing[{}]]], "Grid"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Grid[{{
                Style["max", Bold], 9.5}, {
                Style["75%", Bold], 8.8}, {
                Style["median", Bold], 8.56}, {
                Style["25%", Bold], 8.4}, {
                Style["min", Bold], 7.6}}, Dividers -> {{
                 Directive[
                  GrayLevel[0.3]], {
                  Directive[
                   GrayLevel[0.3]]}, 
                 Directive[
                  GrayLevel[0.3]]}, {
                 Directive[
                  GrayLevel[0.3]], {
                  Directive[
                   GrayLevel[0.3]]}, 
                 Directive[
                  GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
              Frame -> GrayLevel[0], BaseStyle -> Directive[
                AbsoluteThickness[1], 
                Dashing[{}]]], {
              GrayLevel[0]}], 
            "Tooltip"]& ]}}, {}, {}}, {{{{{}, {{{}, {}}, {}}, {{{}, {}}, \
{}}}, {}}, {}}, {}}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{False, False},
      Frame->True,
      FrameLabel->{None, None},
      FrameTicks->{{{{0.7509076238812251, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[0]], TraditionalForm], {0, 0}}, {3.249092376118775, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[0]], TraditionalForm], {0, 0}}, {1., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[0]], TraditionalForm], {0.008, 0}}, {1., 
           FormBox["\"small\"", TraditionalForm], 0}, {2., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[0]], TraditionalForm], {0.008, 0}}, {2., 
           FormBox["\"medium\"", TraditionalForm], 0}, {3., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[0]], TraditionalForm], {0.008, 0}}, {3., 
           FormBox["\"large\"", TraditionalForm], 0}}, {{0.7509076238812251, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[0]], TraditionalForm], {0, 0}}, {3.249092376118775, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[0]], TraditionalForm], {0, 0}}, {1., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[0]], TraditionalForm], {0.008, 0}}, {2., 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[0]], TraditionalForm], {0.008, 0}}, {3., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[0]], TraditionalForm], {0.008, 0}}}}, {
        Automatic, Automatic}},
      ImageSize->250,
      PlotLabel->FormBox["\"low\"", TraditionalForm],
      PlotRangePadding->Scaled[0.02],
      Ticks->{Automatic, None}], 
     GraphicsBox[{
       {Opacity[0], 
        PointBox[{{5.425, 0.4990857618568485}, {9.275, 
         3.5009142381431513`}}]}, 
       {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], {}, 
        {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
         {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
          TagBox[
           TooltipBox[
            DynamicBox[{
              FEPrivate`If[
               CurrentValue["MouseOver"], 
               EdgeForm[{
                 GrayLevel[0.5], 
                 AbsoluteThickness[1.5], 
                 Opacity[0.66]}], {}, {}], 
              GraphicsGroupBox[{Antialiasing -> False, 
                
                PolygonBox[{{8.15, 0.7509076238812251}, {8.15, 
                 1.2490923761187749`}, {7.5, 1.2490923761187749`}, {7.5, 
                 0.7509076238812251}}], {}, {{
                  InsetBox[
                   BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                   5.6, 1.}], 
                  InsetBox[
                   BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                   5.7, 1.}], 
                  InsetBox[
                   BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                   6.5, 1.}], 
                  InsetBox[
                   BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                   6.4, 1.}]}, {}}, {}, {
                 GrayLevel[0], 
                 GrayLevel[1], 
                 
                 LineBox[{{8., 1.2490923761187749`}, {8., 
                  0.7509076238812251}}]}, {}, {
                 GrayLevel[0], 
                 GrayLevel[0.5], 
                 LineBox[{{{7.5, 1.}, {6.6, 1.}}, {{8.15, 1.}, {8.7, 1.}}}]}, {
                 GrayLevel[0], 
                 GrayLevel[0.5], 
                 
                 LineBox[{{{6.6, 1.1245461880593874`}, {6.6, 
                  0.8754538119406126}}, {{8.7, 1.1245461880593874`}, {8.7, 
                  0.8754538119406126}}}]}, {}}]},
             
             ImageSizeCache->{{45.38578643762685, 212.4142135623731}, {
              26.58578643762689, 50.41421356237311}}],
            StyleBox[
             TagBox[
              GridBox[{{
                 StyleBox["\"max\"", Bold, StripOnInput -> False], "8.7`"}, {
                 StyleBox["\"75%\"", Bold, StripOnInput -> False], "8.15`"}, {
                 StyleBox["\"median\"", Bold, StripOnInput -> False], "8.`"}, {
                 StyleBox["\"25%\"", Bold, StripOnInput -> False], "7.5`"}, {
                 StyleBox["\"min\"", Bold, StripOnInput -> False], "5.6`"}}, 
               GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
               AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, 
               GridBoxFrame -> {
                "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> Directive[
                 AbsoluteThickness[1], 
                 Dashing[{}]]], "Grid"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Grid[{{
                Style["max", Bold], 8.7}, {
                Style["75%", Bold], 8.15}, {
                Style["median", Bold], 8.}, {
                Style["25%", Bold], 7.5}, {
                Style["min", Bold], 5.6}}, Dividers -> {{
                 Directive[
                  GrayLevel[0.3]], {
                  Directive[
                   GrayLevel[0.3]]}, 
                 Directive[
                  GrayLevel[0.3]]}, {
                 Directive[
                  GrayLevel[0.3]], {
                  Directive[
                   GrayLevel[0.3]]}, 
                 Directive[
                  GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
              Frame -> GrayLevel[0], BaseStyle -> Directive[
                AbsoluteThickness[1], 
                Dashing[{}]]], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
          TagBox[
           TooltipBox[
            DynamicBox[{
              FEPrivate`If[
               CurrentValue["MouseOver"], 
               EdgeForm[{
                 GrayLevel[0.5], 
                 AbsoluteThickness[1.5], 
                 Opacity[0.66]}], {}, {}], 
              GraphicsGroupBox[{Antialiasing -> False, 
                
                PolygonBox[{{8.2, 1.7509076238812251`}, {8.2, 
                 2.249092376118775}, {7.8, 2.249092376118775}, {7.8, 
                 1.7509076238812251`}}], {}, {{
                  InsetBox[
                   BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                   9.1, 2.}], 
                  InsetBox[
                   BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                   9., 2.}]}, {}}, {}, {
                 GrayLevel[0], 
                 GrayLevel[1], 
                 
                 LineBox[{{8., 2.249092376118775}, {8., 
                  1.7509076238812251`}}]}, {}, {
                 GrayLevel[0], 
                 GrayLevel[0.5], 
                 LineBox[{{{7.8, 2.}, {7.4, 2.}}, {{8.2, 2.}, {8.7, 2.}}}]}, {
                 GrayLevel[0], 
                 GrayLevel[0.5], 
                 
                 LineBox[{{{7.4, 2.124546188059387}, {7.4, 
                  1.8754538119406126`}}, {{8.7, 2.124546188059387}, {8.7, 
                  1.8754538119406126`}}}]}, {}}]},
             
             ImageSizeCache->{{141.5857864376269, 
              235.61421356237304`}, {-15.414213562373106`, 
              8.414213562373106}}],
            StyleBox[
             TagBox[
              GridBox[{{
                 StyleBox["\"max\"", Bold, StripOnInput -> False], "9.1`"}, {
                 StyleBox["\"75%\"", Bold, StripOnInput -> False], "8.2`"}, {
                 StyleBox["\"median\"", Bold, StripOnInput -> False], "8.`"}, {
                 StyleBox["\"25%\"", Bold, StripOnInput -> False], "7.8`"}, {
                 StyleBox["\"min\"", Bold, StripOnInput -> False], "7.4`"}}, 
               GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
               AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, 
               GridBoxFrame -> {
                "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> Directive[
                 AbsoluteThickness[1], 
                 Dashing[{}]]], "Grid"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Grid[{{
                Style["max", Bold], 9.1}, {
                Style["75%", Bold], 8.2}, {
                Style["median", Bold], 8.}, {
                Style["25%", Bold], 7.8}, {
                Style["min", Bold], 7.4}}, Dividers -> {{
                 Directive[
                  GrayLevel[0.3]], {
                  Directive[
                   GrayLevel[0.3]]}, 
                 Directive[
                  GrayLevel[0.3]]}, {
                 Directive[
                  GrayLevel[0.3]], {
                  Directive[
                   GrayLevel[0.3]]}, 
                 Directive[
                  GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
              Frame -> GrayLevel[0], BaseStyle -> Directive[
                AbsoluteThickness[1], 
                Dashing[{}]]], {
              GrayLevel[0]}], "Tooltip"]& ]}, 
         {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
          TagBox[
           TooltipBox[
            DynamicBox[{
              FEPrivate`If[
               CurrentValue["MouseOver"], 
               EdgeForm[{
                 GrayLevel[0.5], 
                 AbsoluteThickness[1.5], 
                 Opacity[0.66]}], {}, {}], 
              GraphicsGroupBox[{Antialiasing -> False, 
                
                PolygonBox[{{8.5, 2.750907623881225}, {8.5, 
                 3.249092376118775}, {8.21, 3.249092376118775}, {8.21, 
                 2.750907623881225}}], {}, {{
                  InsetBox[
                   BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                   9.06, 3.}]}, {}}, {}, {
                 GrayLevel[0], 
                 GrayLevel[1], 
                 
                 LineBox[{{8.4, 3.249092376118775}, {8.4, 
                  2.750907623881225}}]}, {}, {
                 GrayLevel[0], 
                 GrayLevel[0.5], 
                 
                 LineBox[{{{8.21, 3.}, {7.91, 3.}}, {{8.5, 3.}, {8.7, 
                  3.}}}]}, {
                 GrayLevel[0], 
                 GrayLevel[0.5], 
                 
                 LineBox[{{{7.91, 3.124546188059387}, {7.91, 
                  2.875453811940613}}, {{8.7, 3.124546188059387}, {8.7, 
                  2.875453811940613}}}]}, {}}]},
             
             ImageSizeCache->{{167.5857864376269, 
              233.5296421338017}, {-56.414213562373114`, -32.58578643762689}}],
            StyleBox[
             TagBox[
              GridBox[{{
                 StyleBox["\"max\"", Bold, StripOnInput -> False], "9.06`"}, {
                 StyleBox["\"75%\"", Bold, StripOnInput -> False], "8.5`"}, {
                 StyleBox["\"median\"", Bold, StripOnInput -> False], 
                 "8.4`"}, {
                 StyleBox["\"25%\"", Bold, StripOnInput -> False], "8.21`"}, {
                 StyleBox["\"min\"", Bold, StripOnInput -> False], "7.91`"}}, 
               GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
               AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, 
               GridBoxFrame -> {
                "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> Directive[
                 AbsoluteThickness[1], 
                 Dashing[{}]]], "Grid"], {
              GrayLevel[0]}, StripOnInput -> False]],
           Annotation[#, 
            Style[
             Grid[{{
                Style["max", Bold], 9.06}, {
                Style["75%", Bold], 8.5}, {
                Style["median", Bold], 8.4}, {
                Style["25%", Bold], 8.21}, {
                Style["min", Bold], 7.91}}, Dividers -> {{
                 Directive[
                  GrayLevel[0.3]], {
                  Directive[
                   GrayLevel[0.3]]}, 
                 Directive[
                  GrayLevel[0.3]]}, {
                 Directive[
                  GrayLevel[0.3]], {
                  Directive[
                   GrayLevel[0.3]]}, 
                 Directive[
                  GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
              Frame -> GrayLevel[0], BaseStyle -> Directive[
                AbsoluteThickness[1], 
                Dashing[{}]]], {
              GrayLevel[0]}], 
            "Tooltip"]& ]}}, {}, {}}, {{{{{{{}, {}}, {}}, {{{}, {}}, {}}, \
{{{}, {}}, {}}}, {}}, {}}, {}}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{False, False},
      Frame->True,
      FrameLabel->{None, None},
      FrameTicks->{{{{0.7509076238812251, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[0]], TraditionalForm], {0, 0}}, {3.249092376118775, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[0]], TraditionalForm], {0, 0}}, {1., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[0]], TraditionalForm], {0.008, 0}}, {1., 
           FormBox["\"small\"", TraditionalForm], 0}, {2., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[0]], TraditionalForm], {0.008, 0}}, {2., 
           FormBox["\"medium\"", TraditionalForm], 0}, {3., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[0]], TraditionalForm], {0.008, 0}}, {3., 
           FormBox["\"large\"", TraditionalForm], 0}}, {{0.7509076238812251, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[0]], TraditionalForm], {0, 0}}, {3.249092376118775, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[0]], TraditionalForm], {0, 0}}, {1., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[0]], TraditionalForm], {0.008, 0}}, {2., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[0]], TraditionalForm], {0.008, 0}}, {3., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[0]], TraditionalForm], {0.008, 0}}}}, {
        Automatic, Automatic}},
      ImageSize->250,
      PlotLabel->FormBox["\"medium\"", TraditionalForm],
      PlotRangePadding->Scaled[0.02],
      Ticks->{Automatic, None}]}
   },
   AutoDelete->False,
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellChangeTimes->{
  3.585506253939495*^9, 3.585506293023015*^9, {3.5855063582642927`*^9, 
   3.585506425097146*^9}, 3.585506464135495*^9, 3.585999767046001*^9, 
   3.585999841179864*^9}]
}, {2}]],

Cell["\<\
In principle we could apply a centrality measure to the conditional \
distributions our missing values are members of.  Unfortunately in this case \
the missing mxPH value corresponds to a size/speed combination we have no \
data for:\
\>", "Text",
 CellChangeTimes->{{3.585506592829442*^9, 3.5855067150510197`*^9}, {
  3.5855067714897327`*^9, 3.585506801417091*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"trimmed", "[", "All", "]"}], "[", 
  RowBox[{"[", "48", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.574764521276771*^9, 3.574764527064102*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"winter\"\>", ",", "\<\"small\"\>", ",", "\<\"low\"\>", ",", 
   RowBox[{"Missing", "[", "]"}], ",", "12.6`", ",", "9.`", ",", "0.23`", ",",
    "10.`", ",", "5.`", ",", "6.`", ",", "1.1`", ",", "35.5`", ",", "0.`", 
   ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.574764527401121*^9, 3.5747715874429326`*^9, 
  3.5747716395899153`*^9, 3.574772701111631*^9, 3.5747902309922757`*^9, 
  3.575109355264721*^9, 3.575204948781221*^9, 3.575801829759947*^9, 
  3.585506729189611*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Similarities between Rows", "Title",
 CellChangeTimes->{{3.585417299136742*^9, 3.585417302023638*^9}, {
  3.585486190840365*^9, 3.585486194479013*^9}, {3.5854955216795692`*^9, 
  3.585495536078971*^9}, {3.585495869960773*^9, 3.585495877024088*^9}, {
  3.5854984265503893`*^9, 3.585498429740182*^9}, {3.585499094894772*^9, 
  3.585499097542303*^9}, {3.58550056152886*^9, 3.585500572056347*^9}, {
  3.5855041255687923`*^9, 3.585504130967813*^9}, {3.58550491005755*^9, 
  3.5855049179996977`*^9}, {3.585505127301998*^9, 3.585505130595188*^9}, {
  3.585506505509509*^9, 3.585506509199935*^9}, {3.5855073849495363`*^9, 
  3.585507390853044*^9}}],

Cell["\<\
The correlation technique looks for similarities between columns.  It is also \
possible to impute using similarities between rows.\
\>", "Text",
 CellChangeTimes->{{3.585507399244678*^9, 3.585507504034893*^9}, {
  3.5855691695246*^9, 3.585569171170711*^9}}],

Cell["\<\
Define a distance metric applicable to two rows, then use the k nearest \
neighbors of the problematic row to fill in missing values (again using a \
centrality measure).\
\>", "Text",
 CellChangeTimes->{{3.585507399244678*^9, 3.585507504034893*^9}, {
  3.5855691695246*^9, 3.585569183856588*^9}}],

Cell["\<\
We will use a Euclidean distance metric with special treatment for nominal \
variables, then (in the default treatment) exponentially weight the average \
of the top k nearest distances.\
\>", "Text",
 CellChangeTimes->{{3.585507535001848*^9, 3.585507570121314*^9}, {
  3.5855691951204643`*^9, 3.585569197336244*^9}, {3.585911620430101*^9, 
  3.58591162687502*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", 
    RowBox[{
    "delta", ",", "distFn", ",", "normalize", ",", "normalizeCol", ",", 
     "knnImpute"}], "]"}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Note", " ", "how", " ", "difference", " ", "is", " ", "defined", " ", 
    "for", " ", "nominal", " ", "variables"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"delta", "[", 
     RowBox[{"u1_", ",", "u2_"}], "]"}], ":=", 
    RowBox[{"Switch", "[", 
     RowBox[{"u1", ",", "\[IndentingNewLine]", 
      RowBox[{"_", "?", "NumericQ"}], ",", 
      RowBox[{"(", 
       RowBox[{"u1", "-", "u2"}], ")"}], ",", "\[IndentingNewLine]", "_", ",", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"u1", "\[Equal]", "u2"}], ",", "1", ",", "0"}], "]"}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Distance", " ", "between", " ", "two", " ", "rows"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"distFn", "[", 
     RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"distFn", "[", 
      RowBox[{"x", ",", "y"}], "]"}], "=", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"MemberQ", "[", 
        RowBox[{"x", ",", 
         RowBox[{"Missing", "[", "]"}]}], "]"}], ",", "\[IndentingNewLine]", 
       "Infinity", ",", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", "else", " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"Sqrt", "@", 
        RowBox[{"Total", "[", 
         RowBox[{"MapThread", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"delta", "[", 
              RowBox[{"#1", ",", "#2"}], "]"}], "^", "2"}], "&"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "y"}], "}"}]}], "]"}], "]"}]}]}], 
      "\[IndentingNewLine]", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Normalize", " ", "dataset", " ", "to", " ", "mean", " ", "and", " ", 
    "standard", " ", "deviation"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"normalizeCol", "[", "colDat_", "]"}], ":=", 
   RowBox[{"Module", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"d", "=", 
        RowBox[{"DeleteCases", "[", 
         RowBox[{"colDat", ",", "_Missing"}], "]"}]}], ",", "\[Mu]", ",", 
       "\[Sigma]"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[Mu]", ",", "\[Sigma]"}], "}"}], "=", 
       RowBox[{"Through", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Mean", ",", "StandardDeviation"}], "}"}], "[", "d", "]"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"colDat", "/.", 
       RowBox[{
        RowBox[{"x_", "?", "NumericQ"}], "\[RuleDelayed]", 
        RowBox[{"N", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"x", "-", "\[Mu]"}], ")"}], "/", "\[Sigma]"}], 
         "]"}]}]}]}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"normalize", "[", "dat_", "]"}], ":=", 
    RowBox[{"Transpose", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"normalizeCol", "[", "#", "]"}], "&"}], "/@", 
      RowBox[{"Transpose", "[", "dat", "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Options", "[", "knnImpute", "]"}], "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\"\<Method\>\"", "\[Rule]", "Automatic"}], ",", 
      RowBox[{"\"\<Neighbors\>\"", "\[Rule]", "10"}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"knnImpute", "[", 
     RowBox[{"set_", ",", 
      RowBox[{"o", ":", 
       RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
    RowBox[{"knnImpute", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"set", ",", "set"}], "}"}], ",", 
      RowBox[{"set", "[", 
       RowBox[{"All", ",", "\"\<columns\>\""}], "]"}], ",", 
      RowBox[{"Complement", "[", 
       RowBox[{
        RowBox[{"set", "[", 
         RowBox[{"All", ",", "\"\<columns\>\""}], "]"}], ",", 
        RowBox[{"set", "[", 
         RowBox[{"All", ",", "\"\<nominals\>\""}], "]"}]}], "]"}], ",", "o"}],
      "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"knnImpute", "[", 
     RowBox[{"set_", ",", "useCols_", ",", "fixCols_", ",", 
      RowBox[{"o", ":", 
       RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
    RowBox[{"knnImpute", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"set", ",", "set"}], "}"}], ",", "useCols", ",", "fixCols", 
      ",", "o"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"knnImpute", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"fromSet_", ",", "toSet_"}], "}"}], ",", "useCols_", ",", 
    "fixCols_", ",", 
    RowBox[{"o", ":", 
     RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
     "toDat", ",", "toDistDat", ",", "fromDat", ",", "fromDistDat", ",", 
      "\[IndentingNewLine]", "suggestFix", ",", "fixes", ",", "fixPos", ",", 
      "\[IndentingNewLine]", 
      RowBox[{"k", "=", 
       RowBox[{"OptionValue", "[", "\"\<Neighbors\>\"", "]"}]}]}], 
     "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"fromDat", "=", 
      RowBox[{"fromSet", "[", "All", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"fromDistDat", "=", 
      RowBox[{"normalize", "@", "fromDat"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"toDat", "=", 
      RowBox[{"toSet", "[", "All", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"toDistDat", "=", 
      RowBox[{"normalize", "@", "toDat"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"fixPos", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"Rule", "[", 
         RowBox[{"#", ",", 
          RowBox[{"Flatten", "@", 
           RowBox[{"toSet", "[", 
            RowBox[{"#", ",", "\"\<missing\>\""}], "]"}]}]}], "]"}], "&"}], "/@",
        "fixCols"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{
       "Given", " ", "position", " ", "of", " ", "missing", " ", "element"}], 
       ",", " ", 
       RowBox[{
       "suggest", " ", "imputation", " ", "based", " ", "on", " ", "k", " ", 
        "nearest", " ", "neighbors"}]}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"suggestFix", "[", 
       RowBox[{"row_", ",", "colnum_"}], "]"}], ":=", 
      RowBox[{"Module", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "distances", ",", "ord", ",", "weights", ",", "theCols", ",", 
          "cleanVect", ",", "v"}], "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"theCols", "=", 
          RowBox[{"Complement", "[", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"useCols", "/.", "numberedColumns"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"Flatten", "@", 
             RowBox[{"Position", "[", 
              RowBox[{
               RowBox[{"toDat", "[", 
                RowBox[{"[", "row", "]"}], "]"}], ",", 
               RowBox[{"Missing", "[", "]"}]}], "]"}]}]}], 
           "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"distances", "=", 
          RowBox[{
           RowBox[{
            RowBox[{"distFn", "[", 
             RowBox[{"#", ",", 
              RowBox[{"toDistDat", "[", 
               RowBox[{"[", 
                RowBox[{"row", ",", "theCols"}], "]"}], "]"}]}], "]"}], "&"}],
            "/@", 
           RowBox[{"fromDistDat", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "theCols"}], "]"}], "]"}]}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"ord", "=", 
          RowBox[{"Ordering", "[", "distances", "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"cleanVect", "[", "vect_", "]"}], ":=", 
          RowBox[{"With", "[", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"vPrime", "=", 
              RowBox[{
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{"fromSet", "===", "toSet"}], ",", 
                 RowBox[{"Rest", "[", "vect", "]"}], ",", "vect"}], "]"}], "/.", 
               RowBox[{
                RowBox[{"Missing", "[", "]"}], "\[Rule]", 
                RowBox[{"Sequence", "[", "]"}]}]}]}], "}"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"Take", "[", 
             RowBox[{"vPrime", ",", 
              RowBox[{"Min", "[", 
               RowBox[{"k", ",", 
                RowBox[{"Length", "[", "vPrime", "]"}]}], "]"}]}], "]"}]}], 
           "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"v", "=", 
          RowBox[{"cleanVect", "@", 
           RowBox[{"fromDat", "[", 
            RowBox[{"[", 
             RowBox[{"ord", ",", "colnum"}], "]"}], "]"}]}]}], ";", 
         "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{"Switch", "[", 
          RowBox[{
           RowBox[{"OptionValue", "[", "\"\<Method\>\"", "]"}], ",", 
           "\[IndentingNewLine]", "\"\<Median\>\"", ",", 
           "\[IndentingNewLine]", 
           RowBox[{"v", "/.", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"x", ":", 
                RowBox[{"{", 
                 RowBox[{"__", "?", "NumericQ"}], "}"}]}], "\[RuleDelayed]", 
               RowBox[{"Median", "[", "x", "]"}]}], ",", 
              RowBox[{"y_List", "\[RuleDelayed]", 
               RowBox[{"First", "@", 
                RowBox[{"Commonest", "[", "y", "]"}]}]}]}], "}"}]}], ",", 
           "\[IndentingNewLine]", "\[IndentingNewLine]", "_", ",", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"weights", "=", 
             RowBox[{"Exp", "[", 
              RowBox[{"-", 
               RowBox[{"cleanVect", "@", 
                RowBox[{"distances", "[", 
                 RowBox[{"[", "ord", "]"}], "]"}]}]}], "]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"Dot", "[", 
              RowBox[{"weights", ",", "v"}], "]"}], "/", 
             RowBox[{"Total", "[", "weights", "]"}]}]}]}], 
          "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", "]"}]}], 
     ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
      "Collect", " ", "suggested", " ", "fixes", " ", "at", " ", "positions", 
       " ", "of", " ", "missing", " ", "elements"}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"fixes", "=", 
      RowBox[{"Flatten", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"With", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"colnum", "=", 
              RowBox[{
               RowBox[{"First", "[", "#", "]"}], "/.", "numberedColumns"}]}], 
             "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"Map", "[", 
             RowBox[{
              RowBox[{"Function", "[", 
               RowBox[{"row", ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"row", ",", "colnum"}], "}"}], ",", 
                  RowBox[{"suggestFix", "[", 
                   RowBox[{"row", ",", "colnum"}], "]"}]}], "}"}]}], "]"}], 
              ",", 
              RowBox[{"Last", "@", "#"}]}], "]"}]}], "\[IndentingNewLine]", 
           "]"}], "&"}], "/@", "fixPos"}], ",", "1"}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
      "Fill", " ", "in", " ", "destination", " ", "matrix", " ", "with", " ", 
       "fixes", " ", "and", " ", "columnize"}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"Scan", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"toDat", "[", 
           RowBox[{"[", 
            RowBox[{"Sequence", "@@", 
             RowBox[{"First", "[", "#", "]"}]}], "]"}], "]"}], "=", 
          RowBox[{"Last", "@", "#"}]}], ")"}], "&"}], ",", "fixes"}], "]"}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"columnize", "@", "toDat"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.574764572851721*^9, 3.5747645793370914`*^9}, {
   3.5747646157971773`*^9, 3.574764616032191*^9}, {3.574764715411875*^9, 
   3.574764767041828*^9}, {3.574764854244816*^9, 3.5747648552078705`*^9}, {
   3.57476521360437*^9, 3.57476521431441*^9}, {3.5747717874993753`*^9, 
   3.574771795261819*^9}, {3.5747718274566603`*^9, 3.5747719034570074`*^9}, {
   3.5747720848653836`*^9, 3.5747720857374334`*^9}, {3.5747721223995304`*^9, 
   3.574772136274324*^9}, {3.5747721736294603`*^9, 3.574772190649434*^9}, {
   3.5747722412713294`*^9, 3.574772242100377*^9}, {3.574772274916254*^9, 
   3.5747722968735094`*^9}, {3.5747728718793983`*^9, 
   3.5747728799808617`*^9}, {3.5747731314162426`*^9, 
   3.5747731467641206`*^9}, {3.5747731848602996`*^9, 3.574773198450077*^9}, {
   3.574773253177207*^9, 3.5747732571604347`*^9}, {3.574773335375909*^9, 
   3.574773341981286*^9}, {3.574773639863324*^9, 3.5747736562582617`*^9}, {
   3.574773855604664*^9, 3.574773884703328*^9}, {3.5747739200413494`*^9, 
   3.5747741206368227`*^9}, {3.574774169483617*^9, 3.574774172496789*^9}, {
   3.5747743808037033`*^9, 3.5747744164817443`*^9}, {3.574774479184331*^9, 
   3.5747744806154127`*^9}, {3.574790611344031*^9, 3.574790678852892*^9}, {
   3.575028934607971*^9, 3.5750289385421963`*^9}, {3.5750290304444523`*^9, 
   3.5750290761240654`*^9}, {3.575029212612872*^9, 3.575029259748568*^9}, {
   3.5750293802994633`*^9, 3.575029392708173*^9}, {3.575029685139899*^9, 
   3.575029705489063*^9}, {3.5750298380986476`*^9, 3.57502986366811*^9}, {
   3.575029922370468*^9, 3.575029931313979*^9}, {3.5750300853407893`*^9, 
   3.5750301179896564`*^9}, {3.5750309631039944`*^9, 3.575030981332037*^9}, {
   3.575031052247093*^9, 3.575031109334358*^9}, {3.5750314668948097`*^9, 
   3.5750314784824724`*^9}, {3.5750315167336597`*^9, 3.575031659341817*^9}, {
   3.575031695951911*^9, 3.5750318201250134`*^9}, {3.5750318507897673`*^9, 
   3.5750318608193407`*^9}, {3.5750320040535336`*^9, 3.575032149579857*^9}, {
   3.575032232040573*^9, 3.5750322383739357`*^9}, {3.575032366061239*^9, 
   3.575032383147216*^9}, {3.5750324392594256`*^9, 3.5750326619751644`*^9}, {
   3.5750327109839673`*^9, 3.5750327115630007`*^9}, {3.5750328057613883`*^9, 
   3.5750328373771963`*^9}, {3.575032885182931*^9, 3.5750328973026237`*^9}, {
   3.5750331411735725`*^9, 3.575033152365213*^9}, {3.5750332535239987`*^9, 
   3.5750332573252163`*^9}, {3.5750332941133204`*^9, 
   3.5750333643273363`*^9}, {3.57503340827785*^9, 3.5750335218753476`*^9}, {
   3.575033575713427*^9, 3.57503358467994*^9}, {3.5750340923739786`*^9, 
   3.5750341402277155`*^9}, {3.575034246832813*^9, 3.575034249337956*^9}, {
   3.5750343501757236`*^9, 3.5750344242129583`*^9}, {3.5750344645722666`*^9, 
   3.575034501538381*^9}, {3.5750345484640656`*^9, 3.575034715116597*^9}, {
   3.57503483912269*^9, 3.575034846529114*^9}, {3.5750348805520597`*^9, 
   3.575034904759444*^9}, {3.575034993430516*^9, 3.575035035955948*^9}, {
   3.5750350841387043`*^9, 3.5750352159202414`*^9}, {3.5750352637539773`*^9, 
   3.5750353411304035`*^9}, {3.5750353838328457`*^9, 
   3.5750353851409206`*^9}, {3.5750354252972174`*^9, 3.575035436609864*^9}, {
   3.5750356961157074`*^9, 3.5750356981908255`*^9}, {3.5750361927021103`*^9, 
   3.5750362096680803`*^9}, {3.5750362889166136`*^9, 
   3.5750363230645666`*^9}, {3.5750363676481166`*^9, 
   3.5750363760895996`*^9}, {3.5750365109413123`*^9, 3.575036557322965*^9}, {
   3.5750365939990635`*^9, 3.5750366005784397`*^9}, {3.575036670790455*^9, 
   3.575036672547556*^9}, 3.575036838453045*^9, {3.5750369298632736`*^9, 
   3.57503696144908*^9}, {3.5750376980562115`*^9, 3.5750378856329403`*^9}, {
   3.5750379725829134`*^9, 3.575037988872845*^9}, {3.5750380362615557`*^9, 
   3.5750381100977793`*^9}, {3.575038332266486*^9, 3.575038376412011*^9}, {
   3.575038687492804*^9, 3.5750387077159605`*^9}, {3.5750387382717085`*^9, 
   3.575038773576728*^9}, {3.575038847117934*^9, 3.5750388534362955`*^9}, {
   3.575038981550623*^9, 3.5750389823146667`*^9}, {3.575039246913801*^9, 
   3.5750393145506697`*^9}, {3.575039423288889*^9, 3.575039470409584*^9}, {
   3.575039529500964*^9, 3.575039550633173*^9}, {3.5750397032058997`*^9, 
   3.575039743374197*^9}, {3.575039810298025*^9, 3.5750398305931854`*^9}, {
   3.575039873581644*^9, 3.575039983391925*^9}, {3.5750401969021378`*^9, 
   3.575040383817828*^9}, {3.575040439482012*^9, 3.575040520340637*^9}, {
   3.5750406963027015`*^9, 3.5750406987378407`*^9}, {3.5750407405322313`*^9, 
   3.5750407849897738`*^9}, 3.57504084086397*^9, {3.5750422205178814`*^9, 
   3.5750422360577707`*^9}, {3.575042283278471*^9, 3.575042392741732*^9}, {
   3.5750424448947153`*^9, 3.5750424585714974`*^9}, {3.575042491746395*^9, 
   3.5750425671707087`*^9}, {3.575042640181885*^9, 3.5750426468712673`*^9}, {
   3.5750427067506924`*^9, 3.575042848533802*^9}, {3.575289394307476*^9, 
   3.575289455602108*^9}, {3.575289711334694*^9, 3.575289737008934*^9}, {
   3.575289817339439*^9, 3.575289820763196*^9}, {3.575289927849063*^9, 
   3.5752899796070023`*^9}, {3.575290014326939*^9, 3.5752900522134113`*^9}, {
   3.575290150667467*^9, 3.575290182452441*^9}, {3.5752902600059643`*^9, 
   3.575290361351457*^9}, {3.5752915733333197`*^9, 3.575291608972906*^9}, {
   3.575291697333076*^9, 3.575291762073799*^9}, {3.575291875667858*^9, 
   3.5752918833024693`*^9}, {3.575292222591403*^9, 3.575292284461732*^9}, {
   3.575292318516726*^9, 3.57529232356077*^9}, {3.57529273100485*^9, 
   3.575292734861814*^9}, {3.585507651726873*^9, 3.5855076876691523`*^9}, {
   3.585507723861188*^9, 3.585507863602862*^9}, {3.585507915825589*^9, 
   3.585507929584635*^9}, {3.585508127198008*^9, 3.5855081998339767`*^9}, {
   3.585508248941828*^9, 3.585508258969455*^9}, {3.585508315082159*^9, 
   3.585508362267336*^9}, {3.585568642451804*^9, 3.585568647107689*^9}, {
   3.585569273806849*^9, 3.585569384959551*^9}, {3.5855694174797792`*^9, 
   3.585569644822383*^9}, {3.585569709065325*^9, 3.5855698299802837`*^9}, {
   3.585569862797141*^9, 3.585569863429928*^9}, {3.5855701544000893`*^9, 
   3.585570185574099*^9}, {3.585570268521832*^9, 3.585570271527626*^9}, {
   3.585570314523363*^9, 3.585570390056424*^9}, {3.58557043828516*^9, 
   3.5855704393181467`*^9}, {3.585570471623261*^9, 3.58557049209184*^9}, {
   3.5855706701066103`*^9, 3.585570670424679*^9}, {3.585570795038392*^9, 
   3.585570797893362*^9}, {3.585570946119533*^9, 3.585571004132873*^9}, {
   3.585571059744933*^9, 3.585571091759405*^9}, {3.5855715307789507`*^9, 
   3.585571532529763*^9}, {3.585571567142364*^9, 3.585571575505994*^9}, 
   3.585571685203529*^9, {3.5855718220318737`*^9, 3.585571851848255*^9}, {
   3.5855764636341877`*^9, 3.585576480223536*^9}, {3.58557669398487*^9, 
   3.585576699858986*^9}, {3.585576911688122*^9, 3.585576918890036*^9}, {
   3.586000006553406*^9, 3.5860000105269737`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["knnImpute Usage", "Title",
 CellChangeTimes->{{3.585417299136742*^9, 3.585417302023638*^9}, {
  3.585486190840365*^9, 3.585486194479013*^9}, {3.5854955216795692`*^9, 
  3.585495536078971*^9}, {3.585495869960773*^9, 3.585495877024088*^9}, {
  3.5854984265503893`*^9, 3.585498429740182*^9}, {3.585499094894772*^9, 
  3.585499097542303*^9}, {3.58550056152886*^9, 3.585500572056347*^9}, {
  3.5855041255687923`*^9, 3.585504130967813*^9}, {3.58550491005755*^9, 
  3.5855049179996977`*^9}, {3.585505127301998*^9, 3.585505130595188*^9}, {
  3.585506505509509*^9, 3.585506509199935*^9}, {3.5855073849495363`*^9, 
  3.585507390853044*^9}, {3.585572219240795*^9, 3.585572222920883*^9}}],

Cell["Fix the pH column only:", "Text",
 CellChangeTimes->{{3.585572290968091*^9, 3.585572300710848*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"temp", "=", 
   RowBox[{"knnImpute", "[", 
    RowBox[{"trimmed", ",", "columns", ",", 
     RowBox[{"{", "mxPH", "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5750318268323965`*^9, 3.575031837450004*^9}, {
   3.575031868374773*^9, 3.575031870527896*^9}, {3.5750321205501966`*^9, 
   3.575032121087227*^9}, {3.5750321597684393`*^9, 3.575032161629546*^9}, {
   3.575032797472914*^9, 3.575032798876994*^9}, 3.5750352222026005`*^9, {
   3.575035347835787*^9, 3.57503535191502*^9}, {3.575037851640996*^9, 
   3.5750378543481507`*^9}, {3.5750382525919294`*^9, 
   3.5750382629905243`*^9}, {3.575040033981819*^9, 3.5750400544339886`*^9}, {
   3.5750401472983003`*^9, 3.5750401648883066`*^9}, {3.575042578766372*^9, 
   3.5750425790773897`*^9}, 3.5750428908512225`*^9, 3.5752927386884403`*^9, {
   3.575292769576413*^9, 3.5752927794959784`*^9}, {3.585572306895479*^9, 
   3.585572307249197*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"phPos", "=", 
  RowBox[{"trimmed", "[", 
   RowBox[{"mxPH", ",", "\"\<missing\>\""}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5752927926416197`*^9, 3.575292798027996*^9}, {
  3.5855725816821012`*^9, 3.585572582801313*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", "48", "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.5752927984335546`*^9, 3.575801880222024*^9, 3.5758082212614822`*^9, 
   3.585572156267088*^9, 3.5855723028514023`*^9, 3.5855723399783382`*^9, {
   3.585572583860153*^9, 3.585572591167081*^9}, {3.585576513396694*^9, 
   3.5855765150038433`*^9}, 3.5855767704167137`*^9, 3.585576832154751*^9, 
   3.5855769235749063`*^9, 3.586000079432991*^9, 3.586086536464459*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Extract", "[", 
  RowBox[{
   RowBox[{"temp", "[", 
    RowBox[{"mxPH", ",", "\"\<raw\>\""}], "]"}], ",", "phPos"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.575292780731826*^9, 3.575292803199128*^9}, {
  3.585572325012403*^9, 3.585572332463025*^9}, {3.585572585390771*^9, 
  3.585572586819241*^9}, {3.585576507224819*^9, 3.5855765090328197`*^9}}],

Cell[BoxData[
 RowBox[{"{", "8.05919641233121`", "}"}]], "Output",
 CellChangeTimes->{{3.575292784592696*^9, 3.575292803621035*^9}, 
   3.575801880922945*^9, 3.575808223321013*^9, 3.5855721609830437`*^9, {
   3.585572333369584*^9, 3.585572340659354*^9}, {3.585572587518264*^9, 
   3.585572591883216*^9}, 3.585576516133267*^9, 3.585576771941472*^9, 
   3.5855768337545*^9, 3.585576925021501*^9, 3.5860000884433193`*^9, 
   3.586086537549899*^9}]
}, Open  ]],

Cell["\<\
Use the Median method (instead of the exponentially weighted average) with \
the 20 nearest neigbors:\
\>", "Text",
 CellChangeTimes->{{3.585572498827691*^9, 3.585572555273396*^9}, {
  3.5855735059176826`*^9, 3.5855735079419947`*^9}, {3.585911806210099*^9, 
  3.585911810830855*^9}, {3.586000104403782*^9, 3.586000105851817*^9}, {
  3.5860224181426764`*^9, 3.5860224188365297`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"temp", "=", 
   RowBox[{"knnImpute", "[", 
    RowBox[{"trimmed", ",", "columns", ",", 
     RowBox[{"{", "mxPH", "}"}], ",", 
     RowBox[{"\"\<Method\>\"", "\[Rule]", "\"\<Median\>\""}], ",", 
     RowBox[{"\"\<Neighbors\>\"", "\[Rule]", "20"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.5750318268323965`*^9, 3.575031837450004*^9}, {
   3.575031868374773*^9, 3.575031870527896*^9}, {3.5750321205501966`*^9, 
   3.575032121087227*^9}, {3.5750321597684393`*^9, 3.575032161629546*^9}, {
   3.575032797472914*^9, 3.575032798876994*^9}, 3.5750352222026005`*^9, {
   3.575035347835787*^9, 3.57503535191502*^9}, {3.575037851640996*^9, 
   3.5750378543481507`*^9}, {3.5750382525919294`*^9, 
   3.5750382629905243`*^9}, {3.575040033981819*^9, 3.5750400390491085`*^9}, {
   3.5750405283880973`*^9, 3.5750405332943783`*^9}, {3.5750406294878798`*^9, 
   3.5750406316050005`*^9}, {3.57504079575239*^9, 3.5750408000126333`*^9}, {
   3.575040866251422*^9, 3.575040875007923*^9}, 3.5750428939794016`*^9, {
   3.575292811016364*^9, 3.57529281180687*^9}, {3.585572557610423*^9, 
   3.5855725651475687`*^9}, {3.585573490717058*^9, 3.585573499222579*^9}, {
   3.58600010772091*^9, 3.586000108011614*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Extract", "[", 
  RowBox[{
   RowBox[{"temp", "[", 
    RowBox[{"mxPH", ",", "\"\<raw\>\""}], "]"}], ",", "phPos"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.575292780731826*^9, 3.575292803199128*^9}, {
  3.585572325012403*^9, 3.585572332463025*^9}, {3.5855725975816174`*^9, 
  3.585572599218245*^9}, {3.58557657918361*^9, 3.58557658083945*^9}}],

Cell[BoxData[
 RowBox[{"{", "7.9`", "}"}]], "Output",
 CellChangeTimes->{{3.575292784592696*^9, 3.575292803621035*^9}, 
   3.575801880922945*^9, 3.575808223321013*^9, 3.5855721609830437`*^9, {
   3.585572333369584*^9, 3.585572340659354*^9}, {3.585572599593669*^9, 
   3.5855726037086782`*^9}, {3.585573492003501*^9, 3.5855735097118053`*^9}, {
   3.585576566391285*^9, 3.5855765815560713`*^9}, 3.585576943462932*^9, {
   3.586000097530978*^9, 3.586000110382174*^9}}]
}, Open  ]],

Cell["\<\
In this instance, these values aren\[CloseCurlyQuote]t much different from \
those for column as a whole:\
\>", "Text",
 CellChangeTimes->{{3.5855734459670477`*^9, 3.585573468334741*^9}, {
  3.585573515862981*^9, 3.5855735220695887`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Through", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"Mean", ",", "Median"}], "}"}], "[", 
   RowBox[{"trimmed", "[", "mxPH", "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.585573368066675*^9, 3.585573380093906*^9}, {
  3.5855734350031023`*^9, 3.585573435986092*^9}, {3.5855734738798113`*^9, 
  3.585573481735446*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"8.01997461928934`", ",", "8.06`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.585573381170869*^9, 3.5855734363068733`*^9, {3.585573482082018*^9, 
   3.58557351103683*^9}, 3.585576569762636*^9, 3.585576945635023*^9, 
   3.5860001133422537`*^9}]
}, Open  ]],

Cell["Impute everything:", "Text",
 CellChangeTimes->{{3.585573529661582*^9, 3.585573543533372*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"knnd", "=", 
   RowBox[{"knnImpute", "[", "trimmed", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.585573549142815*^9, 3.585573555662135*^9}, {
  3.5855744849206753`*^9, 3.585574486644191*^9}}],

Cell["\<\
There should be no missing values left (matrix is transposed to use less \
vertical space):\
\>", "Text",
 CellChangeTimes->{{3.58557360995537*^9, 3.585573626939167*^9}, {
  3.5860223907117558`*^9, 3.586022399572898*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MatrixPlot", "[", 
  RowBox[{"Transpose", "@", 
   RowBox[{"Replace", "[", 
    RowBox[{
     RowBox[{"knnd", "[", "All", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Except", "[", 
         RowBox[{"Missing", "[", "]"}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{"_", "\[Rule]", "1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"-", "1"}], "}"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.585497180624794*^9, 3.585497254733642*^9}, {
  3.585497297029014*^9, 3.585497298348521*^9}, {3.585498039911702*^9, 
  3.58549804138175*^9}, {3.585573603952903*^9, 3.585573604430615*^9}, {
  3.585574499909071*^9, 3.585574504211855*^9}, {3.586016327363186*^9, 
  3.5860163295792*^9}}],

Cell[BoxData[
 GraphicsBox[
  RasterBox[SparseArray[
   Automatic, {18, 99}, 1., {
    1, {{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0}, {}}, {}}], {{0, 0}, {99, 18}}, {0, 1}],
  Frame->True,
  FrameLabel->{None, None},
  FrameTicks->{{{{17.5, 
       FormBox["1", TraditionalForm]}, {13.5, 
       FormBox["5", TraditionalForm]}, {8.5, 
       FormBox["10", TraditionalForm]}, {3.5, 
       FormBox["15", TraditionalForm]}, {0.5, 
       FormBox["18", TraditionalForm]}}, {{17.5, 
       FormBox["1", TraditionalForm]}, {13.5, 
       FormBox["5", TraditionalForm]}, {8.5, 
       FormBox["10", TraditionalForm]}, {3.5, 
       FormBox["15", TraditionalForm]}, {0.5, 
       FormBox["18", TraditionalForm]}}}, {{{0.25, 
       FormBox["1", TraditionalForm]}, {24.75, 
       FormBox["50", TraditionalForm]}, {49.75, 
       FormBox["100", TraditionalForm]}, {74.75, 
       FormBox["150", TraditionalForm]}, {98.75, 
       FormBox["198", TraditionalForm]}}, {{0.25, 
       FormBox["1", TraditionalForm]}, {24.75, 
       FormBox["50", TraditionalForm]}, {49.75, 
       FormBox["100", TraditionalForm]}, {74.75, 
       FormBox["150", TraditionalForm]}, {98.75, 
       FormBox["198", TraditionalForm]}}}}]], "Output",
 CellChangeTimes->{3.5854972195369463`*^9, 3.5854972554266872`*^9, 
  3.58549729905581*^9, 3.585498041737479*^9, 3.585573604696828*^9, 
  3.585574504900337*^9, 3.585575920891366*^9, 3.585576134360591*^9, 
  3.585576598172202*^9, 3.585576948393236*^9, 3.586000117875361*^9, 
  3.5860163298648787`*^9}]
}, Open  ]],

Cell["\<\
How does one choose an imputation method?  Usually we would want \
domain-specific reasons for choosing one  technique over another.  Are there \
good chemical and biological reasons to believe, for example, that the pH \
will track changes in the feature set as a whole?\
\>", "Text",
 CellChangeTimes->{{3.585572426533279*^9, 3.585572488779134*^9}, {
  3.585573642300845*^9, 3.5855736538273487`*^9}, {3.585573713555057*^9, 
  3.5855737323208447`*^9}, {3.5855739280291233`*^9, 3.5855739406926117`*^9}, {
  3.585574119770583*^9, 3.58557416703205*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Obtaining Prediction Models", "Title",
 CellChangeTimes->{{3.585417299136742*^9, 3.585417302023638*^9}, {
  3.585486190840365*^9, 3.585486194479013*^9}, {3.5854955216795692`*^9, 
  3.585495536078971*^9}, {3.585495869960773*^9, 3.585495877024088*^9}, {
  3.5854984265503893`*^9, 3.585498429740182*^9}, {3.585499094894772*^9, 
  3.585499097542303*^9}, {3.58550056152886*^9, 3.585500572056347*^9}, {
  3.5855041255687923`*^9, 3.585504130967813*^9}, {3.58550491005755*^9, 
  3.5855049179996977`*^9}, {3.585505127301998*^9, 3.585505130595188*^9}, {
  3.585506505509509*^9, 3.585506509199935*^9}, {3.5855073849495363`*^9, 
  3.585507390853044*^9}, {3.585572219240795*^9, 3.585572222920883*^9}, {
  3.5855745218266373`*^9, 3.5855745276170263`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"reset", "[", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"knnd", "=", 
   RowBox[{"knnImpute", "[", "trimmed", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.585573549142815*^9, 3.585573555662135*^9}, {
  3.5855744849206753`*^9, 3.585574486644191*^9}, {3.585575577455385*^9, 
  3.585575578080893*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox["\<\"med dataset defined, \\!\\(200\\) rows\"\>",
  StringForm["med dataset defined, `` rows", 200],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.585575579034737*^9, 3.585575617073638*^9, {3.5855769785020323`*^9, 
   3.585576996842194*^9}, 3.586000140864311*^9, 3.586086471400155*^9, 
   3.586086540838462*^9, 3.586090069699224*^9, 3.5860922209723053`*^9}],

Cell[BoxData[
 InterpretationBox["\<\"trimmed dataset defined, \\!\\(198\\) rows\"\>",
  StringForm["trimmed dataset defined, `` rows", 198],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.585575579034737*^9, 3.585575617073638*^9, {3.5855769785020323`*^9, 
   3.585576996842194*^9}, 3.586000140864311*^9, 3.586086471400155*^9, 
   3.586086540838462*^9, 3.586090069699224*^9, 3.586092220978956*^9}],

Cell[BoxData[
 InterpretationBox["\<\"centrally imputed dataset defined, \\!\\(198\\) \
rows\"\>",
  StringForm["centrally imputed dataset defined, `` rows", 198],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.585575579034737*^9, 3.585575617073638*^9, {3.5855769785020323`*^9, 
   3.585576996842194*^9}, 3.586000140864311*^9, 3.586086471400155*^9, 
   3.586086540838462*^9, 3.586090069699224*^9, 3.5860922209859543`*^9}]
}, Open  ]]
}, Open  ]],

Cell["\<\
With this fully imputed dataset, we can tackle the task of building a \
predictive model for the algae levels.\
\>", "Text",
 CellChangeTimes->{{3.585574693861113*^9, 3.585574719748809*^9}}],

Cell[TextData[{
 "Begin with a linear model, where the assumption is that the algae levels \
can be expressed as a linear combination of the observations.  Here, we are \
predicting the first algae column, a1.  ",
 StyleBox["LinearModelFit", "Input"],
 " can handle nominal variables, as long as you tell it where they are:"
}], "Text",
 CellChangeTimes->{{3.585575699871434*^9, 3.585575750935637*^9}, {
  3.585577106870015*^9, 3.58557711919584*^9}, {3.585911838558538*^9, 
  3.5859118416143084`*^9}, {3.5860001616683702`*^9, 3.5860001965142593`*^9}, {
  3.586022462764976*^9, 3.586022467339517*^9}, {3.5860969435016336`*^9, 
  3.5860969495643387`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"lm", "[", "1", "]"}], "=", 
  RowBox[{"LinearModelFit", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"knnd", "[", "All", "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", 
       RowBox[{"1", ";;", "12"}]}], "]"}], "]"}], ",", "featureColumns", ",", 
    "featureColumns", ",", 
    RowBox[{"NominalVariables", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"size", ",", "season", ",", "speed"}], "}"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.5750447405690203`*^9, 3.575044754533819*^9}, {
   3.57504520824177*^9, 3.5750452119089794`*^9}, {3.5750453458006372`*^9, 
   3.5750454082302084`*^9}, 3.58558238762107*^9, {3.5855865105009127`*^9, 
   3.585586510749321*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"FittedModel", "[", 
   TagBox[
    PanelBox[
     TagBox[
      RowBox[{
       RowBox[{"\[LeftSkeleton]", "26", "\[RightSkeleton]"}], "+", 
       RowBox[{"3.7136414155709847`", " ", 
        RowBox[{"DiscreteIndicator", "[", 
         RowBox[{"speed", ",", "\<\"low\"\>", ",", 
          RowBox[{"{", 
           
           RowBox[{"\<\"high\"\>", ",", "\<\"low\"\>", 
            ",", "\<\"medium\"\>"}], "}"}]}], "]"}]}]}],
      Short[#, 2]& ],
     FrameMargins->5],
    Editable -> False], "]"}],
  InterpretTemplate[
  FittedModel[{
    "Linear", {56.95172339815185, -3.690421026378989, 
     0.02706864067620658, -2.9494830533631857`, -9.692248958567845, \
-6.419912392127466, -0.24413115437456073`, 
     3.7136414155709847`, -3.620877186081447, 
     1.0409682609158408`, -0.04059296594268069, -1.5111631948473399`, 
     0.0016314876142141728`, -0.005159167544518979, -0.05249289872674217, \
-0.08732108355205627}, {{{$CellContext`season, {
        "autumn", "spring", "summer", "winter"}}, {$CellContext`size, {
        "large", "medium", "small"}}, {$CellContext`speed, {
        "high", "low", 
         "medium"}}, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla}, {1, 
       $CellContext`season["autumn"], 
       $CellContext`season["spring"], 
       $CellContext`season["summer"], 
       $CellContext`size["large"], 
       $CellContext`size["medium"], 
       $CellContext`speed["high"], 
       $CellContext`speed[
       "low"], $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla}}, {0, 0}}, CompressedData["
1:eJxTTMoPSmViYGBgBOJjDDDwwX6UHqVH6VF6lB6l8dEAb4jszQ==
    "], {{
     "winter", "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170., 50.,
       0.}, {"spring", "small", "medium", 8.35, 8., 57.75, 1.288, 370., 
      428.75, 558.75, 1.3, 1.4}, {
     "autumn", "small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 125.667, 
      187.05701, 15.6, 3.3}, {
     "spring", "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 61.182, 
      138.7, 1.4, 3.1}, {
     "autumn", "small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222, 
      97.58, 10.5, 9.2}, {
     "winter", "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 56.667,
       28.4, 15.1}, {
     "summer", "small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 111.75,
       3.2, 2.4}, {
     "autumn", "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 44.667, 
      77.434, 6.9, 18.2}, {
     "winter", "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 71., 
      5.544, 25.4}, {
     "winter", "small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 0.8, 
      17.}, {"spring", "small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 
      20.75, 0.8, 16.6}, {
     "summer", "small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 19., 
      0.6, 32.1}, {
     "winter", "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 41., 
      43.5}, {"summer", "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 
      0.5, 31.1}, {
     "winter", "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 0.3, 
      52.2}, {"autumn", "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 
      98.25, 1.1, 69.9}, {
     "winter", "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50., 1.1,
       46.2}, {"spring", "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 
      57.833, 0.4, 31.8}, {
     "summer", "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 0.8, 
      50.6}, {"spring", "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 
      564.59998, 771.59998, 4.5, 0.}, {
     "winter", "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 586., 
      16., 0.}, {
     "spring", "small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 0.5, 
      15.5}, {"autumn", "small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 
      40., 7.6, 23.2}, {
     "winter", "small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 27.5,
       1.7, 74.2}, {
     "spring", "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 1.5, 
      13.}, {"summer", "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 
      44.136, 3., 4.1}, {
     "winter", "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 0.5, 
      29.7}, {"autumn", "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 
      16.369371260220625`, 2.7, 30.3}, {
     "winter", "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 
      17.1}, {"spring", "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 
      0.5, 33.9}, {
     "autumn", "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 4.9, 
      3.4}, {"winter", "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304.,
       2.8, 6.9}, {
     "summer", "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 130.75, 
      5.8, 0.}, {
     "autumn", "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47., 2.3,
       13.6}, {"winter", "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4,
       23., 0.9, 5.3}, {
     "summer", "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 58.875, 
      84.46, 3.6, 18.3}, {
     "winter", "small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 0.2, 
      66.}, {"spring", "small", "high", 8., 10.214452952751651`, 1.45, 0.81, 
      10., 2.5, 3., 0.3, 75.8}, {
     "winter", "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 196.62, 
      253.25, 12.32, 2.}, {
     "spring", "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 182.42,
       255.28, 8.957, 2.2}, {
     "winter", "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001, 
      296., 3.7, 0.}, {
     "summer", "small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 59.429, 
      175.04601, 13.2, 0.}, {
     "winter", "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 
      344.60001, 22.5, 0.}, {
     "spring", "small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 276.85001, 
      326.85699, 11.84, 4.1}, {
     "winter", "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 40.667, 
      3.9, 51.8}, {
     "spring", "small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 3.3, 
      29.5}, {
     "autumn", "small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 0.8, 
      54.4}, {"winter", "small", "low", 8.05919641233121, 12.6, 9., 0.23, 10.,
       5., 6., 1.1, 35.5}, {
     "spring", "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 2.8, 
      89.8}, {"autumn", "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13.,
       20.812, 12.1, 24.8}, {
     "winter", "small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 
      49.333, 7.9, 0.}, {
     "summer", "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 22.9, 
      4.5, 39.1}, {
     "winter", "small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 11.8, 
      0.5, 81.9}, {
     "spring", "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818, 0.8,
       54.}, {"winter", "small", "high", 6.6, 10.8, 6.013115993877201, 3.245, 
      10., 1., 6.5, 0.8364380530399255, 24.3}, {
     "spring", "small", "medium", 5.6, 11.8, 6.418402172011745, 2.22, 5., 1., 
      1., 0.9646753712906323, 82.7}, {
     "autumn", "small", "medium", 5.7, 10.8, 10.009721333679945`, 2.55, 10., 
      1., 4., 1.297647641898099, 16.8}, {
     "spring", "small", "high", 6.6, 9.5, 21.735126900601863`, 1.32, 20., 1., 
      6., 7.196816371858979, 46.8}, {
     "summer", "small", "high", 6.6, 10.8, 9.597101331984843, 2.64, 10., 2., 
      11., 1.5011275699367495`, 46.9}, {
     "autumn", "small", "medium", 6.6, 11.3, 5.864630296982661, 4.17, 10., 1.,
       6., 3.556597519567581, 47.1}, {
     "spring", "small", "medium", 6.5, 10.4, 6.368686180255313, 5.97, 10., 2.,
       14., 3.634367808702219, 66.9}, {
     "autumn", "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 6.667, 
      3.8005964534583807`, 14.4}, {
     "spring", "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75, 1., 
      20.3}, {"summer", "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 
      7.2, 0.3, 15.8}, {
     "winter", "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 0.6, 
      55.5}, {"spring", "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 
      10.75, 2.5, 10.3}, {
     "summer", "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 0.5, 
      64.2}, {
     "winter", "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75, 
      351.60001, 10., 0.}, {
     "spring", "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 
      209.85699, 313.60001, 1., 1.9}, {
     "summer", "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 151.125, 
      279.06601, 13.1, 25.5}, {
     "autumn", "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 
      152.33299, 5.2, 11.3}, {
     "summer", "medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
      58.623, 11.6, 4.4}, {
     "winter", "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 
      249.25, 20.87, 1.9}, {
     "spring", "medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 100., 
      233.5, 13., 1.6}, {
     "spring", "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 215.5, 
      18.37, 2.2}, {
     "autumn", "medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 25.167, 
      102.333, 3.6, 64.9}, {
     "winter", "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 
      105.727, 3., 15.1}, {
     "spring", "medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
      111.375, 3., 14.4}, {
     "winter", "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 1.3, 
      6.7}, {"spring", "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 
      56.667, 2., 10.8}, {
     "autumn", "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 4.3, 
      1.2}, {"winter", "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 
      27.667, 104., 21., 12.6}, {
     "summer", "medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 69.93, 
      3.1, 14.7}, {
     "autumn", "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 214.,
       2.9, 3.3}, {
     "winter", "medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
      254.60001, 4.3, 0.}, {
     "summer", "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 57.6, 
      169.00101, 3.2, 2.8}, {
     "winter", "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 
      412.33301, 607.16699, 4.3, 0.}, {
     "summer", "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 
      282.16699, 624.73297, 6.8, 0.}, {
     "winter", "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 197.83299,
       303.33301, 40., 0.}, {
     "spring", "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 267.75, 
      391.75, 3.5, 0.}, {
     "summer", "medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 191.75, 
      265.25, 7.3, 0.}, {
     "winter", "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 
      232.83299, 31., 1.2}, {
     "spring", "medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 144.66701, 
      244., 9., 0.}, {
     "summer", "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 218., 
      6.5, 0.}, {
     "autumn", "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 138.5, 
      20.829, 5.7}, {
     "winter", "medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222, 
      239., 72.478, 3.6}, {
     "spring", "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 
      235.66701, 98.817, 1.2}, {
     "winter", "medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75, 
      205.875, 2., 4.}, {
     "summer", "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 31.333, 
      211.66701, 21.9, 5.9}, {
     "winter", "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625, 
      186.5, 30., 16.5}, {
     "spring", "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 12.889, 
      154.125, 5.2, 7.}, {
     "winter", "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 51.111, 
      183.66701, 17.2, 58.7}, {
     "summer", "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 
      292.625, 3., 8.7}, {
     "autumn", "medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
      285.71399, 75., 17.}, {
     "winter", "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 
      201.778, 3., 12.3}, {
     "summer", "medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 
      275.14301, 65.7, 8.8}, {
     "autumn", "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 
      124.2, 13.1, 23.7}, {
     "winter", "medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 60.833, 
      141.83299, 25., 0.}, {
     "summer", "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71., 
      132.54601, 15., 3.6}, {
     "winter", "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 
      17.333, 1., 64.3}, {
     "spring", "medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 0.3, 
      46.6}, {"summer", "medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 
      8.692, 16.662, 2.1, 24.}, {
     "spring", "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 37.857, 
      102.571, 1.2, 3.7}, {
     "summer", "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 
      86.997, 3., 18.1}, {
     "winter", "medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 10.111,
       1.6812921234898004`, 41.}, {
     "summer", "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 16.833, 
      18.293, 1.4, 43.7}, {
     "autumn", "medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545, 
      13.2, 3.2, 86.6}, {
     "spring", "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 261.60001, 
      432.909, 24.917, 1.9}, {
     "summer", "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 
      320.39999, 6.8, 1.2}, {
     "winter", "medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 144., 
      287., 9.882, 1.4}, {
     "spring", "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 166.72701,
       262.72699, 17.2, 1.6}, {
     "summer", "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 
      222.286, 6.429, 3.3}, {
     "winter", "medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 36.909, 
      122., 5.555, 14.6}, {
     "spring", "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556, 
      127.222, 5.233, 1.7}, {
     "summer", "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 89.625,
       2.15, 3.3}, {
     "winter", "medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 55., 
      284., 88.255, 0.}, {
     "spring", "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 102.333, 
      277.33301, 110.456, 0.}, {
     "summer", "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 75.875, 
      177.625, 50.225, 1.5}, {
     "winter", "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 72.9,
       11.1, 4.2}, {
     "spring", "medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 48.667, 
      82.444, 2., 4.1}, {
     "summer", "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 48.625, 
      66.75, 3.3, 1.2}, {
     "winter", "medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 23., 
      173.75, 15.3, 0.}, {
     "spring", "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 317., 
      5.5, 2.4}, {
     "autumn", "medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 84., 
      4.5, 7.8}, {
     "spring", "medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 2., 
      10.3}, {"autumn", "medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49.,
       88.5, 2.5, 1.5}, {
     "winter", "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115., 
      11.7, 9.2}, {
     "summer", "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 98.143, 
      2., 28.1}, {
     "winter", "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 143.75,
       5.45, 2.1}, {
     "summer", "medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
      197.14301, 6.4, 1.4}, {
     "spring", "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 1., 
      19.}, {"autumn", "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 
      10.583, 23.485, 2., 42.5}, {
     "winter", "medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 200.231, 
      19.4, 2.5}, {
     "spring", "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 77.333, 
      147.83299, 3., 4.4}, {
     "autumn", "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5, 
      276., 8.1, 6.5}, {
     "winter", "medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
      123.333, 30.4, 39.7}, {
     "autumn", "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 75.207, 
      23.8, 32.8}, {
     "winter", "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 116.2, 
      7.3, 12.2}, {
     "spring", "medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 
      188.66701, 32., 1.9}, {
     "autumn", "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 72.696,
       22.7, 0.}, {
     "summer", "medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 16., 
      0.}, {
     "autumn", "medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 34., 
      53.1, 2.2}, {
     "spring", "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 27.5, 
      76.333, 2.1, 3.4}, {
     "autumn", "medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
      58.374, 27.5, 2.8}, {
     "spring", "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 175.66701, 
      361., 28.567, 24.8}, {
     "summer", "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 22.5,
       32.5}, {"spring", "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 
      125.8, 26.8, 0.}, {
     "autumn", "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 
      54.916, 20.6, 0.}, {
     "winter", "large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333, 
      34.75, 0.}, {
     "spring", "large", "low", 9., 5.8, 77.49257553979058, 0.9, 142., 102., 
      186., 68.05, 1.7}, {
     "spring", "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 151.33299, 
      252.5, 93.683, 12.3}, {
     "summer", "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 
      269.66699, 92.667, 7.2}, {
     "autumn", "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 46.438, 
      81.54, 3.4}, {
     "winter", "large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 85., 2.,
       0.}, {"autumn", "large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 
      66.4, 171.272, 3.8, 1.1}, {
     "spring", "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 102.364, 
      232.89999, 54.367, 0.}, {
     "autumn", "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 84.3, 
      146.452, 21.22, 1.4}, {
     "winter", "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 
      246.66701, 14.7, 12.5}, {
     "autumn", "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 205.636, 
      219.909, 6.209, 0.}, {
     "winter", "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 236.39999, 
      272.22198, 20.578, 2.5}, {
     "summer", "large", "medium", 7.91, 6.2, 151.83299, 3.923, 1081.66003, 
      346.16699, 388.16699, 5.083, 1.7}, {
     "winter", "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 82.222, 
      167.89999, 5.609, 1.4}, {
     "spring", "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 64.389, 
      137.778, 9.384, 0.}, {
     "spring", "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 87.333, 
      194.10001, 27.618, 0.}, {
     "winter", "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 
      159.16701, 221.278, 20.8, 0.}, {
     "autumn", "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 21.3, 
      1.1, 39.7}, {
     "spring", "large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 0.6, 
      37.3}, {"summer", "large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 
      7.667, 14.354, 0.8, 52.4}, {
     "spring", "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222, 7., 
      1.3, 48.3}, {
     "summer", "large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 0.8, 
      50.4}, {"winter", "large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 
      7.654, 4., 56.8}, {
     "summer", "large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 2.86, 
      17.3}, {"winter", "large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 
      56.091, 12.7828046039726, 16.8}, {
     "summer", "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 52.875,
       2., 18.1}, {
     "winter", "large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 104.727, 
      228.364, 46.075, 1.1}, {
     "winter", "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 85.4, 
      17.491, 0.}, {
     "summer", "large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 87.125, 
      14.775, 0.}, {
     "autumn", "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 101.455, 
      18.33, 1.7}, {
     "spring", "large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 50.889, 
      127., 24.556, 0.}, {
     "autumn", "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 
      81.558, 5.62, 7.6}, {
     "winter", "large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 19.727, 
      50.455, 8.155, 2.9}, {
     "spring", "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111, 
      120.889, 5.111, 2.2}, {
     "autumn", "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 51.111, 
      91.111, 22.9, 3.8}, {
     "summer", "large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 19.111, 
      61.444, 6.167, 18.9}, {
     "autumn", "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625, 
      79.75, 2.338, 12.7}, {
     "spring", "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333, 
      75.904, 4.667, 18.}, {
     "autumn", "large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333, 
      140.22, 31.738, 0.}, {
     "summer", "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 140.517,
       18.3, 2.4}}, CompressedData["
1:eJytXAl0FFXWjjEsIsawBEIMSWcPiEAIhAhi3ywQspIVCEs2IEAgkBiCiKiN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    "], 
    Function[Null, 
     Internal`LocalizedBlock[{$CellContext`Chla, $CellContext`Cl, \
$CellContext`mnO2, $CellContext`mxPH, $CellContext`NH4, $CellContext`NO3, \
$CellContext`oPO4, $CellContext`PO4, $CellContext`season, $CellContext`size, \
$CellContext`speed, 
       $CellContext`season["autumn"], 
       $CellContext`season["spring"], 
       $CellContext`season["summer"], 
       $CellContext`season["winter"], 
       $CellContext`size["large"], 
       $CellContext`size["medium"], 
       $CellContext`size["small"], 
       $CellContext`speed["high"], 
       $CellContext`speed["low"], 
       $CellContext`speed["medium"]}, #], {HoldAll}]]& ],
  Editable->False,
  SelectWithContents->True,
  Selectable->True]], "Output",
 CellChangeTimes->{
  3.585577009241221*^9, 3.585577327315988*^9, 3.585582388000825*^9, {
   3.585586511770857*^9, 3.5855865195740957`*^9}, {3.586000203433131*^9, 
   3.586000220996818*^9}}]
}, Open  ]],

Cell["\<\
Note the creation of k-1 auxiliary variables for the k possible values of \
each factorized variable.  The first row in the table is the intercept of the \
model.\
\>", "Text",
 CellChangeTimes->{{3.585577806286373*^9, 3.5855778362208977`*^9}, {
  3.585911858343573*^9, 3.585911866358028*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"lm", "[", "1", "]"}], "[", "\"\<ParameterTable\>\"", 
  "]"}]], "Input",
 CellChangeTimes->{{3.5750454262952414`*^9, 3.575045430999511*^9}, 
   3.585582389372561*^9, {3.585586528508298*^9, 3.585586528764666*^9}}],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"Estimate\"\>", "\<\"Standard Error\"\>", "\<\"t\
\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"1", "56.95172339815185`", "22.262512843787597`", "2.5581893561509768`",
       "0.011336237406381941`"},
     {
      RowBox[{"season", "[", "\<\"autumn\"\>", "]"}], 
      RowBox[{"-", "3.690421026378989`"}], "3.8674771442958376`", 
      RowBox[{"-", "0.9542192206156953`"}], "0.34123833679537974`"},
     {
      RowBox[{"season", "[", "\<\"spring\"\>", "]"}], "0.02706864067620658`", 
      "3.3980119266906055`", "0.00796602285695015`", "0.9936528255356907`"},
     {
      RowBox[{"season", "[", "\<\"summer\"\>", "]"}], 
      RowBox[{"-", "2.9494830533631857`"}], "3.5849495691036446`", 
      RowBox[{"-", "0.8227404588290077`"}], "0.4117322583551841`"},
     {
      RowBox[{"size", "[", "\<\"large\"\>", "]"}], 
      RowBox[{"-", "9.692248958567845`"}], "4.1711100492502`", 
      RowBox[{"-", "2.323661769679303`"}], "0.02124844376032602`"},
     {
      RowBox[{"size", "[", "\<\"medium\"\>", "]"}], 
      RowBox[{"-", "6.419912392127466`"}], "3.4470131563216104`", 
      RowBox[{"-", "1.8624565967651558`"}], "0.06415050606659792`"},
     {
      RowBox[{"speed", "[", "\<\"high\"\>", "]"}], 
      RowBox[{"-", "0.24413115437456073`"}], "3.239184866119633`", 
      RowBox[{"-", "0.07536808316439701`"}], "0.9400046320781155`"},
     {
      RowBox[{"speed", "[", "\<\"low\"\>", "]"}], "3.7136414155709847`", 
      "4.109513912604911`", "0.9036692646739347`", "0.36736534100464324`"},
     {"mxPH", 
      RowBox[{"-", "3.620877186081447`"}], "2.704128264743019`", 
      RowBox[{"-", "1.339018283004985`"}], "0.18223469741771148`"},
     {"mnO2", "1.0409682609158408`", "0.7053066940950891`", 
      "1.4759086644589512`", "0.14169641742847738`"},
     {"Cl", 
      RowBox[{"-", "0.04059296594268069`"}], "0.033614090146805345`", 
      RowBox[{"-", "1.207617572434535`"}], "0.22876137401348162`"},
     {"NO3", 
      RowBox[{"-", "1.5111631948473399`"}], "0.551529966576203`", 
      RowBox[{"-", "2.7399475757017595`"}], "0.006756849597933892`"},
     {"NH4", "0.0016314876142141728`", "0.0010030980355087093`", 
      "1.6264488180228398`", "0.10558438932894276`"},
     {"oPO4", 
      RowBox[{"-", "0.005159167544518979`"}], "0.039902761508412814`", 
      RowBox[{"-", "0.1292934962266022`"}], "0.8972681922771287`"},
     {"PO4", 
      RowBox[{"-", "0.05249289872674217`"}], "0.03077289920663082`", 
      RowBox[{"-", "1.7058158340645138`"}], "0.08974829309560328`"},
     {"Chla", 
      RowBox[{"-", "0.08732108355205627`"}], "0.07996033502622273`", 
      RowBox[{"-", "1.0920549985617194`"}], "0.2762524222001891`"}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{
  3.575045431396533*^9, 3.5750514343358817`*^9, {3.5751097240978174`*^9, 
   3.5751097431209054`*^9}, 3.585577054606749*^9, 3.585577333217702*^9, 
   3.5855823897800417`*^9, 3.585586530925806*^9, 3.585682590587392*^9, 
   3.586000227538513*^9}]
}, Open  ]],

Cell["\<\
We can only reject the null hypothesis (that a coefficient is zero) with \
confidence for the cofficients size[large] and nitrate.\
\>", "Text",
 CellChangeTimes->{{3.585578579757537*^9, 3.5855786218848333`*^9}, {
  3.5855847241549273`*^9, 3.585584734976383*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Examining the Linear Model", "Title",
 CellChangeTimes->{{3.585417299136742*^9, 3.585417302023638*^9}, {
  3.585486190840365*^9, 3.585486194479013*^9}, {3.5854955216795692`*^9, 
  3.585495536078971*^9}, {3.585495869960773*^9, 3.585495877024088*^9}, {
  3.5854984265503893`*^9, 3.585498429740182*^9}, {3.585499094894772*^9, 
  3.585499097542303*^9}, {3.58550056152886*^9, 3.585500572056347*^9}, {
  3.5855041255687923`*^9, 3.585504130967813*^9}, {3.58550491005755*^9, 
  3.5855049179996977`*^9}, {3.585505127301998*^9, 3.585505130595188*^9}, {
  3.585506505509509*^9, 3.585506509199935*^9}, {3.5855073849495363`*^9, 
  3.585507390853044*^9}, {3.585572219240795*^9, 3.585572222920883*^9}, {
  3.5855745218266373`*^9, 3.5855745276170263`*^9}, {3.585577899333741*^9, 
  3.585577904259273*^9}, {3.585578160759005*^9, 3.585578161046257*^9}}],

Cell["Some statistics on the fit residuals:", "Text",
 CellChangeTimes->{{3.585577560027076*^9, 3.585577567234325*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Flatten", "@", 
  RowBox[{"Through", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"Min", ",", "Quartiles", ",", "Max"}], "}"}], "[", 
    RowBox[{
     RowBox[{"lm", "[", "1", "]"}], "[", "\"\<FitResiduals\>\"", "]"}], "]"}],
    "]"}]}]], "Input",
 CellChangeTimes->{{3.585577381927058*^9, 3.585577386631049*^9}, {
   3.585577466553879*^9, 3.585577517548943*^9}, 3.585585578733526*^9, {
   3.585586535156559*^9, 3.5855865355073442`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "37.683165984362546`"}], ",", 
   RowBox[{"-", "12.005977453558092`"}], ",", 
   RowBox[{"-", "2.5661765427012453`"}], ",", "7.48545988488943`", ",", 
   "62.189364407193054`"}], "}"}]], "Output",
 CellChangeTimes->{{3.5855775067873917`*^9, 3.585577517792843*^9}, 
   3.58558558245548*^9, 3.585586536178076*^9, 3.586000261984301*^9}]
}, Open  ]],

Cell["The fit residuals should be normally distributed:", "Text",
 CellChangeTimes->{{3.585578196637183*^9, 3.585578210173354*^9}, {
  3.585578262275679*^9, 3.585578264772081*^9}, {3.585578325458351*^9, 
  3.585578326643011*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"QuantilePlot", "[", 
  RowBox[{
   RowBox[{"lm", "[", "1", "]"}], "[", "\"\<StandardizedResiduals\>\"", "]"}],
   "]"}]], "Input",
 CellChangeTimes->{{3.5855782120117207`*^9, 3.5855782237422123`*^9}, {
   3.585578285084391*^9, 3.585578323251257*^9}, {3.58557842757542*^9, 
   3.585578430801137*^9}, 3.5855855881474857`*^9, {3.58558654003655*^9, 
   3.5855865403813562`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{
     {Hue[0.9060679774997897, 0.6, 0.6], Opacity[0], Dashing[Small], 
      LineBox[{{-8.052061689250559, -2.3988806728170275`}, \
{-2.6578879788688186`, -2.3988806728170275`}}]}, 
     {Hue[0.9060679774997897, 0.6, 0.6], Opacity[0], Dashing[Small], 
      LineBox[{{4.426120397126956, 3.6322805948062693`}, {8.092754735255532, 
       3.6322805948062693`}}]}, {}, 
     {Hue[0.9060679774997897, 0.6, 0.6], Opacity[0], 
      LineBox[{{-2.6578879788688186`, -2.3988806728170275`}, {
       4.426120397126956, 3.6322805948062693`}}]}}, {{}, 
     {RGBColor[0.24720000000000014`, 0.24, 0.6], PointBox[CompressedData["
1:eJwVkGk0FIofhm3JklRIibpZUrqVcBXRb4SicpNKyHIjutm1KUnJkiXc7JKy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       "]]}, {}, {}}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Epilog->{{}, 
    StyleBox[
     LineBox[{{-8.052061689250559, -6.99135569912064}, {8.092754735255532, 
      6.753968462594843}}], 
     Directive[
      RGBColor[0.24720000000000014`, 0.24, 0.6], 
      Dashing[{0, Small}]], StripOnInput -> False]},
  Frame->True,
  FrameLabel->{None, None},
  Method->{"ScalingFunctions" -> None},
  PlotRange->{{-2.6840205630835197`, 
   2.697584911751844}, {-2.3988806728170275`, 3.6322805948062693`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.585578224568228*^9, 3.58557833144705*^9, 
  3.585578431278702*^9, 3.5855855884765253`*^9, 
  3.5855865408255367`*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell["\<\
The deviations from linearity here are not a good sign for the model.\
\>", "Text",
 CellChangeTimes->{{3.585578334620792*^9, 3.585578349425725*^9}}],

Cell[TextData[{
 "The ",
 Cell[BoxData[
  SuperscriptBox["R", "2"]],
  CellChangeTimes->{3.585578660744142*^9}],
 " coefficients can be interpreted as the proportion of variance in the data \
that the model explains (the adjusted one is more strict)."
}], "Text",
 CellChangeTimes->{{3.585578647748148*^9, 3.585578730506425*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"lm", "[", "1", "]"}], "[", "#", "]"}], "&"}], "/@", 
  RowBox[{"{", 
   RowBox[{
   "\"\<RSquared\>\"", ",", "\"\<AdjustedRSquared\>\"", ",", "\"\<AIC\>\""}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.5750460154369383`*^9, 3.575046019940196*^9}, {
   3.575046275699825*^9, 3.5750462866254497`*^9}, {3.585577368376519*^9, 
   3.585577380329494*^9}, 3.5855855902358007`*^9, {3.58558654346876*^9, 
   3.585586543708028*^9}, {3.5855867289139223`*^9, 3.585586730472678*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.3731909961988038`", ",", "0.321530913467936`", ",", 
   "1715.9130632862714`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.575046020168209*^9, 3.5750462872274837`*^9, {3.575109724124819*^9, 
   3.575109743154907*^9}, 3.585577056287941*^9, 3.585577334745885*^9, {
   3.585577373456113*^9, 3.5855773807957907`*^9}, 3.5855855912072887`*^9, 
   3.585586544353589*^9, 3.585586731044869*^9, 3.586000284299219*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Revising the Linear Model", "Title",
 CellChangeTimes->{{3.585417299136742*^9, 3.585417302023638*^9}, {
  3.585486190840365*^9, 3.585486194479013*^9}, {3.5854955216795692`*^9, 
  3.585495536078971*^9}, {3.585495869960773*^9, 3.585495877024088*^9}, {
  3.5854984265503893`*^9, 3.585498429740182*^9}, {3.585499094894772*^9, 
  3.585499097542303*^9}, {3.58550056152886*^9, 3.585500572056347*^9}, {
  3.5855041255687923`*^9, 3.585504130967813*^9}, {3.58550491005755*^9, 
  3.5855049179996977`*^9}, {3.585505127301998*^9, 3.585505130595188*^9}, {
  3.585506505509509*^9, 3.585506509199935*^9}, {3.5855073849495363`*^9, 
  3.585507390853044*^9}, {3.585572219240795*^9, 3.585572222920883*^9}, {
  3.5855745218266373`*^9, 3.5855745276170263`*^9}, {3.585577899333741*^9, 
  3.585577904259273*^9}, {3.585578160759005*^9, 3.585578161046257*^9}, {
  3.585583633222761*^9, 3.585583635807008*^9}}],

Cell[TextData[{
 "We may be able to make some progress by eliminating insignificant \
coefficients from the model.  Here is the analysis-of-variance table for the \
model, with degrees of freedom, sums of squares, mean square errors, \
F-statistics (",
 Cell[BoxData[
  FractionBox["MS", 
   SubscriptBox["MS", "error"]]],
  CellChangeTimes->{3.585586089417841*^9}],
 "), and P-values (the probability that our sample would result if the \
variable had no effect on the response):"
}], "Text",
 CellChangeTimes->{{3.585578334620792*^9, 3.585578349425725*^9}, {
  3.585583662038971*^9, 3.585583672237997*^9}, {3.585583735309367*^9, 
  3.585583744284328*^9}, {3.585583788259857*^9, 3.585583800579356*^9}, {
  3.585585810603355*^9, 3.585585848442052*^9}, {3.585586061678012*^9, 
  3.585586068269073*^9}, {3.585586103412735*^9, 3.585586157883334*^9}, {
  3.585586193275256*^9, 3.585586196531492*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"lm", "[", "1", "]"}], "[", "\"\<ANOVATable\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.585578907533682*^9, 3.585578934788425*^9}, 
   3.585585594402904*^9, {3.5855865508450108`*^9, 3.585586551115938*^9}}],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"DF\"\>", "\<\"SS\"\>", "\<\"MS\"\>", \
"\<\"F\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"season", "3", "84.54191817494575`", "28.180639391648583`", 
      "0.09051329779777942`", "0.9651907890126915`"},
     {"size", "2", "11401.44787219516`", "5700.72393609758`", 
      "18.31013541317466`", "5.68417396854399`*^-8"},
     {"speed", "2", "3934.3768544382765`", "1967.1884272191382`", 
      "6.318405677835643`", "0.002223427757890403`"},
     {"mxPH", "1", "1289.9125915222976`", "1289.9125915222976`", 
      "4.143065773169206`", "0.0432553391731883`"},
     {"mnO2", "1", "2270.7460699587828`", "2270.7460699587828`", 
      "7.293401416371936`", "0.007574129915629664`"},
     {"Cl", "1", "4353.331615345203`", "4353.331615345203`", 
      "13.982450697303971`", "0.00024702243085613816`"},
     {"NO3", "1", "3413.7060869466222`", "3413.7060869466222`", 
      "10.964470725723164`", "0.0011200282295343153`"},
     {"NH4", "1", "403.9002119707293`", "403.9002119707293`", 
      "1.2972856881851667`", "0.25620655051862307`"},
     {"oPO4", "1", "4797.609986594136`", "4797.609986594136`", 
      "15.409426855051631`", "0.00012265538639283713`"},
     {"PO4", "1", "1416.0711815534596`", "1416.0711815534596`", 
      "4.548274110373315`", "0.03429226845772953`"},
     {"Chla", "1", "371.3021605038739`", "371.3021605038739`", 
      "1.1925841198835891`", "0.27625242220020285`"},
     {"\<\"Error\"\>", "182", "56664.34097604904`", "311.3425328354343`", "", 
      ""},
     {"\<\"Total\"\>", "197", "90401.28752525253`", "", "", ""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.5855789352095823`*^9, 3.585585594683009*^9, 
  3.585586552225119*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["season", "Input"],
 " contributes least, so try removing it:"
}], "Text",
 CellChangeTimes->{{3.585586426102715*^9, 3.585586433869883*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"lm", "[", "2", "]"}], "=", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"cols", "=", 
      RowBox[{"featureColumns", "/.", 
       RowBox[{
        RowBox[{"Alternatives", "@@", 
         RowBox[{"{", "season", "}"}]}], "\[Rule]", 
        RowBox[{"Sequence", "[", "]"}]}]}]}], "}"}], ",", 
    RowBox[{"LinearModelFit", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"knnd", "[", "All", "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", 
         RowBox[{"Append", "[", 
          RowBox[{
           RowBox[{"Sort", "[", 
            RowBox[{"cols", "/.", "numberedColumns"}], "]"}], ",", 
           RowBox[{"a1", "/.", "numberedColumns"}]}], "]"}]}], "]"}], "]"}], 
      ",", "cols", ",", "cols", ",", 
      RowBox[{"NominalVariables", "\[Rule]", 
       RowBox[{"Cases", "[", 
        RowBox[{"cols", ",", 
         RowBox[{"x_", "/;", 
          RowBox[{"knnd", "[", 
           RowBox[{"x", ",", "\"\<factorized\>\""}], "]"}]}]}], "]"}]}]}], 
     "]"}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.585586461751087*^9, 3.585586462984416*^9}, {
  3.585587763678216*^9, 3.585587794533242*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"FittedModel", "[", 
   TagBox[
    PanelBox[
     TagBox[
      RowBox[{
       RowBox[{"\[LeftSkeleton]", "19", "\[RightSkeleton]"}], "+", 
       RowBox[{
        RowBox[{"\[LeftSkeleton]", "20", "\[RightSkeleton]"}], " ", 
        RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]}], "+", 
       RowBox[{"3.391513618944541`", " ", 
        RowBox[{"DiscreteIndicator", "[", 
         RowBox[{"speed", ",", "\<\"low\"\>", ",", 
          RowBox[{"{", 
           
           RowBox[{"\<\"high\"\>", ",", "\<\"low\"\>", 
            ",", "\<\"medium\"\>"}], "}"}]}], "]"}]}]}],
      Short[#, 2]& ],
     FrameMargins->5],
    Editable -> False], "]"}],
  InterpretTemplate[
  FittedModel[{
    "Linear", {55.17412150596693, -10.28803519825331, -6.9703969912203, 
     0.29965188893419337`, 3.391513618944541, -3.281831010251743, 
     0.7891817564817032, -0.03864465160268807, -1.5319448636236168`, 
     0.0015748808483351353`, -0.006047660541546096, -0.051146729118126025`, \
-0.08390222146867636}, {{{$CellContext`size, {
        "large", "medium", "small"}}, {$CellContext`speed, {
        "high", "low", 
         "medium"}}, $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla}, {1, 
       $CellContext`size["large"], 
       $CellContext`size["medium"], 
       $CellContext`speed["high"], 
       $CellContext`speed[
       "low"], $CellContext`mxPH, $CellContext`mnO2, $CellContext`Cl, \
$CellContext`NO3, $CellContext`NH4, $CellContext`oPO4, $CellContext`PO4, \
$CellContext`Chla}}, {0, 0}}, CompressedData["
1:eJxTTMoPSmViYGBgBOJjDDDwwX6UHqVH6VF6lB6l8dEAb4jszQ==
    "], {{
     "small", "medium", 8., 9.8, 60.8, 6.238, 578., 105., 170., 50., 0.}, {
     "small", "medium", 8.35, 8., 57.75, 1.288, 370., 428.75, 558.75, 1.3, 
      1.4}, {"small", "medium", 8.1, 11.4, 40.02, 5.33, 346.66699, 125.667, 
      187.05701, 15.6, 3.3}, {
     "small", "medium", 8.07, 4.8, 77.364, 2.302, 98.182, 61.182, 138.7, 1.4, 
      3.1}, {"small", "medium", 8.06, 9., 55.35, 10.416, 233.7, 58.222, 97.58,
       10.5, 9.2}, {
     "small", "high", 8.25, 13.1, 65.75, 9.248, 430., 18.25, 56.667, 28.4, 
      15.1}, {"small", "high", 8.15, 10.3, 73.25, 1.535, 110., 61.25, 111.75, 
      3.2, 2.4}, {
     "small", "high", 8.05, 10.6, 59.067, 4.99, 205.66701, 44.667, 77.434, 
      6.9, 18.2}, {
     "small", "medium", 8.7, 3.4, 21.95, 0.886, 102.75, 36.3, 71., 5.544, 
      25.4}, {"small", "high", 7.93, 9.9, 8., 1.39, 5.8, 27.25, 46.6, 0.8, 
      17.}, {"small", "high", 7.7, 10.2, 8., 1.527, 21.571, 12.75, 20.75, 0.8,
       16.6}, {"small", "high", 7.45, 11.7, 8.69, 1.588, 18.429, 10.667, 19., 
      0.6, 32.1}, {
     "small", "high", 7.74, 9.6, 5., 1.223, 27.286, 12., 17., 41., 43.5}, {
     "small", "high", 7.72, 11.8, 6.3, 1.47, 8., 16., 15., 0.5, 31.1}, {
     "small", "high", 7.9, 9.6, 3., 1.448, 46.2, 13., 61.6, 0.3, 52.2}, {
     "small", "high", 7.55, 11.5, 4.7, 1.32, 14.75, 4.25, 98.25, 1.1, 69.9}, {
     "small", "high", 7.78, 12., 7., 1.42, 34.333, 18.667, 50., 1.1, 46.2}, {
     "small", "high", 7.61, 9.8, 7., 1.443, 31.333, 20., 57.833, 0.4, 31.8}, {
     "small", "high", 7.35, 10.4, 7., 1.718, 49., 41.5, 61.5, 0.8, 50.6}, {
     "small", "medium", 7.79, 3.2, 64., 2.822, 8777.59961, 564.59998, 
      771.59998, 4.5, 0.}, {
     "small", "medium", 7.83, 10.7, 88., 4.825, 1729., 467.5, 586., 16., 
      0.}, {"small", "high", 7.2, 9.2, 0.8, 0.642, 81., 15.6, 18., 0.5, 
      15.5}, {"small", "high", 7.75, 10.3, 32.92, 2.942, 42., 16., 40., 7.6, 
      23.2}, {"small", "high", 7.62, 8.5, 11.867, 1.715, 208.33299, 3., 27.5, 
      1.7, 74.2}, {
     "small", "high", 7.84, 9.4, 10.975, 1.51, 12.5, 3., 11.5, 1.5, 13.}, {
     "small", "high", 7.77, 10.7, 12.536, 3.976, 58.5, 9., 44.136, 3., 4.1}, {
     "small", "high", 7.09, 8.4, 10.5, 1.572, 28., 4., 13.6, 0.5, 29.7}, {
     "small", "high", 6.8, 11.1, 9., 0.63, 20., 4., 16.369371260220625`, 2.7, 
      30.3}, {
     "small", "high", 8., 9.8, 16., 0.73, 20., 26., 45., 0.8, 17.1}, {
     "small", "high", 7.2, 11.3, 9., 0.23, 120., 12., 19., 0.5, 33.9}, {
     "small", "high", 7.4, 12.5, 13., 3.33, 60., 72., 142., 4.9, 3.4}, {
     "small", "high", 8.1, 10.3, 26., 3.78, 60., 246., 304., 2.8, 6.9}, {
     "small", "high", 7.8, 11.3, 20.083, 3.02, 49.5, 53., 130.75, 5.8, 0.}, {
     "small", "medium", 8.4, 9.9, 34.5, 2.818, 3515., 20., 47., 2.3, 13.6}, {
     "small", "medium", 8.27, 7.8, 29.2, 0.05, 6400., 7.4, 23., 0.9, 5.3}, {
     "small", "medium", 8.66, 8.4, 30.523, 3.444, 1911., 58.875, 84.46, 3.6, 
      18.3}, {"small", "high", 8.3, 10.9, 1.17, 0.735, 13.5, 1.625, 3., 0.2, 
      66.}, {"small", "high", 8., 10.214452952751651`, 1.45, 0.81, 10., 2.5, 
      3., 0.3, 75.8}, {
     "small", "medium", 8.3, 8.9, 20.625, 3.414, 228.75, 196.62, 253.25, 
      12.32, 2.}, {
     "small", "medium", 8.1, 10.5, 22.286, 4.071, 178.57001, 182.42, 255.28, 
      8.957, 2.2}, {
     "small", "medium", 8., 5.5, 77., 6.096, 122.85, 143.71001, 296., 3.7, 
      0.}, {"small", "medium", 8.15, 7.1, 54.19, 3.829, 647.57001, 59.429, 
      175.04601, 13.2, 0.}, {
     "small", "high", 8.3, 7.7, 50., 8.543, 76., 264.89999, 344.60001, 22.5, 
      0.}, {"small", "high", 8.3, 8.8, 54.143, 7.83, 51.429, 276.85001, 
      326.85699, 11.84, 4.1}, {
     "small", "high", 8.4, 13.4, 69.75, 4.555, 37.5, 10., 40.667, 3.9, 
      51.8}, {"small", "high", 8.3, 12.5, 87., 4.87, 22.5, 27., 43.5, 3.3, 
      29.5}, {"small", "high", 8., 12.1, 66.3, 4.535, 39., 16., 39., 0.8, 
      54.4}, {"small", "low", 8.05919641233121, 12.6, 9., 0.23, 10., 5., 6., 
      1.1, 35.5}, {
     "small", "medium", 7.6, 9.6, 15., 3.02, 40., 27., 121., 2.8, 89.8}, {
     "small", "medium", 7.29, 11.21, 17.75, 3.07, 35., 13., 20.812, 12.1, 
      24.8}, {"small", "medium", 7.6, 10.2, 32.3, 4.508, 192.5, 12.75, 49.333,
       7.9, 0.}, {
     "small", "medium", 8., 7.9, 27.233, 1.651, 28.333, 7.3, 22.9, 4.5, 
      39.1}, {"small", "high", 7.9, 11., 6.167, 1.172, 18.333, 7.75, 11.8, 
      0.5, 81.9}, {
     "small", "high", 7.9, 9., 5.273, 0.91, 33.636, 9., 11.818, 0.8, 54.}, {
     "small", "high", 6.6, 10.8, 6.013115993877201, 3.245, 10., 1., 6.5, 
      0.8364380530399255, 24.3}, {
     "small", "medium", 5.6, 11.8, 6.418402172011745, 2.22, 5., 1., 1., 
      0.9646753712906323, 82.7}, {
     "small", "medium", 5.7, 10.8, 10.009721333679945`, 2.55, 10., 1., 4., 
      1.297647641898099, 16.8}, {
     "small", "high", 6.6, 9.5, 21.735126900601863`, 1.32, 20., 1., 6., 
      7.196816371858979, 46.8}, {
     "small", "high", 6.6, 10.8, 9.597101331984843, 2.64, 10., 2., 11., 
      1.5011275699367495`, 46.9}, {
     "small", "medium", 6.6, 11.3, 5.864630296982661, 4.17, 10., 1., 6., 
      3.556597519567581, 47.1}, {
     "small", "medium", 6.5, 10.4, 6.368686180255313, 5.97, 10., 2., 14., 
      3.634367808702219, 66.9}, {
     "small", "high", 7.83, 11.7, 4.083, 1.328, 18., 3.333, 6.667, 
      3.8005964534583807`, 14.4}, {
     "small", "high", 7.57, 10.8, 4.575, 1.203, 27.5, 2., 6.75, 1., 20.3}, {
     "small", "high", 7.19, 11.7, 4.326, 1.474, 160., 2.5, 7.2, 0.3, 15.8}, {
     "small", "high", 7.44, 10.1, 2.933, 0.77, 15., 1.333, 6., 0.6, 55.5}, {
     "small", "high", 7.14, 9.8, 3.275, 0.923, 15., 1.25, 10.75, 2.5, 10.3}, {
     "small", "high", 7., 12.1, 3.136, 1.208, 16.2, 1.8, 2.5, 0.5, 64.2}, {
     "small", "medium", 7.5, 1.5, 32.4, 0.921, 1386.25, 220.75, 351.60001, 
      10., 0.}, {
     "small", "medium", 7.5, 1.8, 29.775, 1.051, 2082.8501, 209.85699, 
      313.60001, 1., 1.9}, {
     "small", "medium", 7.8, 7.1, 32.54, 1.72, 2167.37012, 151.125, 279.06601,
       13.1, 25.5}, {
     "medium", "medium", 8.5, 8.1, 38.125, 3.85, 225., 45., 152.33299, 5.2, 
      11.3}, {"medium", "medium", 7.925, 10.2, 34.037, 9.08, 109., 55., 
      58.623, 11.6, 4.4}, {
     "medium", "medium", 8.1, 8.1, 136., 3.773, 245., 136.75, 249.25, 20.87, 
      1.9}, {"medium", "medium", 8.2, 6.8, 129.375, 3.316, 271.25, 100., 
      233.5, 13., 1.6}, {
     "medium", "high", 9.1, 9.4, 35.75, 5.164, 32.5, 85.5, 215.5, 18.37, 
      2.2}, {"medium", "medium", 8.1, 9.8, 29.5, 1.287, 224.286, 25.167, 
      102.333, 3.6, 64.9}, {
     "medium", "medium", 8., 5.9, 27.4, 0.735, 133.636, 36., 105.727, 3., 
      15.1}, {"medium", "medium", 8., 3.3, 26.76, 0.658, 165., 37.375, 
      111.375, 3., 14.4}, {
     "medium", "high", 7.5, 9.2, 11., 3.31, 101., 26.6, 108., 1.3, 6.7}, {
     "medium", "high", 7.4, 9.8, 11., 3.235, 255., 38.75, 56.667, 2., 10.8}, {
     "medium", "high", 7.3, 11.7, 10.4, 4.93, 130., 10.8, 60., 4.3, 1.2}, {
     "medium", "high", 7.4, 8.9, 13.5, 5.442, 123.333, 27.667, 104., 21., 
      12.6}, {"medium", "high", 7.4, 11.17, 12.146, 6.188, 89.6, 32., 69.93, 
      3.1, 14.7}, {
     "medium", "medium", 7.5, 10.8, 31., 4.408, 737.5, 111.25, 214., 2.9, 
      3.3}, {"medium", "medium", 7.6, 6., 53., 3.734, 914., 137.60001, 
      254.60001, 4.3, 0.}, {
     "medium", "medium", 7.4, 10.77, 36.248, 3.73, 429.20001, 57.6, 169.00101,
       3.2, 2.8}, {
     "medium", "medium", 7.8, 3.6, 48.667, 4.03, 5738.33008, 412.33301, 
      607.16699, 4.3, 0.}, {
     "medium", "medium", 7.6, 9.7, 53.102, 7.16, 4073.33008, 282.16699, 
      624.73297, 6.8, 0.}, {
     "medium", "medium", 8.5, 8.6, 125.6, 3.778, 124.167, 197.83299, 
      303.33301, 40., 0.}, {
     "medium", "medium", 8.7, 9.4, 173.75, 3.318, 101.25, 267.75, 391.75, 3.5,
       0.}, {"medium", "medium", 8.1, 10.7, 94.405, 4.698, 153., 191.75, 
      265.25, 7.3, 0.}, {
     "medium", "high", 8.8, 8.5, 53.333, 5.132, 96.667, 120.5, 232.83299, 31.,
       1.2}, {"medium", "high", 7.8, 10.5, 70., 2.443, 98.333, 144.66701, 
      244., 9., 0.}, {
     "medium", "high", 7.9, 11.8, 63.51, 4.94, 137., 159.5, 218., 6.5, 0.}, {
     "medium", "low", 8.5, 10.5, 56.717, 0.33, 215.714, 23., 138.5, 20.829, 
      5.7}, {"medium", "low", 9.1, 5.4, 61.05, 0.308, 105.556, 104.222, 239., 
      72.478, 3.6}, {
     "medium", "low", 8.9, 4.5, 57.75, 0.267, 155., 97.333, 235.66701, 98.817,
       1.2}, {"medium", "high", 7.9, 6.3, 101.875, 3.978, 153.75, 51.75, 
      205.875, 2., 4.}, {
     "medium", "high", 7.8, 8.2, 85.982, 6.2, 421.66699, 31.333, 211.66701, 
      21.9, 5.9}, {
     "medium", "medium", 7.7, 7.1, 63.625, 3.14, 122.5, 28.625, 186.5, 30., 
      16.5}, {
     "medium", "medium", 7.8, 6.5, 82.111, 2.603, 215.556, 12.889, 154.125, 
      5.2, 7.}, {
     "medium", "low", 7.7, 5.3, 65.333, 2.899, 371.11099, 51.111, 183.66701, 
      17.2, 58.7}, {
     "medium", "low", 7.5, 8.8, 58.331, 8.688, 758.75, 104.5, 292.625, 3., 
      8.7}, {"medium", "low", 7.6, 10., 49.625, 5.456, 308.75, 38.625, 
      285.71399, 75., 17.}, {
     "medium", "low", 8.7, 7.4, 47.778, 2.316, 38.111, 24.667, 201.778, 3., 
      12.3}, {"medium", "low", 7.7, 11.1, 47.229, 8.759, 239., 54., 275.14301,
       65.7, 8.8}, {
     "medium", "high", 8.3, 11.1, 41.5, 4.665, 931.83301, 39., 124.2, 13.1, 
      23.7}, {"medium", "high", 8.43, 6., 40.167, 2.67, 723.66699, 60.833, 
      141.83299, 25., 0.}, {
     "medium", "high", 8.16, 11.1, 32.056, 5.694, 461.875, 71., 132.54601, 
      15., 3.6}, {
     "medium", "high", 8.7, 9.8, 5.889, 1.534, 51.111, 9.667, 17.333, 1., 
      64.3}, {"medium", "high", 8.2, 11.3, 7.25, 1.875, 25., 6.5, 26., 0.3, 
      46.6}, {"medium", "high", 8.5, 11.8, 7.838, 1.732, 206.53799, 8.692, 
      16.662, 2.1, 24.}, {
     "medium", "medium", 7.8, 6., 53.425, 0.381, 118.571, 37.857, 102.571, 
      1.2, 3.7}, {
     "medium", "medium", 8., 9.7, 57.848, 0.461, 217.75, 37., 86.997, 3., 
      18.1}, {"medium", "high", 9.7, 10.8, 0.222, 0.406, 10., 22.444, 10.111, 
      1.6812921234898004`, 41.}, {
     "medium", "high", 8.6, 11.62, 1.549, 0.445, 25.833, 16.833, 18.293, 1.4, 
      43.7}, {"medium", "medium", 8.3, 11.6, 5.83, 0.701, 12.727, 3.545, 13.2,
       3.2, 86.6}, {
     "medium", "low", 8.4, 5.3, 74.667, 3.9, 131.66701, 261.60001, 432.909, 
      24.917, 1.9}, {
     "medium", "low", 8.2, 6.6, 131.39999, 4.188, 92., 238.2, 320.39999, 6.8, 
      1.2}, {"medium", "medium", 8.2, 9.4, 45.273, 7.195, 345.45499, 144., 
      287., 9.882, 1.4}, {
     "medium", "medium", 8.1, 7.1, 42.636, 5.078, 56.364, 166.72701, 
      262.72699, 17.2, 1.6}, {
     "medium", "medium", 8.1, 9., 48.429, 6.64, 128.571, 181., 222.286, 6.429,
       3.3}, {"medium", "high", 7.4, 10.7, 11.818, 2.163, 170.909, 36.909, 
      122., 5.555, 14.6}, {
     "medium", "high", 8.3, 9.7, 10.556, 1.921, 65.556, 61.556, 127.222, 
      5.233, 1.7}, {
     "medium", "high", 8.6, 10.7, 12., 2.231, 43.75, 62.625, 89.625, 2.15, 
      3.3}, {"medium", "medium", 9.1, 11.6, 31.091, 5.099, 246.364, 55., 284.,
       88.255, 0.}, {
     "medium", "medium", 9., 6.9, 28.333, 2.954, 76.667, 102.333, 277.33301, 
      110.456, 0.}, {
     "medium", "medium", 8.3, 10., 30.125, 3.726, 102.5, 75.875, 177.625, 
      50.225, 1.5}, {
     "medium", "high", 8.5, 10.1, 10.936, 1.335, 236., 34.636, 72.9, 11.1, 
      4.2}, {"medium", "high", 8.3, 7.7, 10.078, 1.212, 103.333, 48.667, 
      82.444, 2., 4.1}, {
     "medium", "high", 7.3, 10.5, 11.088, 1.374, 92.375, 48.625, 66.75, 3.3, 
      1.2}, {"medium", "medium", 7.9, 9.8, 194.75, 6.513, 3466.65991, 23., 
      173.75, 15.3, 0.}, {
     "medium", "medium", 7.9, 8.3, 391.5, 6.045, 380., 173., 317., 5.5, 
      2.4}, {"medium", "medium", 8., 11.9, 130.67, 6.54, 196., 75., 84., 4.5, 
      7.8}, {"medium", "medium", 8., 9.2, 39., 4.86, 120., 187., 213., 2., 
      10.3}, {"medium", "medium", 8.1, 11.7, 35.66, 5.13, 46.5, 49., 88.5, 
      2.5, 1.5}, {
     "medium", "low", 8.43, 9.9, 37.6, 0.826, 124., 32.5, 115., 11.7, 9.2}, {
     "medium", "low", 8.1, 6.2, 39., 0.673, 112.857, 60., 98.143, 2., 28.1}, {
     "medium", "medium", 7.9, 11.2, 49.9, 9.773, 505., 67.5, 143.75, 5.45, 
      2.1}, {"medium", "medium", 8.1, 6.2, 51.113, 5.099, 175., 132.5, 
      197.14301, 6.4, 1.4}, {
     "medium", "high", 7.8, 9.5, 8.3, 1.67, 34., 16.8, 35.2, 1., 19.}, {
     "medium", "high", 7.9, 10.5, 10.207, 2.304, 132.25, 10.583, 23.485, 2., 
      42.5}, {"medium", "low", 8., 4.5, 79.077, 8.984, 920., 70., 200.231, 
      19.4, 2.5}, {
     "medium", "low", 7.6, 6.3, 81.333, 9.715, 196.66701, 77.333, 147.83299, 
      3., 4.4}, {
     "medium", "low", 7.8, 6.5, 64.093, 7.74, 1990.16003, 47.5, 276., 8.1, 
      6.5}, {"medium", "high", 8.22, 8.1, 41.25, 1.415, 172.5, 46.667, 
      123.333, 30.4, 39.7}, {
     "medium", "high", 8.3, 9.9, 40.226, 1.587, 235., 33.8, 75.207, 23.8, 
      32.8}, {
     "medium", "high", 8.47, 9., 46.167, 2.102, 84.667, 48., 116.2, 7.3, 
      12.2}, {"medium", "high", 8.4, 4.9, 47., 0.536, 91.833, 109., 188.66701,
       32., 1.9}, {
     "medium", "high", 8.87, 11., 41.163, 2.273, 54.75, 39., 72.696, 22.7, 
      0.}, {"medium", "high", 7.7, 4.4, 53., 2.31, 90., 22.2, 116.2, 16., 
      0.}, {"medium", "high", 7.3, 11.8, 44.205, 45.65, 24064., 44., 34., 
      53.1, 2.2}, {
     "medium", "medium", 7.9, 6., 127.833, 2.68, 176.66701, 27.5, 76.333, 2.1,
       3.4}, {"medium", "medium", 7.8, 10.53, 100.83, 5.41, 486.5, 24., 
      58.374, 27.5, 2.8}, {
     "large", "low", 7.8, 3.2, 94., 4.908, 1131.66003, 175.66701, 361., 
      28.567, 24.8}, {
     "large", "low", 7.6, 4.9, 69., 3.685, 1495., 234.5, 236., 22.5, 32.5}, {
     "large", "low", 8.6, 3.6, 50., 0.376, 134., 54.1, 125.8, 26.8, 0.}, {
     "large", "low", 8.4, 10.6, 19.22, 1.655, 96.833, 20.667, 54.916, 20.6, 
      0.}, {"large", "low", 8.3, 11.5, 26., 1.87, 62.5, 30.75, 75.333, 34.75, 
      0.}, {"large", "low", 9., 5.8, 77.49257553979058, 0.9, 142., 102., 186.,
       68.05, 1.7}, {
     "large", "low", 9.5, 5.7, 44., 0.102, 146.66701, 151.33299, 252.5, 
      93.683, 12.3}, {
     "large", "low", 8.8, 8.8, 43., 0.13, 103.333, 180.66701, 269.66699, 
      92.667, 7.2}, {
     "large", "low", 8.84, 12.9, 43.09, 0.846, 52.2, 8.6, 46.438, 81.54, 
      3.4}, {"large", "high", 7.3, 9.9, 16., 4.82, 101.667, 14.667, 85., 2., 
      0.}, {"large", "high", 7.4, 10.68, 22.35, 5.414, 244.60001, 66.4, 
      171.272, 3.8, 1.1}, {
     "large", "low", 9.1, 4.3, 82.857, 0.86, 137.27299, 102.364, 232.89999, 
      54.367, 0.}, {
     "large", "low", 8.53, 11.1, 63.292, 1.726, 227.60001, 84.3, 146.452, 
      21.22, 1.4}, {
     "large", "low", 8.56, 8.7, 43.97, 4.053, 643., 221.89999, 246.66701, 
      14.7, 12.5}, {
     "large", "low", 8.06, 8.3, 38.902, 3.678, 627.27301, 205.636, 219.909, 
      6.209, 0.}, {
     "large", "medium", 8.24, 6.1, 95.367, 3.561, 1168., 236.39999, 272.22198,
       20.578, 2.5}, {
     "large", "medium", 7.91, 6.2, 151.83299, 3.923, 1081.66003, 346.16699, 
      388.16699, 5.083, 1.7}, {
     "large", "medium", 8.21, 9.3, 104.818, 3.908, 124.364, 82.222, 167.89999,
       5.609, 1.4}, {
     "large", "medium", 8.5, 7.3, 71.444, 2.512, 66.667, 64.389, 137.778, 
      9.384, 0.}, {
     "large", "medium", 8.6, 10.6, 208.364, 4.459, 197.909, 87.333, 194.10001,
       27.618, 0.}, {
     "large", "medium", 9.06, 6.35, 187.183, 3.351, 54.778, 159.16701, 
      221.278, 20.8, 0.}, {
     "large", "high", 8.7, 10.7, 4.545, 0.941, 32.727, 16., 21.3, 1.1, 
      39.7}, {"large", "high", 8.1, 10.7, 3.5, 1.013, 12.5, 12.75, 11., 0.6, 
      37.3}, {"large", "high", 8.4, 10.29, 5.326, 0.996, 53.846, 7.667, 
      14.354, 0.8, 52.4}, {
     "large", "medium", 8.6, 10.1, 2.111, 0.663, 11.111, 3.222, 7., 1.3, 
      48.3}, {"large", "medium", 8.2, 9.5, 2.2, 0.672, 10., 3.8, 6.2, 0.8, 
      50.4}, {"large", "medium", 8.5, 10.5, 2.75, 0.758, 10.5, 4., 7.654, 4., 
      56.8}, {"large", "medium", 8.3, 10., 3.86, 0.866, 32., 6., 16., 2.86, 
      17.3}, {"large", "high", 8., 10.9, 9.055, 0.825, 40., 21.083, 56.091, 
      12.7828046039726, 16.8}, {
     "large", "high", 8.1, 10.2, 7.613, 0.699, 32.5, 26.625, 52.875, 2., 
      18.1}, {"large", "low", 8.7, 10.8, 39.109, 6.225, 161.81799, 104.727, 
      228.364, 46.075, 1.1}, {
     "large", "low", 8.7, 11.7, 22.455, 3.765, 88.182, 41.3, 85.4, 17.491, 
      0.}, {"large", "low", 8.4, 8.2, 23.25, 2.805, 43.75, 51.125, 87.125, 
      14.775, 0.}, {
     "large", "low", 8.55, 11., 22.32, 3.14, 82.1, 45.9, 101.455, 18.33, 
      1.7}, {"large", "medium", 8.5, 7.6, 12.778, 1.873, 17.778, 50.889, 127.,
       24.556, 0.}, {
     "large", "medium", 8.7, 11.4, 15.541, 2.323, 103., 34.5, 81.558, 5.62, 
      7.6}, {"large", "medium", 8.4, 10.5, 12.182, 1.519, 65.455, 19.727, 
      50.455, 8.155, 2.9}, {
     "large", "medium", 8.2, 8.2, 7.333, 1.003, 37.778, 19.111, 120.889, 
      5.111, 2.2}, {
     "large", "medium", 8.58, 11.1, 23.825, 3.617, 72.6, 51.111, 91.111, 22.9,
       3.8}, {"large", "medium", 8.5, 7.9, 12.444, 2.586, 96.667, 19.111, 
      61.444, 6.167, 18.9}, {
     "large", "medium", 8.4, 8.4, 17.375, 3.833, 83.75, 53.625, 79.75, 2.338, 
      12.7}, {
     "large", "medium", 8.3, 10.6, 14.32, 3.2, 125.333, 35.333, 75.904, 4.667,
       18.}, {"large", "medium", 8.2, 7., 139.989, 2.978, 60.11, 78.333, 
      140.22, 31.738, 0.}, {
     "large", "medium", 8.5, 6.7, 82.852, 2.8, 27.069, 64., 140.517, 18.3, 
      2.4}}, CompressedData["
1:eJydXAl0VFW2jTEMImAYAgFDUhkqAUQgBEIkYt0MEDKSEQhDJiBAIJDIICJq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    "], 
    Function[Null, 
     Internal`LocalizedBlock[{$CellContext`Chla, $CellContext`Cl, \
$CellContext`mnO2, $CellContext`mxPH, $CellContext`NH4, $CellContext`NO3, \
$CellContext`oPO4, $CellContext`PO4, $CellContext`size, $CellContext`speed, 
       $CellContext`size["large"], 
       $CellContext`size["medium"], 
       $CellContext`size["small"], 
       $CellContext`speed["high"], 
       $CellContext`speed["low"], 
       $CellContext`speed["medium"]}, #], {HoldAll}]]& ],
  Editable->False,
  SelectWithContents->True,
  Selectable->True]], "Output",
 CellChangeTimes->{
  3.585586581665464*^9, {3.585587764547728*^9, 3.585587794956917*^9}, 
   3.585682706779488*^9, 3.586000336048271*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"lm", "[", "2", "]"}], "[", "\"\<ParameterTable\>\"", 
  "]"}]], "Input",
 CellChangeTimes->{{3.585586779159347*^9, 3.5855867877328672`*^9}}],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"Estimate\"\>", "\<\"Standard Error\"\>", "\<\"t\
\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"1", "55.17412150596693`", "21.505099026551047`", "2.565629734503746`", 
      "0.011091173494009423`"},
     {
      RowBox[{"size", "[", "\<\"large\"\>", "]"}], 
      RowBox[{"-", "10.28803519825331`"}], "4.112944478375971`", 
      RowBox[{"-", "2.501379547509871`"}], "0.01323924581823458`"},
     {
      RowBox[{"size", "[", "\<\"medium\"\>", "]"}], 
      RowBox[{"-", "6.9703969912203`"}], "3.3893148986228465`", 
      RowBox[{"-", "2.0565799283072006`"}], "0.0411304682375492`"},
     {
      RowBox[{"speed", "[", "\<\"high\"\>", "]"}], "0.29965188893419337`", 
      "3.1790068650711962`", "0.09425959164371998`", "0.925004959590893`"},
     {
      RowBox[{"speed", "[", "\<\"low\"\>", "]"}], "3.391513618944541`", 
      "4.078241238798232`", "0.8316118199873693`", "0.4067001896396728`"},
     {"mxPH", 
      RowBox[{"-", "3.281831010251743`"}], "2.655637517945988`", 
      RowBox[{"-", "1.2357978030036594`"}], "0.2181006180917462`"},
     {"mnO2", "0.7891817564817032`", "0.6590282511620177`", 
      "1.1974930590459438`", "0.23264650882242843`"},
     {"Cl", 
      RowBox[{"-", "0.03864465160268807`"}], "0.033333231562720986`", 
      RowBox[{"-", "1.1593430876923208`"}], "0.24781053330014402`"},
     {"NO3", 
      RowBox[{"-", "1.5319448636236168`"}], "0.5478392729128346`", 
      RowBox[{"-", "2.796339983948834`"}], "0.005714570990315252`"},
     {"NH4", "0.0015748808483351353`", "0.0009949370252266723`", 
      "1.5828950058184204`", "0.11515342968866804`"},
     {"oPO4", 
      RowBox[{"-", "0.006047660541546096`"}], "0.03952221735349041`", 
      RowBox[{"-", "0.1530192622406596`"}], "0.878549856428549`"},
     {"PO4", 
      RowBox[{"-", "0.051146729118126025`"}], "0.03053105268865679`", 
      RowBox[{"-", "1.6752363450975465`"}], "0.09557729300325479`"},
     {"Chla", 
      RowBox[{"-", "0.08390222146867636`"}], "0.07940477120717192`", 
      RowBox[{"-", "1.0566395468827725`"}], "0.29205397144562817`"}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{
  3.5855867881014843`*^9, {3.585587781443225*^9, 3.585587795657201*^9}, 
   3.5860003373616447`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"lm", "[", "2", "]"}], "[", "#", "]"}], "&"}], "/@", 
  RowBox[{"{", 
   RowBox[{
   "\"\<RSquared\>\"", ",", "\"\<AdjustedRSquared\>\"", ",", "\"\<AIC\>\""}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.5750460154369383`*^9, 3.575046019940196*^9}, {
   3.575046275699825*^9, 3.5750462866254497`*^9}, {3.585577368376519*^9, 
   3.585577380329494*^9}, 3.5855855902358007`*^9, {3.58558654346876*^9, 
   3.585586543708028*^9}, {3.5855867289139223`*^9, 3.5855867447200327`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.3682518466002283`", ",", "0.32727358800132417`", ",", 
   "1711.4671550262563`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.575046020168209*^9, 3.5750462872274837`*^9, {3.575109724124819*^9, 
   3.575109743154907*^9}, 3.585577056287941*^9, 3.585577334745885*^9, {
   3.585577373456113*^9, 3.5855773807957907`*^9}, 3.5855855912072887`*^9, 
   3.585586544353589*^9, {3.585586731044869*^9, 3.585586744819228*^9}, {
   3.5855877884629602`*^9, 3.585587796412422*^9}, 3.585682717232897*^9, 
   3.586000340532549*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"lm", "[", "2", "]"}], "[", "\"\<ANOVATable\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.585587145087481*^9, 3.585587154530374*^9}}],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"DF\"\>", "\<\"SS\"\>", "\<\"MS\"\>", \
"\<\"F\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"size", "2", "11400.247278499271`", "5700.123639249636`", 
      "18.464493850874483`", "4.8818777536238156`*^-8"},
     {"speed", "2", "3909.3344453091413`", "1954.6672226545707`", 
      "6.331782115161692`", "0.002188629873007728`"},
     {"mxPH", "1", "1306.6223898133758`", "1306.6223898133758`", 
      "4.232561012536205`", "0.041058580580439034`"},
     {"mnO2", "1", "2068.72619948996`", "2068.72619948996`", 
      "6.701255026575825`", "0.010400230863238286`"},
     {"Cl", "1", "4185.667913905767`", "4185.667913905767`", 
      "13.558695275650129`", "0.00030332601339085264`"},
     {"NO3", "1", "3571.7326556501794`", "3571.7326556501794`", 
      "11.569965816724286`", "0.0008213106497865568`"},
     {"NH4", "1", "392.44778461460373`", "392.44778461460373`", 
      "1.2712618470078614`", "0.26099030590081373`"},
     {"oPO4", "1", "4764.225189958597`", "4764.225189958597`", 
      "15.43282431953565`", "0.00012061317697386558`"},
     {"PO4", "1", "1346.7695053432326`", "1346.7695053432326`", 
      "4.36261015089647`", "0.03810452090800629`"},
     {"Chla", "1", "344.66770362829993`", "344.66770362829993`", 
      "1.116487132036586`", "0.2920539714456343`"},
     {"\<\"Error\"\>", "185", "57110.8464590401`", "308.70727815697353`", "", 
      ""},
     {"\<\"Total\"\>", "197", "90401.28752525253`", "", "", ""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.5855871548956833`*^9, 3.586000342082898*^9}]
}, Open  ]],

Cell[TextData[{
 "The adjusted ",
 Cell[BoxData[
  SuperscriptBox["R", "2"]],
  CellChangeTimes->{3.585578660744142*^9}],
 "has increased slightly, and some of the sum-of-squared-errors has shifted \
from the features, but the effect is small."
}], "Text",
 CellChangeTimes->{{3.5855881533782883`*^9, 3.585588215329549*^9}, {
  3.5855883032153397`*^9, 3.585588310079179*^9}, {3.5860003535109863`*^9, 
  3.586000383230386*^9}}],

Cell["\<\
The continuation of this removal process until there are no more suitable \
removal candidates is called backward elimination.\
\>", "Text",
 CellChangeTimes->{{3.585588311694849*^9, 3.585588325703136*^9}, {
  3.585588483150424*^9, 3.585588496443672*^9}, {3.5860970840358257`*^9, 
  3.586097086017764*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Backward Elimination", "Title",
 CellChangeTimes->{{3.585417299136742*^9, 3.585417302023638*^9}, {
  3.585486190840365*^9, 3.585486194479013*^9}, {3.5854955216795692`*^9, 
  3.585495536078971*^9}, {3.585495869960773*^9, 3.585495877024088*^9}, {
  3.5854984265503893`*^9, 3.585498429740182*^9}, {3.585499094894772*^9, 
  3.585499097542303*^9}, {3.58550056152886*^9, 3.585500572056347*^9}, {
  3.5855041255687923`*^9, 3.585504130967813*^9}, {3.58550491005755*^9, 
  3.5855049179996977`*^9}, {3.585505127301998*^9, 3.585505130595188*^9}, {
  3.585506505509509*^9, 3.585506509199935*^9}, {3.5855073849495363`*^9, 
  3.585507390853044*^9}, {3.585572219240795*^9, 3.585572222920883*^9}, {
  3.5855745218266373`*^9, 3.5855745276170263`*^9}, {3.585577899333741*^9, 
  3.585577904259273*^9}, {3.585578160759005*^9, 3.585578161046257*^9}, {
  3.585583633222761*^9, 3.585583635807008*^9}, {3.585588337600482*^9, 
  3.5855883404788017`*^9}}],

Cell["\<\
We can automate backward elimination. The criterion for termination is an \
increase in the Aikake Information Criterion (for which smaller is better).\
\>", "Text",
 CellChangeTimes->{{3.5855881533782883`*^9, 3.585588215329549*^9}, {
  3.5855883032153397`*^9, 3.585588310079179*^9}, {3.5855885053340263`*^9, 
  3.585588518146798*^9}, {3.5855887468313713`*^9, 3.585588770981682*^9}, {
  3.58600041666321*^9, 3.586000420677517*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"beLm", "=", 
   RowBox[{"NestWhile", "[", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"Module", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"m", ",", "cols", ",", "worstCol"}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"cols", "=", 
          RowBox[{"Rest", "[", 
           RowBox[{"DeleteDuplicates", "[", 
            RowBox[{
             RowBox[{"#", "[", "\"\<BasisFunctions\>\"", "]"}], "/.", 
             RowBox[{
              RowBox[{"HoldPattern", "[", 
               RowBox[{"DiscreteIndicator", "[", 
                RowBox[{"x_", ",", "args__"}], "]"}], "]"}], "\[RuleDelayed]",
               "x"}]}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"Print", "@", 
          RowBox[{"StringForm", "[", 
           RowBox[{"\"\<Fitting using columns: `` ...\>\"", ",", "cols"}], 
           "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"worstCol", "=", 
          RowBox[{"First", "@", 
           RowBox[{"cols", "[", 
            RowBox[{"[", 
             RowBox[{"Ordering", "[", 
              RowBox[{"#", "[", "\"\<SequentialSumOfSquares\>\"", "]"}], 
              "]"}], "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"Print", "@", 
          RowBox[{"StringForm", "[", 
           RowBox[{"\"\<Least significant column: ``\>\"", ",", "worstCol"}], 
           "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"m", "=", 
          RowBox[{"With", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"newCols", "=", 
              RowBox[{"cols", "/.", 
               RowBox[{"worstCol", "\[Rule]", 
                RowBox[{"Sequence", "[", "]"}]}]}]}], "}"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"Print", "@", "newCols"}], ";", "\[IndentingNewLine]", 
             RowBox[{"LinearModelFit", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"knnd", "[", "All", "]"}], "[", 
                RowBox[{"[", 
                 RowBox[{"All", ",", 
                  RowBox[{"Append", "[", 
                   RowBox[{
                    RowBox[{"Sort", "[", 
                    RowBox[{"newCols", "/.", "numberedColumns"}], "]"}], ",", 
                    RowBox[{"a1", "/.", "numberedColumns"}]}], "]"}]}], "]"}],
                 "]"}], ",", "newCols", ",", "newCols", ",", 
               "\[IndentingNewLine]", 
               RowBox[{"NominalVariables", "\[Rule]", 
                RowBox[{"Cases", "[", 
                 RowBox[{"newCols", ",", 
                  RowBox[{"x_", "/;", 
                   RowBox[{"knnd", "[", 
                    RowBox[{"x", ",", "\"\<factorized\>\""}], "]"}]}]}], 
                 "]"}]}]}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"Print", "@", 
          RowBox[{"StringForm", "[", 
           RowBox[{"\"\<Current AIC: ``\>\"", ",", 
            RowBox[{"m", "[", "\"\<AIC\>\"", "]"}]}], "]"}]}], ";", 
         "\[IndentingNewLine]", "m"}]}], "\[IndentingNewLine]", "]"}], "&"}], 
     ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"lm", "[", "1", "]"}], ",", 
     RowBox[{"(*", " ", 
      RowBox[{"starting", " ", "element"}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"#1", "[", "\"\<AIC\>\"", "]"}], ">", 
       RowBox[{"#2", "[", "\"\<AIC\>\"", "]"}]}], "&"}], ",", 
     RowBox[{"(*", " ", 
      RowBox[{"Termination", " ", "condition"}], " ", "*)"}], 
     "\[IndentingNewLine]", "2", ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
      "supply", " ", "2", " ", "most", " ", "recent", " ", "results", " ", 
       "for", " ", "test"}], " ", "*)"}], "\[IndentingNewLine]", "10", ",", 
     RowBox[{"(*", " ", 
      RowBox[{"at", " ", "most", " ", "this", " ", "many", " ", "steps"}], 
      " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"-", "1"}]}], " ", 
    RowBox[{"(*", " ", 
     RowBox[{"back", " ", "up"}], " ", "*)"}], "\[IndentingNewLine]", "]"}]}],
   ";"}]], "Input",
 CellChangeTimes->CompressedData["
1:eJwdzE0ogwEAxvG3IbHVao3UXMSWctmB7eSwZWqttEZRyqJJagw3C0sUUWMp
SyS2pczKlOZjlpmxZsTUJjLaTLEDMp+x8T7v4el3eOpf1KJRtNIIgigkB2vG
uaqIKSFiMefaoMNVOgBVUgnloVk8BKPVmhG4U108CQNjp5R1jEEjHHboKT3m
i1k4dcExwweXchnqftopG/SsGHxZNMThW6Wx5IaUd7XHh11ZhBGqpV4LdAjq
bbDJb6PcNCTtMCzMWIP76dAuLOguP4DHZVY/ZGrZl1DiVN5B+YQgDqd1ngdY
o01RVknWPyA/b+sb5svMtFvSnlpFJrTSa22fjoRofjZ3AzJkFW6Yf91B+bQU
90EnZ/sE9veeB2GfeiUMeUJxBDYHfVFoSp/dU71Q7B12Po/+QsOM/Q8uWF5z
vkg92Y106BWucqAgyS2EbLniyL1B/o+pAPwH1AYSwQ==
  "]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"beLm", "[", "#", "]"}], "&"}], "/@", 
  RowBox[{"{", 
   RowBox[{
   "\"\<RSquared\>\"", ",", "\"\<AdjustedRSquared\>\"", ",", "\"\<AIC\>\""}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.585589349396656*^9, 3.5855893549227324`*^9}, {
  3.5855894483562717`*^9, 3.5855894773839808`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.3644392050653163`", ",", "0.3268522763326199`", ",", 
   "1710.658506673239`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.5855893553920527`*^9, {3.585589456063747*^9, 3.5855894779322*^9}, 
   3.586000488523423*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"beLm", "[", "\"\<ParameterTable\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.585589392515489*^9, 3.58558939787422*^9}, {
  3.585589478739142*^9, 3.585589480216301*^9}}],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"Estimate\"\>", "\<\"Standard Error\"\>", "\<\"t\
\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"1", "62.455859823675404`", "20.377380025145644`", 
      "3.0649602523290533`", "0.002500874210657161`"},
     {
      RowBox[{"size", "[", "\<\"large\"\>", "]"}], 
      RowBox[{"-", "10.346139853947209`"}], "4.113864453923497`", 
      RowBox[{"-", "2.5149442743743857`"}], "0.012752451125568713`"},
     {
      RowBox[{"size", "[", "\<\"medium\"\>", "]"}], 
      RowBox[{"-", "6.7108905337908`"}], "3.3814633831181324`", 
      RowBox[{"-", "1.9846113275378776`"}], "0.04865795303601228`"},
     {
      RowBox[{"speed", "[", "\<\"high\"\>", "]"}], "0.3138695124953617`", 
      "3.179973690336258`", "0.09870192116657808`", "0.9214812333141414`"},
     {
      RowBox[{"speed", "[", "\<\"low\"\>", "]"}], "2.125438657953884`", 
      "3.8994697084294083`", "0.5450583840565204`", "0.5863663276253626`"},
     {"mxPH", 
      RowBox[{"-", "4.2205951159712205`"}], "2.5033980724712643`", 
      RowBox[{"-", "1.685946459088227`"}], "0.09348284133297713`"},
     {"mnO2", "0.7780055863746227`", "0.6591496746363487`", 
      "1.1803170301249812`", "0.23938140893399407`"},
     {"Cl", 
      RowBox[{"-", "0.037486196367124004`"}], "0.033325627218252794`", 
      RowBox[{"-", "1.1248459367808215`"}], "0.2621037919903566`"},
     {"NO3", 
      RowBox[{"-", "1.6041408575093579`"}], "0.5437319746811488`", 
      RowBox[{"-", "2.950241906317991`"}], "0.0035834936040339154`"},
     {"NH4", "0.0015591339979014918`", "0.0009951368760187727`", 
      "1.5667533135131047`", "0.11887206846325948`"},
     {"oPO4", "0.005626240436217363`", "0.037958478393689314`", 
      "0.14822091596676695`", "0.8823289886024241`"},
     {"PO4", 
      RowBox[{"-", "0.06082955823091545`"}], "0.02913247691464609`", 
      RowBox[{"-", "2.0880324872182063`"}], "0.03815678859068686`"}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.585589398236644*^9, 3.5855894806681356`*^9, 
  3.586000491839149*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"beLm", "[", "\"\<ANOVATable\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.585589368062475*^9, 3.585589375987998*^9}, {
  3.585589481570854*^9, 3.585589483039826*^9}}],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"DF\"\>", "\<\"SS\"\>", "\<\"MS\"\>", \
"\<\"F\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"size", "2", "11400.247278499271`", "5700.123639249636`", 
      "18.452937239387023`", "4.891060158421258`*^-8"},
     {"speed", "2", "3909.3344453091413`", "1954.6672226545707`", 
      "6.32781916082787`", "0.0021944237518128026`"},
     {"mxPH", "1", "1306.6223898133758`", "1306.6223898133758`", 
      "4.229911924853981`", "0.04111364554562562`"},
     {"mnO2", "1", "2068.72619948996`", "2068.72619948996`", 
      "6.697060825454149`", "0.010419663991380976`"},
     {"Cl", "1", "4185.667913905767`", "4185.667913905767`", 
      "13.550209119742307`", "0.00030418186601174283`"},
     {"NO3", "1", "3571.7326556501794`", "3571.7326556501794`", 
      "11.562724372634513`", "0.0008234598582441809`"},
     {"NH4", "1", "392.44778461460373`", "392.44778461460373`", 
      "1.2704661859199726`", "0.2611312313478362`"},
     {"oPO4", "1", "4764.225189958597`", "4764.225189958597`", 
      "15.42316517825317`", "0.00012097075320684088`"},
     {"PO4", "1", "1346.7695053432326`", "1346.7695053432326`", 
      "4.35987966767866`", "0.03815678859068588`"},
     {"\<\"Error\"\>", "186", "57455.5141626684`", "308.9006137777871`", "", 
      ""},
     {"\<\"Total\"\>", "197", "90401.28752525253`", "", "", ""}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.5855893763567753`*^9, 3.585589485058845*^9, 
  3.586000495667924*^9}]
}, Open  ]],

Cell[TextData[{
 "This technique yields some very limited progress (the ",
 Cell[BoxData[
  SuperscriptBox["R", "2"]],
  CellChangeTimes->{3.585578660744142*^9}],
 "coefficients have actually increased in the final iteration), but it may be \
profitable to look at another type of model."
}], "Text",
 CellChangeTimes->{{3.585589496935422*^9, 3.58558950539858*^9}, {
  3.585589545854083*^9, 3.585589602132657*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"beLmCols", "=", 
   RowBox[{"{", 
    RowBox[{
    "size", ",", "speed", ",", "mxPH", ",", "mnO2", ",", "Cl", ",", "NO3", 
     ",", "NH4", ",", "oPO4", ",", "PO4"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.585913443317033*^9, 3.585913452357602*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Regression Trees", "Title",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBmIQbZiQwrVk2yvHJQcPgGnXJ7fWHgXSwiH+60A0x35T
m1NA+l0bkx2IXr5vXzqIDjm6IANEn5oTuPw0kJ60fjuY/rnwzi8Q3RNl+BtE
57wx2HQGSM8427gZRPcYb8o/B6SDf8QVgOji6wcvgui2v/svgegfK1++AdEn
uIPfguhnvgYzzwPpe6nLwPSsJDn2C0Ba2ec2mJ6xJX39eyD9oPwumL5QbHX+
A5Bet+8zmGZal1X6CUh/9+YoA9FHPSWmgegPVYpg+o6CutNXkLrLlWBazdy4
7zuQjgjqB9NVb3L0fwDpoHUHwTQAu8q5iA==
  "]],

Cell["\<\
A regression tree is a hierarchical series of tests on some predictor \
variables (not necessarily all of them), culminating in a guess at a response \
value.\
\>", "Text",
 CellChangeTimes->{{3.585589705275578*^9, 3.585589760961503*^9}, {
  3.58559039062878*^9, 3.585590392748694*^9}, {3.585590497946117*^9, 
  3.5855905090180798`*^9}, {3.585590869858664*^9, 3.585590892658271*^9}, {
  3.585657490713347*^9, 3.585657491975215*^9}, {3.585912659488049*^9, 
  3.585912673172035*^9}}],

Cell[CellGroupData[{

Cell["Cart code", "Subsubsection",
 CellChangeTimes->{{3.585592071233885*^9, 3.585592074562066*^9}},
 FontColor->GrayLevel[0.5]],

Cell[TextData[ButtonBox["Andy Ross\[CloseCurlyQuote]s implementation of \
Classification and Regression Trees (CARTs):",
 BaseStyle->"Hyperlink",
 ButtonData->{
   URL["http://mathematica.stackexchange.com/questions/19285/mathematica-\
implementations-of-the-random-forest-algorithm/20556"], None},
 ButtonNote->
  "http://mathematica.stackexchange.com/questions/19285/mathematica-\
implementations-of-the-random-forest-algorithm/20556"]], "Text",
 CellChangeTimes->{{3.585592026579977*^9, 3.585592056095248*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"condEnt", "=", "Statistics`Library`NConditionalEntropy"}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"ent", "=", "Statistics`Library`NEntropy"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"deviance", "[", "v_", "]"}], ":=", 
   RowBox[{"Total", "@", 
    RowBox[{"With", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m", "=", 
        RowBox[{"Mean", "@", "v"}]}], "}"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"#", "-", "m"}], ")"}], "^", "2"}], "&"}], "/@", "v"}]}], 
     "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"maxI", "[", "v_", "]"}], ":=", 
   RowBox[{
    RowBox[{"Ordering", "[", 
     RowBox[{"v", ",", 
      RowBox[{"-", "1"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.571596432070767*^9, 3.571596432074038*^9}, {
  3.5856789472188473`*^9, 3.5856790202413588`*^9}, {3.58591269215998*^9, 
  3.585912696594509*^9}}],

Cell["\<\
x is all data cols;  y is response;  m is number of the k possible variables \
used to classify the response.\
\>", "Text",
 CellChangeTimes->{{3.572018439685808*^9, 3.572018457524166*^9}, {
  3.572018519874712*^9, 3.57201855511404*^9}, {3.5720186119159937`*^9, 
  3.572018627751731*^9}, {3.5855908562345457`*^9, 3.58559085903506*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "@", "cart"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Options", "[", "cart", "]"}], ":=", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
      "Min", " ", "change", " ", "in", " ", "response", " ", "deviance", " ", 
       "to", " ", "continue"}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"\"\<MinDevianceChange\>\"", "\[Rule]", "0.01"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "Min", " ", "number", " ", "of", " ", "samples", " ", "in", " ", 
        "node", " ", "to", " ", "continue"}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"\"\<MinSplit\>\"", "\[Rule]", "20"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"Max", " ", "tree", " ", "depth", " ", "to", " ", "continue"}],
        " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"\"\<MaxDepth\>\"", "\[Rule]", "30"}]}], "\[IndentingNewLine]", 
     "}"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"cart", "[", 
     RowBox[{"x_", ",", "y_", ",", "m_", ",", 
      RowBox[{"o", ":", 
       RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
    RowBox[{"cart", "[", 
     RowBox[{"x", ",", "y", ",", "m", ",", "1", ",", "Infinity", ",", "o"}], 
     "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"cart", "[", 
     RowBox[{"x_", ",", 
      RowBox[{"y_", "/;", 
       RowBox[{
        RowBox[{"ent", "[", "y", "]"}], "\[Equal]", "0"}]}], ",", "m_", ",", 
      "counter_", ",", "dev_", ",", 
      RowBox[{"o", ":", 
       RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
    RowBox[{"First", "[", "y", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"cart", "[", 
     RowBox[{"x_", ",", "y_", ",", "m_", ",", "counter_", ",", "dev_", ",", 
      RowBox[{"o", ":", 
       RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
    RowBox[{
     RowBox[{"Mean", "[", "y", "]"}], "/;", 
     RowBox[{
      RowBox[{"Length", "[", "y", "]"}], "<", 
      RowBox[{"OptionValue", "[", "\"\<MinSplit\>\"", "]"}]}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"cart", "[", 
     RowBox[{"x_", ",", "y_", ",", "m_", ",", "counter_", ",", "dev_", ",", 
      RowBox[{"o", ":", 
       RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
    RowBox[{
     RowBox[{"Mean", "[", "y", "]"}], "/;", 
     RowBox[{"counter", ">", 
      RowBox[{"OptionValue", "[", "\"\<MaxDepth\>\"", "]"}]}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"cart", "[", 
     RowBox[{"x_", ",", "y_", ",", "m_", ",", "counter_", ",", "dev_", ",", 
      RowBox[{"o", ":", 
       RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"Mean", "[", "y", "]"}], ")"}], "/;", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"dev", "-", 
        RowBox[{"deviance", "[", "y", "]"}]}], ")"}], "<", 
      RowBox[{"OptionValue", "[", "\"\<MinDevianceChange\>\"", "]"}]}]}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cart", "[", 
   RowBox[{"x_", ",", "y_", ",", "m_", ",", "counter_", ",", "dev_", ",", 
    RowBox[{"o", ":", 
     RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
  RowBox[{"Block", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"k", "=", 
       RowBox[{"Length", "[", "x", "]"}]}], ",", "h", ",", "drop", ",", 
      "bestVar", ",", "ub", ",", "best", ",", "masks"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{"Entropy", " ", "of", " ", "response", " ", "vector"}], " ", 
     "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"h", "=", 
      RowBox[{"ent", "[", "y", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
      "Predictors", " ", "we", " ", "are", " ", "not", " ", "paying", " ", 
       "attention", " ", "to"}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"drop", "=", 
      RowBox[{"RandomSample", "[", 
       RowBox[{
        RowBox[{"Range", "[", "k", "]"}], ",", 
        RowBox[{"k", "-", "m"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
      "Which", " ", "variable", " ", "will", " ", "give", " ", "us", " ", 
       "the", " ", "greatest", " ", "information", " ", "gain", " ", "at", 
       " ", "this", " ", 
       RowBox[{"node", "?"}]}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"bestVar", "=", 
      RowBox[{"maxI", "[", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"FreeQ", "[", 
            RowBox[{"drop", ",", "i"}], "]"}], ",", 
           RowBox[{"h", "-", 
            RowBox[{"condEnt", "[", 
             RowBox[{
              RowBox[{"x", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", "y"}], "]"}]}], ",", 
           "0"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "k"}], "}"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
      "Distinct", " ", "values", " ", "in", " ", "best", " ", "column"}], " ",
       "*)"}], "\[IndentingNewLine]", 
     RowBox[{"ub", "=", 
      RowBox[{"Union", "[", 
       RowBox[{"x", "[", 
        RowBox[{"[", "bestVar", "]"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{
       "Bit", " ", "masks", " ", "for", " ", "each", " ", "distinct", " ", 
        "value"}], ",", " ", 
       RowBox[{
       "1", " ", "wherever", " ", "column", " ", "is", " ", "greater", " ", 
        "than", " ", "or", " ", "equal", " ", "to", " ", "the", " ", 
        "value"}]}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"masks", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"UnitStep", "[", 
         RowBox[{
          RowBox[{"x", "[", 
           RowBox[{"[", "bestVar", "]"}], "]"}], "-", "#"}], "]"}], "&"}], "/@",
        "ub"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
      "Find", " ", "the", " ", "optimum", " ", "value", " ", "to", " ", 
       "split", " ", "the", " ", "column", " ", "on", " ", 
       RowBox[{"(", 
        RowBox[{"best", " ", "is", " ", "a", " ", "mask", " ", "index"}], 
        ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"best", "=", 
      RowBox[{"maxI", "[", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"h", "-", 
           RowBox[{"condEnt", "[", 
            RowBox[{"#", ",", "y"}], "]"}]}], "&"}], "/@", "masks"}], ")"}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Min", "[", "#", "]"}], "\[Equal]", 
          RowBox[{"Max", "[", "#", "]"}]}], ",", "\[IndentingNewLine]", 
         RowBox[{"(*", " ", 
          RowBox[{
          "Select", " ", "leaf", " ", "value", " ", "if", " ", "no", " ", 
           "choices", " ", "remain"}], " ", "*)"}], "\[IndentingNewLine]", 
         RowBox[{"Mean", "[", "y", "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"(*", " ", 
          RowBox[{
           RowBox[{"else", " ", "construct", " ", 
            RowBox[{"subtree", ":", " ", "variable"}]}], ",", " ", 
           RowBox[{"pivot", " ", "value"}], ",", " ", 
           RowBox[{"elem", " ", "count"}], ",", " ", "left", ",", " ", 
           "right", ",", " ", "m"}], " ", "*)"}], "\[IndentingNewLine]", 
         RowBox[{"With", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"py1", "=", 
              RowBox[{"Pick", "[", 
               RowBox[{"y", ",", "#", ",", "1"}], "]"}]}], ",", 
             RowBox[{"py0", "=", 
              RowBox[{"Pick", "[", 
               RowBox[{"y", ",", "#", ",", "0"}], "]"}]}]}], "}"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"bestVar", ",", "\[IndentingNewLine]", 
             RowBox[{"ub", "[", 
              RowBox[{"[", "best", "]"}], "]"}], ",", "\[IndentingNewLine]", 
             RowBox[{"Length", "/@", 
              RowBox[{"{", 
               RowBox[{"py1", ",", "py0"}], "}"}]}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"cart", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"Pick", "[", 
                 RowBox[{
                  RowBox[{"x", "\[Transpose]"}], ",", "#", ",", "1"}], "]"}], 
                "\[Transpose]"}], ",", "py1", ",", "m", ",", 
               RowBox[{"counter", "+", "1"}], ",", 
               RowBox[{"deviance", "[", "y", "]"}], ",", "o"}], "]"}], ",", 
             RowBox[{"cart", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"Pick", "[", 
                 RowBox[{
                  RowBox[{"x", "\[Transpose]"}], ",", "#", ",", "0"}], "]"}], 
                "\[Transpose]"}], ",", "py0", ",", "m", ",", 
               RowBox[{"counter", "+", "1"}], ",", 
               RowBox[{"deviance", "[", "y", "]"}], ",", "o"}], "]"}]}], 
            "}"}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
        "]"}], "&"}], "[", 
      RowBox[{"masks", "[", 
       RowBox[{"[", "best", "]"}], "]"}], "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.571596574594924*^9, 3.5715965745990057`*^9}, {
   3.571596637303306*^9, 3.571596655688471*^9}, {3.585592980474963*^9, 
   3.585593012034522*^9}, {3.585593250645941*^9, 3.585593262484642*^9}, {
   3.5855932978522863`*^9, 3.585593324579875*^9}, {3.585593435587039*^9, 
   3.5855934420498657`*^9}, {3.585593482440826*^9, 3.5855935192420063`*^9}, {
   3.585593555088726*^9, 3.585593594919286*^9}, {3.5855936512700853`*^9, 
   3.585593695637896*^9}, {3.58559387479597*^9, 3.585593900376305*^9}, {
   3.585594059144105*^9, 3.585594082134367*^9}, {3.585656761814982*^9, 
   3.585656762147447*^9}, {3.585659618238123*^9, 3.585659664374674*^9}, {
   3.585659695534623*^9, 3.585659745205592*^9}, {3.58565979952493*^9, 
   3.585659872837038*^9}, {3.585660073015759*^9, 3.585660098518407*^9}, {
   3.5856601537879877`*^9, 3.585660215845632*^9}, {3.5856602534661694`*^9, 
   3.585660358235076*^9}, {3.5856605214260483`*^9, 3.585660558581369*^9}, {
   3.5856605994726257`*^9, 3.5856606914509974`*^9}, {3.585660767732788*^9, 
   3.5856607701891108`*^9}, {3.585660804701532*^9, 3.585660838803443*^9}, {
   3.585660903413928*^9, 3.585660908302889*^9}, {3.5856609453097486`*^9, 
   3.5856609886619473`*^9}, {3.585661064611952*^9, 3.585661064970468*^9}, {
   3.585661097467009*^9, 3.585661167540366*^9}, {3.585661222041737*^9, 
   3.585661225735877*^9}, {3.5856612810759487`*^9, 3.585661289093254*^9}, {
   3.58566135163743*^9, 3.585661351800112*^9}, {3.5856614159593782`*^9, 
   3.585661488100319*^9}, {3.5856617377094316`*^9, 3.585661749997284*^9}, {
   3.585663237400181*^9, 3.5856632631796227`*^9}, {3.585663352479567*^9, 
   3.585663404212274*^9}, {3.585663440317415*^9, 3.585663444490443*^9}, {
   3.5856635137945757`*^9, 3.5856636147145157`*^9}, {3.585663826669097*^9, 
   3.5856638402668333`*^9}, 3.585663887098645*^9, {3.585664596109168*^9, 
   3.585664600707273*^9}, {3.585664650945879*^9, 3.585664655787059*^9}, {
   3.585664689713304*^9, 3.585664748835876*^9}, {3.5856648040319643`*^9, 
   3.585664813884659*^9}, {3.585664933667922*^9, 3.58566495236417*^9}, {
   3.585664986334475*^9, 3.585665010539514*^9}, {3.5856654049445972`*^9, 
   3.585665466225891*^9}, {3.585665499603052*^9, 3.5856655382646503`*^9}, {
   3.5856656988880577`*^9, 3.585665699814039*^9}, {3.585665843707741*^9, 
   3.5856658650914183`*^9}, {3.585667350374552*^9, 3.585667482736781*^9}, {
   3.585667728418735*^9, 3.5856677308732758`*^9}, {3.5856777620485973`*^9, 
   3.585677958595426*^9}, {3.58567948814116*^9, 3.5856795232918158`*^9}, {
   3.585679576881383*^9, 3.5856796463692923`*^9}, {3.585679677368327*^9, 
   3.585679748615*^9}, {3.5856797836953773`*^9, 3.585679784127479*^9}, {
   3.585679907539242*^9, 3.585679909292893*^9}, {3.585681578547208*^9, 
   3.585681579201418*^9}, {3.5859307565933743`*^9, 3.58593076804385*^9}, {
   3.585931270991748*^9, 3.585931277296431*^9}, {3.5859344262892437`*^9, 
   3.585934426841262*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "@", "classify"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"classify", "[", 
    RowBox[{"x_", ",", 
     RowBox[{"Except", "[", 
      RowBox[{"_List", ",", "d_"}], "]"}]}], "]"}], ":=", "d"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"classify", "[", 
   RowBox[{"x_", ",", 
    RowBox[{"{", 
     RowBox[{"best_", ",", "value_", ",", "len_", ",", "d1_", ",", "d2_"}], 
     "}"}]}], "]"}], ":=", 
  RowBox[{"classify", "[", 
   RowBox[{"x", ",", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"OrderedQ", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "[", 
          RowBox[{"[", "best", "]"}], "]"}], ",", "value"}], "}"}], "]"}], 
      ",", "d2", ",", "d1"}], "]"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.571597051400979*^9, 3.57159705281839*^9}, {
   3.571597100882312*^9, 3.571597101553258*^9}, {3.5751364814659367`*^9, 
   3.575136489024267*^9}, 3.585660491603888*^9, {3.585667508908195*^9, 
   3.585667509859977*^9}, {3.585667735158732*^9, 3.5856677393843393`*^9}}],

Cell["For cart visualization:", "Text",
 CellChangeTimes->{{3.5859127961708612`*^9, 3.585912802410027*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "treeToGraph", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"treeToGraph", "[", "tree_", "]"}], ":=", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"ttg", ",", "g"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ttg", "[", "tr_", "]"}], ":=", 
      RowBox[{"Module", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"numToCol", "=", 
           RowBox[{"Reverse", "/@", "numberedColumns"}]}], ",", "pm1", ",", 
          "pm2"}], "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"With", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"p", "=", 
            RowBox[{"Position", "[", 
             RowBox[{"tree", ",", "tr"}], "]"}]}], "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Length", "[", "tr", "]"}], "\[Equal]", "5"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"pm1", "=", 
              RowBox[{"Position", "[", 
               RowBox[{"tree", ",", 
                RowBox[{"tr", "[", 
                 RowBox[{"[", 
                  RowBox[{"-", "1"}], "]"}], "]"}]}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"pm2", "=", 
              RowBox[{"Position", "[", 
               RowBox[{"tree", ",", 
                RowBox[{"tr", "[", 
                 RowBox[{"[", 
                  RowBox[{"-", "2"}], "]"}], "]"}]}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"Flatten", "[", 
              RowBox[{
               RowBox[{"DeleteCases", "[", 
                RowBox[{
                 RowBox[{"{", "\[IndentingNewLine]", 
                  RowBox[{
                   RowBox[{"VertexLabel", "[", 
                    RowBox[{"Rule", "[", 
                    RowBox[{"p", ",", 
                    RowBox[{"Total", "@", 
                    RowBox[{"tr", "[", 
                    RowBox[{"[", "3", "]"}], "]"}]}]}], "]"}], "]"}], ",", 
                   "\[IndentingNewLine]", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Rule", "[", 
                    RowBox[{"p", ",", "pm1"}], "]"}], ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"tr", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "/.", "numToCol"}], ")"}],
                     "<", 
                    RowBox[{"tr", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
                   "\[IndentingNewLine]", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Rule", "[", 
                    RowBox[{"p", ",", "pm2"}], "]"}], ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"tr", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "/.", "numToCol"}], ")"}],
                     "\[GreaterEqual]", 
                    RowBox[{"tr", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
                   "\[IndentingNewLine]", 
                   RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"ListQ", "@", 
                    RowBox[{"tr", "[", 
                    RowBox[{"[", 
                    RowBox[{"-", "2"}], "]"}], "]"}]}], ",", 
                    RowBox[{"Sequence", "@@", 
                    RowBox[{"{", "}"}]}], ",", 
                    RowBox[{"VertexLabel", "[", 
                    RowBox[{"Rule", "[", 
                    RowBox[{"pm2", ",", 
                    RowBox[{"Column", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"First", "@", 
                    RowBox[{"tr", "[", 
                    RowBox[{"[", "3", "]"}], "]"}]}], ",", 
                    RowBox[{"tr", "[", 
                    RowBox[{"[", 
                    RowBox[{"-", "2"}], "]"}], "]"}]}], "}"}], ",", 
                    "Center"}], "]"}]}], "]"}], "]"}]}], "]"}], ",", 
                   "\[IndentingNewLine]", 
                   RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"ListQ", "@", 
                    RowBox[{"tr", "[", 
                    RowBox[{"[", 
                    RowBox[{"-", "1"}], "]"}], "]"}]}], ",", 
                    RowBox[{"Sequence", "@@", 
                    RowBox[{"{", "}"}]}], ",", 
                    RowBox[{"VertexLabel", "[", 
                    RowBox[{"Rule", "[", 
                    RowBox[{"pm1", ",", 
                    RowBox[{"Column", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Last", "@", 
                    RowBox[{"tr", "[", 
                    RowBox[{"[", "3", "]"}], "]"}]}], ",", 
                    RowBox[{"tr", "[", 
                    RowBox[{"[", 
                    RowBox[{"-", "1"}], "]"}], "]"}]}], "}"}], ",", 
                    "Center"}], "]"}]}], "]"}], "]"}]}], "]"}], ",", 
                   "\[IndentingNewLine]", 
                   RowBox[{"Sequence", "@@", 
                    RowBox[{"ttg", "[", 
                    RowBox[{"tr", "[", 
                    RowBox[{"[", 
                    RowBox[{"-", "2"}], "]"}], "]"}], "]"}]}], ",", 
                   "\[IndentingNewLine]", 
                   RowBox[{"Sequence", "@@", 
                    RowBox[{"ttg", "[", 
                    RowBox[{"tr", "[", 
                    RowBox[{"[", 
                    RowBox[{"-", "1"}], "]"}], "]"}], "]"}]}]}], 
                  "\[IndentingNewLine]", "}"}], ",", 
                 RowBox[{"{", "}"}]}], "]"}], ",", "0"}], "]"}]}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"{", "}"}]}], "\[IndentingNewLine]", "]"}]}], 
         "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"g", "=", 
      RowBox[{
       RowBox[{"ttg", "[", "tree", "]"}], "/.", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", "}"}], "}"}], "->", "0"}]}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"g", "/.", 
        RowBox[{"_VertexLabel", "\[Rule]", 
         RowBox[{"Sequence", "[", "]"}]}]}], ",", 
       RowBox[{"Cases", "[", 
        RowBox[{"g", ",", 
         RowBox[{
          RowBox[{"VertexLabel", "[", "x_", "]"}], "\[RuleDelayed]", "x"}], 
         ",", "Infinity"}], "]"}]}], "}"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.57323483873932*^9, 3.573234843448023*^9}, {
   3.573235669294647*^9, 3.573235707732093*^9}, {3.5732375181001797`*^9, 
   3.5732375305253*^9}, {3.5732376013468018`*^9, 3.573237624035493*^9}, {
   3.5732377486320477`*^9, 3.573237753105904*^9}, {3.5732378457669363`*^9, 
   3.573237964330433*^9}, {3.57323799855546*^9, 3.5732380008938093`*^9}, {
   3.573238055289648*^9, 3.573238190360181*^9}, {3.57323824176155*^9, 
   3.573238371971438*^9}, {3.57323844953957*^9, 3.573238471921527*^9}, {
   3.573238509001936*^9, 3.573238509767762*^9}, {3.573238542233239*^9, 
   3.573238577726116*^9}, {3.575136798271304*^9, 3.575136799933563*^9}, {
   3.575136833949188*^9, 3.575136869115362*^9}, {3.585667067526146*^9, 
   3.5856672240295763`*^9}, {3.585667556413498*^9, 3.585667570973456*^9}, {
   3.5856676323975687`*^9, 3.58566763255471*^9}, {3.585667769271587*^9, 
   3.585667800608776*^9}, {3.585668075863421*^9, 3.585668100048963*^9}, {
   3.585668167744574*^9, 3.585668198196043*^9}, {3.585668276950769*^9, 
   3.585668296687248*^9}, 3.5856729076942*^9, {3.585672969483218*^9, 
   3.5856729728605843`*^9}, {3.585673019065803*^9, 3.5856730195301332`*^9}, {
   3.585673543857379*^9, 3.585673544218808*^9}, {3.585673577489843*^9, 
   3.5856735880174847`*^9}, {3.5856736710141993`*^9, 
   3.5856737004273367`*^9}, {3.585673754309168*^9, 3.58567375623746*^9}, {
   3.585673791780901*^9, 3.585673793611927*^9}, {3.585673932074233*^9, 
   3.585673932201096*^9}, {3.58567396463418*^9, 3.585673986625395*^9}, {
   3.585674025568685*^9, 3.585674208206996*^9}, {3.585674356426723*^9, 
   3.585674453065559*^9}, {3.5856745077334957`*^9, 3.585674549726605*^9}, {
   3.58567468382642*^9, 3.58567468897297*^9}, {3.5856747257627687`*^9, 
   3.585674757227404*^9}, {3.585674788163001*^9, 3.5856747996397943`*^9}, {
   3.585675281577483*^9, 3.585675486371908*^9}, {3.585675522278686*^9, 
   3.585675540697269*^9}, {3.585675574491789*^9, 3.585675585144074*^9}, {
   3.585675646657135*^9, 3.58567564730306*^9}, {3.5856756860776577`*^9, 
   3.585675687718369*^9}, {3.585675904840261*^9, 3.585675905235346*^9}, {
   3.58567594153675*^9, 3.585675978952662*^9}, {3.58567601868771*^9, 
   3.585676024991304*^9}, {3.585676065143737*^9, 3.585676071707634*^9}, {
   3.5856761284698477`*^9, 3.585676200734357*^9}, {3.585676266015101*^9, 
   3.5856762928171463`*^9}, {3.5856763352647142`*^9, 
   3.5856764901341677`*^9}, {3.585676523990261*^9, 3.585676545616336*^9}, {
   3.585676674370337*^9, 3.585676675723077*^9}, {3.585676789243338*^9, 
   3.5856768351750507`*^9}, {3.585677000276746*^9, 3.585677000301187*^9}, {
   3.585677692926951*^9, 3.585677713087*^9}, {3.585678146396646*^9, 
   3.585678198668045*^9}, {3.585678255684701*^9, 3.585678375221415*^9}, {
   3.585678462476812*^9, 3.5856785208387833`*^9}, {3.585678612227825*^9, 
   3.585678649893168*^9}, {3.585913053681244*^9, 3.5859131128477592`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Prepare data and grow a cart", "Subsubsection",
 CellChangeTimes->{{3.5750594487345157`*^9, 3.5750594513016624`*^9}, {
  3.585658587938446*^9, 3.585658592600718*^9}, {3.58566665846764*^9, 
  3.585666659459317*^9}, {3.585667667351828*^9, 3.585667672606496*^9}}],

Cell["\<\
The cart can\[CloseCurlyQuote]t handle nominal variables, so assign them \
integer values:\
\>", "Text",
 CellChangeTimes->{{3.585658688232012*^9, 3.5856587057503977`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"denominalizeVect", "[", 
   RowBox[{"set_", ",", "col_"}], "]"}], ":=", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"rules", "=", 
      RowBox[{"Rule", "@@@", 
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"set", "[", 
           RowBox[{"col", ",", "\"\<factors\>\""}], "]"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{"Length", "[", 
            RowBox[{"set", "[", 
             RowBox[{"col", ",", "\"\<factors\>\""}], "]"}], "]"}], "]"}]}], 
         "}"}], "]"}]}]}], "}"}], ",", 
    RowBox[{
     RowBox[{"set", "[", "col", "]"}], "/.", "rules"}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.5751380837025557`*^9, 3.575138184392997*^9}, {
  3.585915313939899*^9, 3.5859153166895933`*^9}}],

Cell["\<\
Assemble the training set and grow the tree, predicting a1.  Note the cart \
wants columns, not rows:\
\>", "Text",
 CellChangeTimes->{{3.585658715486487*^9, 3.585658729789671*^9}, {
  3.585912818995023*^9, 3.585912826617004*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"dat", "=", 
    RowBox[{"Join", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"denominalizeVect", "[", 
          RowBox[{"knnd", ",", "#"}], "]"}], "&"}], "/@", 
        RowBox[{"{", 
         RowBox[{"season", ",", "size", ",", "speed"}], "}"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"knnd", "[", "All", "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", 
         RowBox[{"4", ";;", "11"}]}], "]"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"List", "/@", 
       RowBox[{
        RowBox[{"knnd", "[", "All", "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "12"}], "]"}], "]"}]}], ",", 
      "\[IndentingNewLine]", "2"}], "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"specify", " ", "training", " ", "rows"}], " ", "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"train", "=", 
    RowBox[{"Range", "@", 
     RowBox[{"Length", "@", "dat"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tree", "=", 
   RowBox[{"cart", "[", 
    RowBox[{
     RowBox[{"Transpose", "@", 
      RowBox[{"dat", "[", 
       RowBox[{"[", 
        RowBox[{"train", ",", 
         RowBox[{"1", ";;", 
          RowBox[{"-", "2"}]}]}], "]"}], "]"}]}], ",", 
     RowBox[{"dat", "[", 
      RowBox[{"[", 
       RowBox[{"train", ",", 
        RowBox[{"-", "1"}]}], "]"}], "]"}], ",", "11", ",", 
     RowBox[{"\"\<MinSplit\>\"", "\[Rule]", "20"}], ",", 
     RowBox[{"\"\<MaxDepth\>\"", "\[Rule]", "30"}], ",", 
     RowBox[{"\"\<MinDevianceChange\>\"", "\[Rule]", "0.1"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.5750585129579926`*^9, 3.5750585220885143`*^9}, {
   3.5750586450715485`*^9, 3.575058645675583*^9}, 3.575058890199569*^9, 
   3.575110877514789*^9, {3.575110947663801*^9, 3.575111008532283*^9}, {
   3.575131048361354*^9, 3.575131048737197*^9}, {3.575131208718775*^9, 
   3.575131229869527*^9}, {3.5751312777405863`*^9, 3.575131296315819*^9}, {
   3.575131857591812*^9, 3.575131892862303*^9}, {3.5751320175076847`*^9, 
   3.575132026171562*^9}, {3.5751323239736977`*^9, 3.575132336717125*^9}, {
   3.575132386899868*^9, 3.575132387075905*^9}, {3.575132466874321*^9, 
   3.575132473257573*^9}, {3.575132547887751*^9, 3.575132553942631*^9}, {
   3.5751325880960493`*^9, 3.575132652806525*^9}, {3.575135088573346*^9, 
   3.5751350924550877`*^9}, {3.575136521526178*^9, 3.575136541119844*^9}, {
   3.575136589150301*^9, 3.57513659515007*^9}, {3.575137346287025*^9, 
   3.5751375237776546`*^9}, {3.575137608351891*^9, 3.575137666462154*^9}, {
   3.575137729565289*^9, 3.575137729748941*^9}, {3.5751382119067793`*^9, 
   3.5751382169367027`*^9}, {3.5751383056276617`*^9, 
   3.5751383261203613`*^9}, {3.575138397807061*^9, 3.575138440901699*^9}, {
   3.575138983490196*^9, 3.575138991537744*^9}, 3.585658537059506*^9, {
   3.585658634721568*^9, 3.5856586675865498`*^9}, {3.585658974139226*^9, 
   3.5856589856573267`*^9}, {3.585659064587605*^9, 3.58565906950486*^9}, {
   3.585659548256768*^9, 3.585659548630578*^9}, {3.585661198612842*^9, 
   3.585661202437105*^9}, {3.585661338036799*^9, 3.585661346434341*^9}, {
   3.5856614097414637`*^9, 3.585661436552692*^9}, {3.5856615019939003`*^9, 
   3.585661504426219*^9}, {3.585661539918075*^9, 3.585661636908535*^9}, {
   3.5856616750853653`*^9, 3.585661719890418*^9}, {3.585661767809804*^9, 
   3.5856617964170847`*^9}, {3.585664638134466*^9, 3.585664644833321*^9}, {
   3.5856648717899437`*^9, 3.585664872249947*^9}, {3.585665727672267*^9, 
   3.5856657567035427`*^9}, {3.585665824702818*^9, 3.585665834701871*^9}, {
   3.5856658734290953`*^9, 3.585665875805086*^9}, {3.585679813025652*^9, 
   3.58567981366543*^9}, {3.585679859799827*^9, 3.5856798658725*^9}, {
   3.585679921231081*^9, 3.585679972294031*^9}, {3.5856800506873293`*^9, 
   3.585680120259306*^9}, {3.585680159866726*^9, 3.585680161258106*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Depth", "@", "tree"}], "-", "1"}]], "Input",
 CellChangeTimes->{{3.5856617722054453`*^9, 3.585661774040794*^9}, {
  3.585678830380067*^9, 3.585678830555664*^9}}],

Cell[BoxData["6"], "Output",
 CellChangeTimes->{{3.58566177428545*^9, 3.585661797390871*^9}, 
   3.585662542411484*^9, {3.5856638480701313`*^9, 3.585663890095503*^9}, 
   3.585664231921918*^9, {3.5856646182472963`*^9, 3.585664647118518*^9}, {
   3.585664851275097*^9, 3.5856648735207787`*^9}, 3.585664997134314*^9, 
   3.5856655754657507`*^9, {3.585665717566988*^9, 3.5856657593474493`*^9}, {
   3.585665826096088*^9, 3.58566587706022*^9}, 3.585666029191595*^9, 
   3.585667676124866*^9, 3.58567804872232*^9, {3.5856787128692093`*^9, 
   3.585678738755434*^9}, 3.5856788307196817`*^9, {3.58567977220848*^9, 
   3.585679798983286*^9}, {3.585679918795692*^9, 3.5856799760530643`*^9}, {
   3.585680052269704*^9, 3.5856801170227537`*^9}, 3.5856801638349543`*^9, 
   3.585913116949355*^9, 3.585930792719503*^9, 3.585932045977977*^9, 
   3.585932103841174*^9, 3.586000868418996*^9, 3.586000932582116*^9, 
   3.586086497284629*^9, 3.586086554156122*^9}]
}, Open  ]],

Cell["The raw tree:", "Text",
 CellChangeTimes->{{3.586016172908873*^9, 3.586016174699827*^9}}],

Cell[CellGroupData[{

Cell[BoxData["tree"], "Input",
 CellChangeTimes->{{3.5856655881951303`*^9, 3.5856655894347477`*^9}, 
   3.5856657678464212`*^9, 3.585665828463689*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"7", ",", "1.87`", ",", 
   RowBox[{"{", 
    RowBox[{"120", ",", "78"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"10", ",", "85.`", ",", 
     RowBox[{"{", 
      RowBox[{"87", ",", "33"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"6", ",", "48.667`", ",", 
       RowBox[{"{", 
        RowBox[{"47", ",", "40"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", "200.231`", ",", 
         RowBox[{"{", 
          RowBox[{"30", ",", "17"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"10", ",", "292.625`", ",", 
           RowBox[{"{", 
            RowBox[{"15", ",", "15"}], "}"}], ",", "2.9866666666666664`", ",",
            "5.04`"}], "}"}], ",", "6.247058823529413`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", "169.00101`", ",", 
         RowBox[{"{", 
          RowBox[{"20", ",", "20"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"11", ",", "3.8`", ",", 
           RowBox[{"{", 
            RowBox[{"15", ",", "5"}], "}"}], ",", "2.733333333333334`", ",", 
           "7.12`"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"11", ",", "5.233`", ",", 
           RowBox[{"{", 
            RowBox[{"13", ",", "7"}], "}"}], ",", "5.684615384615385`", ",", 
           "16.571428571428573`"}], "}"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"7", ",", "4.535`", ",", 
       RowBox[{"{", 
        RowBox[{"12", ",", "21"}], "}"}], ",", "22.416666666666668`", ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", "49.333`", ",", 
         RowBox[{"{", 
          RowBox[{"10", ",", "11"}], "}"}], ",", "8.97`", ",", 
         "33.872727272727275`"}], "}"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7", ",", "0.941`", ",", 
     RowBox[{"{", 
      RowBox[{"40", ",", "38"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"10", ",", "21.3`", ",", 
       RowBox[{"{", 
        RowBox[{"24", ",", "16"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", "72.9`", ",", 
         RowBox[{"{", 
          RowBox[{"12", ",", "12"}], "}"}], ",", "20.866666666666667`", ",", 
         "31.15833333333333`"}], "}"}], ",", "36.7125`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"9", ",", "23.`", ",", 
       RowBox[{"{", 
        RowBox[{"19", ",", "19"}], "}"}], ",", "9.621052631578948`", ",", 
       "39.284210526315775`"}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.585665828733285*^9, 3.585665853279696*^9}, 
   3.58566602994142*^9, 3.585667677143852*^9, 3.585678049885264*^9, {
   3.585678713616584*^9, 3.5856787398516617`*^9}, 3.585679815784816*^9, 
   3.585679990049839*^9, 3.585680167004822*^9, 3.585913117533156*^9, 
   3.585930793603918*^9, 3.5859320460243483`*^9, 3.585932104536791*^9, 
   3.586000870403824*^9, 3.586000933185131*^9, 3.58608649733006*^9, 
   3.586086555646091*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Visualizing Regression Trees", "Title",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQAWIQbZiQwrVk2yvHJQcPgGnXJ7fWHgXSwiH+60A0x35T
m1NA+l0bkx2IXr5vXzqIDjm6IANEn5oTuPw0kJ60fjuY/rnwzi8Q3RNl+BtE
57wx2HQGSM8427gZRPcYb8o/B6SDf8QVgOji6wcvgui2v/svgegfK1++AdEn
uIPfguhnvgYzzwPpe6nLwPSsJDn2C0Ba2ec2mJ6xJX39eyD9oPwumL5QbHX+
A5Bet+8zmGZal1X6CUh/9+YoA9FHPSWmgegPVYpg+o6CutNXkLrLlWBazdy4
7zuQjgjqB9NVb3L0fwDpoHUHwTTjPfc+2e2vHC8xVvaDaACT/MEW
  "]],

Cell["\<\
Integers on nodes indicate the number of values described by the subtree.  \
Leaf nodes also show the predicted value for decision paths terminating on \
that leaf.\
\>", "Text",
 CellChangeTimes->{{3.586016068270177*^9, 3.58601616145262*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"g", ",", "labelRules"}], "}"}], "=", 
   RowBox[{"treeToGraph", "[", "tree", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.585673515975621*^9, 3.585673519922326*^9}, {
  3.585674567093112*^9, 3.585674567266842*^9}, {3.585675654684901*^9, 
  3.58567566582899*^9}, {3.585676633785741*^9, 3.585676634793861*^9}, {
  3.585678699698197*^9, 3.585678703223413*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TreePlot", "[", 
  RowBox[{"g", ",", "Top", ",", "0", ",", "\[IndentingNewLine]", 
   RowBox[{"VertexLabeling", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
   RowBox[{"VertexRenderingFunction", "\[Rule]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Lighter", "[", 
         RowBox[{"Yellow", ",", "0.75"}], "]"}], ",", 
        RowBox[{"EdgeForm", "[", "Gray", "]"}], ",", 
        RowBox[{"Rectangle", "[", 
         RowBox[{
          RowBox[{"#1", "-", 
           RowBox[{"{", 
            RowBox[{"0.25", ",", "0.15"}], "}"}]}], ",", 
          RowBox[{"#1", "+", 
           RowBox[{"{", 
            RowBox[{"0.25", ",", "0.15"}], "}"}]}], ",", 
          RowBox[{"RoundingRadius", "\[Rule]", ".02"}]}], "]"}], ",", "Black",
         ",", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"#2", "/.", "labelRules"}], ",", "9"}], "]"}], ",", 
          "#1"}], "]"}]}], "}"}], "&"}], ")"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"EdgeRenderingFunction", "\[Rule]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Line", "[", "#", "]"}], ",", 
        RowBox[{"Inset", "[", 
         RowBox[{"#3", ",", 
          RowBox[{"Mean", "[", "#1", "]"}], ",", "Automatic", ",", 
          "Automatic", ",", 
          RowBox[{"Background", "\[Rule]", "White"}]}], "]"}]}], "}"}], "&"}],
      ")"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"ImageSize", "\[Rule]", "700"}], ",", "\[IndentingNewLine]", 
   RowBox[{"AspectRatio", "\[Rule]", "0.62"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{{3.585674211466408*^9, 3.585674213979322*^9}, {
  3.585674623700536*^9, 3.5856746571495037`*^9}, {3.585674697644576*^9, 
  3.585674698721208*^9}, {3.585674848589525*^9, 3.585674855085745*^9}, {
  3.5856748872608337`*^9, 3.585674892357445*^9}, {3.585674950340207*^9, 
  3.585675121308372*^9}, {3.585676627560103*^9, 3.585676630419284*^9}, {
  3.585676694034609*^9, 3.585676694677894*^9}, {3.585676757208098*^9, 
  3.5856767591620197`*^9}, {3.585913133284583*^9, 3.5859131474487534`*^9}}],

Cell[BoxData[
 GraphicsBox[
  TagBox[{{{
      LineBox[{{2.92832162534954, 3.395155507651641}, {1.0185466522954922`, 
       2.716124406121313}}], InsetBox[
       RowBox[{"NO3", "<", "1.87`"}], {1.9734341388225163`, 3.055639956886477},
        Automatic, Automatic,
       Background->GrayLevel[1]]}, {
      LineBox[{{2.92832162534954, 3.395155507651641}, {4.838096598403588, 
       2.716124406121313}}], InsetBox[
       RowBox[{"NO3", "\[GreaterEqual]", "1.87`"}], {3.883209111876564, 3.055639956886477},
        Automatic, Automatic,
       Background->GrayLevel[1]]}, {
      LineBox[{{1.0185466522954922`, 2.716124406121313}, {0.3395155507651641, 
       2.037093304590985}}], InsetBox[
       RowBox[{"NO3", "<", "0.941`"}], {0.6790311015303282, 2.3766088553561486`},
        Automatic, Automatic,
       Background->GrayLevel[1]]}, {
      LineBox[{{1.0185466522954922`, 2.716124406121313}, {1.6975777538258205`,
        2.037093304590985}}], InsetBox[
       RowBox[{"NO3", "\[GreaterEqual]", "0.941`"}], {1.3580622030606564`, 2.3766088553561486`},
        Automatic, Automatic,
       Background->GrayLevel[1]]}, {
      LineBox[{{4.838096598403588, 2.716124406121313}, {3.734671058416805, 
       2.037093304590985}}], InsetBox[
       RowBox[{"PO4", "<", "85.`"}], {4.286383828410196, 2.3766088553561486`},
        Automatic, Automatic,
       Background->GrayLevel[1]]}, {
      LineBox[{{4.838096598403588, 2.716124406121313}, {5.941522138390372, 
       2.037093304590985}}], InsetBox[
       RowBox[{"PO4", "\[GreaterEqual]", "85.`"}], {5.38980936839698, 2.3766088553561486`},
        Automatic, Automatic,
       Background->GrayLevel[1]]}, {
      LineBox[{{3.734671058416805, 2.037093304590985}, {3.395155507651641, 
       1.3580622030606566`}}], InsetBox[
       RowBox[{"NO3", "<", "4.535`"}], {3.564913283034223, 1.6975777538258208`},
        Automatic, Automatic,
       Background->GrayLevel[1]]}, {
      LineBox[{{3.734671058416805, 2.037093304590985}, {4.074186609181969, 
       1.3580622030606566`}}], InsetBox[
       RowBox[{"NO3", "\[GreaterEqual]", "4.535`"}], {3.904428833799387, 1.6975777538258208`},
        Automatic, Automatic,
       Background->GrayLevel[1]]}, {
      LineBox[{{5.941522138390372, 2.037093304590985}, {5.092733261477461, 
       1.3580622030606566`}}], InsetBox[
       RowBox[{"Cl", "<", "48.667`"}], {5.5171276999339165`, 1.6975777538258208`},
        Automatic, Automatic,
       Background->GrayLevel[1]]}, {
      LineBox[{{5.941522138390372, 2.037093304590985}, {6.790311015303282, 
       1.3580622030606566`}}], InsetBox[
       RowBox[{"Cl", "\[GreaterEqual]", "48.667`"}], {6.365916576846827, 1.6975777538258208`},
        Automatic, Automatic,
       Background->GrayLevel[1]]}, {
      LineBox[{{5.092733261477461, 1.3580622030606566`}, {4.4137021599471336`,
        0.6790311015303283}}], InsetBox[
       RowBox[{"PO4", "<", "169.00101`"}], {4.753217710712297, 1.0185466522954925`},
        Automatic, Automatic,
       Background->GrayLevel[1]]}, {
      LineBox[{{5.092733261477461, 1.3580622030606566`}, {5.771764363007789, 
       0.6790311015303283}}], InsetBox[
       RowBox[{"PO4", "\[GreaterEqual]", "169.00101`"}], {5.432248812242625, 1.0185466522954925`},
        Automatic, Automatic,
       Background->GrayLevel[1]]}, {
      LineBox[{{6.790311015303282, 1.3580622030606566`}, {6.450795464538118, 
       0.6790311015303283}}], InsetBox[
       RowBox[{"PO4", "<", "200.231`"}], {6.620553239920699, 1.0185466522954925`},
        Automatic, Automatic,
       Background->GrayLevel[1]]}, {
      LineBox[{{6.790311015303282, 1.3580622030606566`}, {7.129826566068446, 
       0.6790311015303283}}], InsetBox[
       RowBox[{"PO4", "\[GreaterEqual]", "200.231`"}], {6.960068790685864, 1.0185466522954925`},
        Automatic, Automatic,
       Background->GrayLevel[1]]}, {
      LineBox[{{7.129826566068446, 0.6790311015303283}, {6.790311015303282, 
       0.}}], InsetBox[
       RowBox[{"PO4", "<", "292.625`"}], {6.960068790685864, 0.33951555076516415`},
        Automatic, Automatic,
       Background->GrayLevel[1]]}, {
      LineBox[{{7.129826566068446, 0.6790311015303283}, {7.46934211683361, 
       0.}}], InsetBox[
       RowBox[{"PO4", "\[GreaterEqual]", "292.625`"}], {7.299584341451028, 0.33951555076516415`},
        Automatic, Automatic,
       Background->GrayLevel[1]]}, {
      LineBox[{{4.4137021599471336`, 0.6790311015303283}, {4.074186609181969, 
       0.}}], InsetBox[
       RowBox[{"Chla", "<", "5.233`"}], {4.243944384564552, 0.33951555076516415`},
        Automatic, Automatic,
       Background->GrayLevel[1]]}, {
      LineBox[{{4.4137021599471336`, 0.6790311015303283}, {4.753217710712297, 
       0.}}], InsetBox[
       RowBox[{"Chla", "\[GreaterEqual]", "5.233`"}], {4.583459935329715, 0.33951555076516415`},
        Automatic, Automatic,
       Background->GrayLevel[1]]}, {
      LineBox[{{5.771764363007789, 0.6790311015303283}, {5.432248812242626, 
       0.}}], InsetBox[
       RowBox[{"Chla", "<", "3.8`"}], {5.602006587625207, 0.33951555076516415`},
        Automatic, Automatic,
       Background->GrayLevel[1]]}, {
      LineBox[{{5.771764363007789, 0.6790311015303283}, {6.111279913772954, 
       0.}}], InsetBox[
       RowBox[{"Chla", "\[GreaterEqual]", "3.8`"}], {5.941522138390372, 0.33951555076516415`},
        Automatic, Automatic,
       Background->GrayLevel[1]]}, {
      LineBox[{{3.395155507651641, 1.3580622030606566`}, {3.055639956886477, 
       0.6790311015303283}}], InsetBox[
       RowBox[{"PO4", "<", "49.333`"}], {3.225397732269059, 1.0185466522954925`},
        Automatic, Automatic,
       Background->GrayLevel[1]]}, {
      LineBox[{{3.395155507651641, 1.3580622030606566`}, {3.734671058416805, 
       0.6790311015303283}}], InsetBox[
       RowBox[{"PO4", "\[GreaterEqual]", "49.333`"}], {3.564913283034223, 1.0185466522954925`},
        Automatic, Automatic,
       Background->GrayLevel[1]]}, {
      LineBox[{{0.3395155507651641, 2.037093304590985}, {0., 
       1.3580622030606566`}}], InsetBox[
       RowBox[{"oPO4", "<", "23.`"}], {0.16975777538258205`, 1.6975777538258208`},
        Automatic, Automatic,
       Background->GrayLevel[1]]}, {
      LineBox[{{0.3395155507651641, 2.037093304590985}, {0.6790311015303282, 
       1.3580622030606566`}}], InsetBox[
       RowBox[{"oPO4", "\[GreaterEqual]", "23.`"}], {0.5092733261477461, 1.6975777538258208`},
        Automatic, Automatic,
       Background->GrayLevel[1]]}, {
      LineBox[{{1.6975777538258205`, 2.037093304590985}, {1.3580622030606564`,
        1.3580622030606566`}}], InsetBox[
       RowBox[{"PO4", "<", "21.3`"}], {1.5278199784432385`, 1.6975777538258208`},
        Automatic, Automatic,
       Background->GrayLevel[1]]}, {
      LineBox[{{1.6975777538258205`, 2.037093304590985}, {2.0370933045909845`,
        1.3580622030606566`}}], InsetBox[
       RowBox[{"PO4", "\[GreaterEqual]", "21.3`"}], {1.8673355292084026`, 1.6975777538258208`},
        Automatic, Automatic,
       Background->GrayLevel[1]]}, {
      LineBox[{{2.0370933045909845`, 1.3580622030606566`}, {
       1.6975777538258205`, 0.6790311015303283}}], InsetBox[
       RowBox[{"PO4", "<", "72.9`"}], {1.8673355292084026`, 1.0185466522954925`},
        Automatic, Automatic,
       Background->GrayLevel[1]]}, {
      LineBox[{{2.0370933045909845`, 1.3580622030606566`}, {
       2.3766088553561486`, 0.6790311015303283}}], InsetBox[
       RowBox[{"PO4", "\[GreaterEqual]", "72.9`"}], {2.2068510799735668`, 1.0185466522954925`},
        Automatic, Automatic,
       Background->GrayLevel[1]]}}, {
     {RGBColor[1., 1., 0.75], EdgeForm[GrayLevel[0.5]], 
      RectangleBox[{2.67832162534954, 3.245155507651641}, {3.17832162534954, 3.545155507651641},
       RoundingRadius->0.02], 
      {GrayLevel[0], InsetBox[
        StyleBox["198",
         StripOnInput->False,
         FontSize->9], {2.92832162534954, 3.395155507651641}]}}, 
     {RGBColor[1., 1., 0.75], EdgeForm[GrayLevel[0.5]], 
      RectangleBox[{0.7685466522954922, 2.566124406121313}, {1.2685466522954922`, 2.8661244061213127`},
       RoundingRadius->0.02], 
      {GrayLevel[0], InsetBox[
        StyleBox["78",
         StripOnInput->False,
         FontSize->9], {1.0185466522954922`, 2.716124406121313}]}}, 
     {RGBColor[1., 1., 0.75], EdgeForm[GrayLevel[0.5]], 
      RectangleBox[{4.588096598403588, 2.566124406121313}, {5.088096598403588, 2.8661244061213127`},
       RoundingRadius->0.02], 
      {GrayLevel[0], InsetBox[
        StyleBox["120",
         StripOnInput->False,
         FontSize->9], {4.838096598403588, 2.716124406121313}]}}, 
     {RGBColor[1., 1., 0.75], EdgeForm[GrayLevel[0.5]], 
      RectangleBox[{3.484671058416805, 1.887093304590985}, {3.984671058416805, 2.187093304590985},
       RoundingRadius->0.02], 
      {GrayLevel[0], InsetBox[
        StyleBox["33",
         StripOnInput->False,
         FontSize->9], {3.734671058416805, 2.037093304590985}]}}, 
     {RGBColor[1., 1., 0.75], EdgeForm[GrayLevel[0.5]], 
      RectangleBox[{5.691522138390372, 1.887093304590985}, {6.191522138390372, 2.187093304590985},
       RoundingRadius->0.02], 
      {GrayLevel[0], InsetBox[
        StyleBox["87",
         StripOnInput->False,
         FontSize->9], {5.941522138390372, 2.037093304590985}]}}, 
     {RGBColor[1., 1., 0.75], EdgeForm[GrayLevel[0.5]], 
      RectangleBox[{4.842733261477461, 1.2080622030606567`}, {5.342733261477461, 1.5080622030606565`},
       RoundingRadius->0.02], 
      {GrayLevel[0], InsetBox[
        StyleBox["40",
         StripOnInput->False,
         FontSize->9], {5.092733261477461, 1.3580622030606566`}]}}, 
     {RGBColor[1., 1., 0.75], EdgeForm[GrayLevel[0.5]], 
      RectangleBox[{6.540311015303282, 1.2080622030606567`}, {7.040311015303282, 1.5080622030606565`},
       RoundingRadius->0.02], 
      {GrayLevel[0], InsetBox[
        StyleBox["47",
         StripOnInput->False,
         FontSize->9], {6.790311015303282, 1.3580622030606566`}]}}, 
     {RGBColor[1., 1., 0.75], EdgeForm[GrayLevel[0.5]], 
      RectangleBox[{6.200795464538118, 0.5290311015303283}, {6.700795464538118, 0.8290311015303283},
       RoundingRadius->0.02], 
      {GrayLevel[0], InsetBox[
        StyleBox[
         TagBox[GridBox[{
            {"17"},
            {"6.247058823529413`"}
           },
           DefaultBaseStyle->"Column",
           GridBoxAlignment->{"Columns" -> {{Center}}},
           
           GridBoxItemSize->{
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
          "Column"],
         StripOnInput->False,
         FontSize->9], {6.450795464538118, 0.6790311015303283}]}}, 
     {RGBColor[1., 1., 0.75], EdgeForm[GrayLevel[0.5]], 
      RectangleBox[{6.879826566068446, 0.5290311015303283}, {7.379826566068446, 0.8290311015303283},
       RoundingRadius->0.02], 
      {GrayLevel[0], InsetBox[
        StyleBox["30",
         StripOnInput->False,
         FontSize->9], {7.129826566068446, 0.6790311015303283}]}}, 
     {RGBColor[1., 1., 0.75], EdgeForm[GrayLevel[0.5]], 
      RectangleBox[{6.540311015303282, -0.15}, {7.040311015303282, 0.15},
       RoundingRadius->0.02], 
      {GrayLevel[0], InsetBox[
        StyleBox[
         TagBox[GridBox[{
            {"15"},
            {"5.04`"}
           },
           DefaultBaseStyle->"Column",
           GridBoxAlignment->{"Columns" -> {{Center}}},
           
           GridBoxItemSize->{
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
          "Column"],
         StripOnInput->False,
         FontSize->9], {6.790311015303282, 0.}]}}, 
     {RGBColor[1., 1., 0.75], EdgeForm[GrayLevel[0.5]], 
      RectangleBox[{7.21934211683361, -0.15}, {7.71934211683361, 0.15},
       RoundingRadius->0.02], 
      {GrayLevel[0], InsetBox[
        StyleBox[
         TagBox[GridBox[{
            {"15"},
            {"2.9866666666666664`"}
           },
           DefaultBaseStyle->"Column",
           GridBoxAlignment->{"Columns" -> {{Center}}},
           
           GridBoxItemSize->{
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
          "Column"],
         StripOnInput->False,
         FontSize->9], {7.46934211683361, 0.}]}}, 
     {RGBColor[1., 1., 0.75], EdgeForm[GrayLevel[0.5]], 
      RectangleBox[{4.1637021599471336`, 0.5290311015303283}, {4.6637021599471336`, 0.8290311015303283},
       RoundingRadius->0.02], 
      {GrayLevel[0], InsetBox[
        StyleBox["20",
         StripOnInput->False,
         FontSize->9], {4.4137021599471336`, 0.6790311015303283}]}}, 
     {RGBColor[1., 1., 0.75], EdgeForm[GrayLevel[0.5]], 
      RectangleBox[{5.521764363007789, 0.5290311015303283}, {6.021764363007789, 0.8290311015303283},
       RoundingRadius->0.02], 
      {GrayLevel[0], InsetBox[
        StyleBox["20",
         StripOnInput->False,
         FontSize->9], {5.771764363007789, 0.6790311015303283}]}}, 
     {RGBColor[1., 1., 0.75], EdgeForm[GrayLevel[0.5]], 
      RectangleBox[{5.182248812242626, -0.15}, {5.682248812242626, 0.15},
       RoundingRadius->0.02], 
      {GrayLevel[0], InsetBox[
        StyleBox[
         TagBox[GridBox[{
            {"5"},
            {"7.12`"}
           },
           DefaultBaseStyle->"Column",
           GridBoxAlignment->{"Columns" -> {{Center}}},
           
           GridBoxItemSize->{
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
          "Column"],
         StripOnInput->False,
         FontSize->9], {5.432248812242626, 0.}]}}, 
     {RGBColor[1., 1., 0.75], EdgeForm[GrayLevel[0.5]], 
      RectangleBox[{5.861279913772954, -0.15}, {6.361279913772954, 0.15},
       RoundingRadius->0.02], 
      {GrayLevel[0], InsetBox[
        StyleBox[
         TagBox[GridBox[{
            {"15"},
            {"2.733333333333334`"}
           },
           DefaultBaseStyle->"Column",
           GridBoxAlignment->{"Columns" -> {{Center}}},
           
           GridBoxItemSize->{
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
          "Column"],
         StripOnInput->False,
         FontSize->9], {6.111279913772954, 0.}]}}, 
     {RGBColor[1., 1., 0.75], EdgeForm[GrayLevel[0.5]], 
      RectangleBox[{3.824186609181969, -0.15}, {4.324186609181969, 0.15},
       RoundingRadius->0.02], 
      {GrayLevel[0], InsetBox[
        StyleBox[
         TagBox[GridBox[{
            {"7"},
            {"16.571428571428573`"}
           },
           DefaultBaseStyle->"Column",
           GridBoxAlignment->{"Columns" -> {{Center}}},
           
           GridBoxItemSize->{
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
          "Column"],
         StripOnInput->False,
         FontSize->9], {4.074186609181969, 0.}]}}, 
     {RGBColor[1., 1., 0.75], EdgeForm[GrayLevel[0.5]], 
      RectangleBox[{4.503217710712297, -0.15}, {5.003217710712297, 0.15},
       RoundingRadius->0.02], 
      {GrayLevel[0], InsetBox[
        StyleBox[
         TagBox[GridBox[{
            {"13"},
            {"5.684615384615385`"}
           },
           DefaultBaseStyle->"Column",
           GridBoxAlignment->{"Columns" -> {{Center}}},
           
           GridBoxItemSize->{
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
          "Column"],
         StripOnInput->False,
         FontSize->9], {4.753217710712297, 0.}]}}, 
     {RGBColor[1., 1., 0.75], EdgeForm[GrayLevel[0.5]], 
      RectangleBox[{3.145155507651641, 1.2080622030606567`}, {3.645155507651641, 1.5080622030606565`},
       RoundingRadius->0.02], 
      {GrayLevel[0], InsetBox[
        StyleBox["21",
         StripOnInput->False,
         FontSize->9], {3.395155507651641, 1.3580622030606566`}]}}, 
     {RGBColor[1., 1., 0.75], EdgeForm[GrayLevel[0.5]], 
      RectangleBox[{3.824186609181969, 1.2080622030606567`}, {4.324186609181969, 1.5080622030606565`},
       RoundingRadius->0.02], 
      {GrayLevel[0], InsetBox[
        StyleBox[
         TagBox[GridBox[{
            {"12"},
            {"22.416666666666668`"}
           },
           DefaultBaseStyle->"Column",
           GridBoxAlignment->{"Columns" -> {{Center}}},
           
           GridBoxItemSize->{
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
          "Column"],
         StripOnInput->False,
         FontSize->9], {4.074186609181969, 1.3580622030606566`}]}}, 
     {RGBColor[1., 1., 0.75], EdgeForm[GrayLevel[0.5]], 
      RectangleBox[{2.805639956886477, 0.5290311015303283}, {3.305639956886477, 0.8290311015303283},
       RoundingRadius->0.02], 
      {GrayLevel[0], InsetBox[
        StyleBox[
         TagBox[GridBox[{
            {"11"},
            {"33.872727272727275`"}
           },
           DefaultBaseStyle->"Column",
           GridBoxAlignment->{"Columns" -> {{Center}}},
           
           GridBoxItemSize->{
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
          "Column"],
         StripOnInput->False,
         FontSize->9], {3.055639956886477, 0.6790311015303283}]}}, 
     {RGBColor[1., 1., 0.75], EdgeForm[GrayLevel[0.5]], 
      RectangleBox[{3.484671058416805, 0.5290311015303283}, {3.984671058416805, 0.8290311015303283},
       RoundingRadius->0.02], 
      {GrayLevel[0], InsetBox[
        StyleBox[
         TagBox[GridBox[{
            {"10"},
            {"8.97`"}
           },
           DefaultBaseStyle->"Column",
           GridBoxAlignment->{"Columns" -> {{Center}}},
           
           GridBoxItemSize->{
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
          "Column"],
         StripOnInput->False,
         FontSize->9], {3.734671058416805, 0.6790311015303283}]}}, 
     {RGBColor[1., 1., 0.75], EdgeForm[GrayLevel[0.5]], 
      RectangleBox[{0.0895155507651641, 1.887093304590985}, {0.5895155507651642, 2.187093304590985},
       RoundingRadius->0.02], 
      {GrayLevel[0], InsetBox[
        StyleBox["38",
         StripOnInput->False,
         FontSize->9], {0.3395155507651641, 2.037093304590985}]}}, 
     {RGBColor[1., 1., 0.75], EdgeForm[GrayLevel[0.5]], 
      RectangleBox[{1.4475777538258205`, 1.887093304590985}, {1.9475777538258205`, 2.187093304590985},
       RoundingRadius->0.02], 
      {GrayLevel[0], InsetBox[
        StyleBox["40",
         StripOnInput->False,
         FontSize->9], {1.6975777538258205`, 2.037093304590985}]}}, 
     {RGBColor[1., 1., 0.75], EdgeForm[GrayLevel[0.5]], 
      RectangleBox[{1.1080622030606564`, 1.2080622030606567`}, {1.6080622030606564`, 1.5080622030606565`},
       RoundingRadius->0.02], 
      {GrayLevel[0], InsetBox[
        StyleBox[
         TagBox[GridBox[{
            {"16"},
            {"36.7125`"}
           },
           DefaultBaseStyle->"Column",
           GridBoxAlignment->{"Columns" -> {{Center}}},
           
           GridBoxItemSize->{
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
          "Column"],
         StripOnInput->False,
         FontSize->9], {1.3580622030606564`, 1.3580622030606566`}]}}, 
     {RGBColor[1., 1., 0.75], EdgeForm[GrayLevel[0.5]], 
      RectangleBox[{1.7870933045909845`, 1.2080622030606567`}, {2.2870933045909845`, 1.5080622030606565`},
       RoundingRadius->0.02], 
      {GrayLevel[0], InsetBox[
        StyleBox["24",
         StripOnInput->False,
         FontSize->9], {2.0370933045909845`, 1.3580622030606566`}]}}, 
     {RGBColor[1., 1., 0.75], EdgeForm[GrayLevel[0.5]], 
      RectangleBox[{1.4475777538258205`, 0.5290311015303283}, {1.9475777538258205`, 0.8290311015303283},
       RoundingRadius->0.02], 
      {GrayLevel[0], InsetBox[
        StyleBox[
         TagBox[GridBox[{
            {"12"},
            {"31.15833333333333`"}
           },
           DefaultBaseStyle->"Column",
           GridBoxAlignment->{"Columns" -> {{Center}}},
           
           GridBoxItemSize->{
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
          "Column"],
         StripOnInput->False,
         FontSize->9], {1.6975777538258205`, 0.6790311015303283}]}}, 
     {RGBColor[1., 1., 0.75], EdgeForm[GrayLevel[0.5]], 
      RectangleBox[{2.1266088553561486`, 0.5290311015303283}, {2.6266088553561486`, 0.8290311015303283},
       RoundingRadius->0.02], 
      {GrayLevel[0], InsetBox[
        StyleBox[
         TagBox[GridBox[{
            {"12"},
            {"20.866666666666667`"}
           },
           DefaultBaseStyle->"Column",
           GridBoxAlignment->{"Columns" -> {{Center}}},
           
           GridBoxItemSize->{
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
          "Column"],
         StripOnInput->False,
         FontSize->9], {2.3766088553561486`, 0.6790311015303283}]}}, 
     {RGBColor[1., 1., 0.75], EdgeForm[GrayLevel[0.5]], 
      RectangleBox[{-0.25, 1.2080622030606567`}, {0.25, 1.5080622030606565`},
       RoundingRadius->0.02], 
      {GrayLevel[0], InsetBox[
        StyleBox[
         TagBox[GridBox[{
            {"19"},
            {"39.284210526315775`"}
           },
           DefaultBaseStyle->"Column",
           GridBoxAlignment->{"Columns" -> {{Center}}},
           
           GridBoxItemSize->{
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
          "Column"],
         StripOnInput->False,
         FontSize->9], {0., 1.3580622030606566`}]}}, 
     {RGBColor[1., 1., 0.75], EdgeForm[GrayLevel[0.5]], 
      RectangleBox[{0.4290311015303282, 1.2080622030606567`}, {0.9290311015303282, 1.5080622030606565`},
       RoundingRadius->0.02], 
      {GrayLevel[0], InsetBox[
        StyleBox[
         TagBox[GridBox[{
            {"19"},
            {"9.621052631578948`"}
           },
           DefaultBaseStyle->"Column",
           GridBoxAlignment->{"Columns" -> {{Center}}},
           
           GridBoxItemSize->{
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
          "Column"],
         StripOnInput->False,
         FontSize->9], {0.6790311015303282, 1.3580622030606566`}]}}}},
   Annotation[#, VertexCoordinateRules -> CompressedData["
1:eJxTTMoPSmViYGCQBWIQ/TA247FxLrvDyqmFXu6a3A6pnwUmf/f+YN/ucjBv
/i5WBw7FJf9Mo4QdYHzLfZ4Wsx/wOqSB1TE4fElSTpQ7Ig7n2xlcLf8aJ+LQ
AVb/1R5irjScn9DYGjz3rCSU/9T+48pYx48tMnA+TD0DFEDsk4Xz17H/7Vy4
XBCu/nzE2lRPMXE4H+JOUbh6idyZMZ8LJeB8iP8E4Pxv0i8bvJmF4XxYOMDc
C1MP40PM44DbBwsPVPuv2sPCA2Lebzi/HWoOqvkMaOH12x5mHsR9zHDzYe6E
qW+HisP4ANsuwmQ=
     "]]& ],
  AspectRatio->0.62,
  FrameTicks->None,
  ImageSize->700,
  PlotRange->All,
  PlotRangePadding->Scaled[0.1]]], "Output",
 CellChangeTimes->{
  3.585674214347227*^9, 3.585674525503099*^9, 3.585674555968936*^9, {
   3.5856746259639597`*^9, 3.585674657452873*^9}, {3.585674693518442*^9, 
   3.585674699133638*^9}, {3.585674749132316*^9, 3.585674759594882*^9}, 
   3.5856748045282917`*^9, 3.585674856725502*^9, {3.5856748879851007`*^9, 
   3.5856748925950613`*^9}, {3.58567495476408*^9, 3.5856750630909157`*^9}, {
   3.585675094544455*^9, 3.58567511024259*^9}, 3.585676640888805*^9, {
   3.585676679480527*^9, 3.5856766952238083`*^9}, 3.585676759620163*^9, 
   3.585677989745372*^9, {3.585678636636485*^9, 3.5856786537426367`*^9}, 
   3.5856787592915993`*^9, 3.585679824817775*^9, 3.58568017226997*^9, 
   3.5859130896221848`*^9, {3.585913120910838*^9, 3.585913147761141*^9}, 
   3.5859308021860037`*^9, 3.585932052936837*^9, 3.586000885218356*^9, 
   3.586086566273067*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, {2}]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Model Evaluation", "Title",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBWIQbZiQwrVk2yvHJQcPgGnXJ7fWHgXSwiH+60A0x35T
m1NA+l0bkx2IXr5vXzqIDjm6IANEn5oTuPw0kJ60fjuY/rnwzi8Q3RNl+BtE
57wx2HQGSM8427gZRPcYb8o/B6SDf8QVgOji6wcvgui2v/svgegfK1++AdEn
uIPfguhnvgYzzwPpe6nLwPSsJDn2C0Ba2ec2mJ6xJX39eyD9oPwumL5QbHX+
A5Bet+8zmGZal1X6CUh/9+YoA9FHPSWmgegPVYpg+o6CutNXkLrLlWBazdy4
7zuQjgjqB9NVb3L0fwDpoHUHwTTjPfc+2e2vHC8xVvaD6F/hgmtUgPQX51Yw
DQDvfsmZ
  "]],

Cell["\<\
We can get a sense of the tree\[CloseCurlyQuote]s performance (or any model\
\[CloseCurlyQuote]s performance) by defining a Normalized Mean Square Error:\
\>", "Text",
 CellChangeTimes->{{3.5856588665867147`*^9, 3.585658876162767*^9}, {
  3.5856662331325006`*^9, 3.585666244547823*^9}, {3.585681135948842*^9, 
  3.58568113659702*^9}, {3.5860230351370497`*^9, 3.5860230408802443`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"NMSE", "[", 
   RowBox[{"one_", ",", "two_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"Mean", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"one", "-", "two"}], ")"}], "^", "2"}], "]"}], "/", 
   RowBox[{"Mean", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Mean", "[", "two", "]"}], "-", "two"}], ")"}], "^", "2"}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.575113672675663*^9, 3.5751136986641493`*^9}, {
  3.575113732730098*^9, 3.5751137444177666`*^9}}],

Cell["(Also, the Mean Absolute Error and Mean Square Error:)", "Text",
 CellChangeTimes->{{3.5859146317079678`*^9, 3.585914652867017*^9}, {
  3.586097432148238*^9, 3.586097432467146*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MAE", "[", 
    RowBox[{"one_", ",", "two_"}], "]"}], ":=", 
   RowBox[{"Mean", "[", 
    RowBox[{"Abs", "[", 
     RowBox[{"one", "-", "two"}], "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.575113493742429*^9, 3.5751135276393676`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"MSE", "[", 
   RowBox[{"one_", ",", "two_"}], "]"}], ":=", 
  RowBox[{"Mean", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"one", "-", "two"}], ")"}], "^", "2"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.575113591603026*^9, 3.5751136070519094`*^9}}],

Cell["\<\
Try classifying on our training set, and see how well it worked:\
\>", "Text",
 CellChangeTimes->{{3.585658907098976*^9, 3.585658926729841*^9}, {
  3.58565899411331*^9, 3.585658997920456*^9}, {3.585659071378068*^9, 
  3.585659071942903*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"pred", "=", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"dat", "=", 
       RowBox[{"dat", "[", 
        RowBox[{"[", "train", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"classify", "[", 
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", 
           RowBox[{"1", ";;", 
            RowBox[{"-", "2"}]}], "]"}], "]"}], ",", "tree"}], "]"}], "&"}], "/@",
       "dat"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"NMSE", "[", 
  RowBox[{"pred", ",", 
   RowBox[{"knnd", "[", "a1", "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.575130813381617*^9, 3.5751308830999537`*^9}, {
   3.575130916995716*^9, 3.5751310376154203`*^9}, {3.575136572935557*^9, 
   3.5751365735926933`*^9}, {3.5751366147727213`*^9, 3.575136619245492*^9}, 
   3.575136775153098*^9, {3.575137273329055*^9, 3.575137314165781*^9}, 
   3.575137411381433*^9, {3.575137631566787*^9, 3.575137632270718*^9}, {
   3.575138969585771*^9, 3.575138977353128*^9}}],

Cell[BoxData["0.6379419621707062`"], "Output",
 CellChangeTimes->{
  3.575137314492526*^9, {3.575137370698432*^9, 3.575137525209197*^9}, {
   3.575137601332003*^9, 3.575137741635775*^9}, 3.575137774500992*^9, 
   3.575138346124004*^9, {3.575138380506851*^9, 3.5751384437193737`*^9}, {
   3.5751389701300697`*^9, 3.575138994742962*^9}, 3.575200709634186*^9, {
   3.575202567537891*^9, 3.575202585901997*^9}, 3.575205044987911*^9, 
   3.5856590014612494`*^9, {3.5856590670152473`*^9, 3.5856590728960857`*^9}, 
   3.585659552655615*^9, 3.5856607393814096`*^9, 3.585660787770115*^9, 
   3.585660849903096*^9, 3.58566092770999*^9, 3.585661085167614*^9, 
   3.585661118547633*^9, 3.585661173645208*^9, {3.58566132951222*^9, 
   3.585661361380329*^9}, {3.585661425527017*^9, 3.585661438615572*^9}, 
   3.585661506842202*^9, {3.5856615414795227`*^9, 3.585661642173334*^9}, {
   3.585661678834033*^9, 3.5856617219295273`*^9}, 3.58566175627485*^9, 
   3.585661802242381*^9, 3.585662545974064*^9, 3.585662624315015*^9, 
   3.585662706902012*^9, {3.585664860500948*^9, 3.585664901567918*^9}, 
   3.585665000341709*^9, 3.585665614502122*^9, 3.585665884930316*^9, 
   3.5856659293357363`*^9, 3.5856660335547123`*^9, 3.585667713852124*^9, 
   3.585667745822063*^9, 3.585679831144068*^9, 3.5856802059161663`*^9, 
   3.585930815207049*^9, 3.586000965857252*^9, 3.586023054040834*^9, 
   3.586086585497526*^9}]
}, Open  ]],

Cell["\<\
A NMSE of 1 would mean we were doing no better than guessing the average of \
the column, and the model had no predictive value at all.\
\>", "Text",
 CellChangeTimes->{{3.5856788571642*^9, 3.585678874778661*^9}, {
  3.585913182027021*^9, 3.585913193761128*^9}}],

Cell["\<\
A rigorous approach to managing overfitting would do a cross-validation test \
on the model, looking at the relative error of the tree (error relative to \
the root node) as the tree depth increases.  Then one can follow the \
\[OpenCurlyDoubleQuote]1-SE\[CloseCurlyDoubleQuote] rule, which dictates \
selection of the smallest tree with a relative error within one standard \
deviation of the best one.\
\>", "Text",
 CellChangeTimes->{{3.5739068065654883`*^9, 3.5739068097454967`*^9}, {
  3.5750671434302597`*^9, 3.5750671454053726`*^9}, {3.5750671947321944`*^9, 
  3.5750671967473097`*^9}, {3.575067370749262*^9, 3.5750673748774977`*^9}, {
  3.5751369778417664`*^9, 3.5751369806913958`*^9}, {3.5856802807453403`*^9, 
  3.5856804655380907`*^9}, {3.586000992185691*^9, 3.5860009969375267`*^9}}],

Cell["\<\
Some simpler explorations of the parameter space are still helpful.  Here, \
collect NMSE data as a function of number of variables used in the tree \
construction:\
\>", "Text",
 CellChangeTimes->{{3.585681155132195*^9, 3.585681246106536*^9}, {
  3.58568165053901*^9, 3.5856816660900717`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"evaluateModel", "[", "trials_", "]"}], ":=", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"makeTree", ",", "preds"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"makeTree", "[", "n_", "]"}], ":=", 
      RowBox[{"cart", "[", 
       RowBox[{
        RowBox[{"Transpose", "@", 
         RowBox[{"dat", "[", 
          RowBox[{"[", 
           RowBox[{"train", ",", 
            RowBox[{"1", ";;", 
             RowBox[{"-", "2"}]}]}], "]"}], "]"}]}], ",", 
        RowBox[{"dat", "[", 
         RowBox[{"[", 
          RowBox[{"train", ",", 
           RowBox[{"-", "1"}]}], "]"}], "]"}], ",", "n", ",", 
        RowBox[{"\"\<MinSplit\>\"", "\[Rule]", "20"}], ",", 
        RowBox[{"\"\<MaxDepth\>\"", "\[Rule]", "30"}], ",", 
        RowBox[{"\"\<MinDevianceChange\>\"", "\[Rule]", "0.01"}]}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"preds", "[", "tr_", "]"}], ":=", 
      RowBox[{
       RowBox[{
        RowBox[{"classify", "[", 
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", 
            RowBox[{"1", ";;", 
             RowBox[{"-", "2"}]}], "]"}], "]"}], ",", "tr"}], "]"}], "&"}], "/@", 
       RowBox[{"dat", "[", 
        RowBox[{"[", "train", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"Mean", "/@", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"With", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"tr", "=", 
            RowBox[{"makeTree", "[", "i", "]"}]}], "}"}], ",", 
          RowBox[{"NMSE", "[", 
           RowBox[{
            RowBox[{"preds", "[", "tr", "]"}], ",", 
            RowBox[{"knnd", "[", "a1", "]"}]}], "]"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "11"}], "}"}], ",", 
        RowBox[{"{", "trials", "}"}]}], "]"}]}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.585680821907997*^9, 3.585681015553903*^9}, {
  3.585681050281863*^9, 3.58568108516008*^9}, {3.585681531169196*^9, 
  3.585681561222302*^9}, {3.58568159609374*^9, 3.585681623484194*^9}, {
  3.585932083931387*^9, 3.585932113002264*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"testDat", "=", 
  RowBox[{"evaluateModel", "[", "20", "]"}]}]], "Input",
 CellChangeTimes->{{3.585681020129562*^9, 3.5856810227360163`*^9}, {
  3.585681064730425*^9, 3.58568108783016*^9}, {3.585681284146604*^9, 
  3.585681285666092*^9}, {3.585681489537715*^9, 3.585681489662467*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.6452756724006814`", ",", "0.5783245142091336`", ",", 
   "0.546920454271719`", ",", "0.5605966253684815`", ",", 
   "0.5685683547151924`", ",", "0.5821643475120133`", ",", 
   "0.5993342668393962`", ",", "0.6090053426868933`", ",", 
   "0.6013779138704588`", ",", "0.6323937875359579`", ",", 
   "0.637941962170706`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.585681023970934*^9, {3.58568106029828*^9, 3.58568109464155*^9}, 
   3.5856812954198933`*^9, 3.585681502089809*^9, 3.5856815475155287`*^9, 
   3.585681579373933*^9, {3.585681614971034*^9, 3.585681639405046*^9}, {
   3.585913236712894*^9, 3.5859132597351627`*^9}, 3.585930834509184*^9, 
   3.585932129268342*^9, {3.586001035751177*^9, 3.586001062684338*^9}, 
   3.5860231177151117`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Range", "[", 
       RowBox[{"Length", "@", "testDat"}], "]"}], ",", "testDat"}], "}"}], 
    "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<k\>\"", ",", "\"\<NMSE\>\""}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"All", ",", 
      RowBox[{"{", 
       RowBox[{"0.3", ",", "All"}], "}"}]}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"PlotMarkers", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Automatic", ",", "Medium"}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"AxesOrigin", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0.3"}], "}"}]}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{{3.5856812902114*^9, 3.585681338777955*^9}, {
  3.585681378600318*^9, 3.5856814451434517`*^9}, {3.585681479576982*^9, 
  3.5856814813283033`*^9}, {3.585932151613106*^9, 3.5859321517796297`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, GraphicsComplexBox[CompressedData["
1:eJxTTMoPSmViYGAQA2IQDQEf7K9t2K0lueyJPVTAQUs6IXNR4yMon8PBoFM4
OL7hIZQv4GA2pS004wOML+IQGaXovM0Qpl7C4dghPQXxhTC+jMOSgDy+/bqP
oXwFB599e4/+qIHxlRxOtgs/rbGD8VUcXiqVPp1oA3OPmsPWuRzOrFkw/tBx
LwBLs17a
    "], {
     {RGBColor[0.24720000000000014`, 0.24, 0.6], InsetBox[
       StyleBox["\<\"\[FilledCircle]\"\>",
        StripOnInput->False,
        FontSize->Medium], 12], InsetBox[
       StyleBox["\<\"\[FilledCircle]\"\>",
        StripOnInput->False,
        FontSize->Medium], 13], InsetBox[
       StyleBox["\<\"\[FilledCircle]\"\>",
        StripOnInput->False,
        FontSize->Medium], 14], InsetBox[
       StyleBox["\<\"\[FilledCircle]\"\>",
        StripOnInput->False,
        FontSize->Medium], 15], InsetBox[
       StyleBox["\<\"\[FilledCircle]\"\>",
        StripOnInput->False,
        FontSize->Medium], 16], InsetBox[
       StyleBox["\<\"\[FilledCircle]\"\>",
        StripOnInput->False,
        FontSize->Medium], 17], InsetBox[
       StyleBox["\<\"\[FilledCircle]\"\>",
        StripOnInput->False,
        FontSize->Medium], 18], InsetBox[
       StyleBox["\<\"\[FilledCircle]\"\>",
        StripOnInput->False,
        FontSize->Medium], 19], InsetBox[
       StyleBox["\<\"\[FilledCircle]\"\>",
        StripOnInput->False,
        FontSize->Medium], 20], InsetBox[
       StyleBox["\<\"\[FilledCircle]\"\>",
        StripOnInput->False,
        FontSize->Medium], 21], InsetBox[
       StyleBox["\<\"\[FilledCircle]\"\>",
        StripOnInput->False,
        FontSize->Medium], 22]}, {}}], {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"k\"", TraditionalForm], 
    FormBox["\"NMSE\"", TraditionalForm]},
  AxesOrigin->{0, 0.3},
  Method->{"ScalingFunctions" -> None},
  PlotRange->{{0, 11.}, {0.3, 0.6452756724006814}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {None, 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.585681383692526*^9, 3.5856814453254633`*^9}, {
   3.585681481506316*^9, 3.585681503522003*^9}, 3.585681548529975*^9, 
   3.5856815835119*^9, {3.585681615096781*^9, 3.585681639562389*^9}, {
   3.5859132368072042`*^9, 3.585913259834757*^9}, 3.5859308346862993`*^9, 
   3.585932152025136*^9, {3.586001035915999*^9, 3.586001062814982*^9}, {
   3.5860231178349123`*^9, 3.586023122861775*^9}}]
}, {2}]],

Cell["Proceed with some choice of parameters:", "Text",
 CellChangeTimes->{{3.585681751751834*^9, 3.585681758519802*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tree", "=", 
   RowBox[{"cart", "[", 
    RowBox[{
     RowBox[{"Transpose", "@", 
      RowBox[{"dat", "[", 
       RowBox[{"[", 
        RowBox[{"train", ",", 
         RowBox[{"1", ";;", 
          RowBox[{"-", "2"}]}]}], "]"}], "]"}]}], ",", 
     RowBox[{"dat", "[", 
      RowBox[{"[", 
       RowBox[{"train", ",", 
        RowBox[{"-", "1"}]}], "]"}], "]"}], ",", "4"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.5856817353616323`*^9, 3.58568174931364*^9}, {
  3.585913263411688*^9, 3.585913263640737*^9}, {3.585932168940289*^9, 
  3.585932170656049*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Model Comparison", "Title",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQA2IQbZiQwrVk2yvHJQcPgGnXJ7fWHgXSwiH+60A0x35T
m1NA+l0bkx2IXr5vXzqIDjm6IANEn5oTuPw0kJ60fjuY/rnwzi8Q3RNl+BtE
57wx2HQGSM8427gZRPcYb8o/B6SDf8QVgOji6wcvgui2v/svgegfK1++AdEn
uIPfguhnvgYzzwPpe6nLwPSsJDn2C0Ba2ec2mJ6xJX39eyD9oPwumL5QbHX+
A5Bet+8zmGZal1X6CUh/9+YoA9FHPSWmgegPVYpg+o6CutNXkLrLlWBazdy4
7zuQjgjqB9NVb3L0fwDpoHUHwTTjPfc+2e2vHC8xVvaD6F/hgmtUgPQX51Yw
7fKcTV8VSK9aFQumAcac0Og=
  "]],

Cell["Obtain a1 prediction vectors for both models:", "Text",
 CellChangeTimes->{{3.585682341692582*^9, 3.585682351172099*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"lmPredictions", "=", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"dat", "=", 
       RowBox[{
        RowBox[{"knnd", "[", "All", "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", 
          RowBox[{"beLmCols", "/.", "numberedColumns"}]}], "]"}], "]"}]}], 
      "}"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"Apply", "[", 
        RowBox[{
         RowBox[{"beLm", "[", "\"\<Function\>\"", "]"}], ",", "#"}], "]"}], 
       "&"}], "/@", "dat"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5751097872484293`*^9, 3.575109788856521*^9}, {
  3.575109844187686*^9, 3.575109884858012*^9}, {3.575109930961649*^9, 
  3.5751099572411523`*^9}, {3.5751100435750904`*^9, 3.575110046404252*^9}, {
  3.5751104136182556`*^9, 3.5751104952139225`*^9}, {3.5751105522441845`*^9, 
  3.5751105739874287`*^9}, {3.585682280326108*^9, 3.585682299713208*^9}, {
  3.585682452116354*^9, 3.585682480981813*^9}, {3.585682789026428*^9, 
  3.5856827903004704`*^9}, {3.585913292627966*^9, 3.5859133047756767`*^9}, {
  3.585913476120792*^9, 3.5859134832149878`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"cartPredictions", "=", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"dat", "=", 
       RowBox[{
        RowBox[{"knnd", "[", "All", "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", 
          RowBox[{"1", ";;", "11"}]}], "]"}], "]"}]}], "}"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"classify", "[", 
        RowBox[{"#", ",", "tree"}], "]"}], "&"}], "/@", "dat"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.575110504696465*^9, 3.5751105120468855`*^9}, 
   3.5751105422216115`*^9, {3.575110577499629*^9, 3.5751105868551645`*^9}, {
   3.5751107434621215`*^9, 3.5751107564298635`*^9}, {3.585682302329135*^9, 
   3.585682305207299*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"NMSE", "[", 
    RowBox[{"#", ",", 
     RowBox[{"knnd", "[", "a1", "]"}]}], "]"}], "&"}], "/@", 
  RowBox[{"{", 
   RowBox[{"lmPredictions", ",", "cartPredictions"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.575113790955428*^9, 3.575113822966259*^9}, {
  3.5751138775343804`*^9, 3.57511387997852*^9}, {3.585682357591795*^9, 
  3.585682403855035*^9}, {3.5856824894045773`*^9, 3.58568248990156*^9}, {
  3.5856827977795563`*^9, 3.585682801308975*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.6355607949346834`", ",", "0.5988638137441327`"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.5751138234942894`*^9, 3.5751138805005503`*^9, 3.5751990550819187`*^9, 
   3.575205025742053*^9, 3.575205070068302*^9, 3.585682404556265*^9, 
   3.585682460180235*^9, 3.585682490284677*^9, {3.585682801956469*^9, 
   3.585682818099245*^9}, {3.585682951598587*^9, 3.585682957284925*^9}, 
   3.585913285809327*^9, 3.5859134865358667`*^9, 3.585917092951614*^9, 
   3.5859308637064047`*^9, 3.5859321753804693`*^9, 3.586001112513838*^9}]
}, Open  ]],

Cell["Actual vs. predicted, for the linear model and the cart:", "Text",
 CellChangeTimes->{{3.586015955520232*^9, 3.586015965952202*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphicsRow", "[", 
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Show", "[", 
      RowBox[{
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"ListPlot", "[", 
          RowBox[{
           RowBox[{"Transpose", "[", 
            RowBox[{"{", 
             RowBox[{"lmPredictions", ",", 
              RowBox[{"knnd", "[", "a1", "]"}]}], "}"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"PlotMarkers", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Automatic", ",", "Medium"}], "}"}]}]}], 
          "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"Plot", "[", 
          RowBox[{"x", ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "0", ",", "50"}], "}"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"Directive", "[", "Dashed", "]"}]}]}], "]"}]}], 
        "\[IndentingNewLine]", "}"}], ",", 
       RowBox[{"PlotLabel", "\[Rule]", "\"\<Linear Model (a1)\>\""}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<Predicted\>\"", ",", "\"\<Actual\>\""}], "}"}]}]}], 
      "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Show", "[", 
      RowBox[{
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"ListPlot", "[", 
          RowBox[{
           RowBox[{"Transpose", "[", 
            RowBox[{"{", 
             RowBox[{"cartPredictions", ",", 
              RowBox[{"knnd", "[", "a1", "]"}]}], "}"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"PlotMarkers", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Automatic", ",", "Medium"}], "}"}]}]}], 
          "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"Plot", "[", 
          RowBox[{"x", ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "0", ",", "100"}], "}"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"Directive", "[", "Dashed", "]"}]}]}], "]"}]}], 
        "\[IndentingNewLine]", "}"}], ",", 
       RowBox[{"PlotLabel", "\[Rule]", "\"\<CART (a1)\>\""}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<Predicted\>\"", ",", "\"\<Actual\>\""}], "}"}]}]}], 
      "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "600"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5751115826811223`*^9, 3.5751117409631753`*^9}, {
   3.5751118582088814`*^9, 3.5751119281928844`*^9}, {3.5751119875762806`*^9, 
   3.5751120052232904`*^9}, 3.5856828519801483`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{{}, GraphicsComplexBox[CompressedData["
1:eJztV/tfzOkXn8RUUpodSqk2ZKqppmmm21TTnJqhu8YlG1pCN1apXKqv/a6E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         "], {
          {RGBColor[0.24720000000000014`, 0.24, 0.6], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 199], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 200], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 201], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 202], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 203], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 204], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 205], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 206], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 207], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 208], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 209], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 210], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 211], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 212], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 213], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 214], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 215], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 216], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 217], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 218], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 219], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 220], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 221], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 222], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 223], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 224], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 225], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 226], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 227], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 228], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 229], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 230], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 231], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 232], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 233], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 234], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 235], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 236], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 237], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 238], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 239], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 240], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 241], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 242], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 243], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 244], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 245], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 246], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 247], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 248], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 249], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 250], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 251], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 252], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 253], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 254], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 255], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 256], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 257], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 258], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 259], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 260], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 261], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 262], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 263], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 264], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 265], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 266], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 267], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 268], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 269], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 270], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 271], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 272], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 273], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 274], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 275], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 276], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 277], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 278], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 279], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 280], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 281], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 282], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 283], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 284], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 285], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 286], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 287], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 288], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 289], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 290], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 291], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 292], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 293], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 294], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 295], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 296], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 297], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 298], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 299], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 300], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 301], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 302], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 303], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 304], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 305], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 306], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 307], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 308], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 309], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 310], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 311], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 312], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 313], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 314], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 315], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 316], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 317], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 318], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 319], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 320], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 321], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 322], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 323], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 324], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 325], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 326], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 327], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 328], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 329], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 330], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 331], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 332], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 333], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 334], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 335], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 336], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 337], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 338], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 339], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 340], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 341], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 342], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 343], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 344], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 345], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 346], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 347], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 348], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 349], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 350], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 351], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 352], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 353], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 354], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 355], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 356], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 357], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 358], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 359], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 360], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 361], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 362], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 363], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 364], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 365], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 366], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 367], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 368], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 369], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 370], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 371], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 372], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 373], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 374], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 375], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 376], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 377], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 378], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 379], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 380], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 381], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 382], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 383], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 384], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 385], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 386], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 387], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 388], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 389], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 390], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 391], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 392], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 393], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 394], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 395], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 396]}, {}}], {}}, {{}, {}, 
        {Hue[0.67, 0.6, 0.6], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJxFxW0w03EcAPBxMnXtQsrD7TwsyZyyZXkYM9RQmoedLg/HiWb/eQhDqKWh
E201D5fqMJzHuPMwSXJLcx6iHC1vwh26y8PV9eChhUb1wvf34nMfq5hkDlcb
h8Ox//k/Saqpk5l3euzdo0e2SMKkzL2VWW31tlg1PExJ5eli7fAbicpvg9cP
j9Lze7/yJuCxkpnUZd4cfEGBD1jkfYfHCU77dSJxnnt7S1mvmwL1YK7DFoFK
0IfZZO7Po75GsHzqVsaoiwnsZmjXrnObCPO2S6saQi3h5OElx3Y2Cb4Xrntc
k2gNx47cjKNiNrASbxqcEGYLUw1E5SvpdnD0GsM+INEerpUNEdX3T8FdD+gz
Kg4FTn/JCKq6SIX7xxpWiyJOw3xfVwU/1BGubKZ2J8TT4JI1RW5K5hl4sSXj
OiZwggd9Sh/n5TnDWoHTn6QiFxjn9VyrJtsVLjRWs1V36XBKeOyAOt8NXsil
XWU+dIeNyp5MF9Uy4EZ9u+yRCg9YKbBgnWhlwjLLGiIjxBNWCLdw2CTayh//
59hlL/jZBFn8cQotGd6hWEZ6w2VpK/HRs2jhEfNDpLCz8FPyvrH0ebTuupap
Muoc3ETpzJEtockxLQGaJBY8c75XfukLWlV34yQzzQf+3RXsTlpF774QdBdc
84X9KT4s4QZ6JNKBn5DmBxvGYn1VGegorJYwmYn+JTgspwnR1oXqLc0dtEje
LykuR9PxQR3dveiCg0Xay33o9wYDIWav0BiRtpkzgH5ENfH2e4tej5j/MD2L
9rxiakOYQ4vjOFnMBTQpdZBY/xkdXNDMTfqGrhQv9FT/QC8Xmx1QraJFFZI2
JzX6Xc0Qjr+JNm7c4VRso2NanRvGNei2jhT17i76L8FoINM=
          "]]}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox["\"Predicted\"", TraditionalForm], 
        FormBox["\"Actual\"", TraditionalForm]},
      AxesOrigin->{0, 0},
      Method->{"ScalingFunctions" -> None},
      PlotLabel->FormBox["\"Linear Model (a1)\"", TraditionalForm],
      PlotRange->{{-13.23032256528382, 44.15179125779795}, {0, 89.8}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.02]}},
      Ticks->{Automatic, Automatic}], {192., -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[{{{}, GraphicsComplexBox[CompressedData["
1:eJztV8tLVGEUv5M9Z6Yae2tWTPg2cx6BYzjeo2bjY4LJLIhWGbpNcFUQDC1a
iftpWdEiIgJXQYHLENvUItwFgXsThkSQ5t7vnjP9zm3yH7gfA5fffN/5zvt8
58SnH07O7LEsayFkWc73xcdnvxpX4mR568fjE+9y99tp1l1lO+T8WTzm4TBd
XfyZWXzQRV9WnXWQmN7sXxScdtdlOW9wndpP0YxD1mp79H3E/I00SfrW9uRr
W3aQnpeclRDs8o+S0LvHl0fMuUOj5ttg09P+ls+3hsjD47j/6KY6n5PzRj8b
9c2P0b33+yq/o2IvjZneoB6afnWuK3b9jKdvL8q/MCnYnO8UbOwRE+ySL2VF
XiPPgNIvKfvu+U2iN87qTHj8I6KPsedZ2Wf5gV+6S+43+KScN/xTws8lLhbw
/OYkcfx41ws2/EM+ew6Ev7+c+9Rc076M2T4Qf+tjBPFczKL90hMo7/Igxuf8
HfGX8X9GMPPneDP+G1bxNEXo/wn0dz6D+O0U4tWEyoccyj+fQ/svVLHL/0OB
QL7VSyperqC8pR6Ud3kC46nUjPTRAkUq7smupGvUix0b/F3sQ/lKrWJPg+tp
Lus4PCT0jM3+lq3jhfm7uK8g9YLrDWPWH+tVo6onLSo/Nm3M1w6hN/J1Kxwm
Ha+4v3/XerEbZntozPLW2mfM+WD0PyX2NjhK+j6W31DHRD9jr9ME9xcTmG9W
E56/e0PZK67skVT1qJ3Q/3Gsn0u9vnzEfI1ivhwvqPzLqXqbkXgx/A4jbtD1
7Rrmz1r1vXHVe32bsD7t2IzZvviellV8b9mYD2EVn90Kb9s6HrV9VP1V+LfN
+WTsFyPM55jUE5a/Vn3+9/t+Qfm3mTC+qvy5f0D79xPGr6XqRdlGf6bRvzSi
8nOvkqdexWMj1pe1YUL5SPU77b76pe2v+yusfyHVH0XU/dX6we8R6ENE+n7o
h/7ixxjzfdsGfSv5h/HQpPwfUf6zLKzvG756hPqU8X2wOnR/YGl/YXxt2/o+
rf9u9RDzd1jl7xD2T+lxeQ/d/dZR1Q+Nqfc6j/1jPqne44Tq11KqH9rwxU8t
zPbQ++wPI8955b8DGN+V+GN6c/4I4vWUqt8dql9M+eIP87/Otx/MF8F8EcwX
wXwRzBfOCuaLYL4oBfNFMF8E84XqH/i+YL6YDeaL/8wXfwAAqFwp
         "], {
          {RGBColor[0.24720000000000014`, 0.24, 0.6], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 199], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 200], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 201], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 202], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 203], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 204], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 205], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 206], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 207], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 208], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 209], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 210], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 211], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 212], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 213], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 214], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 215], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 216], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 217], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 218], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 219], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 220], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 221], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 222], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 223], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 224], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 225], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 226], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 227], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 228], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 229], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 230], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 231], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 232], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 233], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 234], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 235], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 236], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 237], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 238], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 239], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 240], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 241], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 242], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 243], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 244], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 245], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 246], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 247], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 248], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 249], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 250], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 251], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 252], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 253], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 254], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 255], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 256], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 257], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 258], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 259], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 260], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 261], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 262], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 263], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 264], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 265], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 266], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 267], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 268], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 269], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 270], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 271], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 272], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 273], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 274], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 275], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 276], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 277], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 278], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 279], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 280], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 281], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 282], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 283], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 284], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 285], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 286], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 287], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 288], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 289], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 290], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 291], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 292], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 293], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 294], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 295], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 296], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 297], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 298], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 299], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 300], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 301], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 302], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 303], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 304], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 305], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 306], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 307], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 308], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 309], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 310], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 311], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 312], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 313], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 314], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 315], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 316], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 317], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 318], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 319], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 320], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 321], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 322], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 323], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 324], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 325], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 326], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 327], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 328], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 329], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 330], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 331], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 332], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 333], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 334], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 335], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 336], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 337], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 338], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 339], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 340], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 341], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 342], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 343], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 344], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 345], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 346], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 347], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 348], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 349], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 350], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 351], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 352], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 353], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 354], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 355], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 356], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 357], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 358], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 359], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 360], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 361], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 362], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 363], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 364], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 365], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 366], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 367], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 368], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 369], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 370], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 371], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 372], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 373], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 374], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 375], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 376], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 377], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 378], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 379], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 380], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 381], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 382], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 383], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 384], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 385], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 386], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 387], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 388], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 389], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 390], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 391], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 392], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 393], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 394], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 395], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 396]}, {}}], {}}, {{}, {}, 
        {Hue[0.67, 0.6, 0.6], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJxFxW0w03EcAPBxsurahR483M7DUpnT2WonLQw1zxtb5Ok40ew/D2EItTR0
wlaeLtVhOI9xhyZJbmnOQ5Sj5U24Q3d5uLoePLTQrHrh+3vxuY9VdBKXp4vD
4Vj//J9UrKmXmStddu/ZS7ZIxGoYuysz2xtssA54mJLC18f64TdSldcGfwIe
pef1fuXPwWOlMynL/O+wjwLPXuRr4XGCwz69CAPX3d2Lma+b/U1gnv0WgUqw
hFlk3s+jntawfOpW+qijDXzeyLZD77YdzN8uq24MocBJw0tnOlin4aIw/eOa
BBocM3Izloo5wEq8KSc+1BGmGoorVtLocNSasx07wQmukw0R1fdc4K779BkV
1xVOe+kcUO3nBvePNa4WhrvDAs9zCkHIBbiqhdodH3cRLl1T5CRnMOHF1vTr
mNADHvQoe5Sb6wnr+E9/KhZ7wTi35zq1Wd5wgbGapbrrAyeHxQyo83zhhRza
VcYDP/hw+ePpwjoW3GRgmzVSyYaVQgvmyTZ/WGZZS3QODIAVoi0cNom28sX/
ORbMgZ9NkCUfp9DS4R2KZQQXLk9diYuaRYuOmB8khV6Cn5D3jKXNo/XXdUyV
kYFwM+VptmwJTY5uZWsSg+AZ71550Be0qv7GKUbqZfh3F8eJtIrWvhB2518L
hn0pHkzRBnokwl4QnxoCG8VgfdXp6EisjjCZgf4lPCSnidDWBeotzR20WN4v
LalA0/EBnd296PwDhbrLfej3hgOBZq/QGJG2mT2Afkg1cfd6i14Pn/8wPYt2
vWJ6gjCHlsRyMxkLaFLKILHhM5qT38JL/Iaukiz01PxAL5eY7VetosWV0nYH
Nfpd7RBOsIk2btrhVm6jo9vONo5r0O2dyWqtFv0X2IEqcw==
          "]]}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox["\"Predicted\"", TraditionalForm], 
        FormBox["\"Actual\"", TraditionalForm]},
      AxesOrigin->{0, 0},
      Method->{"ScalingFunctions" -> None},
      PlotLabel->FormBox["\"CART (a1)\"", TraditionalForm],
      PlotRange->{{0, 48.075}, {0, 89.8}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.02]}},
      Ticks->{Automatic, Automatic}], {576., -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}]}, {}},
  ContentSelectable->True,
  ImageSize->600,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{{3.585682847317729*^9, 3.58568285267489*^9}, 
   3.5856829590103197`*^9, 3.585913493906961*^9, 3.5859308660796213`*^9, 
   3.585932178788351*^9, 
   3.586001121515848*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, {2}]],

Cell["Get rid of negative predictions in linear model:", "Text",
 CellChangeTimes->{{3.573912417971489*^9, 3.573912427041515*^9}, 
   3.5751134034132624`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"lmPredSensible", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Max", "[", 
      RowBox[{"#", ",", "0"}], "]"}], "&"}], "/@", "lmPredictions"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.5751134093456016`*^9, 3.575113418116103*^9}, {
  3.5751134542041674`*^9, 3.5751134743393188`*^9}, {3.585683009986537*^9, 
  3.585683019476609*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"NMSE", "[", 
    RowBox[{"#", ",", 
     RowBox[{"knnd", "[", "a1", "]"}]}], "]"}], "&"}], "/@", 
  RowBox[{"{", 
   RowBox[{"lmPredSensible", ",", "cartPredictions"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.575113790955428*^9, 3.575113822966259*^9}, {
  3.5751138775343804`*^9, 3.57511387997852*^9}, {3.585682357591795*^9, 
  3.585682403855035*^9}, {3.5856824894045773`*^9, 3.58568248990156*^9}, {
  3.5856827977795563`*^9, 3.585682801308975*^9}, {3.58568300337451*^9, 
  3.585683005687088*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.6220093308641904`", ",", "0.5988638137441327`"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.5751138234942894`*^9, 3.5751138805005503`*^9, 3.5751990550819187`*^9, 
   3.575205025742053*^9, 3.575205070068302*^9, 3.585682404556265*^9, 
   3.585682460180235*^9, 3.585682490284677*^9, {3.585682801956469*^9, 
   3.585682818099245*^9}, {3.585682951598587*^9, 3.585682957284925*^9}, {
   3.585682999187248*^9, 3.585683020402637*^9}, 3.585913577684085*^9, 
   3.585930868884571*^9, 3.585932185875127*^9, 3.586001187371868*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[TextData[{
 StyleBox["k",
  FontSlant->"Italic"],
 "-Fold Cross-Validation"
}], "Title",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQB2IQbZiQwrVk2yvHJQcPgGnXJ7fWHgXSwiH+60A0x35T
m1NA+l0bkx2IXr5vXzqIDjm6IANEn5oTuPw0kJ60fjuY/rnwzi8Q3RNl+BtE
57wx2HQGSM8427gZRPcYb8o/B6SDf8QVgOji6wcvgui2v/svgegfK1++AdEn
uIPfguhnvgYzzwPpe6nLwPSsJDn2C0Ba2ec2mJ6xJX39eyD9oPwumL5QbHX+
A5Bet+8zmGZal1X6CUh/9+YoA9FHPSWmgegPVYpg+o6CutNXkLrLlWBazdy4
7zuQjgjqB9NVb3L0fwDpoHUHwTTjPfc+2e2vHC8xVvaD6F/hgmtUgPQX51Yw
7fKcTV8VSK9aFQum44q8z4BovljZsyAaABPo2DM=
  "]],

Cell[TextData[{
 "Since the cart has the lower error metric, one could apply it to the test \
samples and obtain final predictions.  But we don\[CloseCurlyQuote]t yet know \
how well the models will generalize to the test data.  To obtain an estimate \
of how reliable they will be, we will use ",
 StyleBox["k",
  FontSlant->"Italic"],
 "-fold cross-validation.  Proceed as follows:"
}], "Text",
 CellChangeTimes->{{3.585682341692582*^9, 3.585682351172099*^9}, {
  3.585913800774098*^9, 3.585913834348152*^9}, {3.58591388518139*^9, 
  3.5859139066668158`*^9}, {3.58591394463378*^9, 3.585913995696838*^9}, {
  3.586097564417632*^9, 3.586097599623472*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 "Partition the data into ",
 StyleBox["k",
  FontSlant->"Italic"],
 " equally sized, randomly selected subsets (",
 StyleBox["k",
  FontSlant->"Italic"],
 " ~ 10)"
}], "Item",
 CellChangeTimes->{{3.5859140158163347`*^9, 3.585914043852188*^9}}],

Cell[TextData[{
 "For each subset, build a fresh model trained on the ",
 StyleBox["k",
  FontSlant->"Italic"],
 "-1 subsets and evaluate it against subset ",
 StyleBox["k",
  FontSlant->"Italic"]
}], "Item",
 CellChangeTimes->{{3.5859140158163347`*^9, 3.585914108054823*^9}, {
  3.585914164245476*^9, 3.585914164250166*^9}, {3.5860012188552933`*^9, 
  3.58600123988451*^9}}],

Cell[TextData[{
 "Rank the model using an average of the ",
 StyleBox["k ",
  FontSlant->"Italic"],
 "obtained performance measures"
}], "Item",
 CellChangeTimes->{{3.5859140158163347`*^9, 3.585914108054823*^9}, {
  3.585914164245476*^9, 3.5859142181641293`*^9}}]
}, Open  ]],

Cell["\<\
With some code for abstracting training, predicting, and evaluating, the \
cross-validation process can be automated.  Define an extended model object, \
with \[OpenCurlyDoubleQuote]methods\[CloseCurlyDoubleQuote] for training, \
predicting, and evaluating:\
\>", "Text",
 CellChangeTimes->{{3.585914310260602*^9, 3.585914315170533*^9}, {
  3.5859143512274933`*^9, 3.585914377224566*^9}, {3.585914466999098*^9, 
  3.585914488678596*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ClearAll", "[", 
   RowBox[{"extModel", ",", "cv"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"extModel", "[", "\"\<lm\>\"", "]"}], "[", 
    RowBox[{"train_", ",", "featureCols_", ",", "respCol_", ",", "test_"}], 
    "]"}], ":=", 
   RowBox[{"Module", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", "sym", "}"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"model", "[", "sym", "]"}], "^=", 
       RowBox[{"LinearModelFit", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"train", "[", "All", "]"}], "[", 
          RowBox[{"[", 
           RowBox[{"All", ",", 
            RowBox[{"Append", "[", 
             RowBox[{
              RowBox[{"Sort", "[", 
               RowBox[{"featureCols", "/.", "numberedColumns"}], "]"}], ",", 
              RowBox[{"respCol", "/.", "numberedColumns"}]}], "]"}]}], "]"}], 
          "]"}], ",", "featureCols", ",", "featureCols", ",", 
         RowBox[{"NominalVariables", "\[Rule]", 
          RowBox[{"Cases", "[", 
           RowBox[{"featureCols", ",", 
            RowBox[{"x_", "/;", 
             RowBox[{"knnd", "[", 
              RowBox[{"x", ",", "\"\<factorized\>\""}], "]"}]}]}], "]"}]}]}], 
        "]"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"predictions", "[", "sym", "]"}], "^=", 
       RowBox[{
        RowBox[{
         RowBox[{"Max", "[", 
          RowBox[{"#", ",", "0"}], "]"}], "&"}], "/@", 
        RowBox[{"With", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"dat", "=", 
            RowBox[{
             RowBox[{"test", "[", "All", "]"}], "[", 
             RowBox[{"[", 
              RowBox[{"All", ",", 
               RowBox[{"Sort", "[", 
                RowBox[{"featureCols", "/.", "numberedColumns"}], "]"}]}], 
              "]"}], "]"}]}], "}"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"Apply", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"model", "[", "sym", "]"}], "[", "\"\<Function\>\"", 
               "]"}], ",", "#"}], "]"}], "&"}], "/@", "dat"}]}], 
         "\[IndentingNewLine]", "]"}]}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"errors", "[", "sym", "]"}], "^=", 
       RowBox[{"With", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"errFns", "=", 
           RowBox[{"{", 
            RowBox[{"MAE", ",", "MSE", ",", "NMSE"}], "}"}]}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Rule", "@@@", 
          RowBox[{"Transpose", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"ToString", "/@", "errFns"}], ",", 
             RowBox[{"Through", "[", 
              RowBox[{"errFns", "[", 
               RowBox[{
                RowBox[{"predictions", "[", "sym", "]"}], ",", 
                RowBox[{"test", "[", "respCol", "]"}]}], "]"}], "]"}]}], 
            "}"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", "sym"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.575115692781206*^9, 3.5751157059129577`*^9}, {
   3.5751157384598193`*^9, 3.5751157527646375`*^9}, {3.575115810001911*^9, 
   3.5751158243787336`*^9}, {3.5751158564125657`*^9, 3.575115891312562*^9}, 
   3.5751159271266108`*^9, {3.575115960045493*^9, 3.5751160300224953`*^9}, {
   3.5751160666775923`*^9, 3.5751161989291563`*^9}, {3.575116236266292*^9, 
   3.5751163100125103`*^9}, {3.575116352949966*^9, 3.575116401054717*^9}, {
   3.575116432723529*^9, 3.5751164731378403`*^9}, {3.5751166938264627`*^9, 
   3.57511669482652*^9}, {3.5751188421913424`*^9, 3.5751188518058925`*^9}, {
   3.575119323206855*^9, 3.5751193336204505`*^9}, {3.575119485086114*^9, 
   3.575119516178892*^9}, {3.575119769054356*^9, 3.5751198128268595`*^9}, {
   3.5751203168096857`*^9, 3.575120325156163*^9}, {3.5752007867287407`*^9, 
   3.575200930523264*^9}, {3.575200993859744*^9, 3.5752010037255783`*^9}, {
   3.575201059024069*^9, 3.575201406569312*^9}, 3.575201452730028*^9, {
   3.575201490874508*^9, 3.575201493512888*^9}, {3.575201636586318*^9, 
   3.57520173080519*^9}, {3.575201788019074*^9, 3.575201789284211*^9}, {
   3.575201837146035*^9, 3.5752018420160637`*^9}, {3.575201872378064*^9, 
   3.5752019153731403`*^9}, {3.5752019712790956`*^9, 
   3.5752020624356833`*^9}, {3.575204470227686*^9, 3.575204471241847*^9}, {
   3.575204509645301*^9, 3.575204551080563*^9}, {3.575204598988826*^9, 
   3.575204738960697*^9}, {3.575205100526782*^9, 3.575205103886634*^9}, {
   3.5752051656772757`*^9, 3.575205202956105*^9}, {3.57520557430993*^9, 
   3.5752055895270767`*^9}, {3.575205631464884*^9, 3.575205661926387*^9}, {
   3.575283781458016*^9, 3.57528380152071*^9}, {3.5752838806540623`*^9, 
   3.575283979100778*^9}, {3.575284064342329*^9, 3.575284065647543*^9}, {
   3.575284107462329*^9, 3.575284109483384*^9}, {3.575284159053138*^9, 
   3.575284309468638*^9}, {3.575284352349062*^9, 3.575284356928845*^9}, {
   3.575284389117112*^9, 3.575284565913199*^9}, {3.575284598021409*^9, 
   3.575284709642083*^9}, {3.575284752369431*^9, 3.575284791257079*^9}, {
   3.57528488054242*^9, 3.575284885882057*^9}, {3.57528492147311*^9, 
   3.57528492701751*^9}, 3.585914391927726*^9, 3.5859144403379803`*^9, {
   3.585914598218178*^9, 3.585914600542294*^9}}],

Cell["\<\
The cross-validator object, which invokes the extended model:\
\>", "Text",
 CellChangeTimes->{{3.585914724473989*^9, 3.5859147279698067`*^9}, {
  3.5860232509089727`*^9, 3.586023262611685*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"cv", "[", "\"\<lm\>\"", "]"}], "[", "args__", "]"}], ":=", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"em", "=", 
       RowBox[{
        RowBox[{"extModel", "[", "\"\<lm\>\"", "]"}], "[", "args", "]"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"errors", "[", "em", "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", 
        RowBox[{"-", "1"}]}], "]"}], "]"}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.575115692781206*^9, 3.5751157059129577`*^9}, {
   3.5751157384598193`*^9, 3.5751157527646375`*^9}, {3.575115810001911*^9, 
   3.5751158243787336`*^9}, {3.5751158564125657`*^9, 3.575115891312562*^9}, 
   3.5751159271266108`*^9, {3.575115960045493*^9, 3.5751160300224953`*^9}, {
   3.5751160666775923`*^9, 3.5751161989291563`*^9}, {3.575116236266292*^9, 
   3.5751163100125103`*^9}, {3.575116352949966*^9, 3.575116401054717*^9}, {
   3.575116432723529*^9, 3.5751164731378403`*^9}, {3.5751166938264627`*^9, 
   3.57511669482652*^9}, {3.5751188421913424`*^9, 3.5751188518058925`*^9}, {
   3.575119323206855*^9, 3.5751193336204505`*^9}, {3.575119485086114*^9, 
   3.575119516178892*^9}, {3.575119769054356*^9, 3.5751198128268595`*^9}, {
   3.5751203168096857`*^9, 3.575120325156163*^9}, {3.5752007867287407`*^9, 
   3.575200930523264*^9}, {3.575200993859744*^9, 3.5752010037255783`*^9}, {
   3.575201059024069*^9, 3.575201406569312*^9}, 3.575201452730028*^9, {
   3.575201490874508*^9, 3.575201493512888*^9}, {3.575201636586318*^9, 
   3.57520173080519*^9}, {3.575201788019074*^9, 3.575201789284211*^9}, {
   3.575201837146035*^9, 3.5752018420160637`*^9}, {3.575201872378064*^9, 
   3.5752019153731403`*^9}, {3.5752019712790956`*^9, 
   3.5752020624356833`*^9}, {3.575204470227686*^9, 3.575204471241847*^9}, {
   3.575204509645301*^9, 3.575204551080563*^9}, {3.575204598988826*^9, 
   3.575204738960697*^9}, {3.575205100526782*^9, 3.575205103886634*^9}, {
   3.5752051656772757`*^9, 3.575205202956105*^9}, {3.57520557430993*^9, 
   3.5752055895270767`*^9}, {3.575205631464884*^9, 3.575205661926387*^9}, {
   3.575283781458016*^9, 3.57528380152071*^9}, {3.5752838806540623`*^9, 
   3.575283979100778*^9}, {3.575284064342329*^9, 3.575284065647543*^9}, {
   3.575284107462329*^9, 3.575284109483384*^9}, {3.575284159053138*^9, 
   3.575284309468638*^9}, {3.575284352349062*^9, 3.575284356928845*^9}, {
   3.575284389117112*^9, 3.575284565913199*^9}, {3.575284598021409*^9, 
   3.575284709642083*^9}, {3.575284752369431*^9, 3.575284791257079*^9}, {
   3.57528488054242*^9, 3.575284885882057*^9}, {3.57528492147311*^9, 
   3.57528492701751*^9}, 3.585914391927726*^9, 3.585914737851542*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"cv", "[", "\"\<lm\>\"", "]"}], "[", 
  RowBox[{"knnd", ",", "featureColumns", ",", "a1", ",", "knnd"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.575204789172112*^9, 3.575204789395969*^9}, {
  3.575204824371477*^9, 3.5752048399966097`*^9}, {3.575205124269883*^9, 
  3.575205146533536*^9}, {3.5752052919492893`*^9, 3.575205295766346*^9}, {
  3.575284009433564*^9, 3.5752840100642233`*^9}, {3.57528448553822*^9, 
  3.575284485698284*^9}, {3.5859170595585423`*^9, 3.5859170627728863`*^9}, {
  3.585917166393785*^9, 3.585917199576527*^9}, {3.585917268002615*^9, 
  3.585917269425392*^9}, {3.5859322381199837`*^9, 3.585932242108611*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "12.25172964586424`", ",", "280.5179211618862`", ",", 
   "0.6143999705152242`"}], "}"}]], "Output",
 CellChangeTimes->{{3.575205297381505*^9, 3.575205320358654*^9}, {
   3.575284003832045*^9, 3.5752840103871317`*^9}, 3.575284073664839*^9, 
   3.575284209691087*^9, 3.575284339111714*^9, 3.575284409954358*^9, 
   3.57528444206032*^9, {3.5752844774872217`*^9, 3.575284487416718*^9}, 
   3.5758024903830147`*^9, 3.575802586763587*^9, 3.585916055502829*^9, {
   3.585917064265423*^9, 3.585917086918026*^9}, 3.5859172156218777`*^9, {
   3.5859172625244913`*^9, 3.5859172758867817`*^9}, 3.5859322132546062`*^9, 
   3.5859322438199987`*^9, 3.585932291476077*^9, 3.585935967105472*^9, 
   3.5860013173142548`*^9, {3.586002061898184*^9, 3.586002081279583*^9}, 
   3.586086604471381*^9, 3.586090109517571*^9, 3.586092285502261*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Similar definitions for cart", "Subsubsection",
 CellChangeTimes->{{3.5859151087069807`*^9, 3.58591511289744*^9}},
 FontColor->GrayLevel[0.5]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"extModel", "[", "\"\<cart\>\"", "]"}], "[", 
     RowBox[{
     "n_", ",", "train_", ",", "featureCols_", ",", "respCol_", ",", 
      "test_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"sym", ",", "denomTrain", ",", "denomTest"}], "}"}], ",", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"denomTrain", "=", 
        RowBox[{"Transpose", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"train", "[", "#", "]"}], "/.", 
            RowBox[{
             RowBox[{"x_List", "/;", 
              RowBox[{"train", "[", 
               RowBox[{"#", ",", "\"\<factorized\>\""}], "]"}]}], 
             "\[RuleDelayed]", 
             RowBox[{"denominalizeVect", "[", 
              RowBox[{"train", ",", "#"}], "]"}]}]}], "&"}], "/@", 
          RowBox[{"Append", "[", 
           RowBox[{"featureCols", ",", "respCol"}], "]"}]}], 
         "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"model", "[", "sym", "]"}], "^=", 
        RowBox[{"cart", "[", 
         RowBox[{
          RowBox[{"Transpose", "@", 
           RowBox[{"denomTrain", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", 
              RowBox[{"1", ";;", 
               RowBox[{"-", "2"}]}]}], "]"}], "]"}]}], ",", 
          RowBox[{"denomTrain", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", 
             RowBox[{"-", "1"}]}], "]"}], "]"}], ",", "n", ",", 
          RowBox[{"\"\<MinSplit\>\"", "\[Rule]", "15"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"denomTest", "=", 
        RowBox[{"Transpose", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"test", "[", "#", "]"}], "/.", 
            RowBox[{
             RowBox[{"x_List", "/;", 
              RowBox[{"test", "[", 
               RowBox[{"#", ",", "\"\<factorized\>\""}], "]"}]}], 
             "\[RuleDelayed]", 
             RowBox[{"denominalizeVect", "[", 
              RowBox[{"test", ",", "#"}], "]"}]}]}], "&"}], "/@", 
          RowBox[{"Append", "[", 
           RowBox[{"featureCols", ",", "respCol"}], "]"}]}], 
         "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"predictions", "[", "sym", "]"}], "^=", 
        RowBox[{"With", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"dat", "=", "denomTest"}], "}"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"classify", "[", 
             RowBox[{
              RowBox[{"#", "[", 
               RowBox[{"[", 
                RowBox[{"1", ";;", 
                 RowBox[{"-", "2"}]}], "]"}], "]"}], ",", 
              RowBox[{"model", "[", "sym", "]"}]}], "]"}], "&"}], "/@", 
           "dat"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"errors", "[", "sym", "]"}], "^=", 
        RowBox[{"With", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"errFns", "=", 
            RowBox[{"{", 
             RowBox[{"MAE", ",", "MSE", ",", "NMSE"}], "}"}]}], "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"Rule", "@@@", 
           RowBox[{"Transpose", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"ToString", "/@", "errFns"}], ",", 
              RowBox[{"Through", "[", 
               RowBox[{"errFns", "[", 
                RowBox[{
                 RowBox[{"predictions", "[", "sym", "]"}], ",", 
                 RowBox[{"test", "[", "respCol", "]"}]}], "]"}], "]"}]}], 
             "}"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", "sym"}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"cv", "[", 
     RowBox[{"\"\<cart\>\"", ",", "3"}], "]"}], "[", "args__", "]"}], ":=", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"em", "=", 
       RowBox[{
        RowBox[{"extModel", "[", "\"\<cart\>\"", "]"}], "[", 
        RowBox[{"3", ",", "args"}], "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"errors", "[", "em", "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", 
        RowBox[{"-", "1"}]}], "]"}], "]"}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"cv", "[", 
     RowBox[{"\"\<cart\>\"", ",", "4"}], "]"}], "[", "args__", "]"}], ":=", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"em", "=", 
       RowBox[{
        RowBox[{"extModel", "[", "\"\<cart\>\"", "]"}], "[", 
        RowBox[{"4", ",", "args"}], "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"errors", "[", "em", "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", 
        RowBox[{"-", "1"}]}], "]"}], "]"}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"cv", "[", 
     RowBox[{"\"\<cart\>\"", ",", "5"}], "]"}], "[", "args__", "]"}], ":=", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"em", "=", 
       RowBox[{
        RowBox[{"extModel", "[", "\"\<cart\>\"", "]"}], "[", 
        RowBox[{"5", ",", "args"}], "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"errors", "[", "em", "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", 
        RowBox[{"-", "1"}]}], "]"}], "]"}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.575115692781206*^9, 3.5751157059129577`*^9}, {
   3.5751157384598193`*^9, 3.5751157527646375`*^9}, {3.575115810001911*^9, 
   3.5751158243787336`*^9}, {3.5751158564125657`*^9, 3.575115891312562*^9}, 
   3.5751159271266108`*^9, {3.575115960045493*^9, 3.5751160300224953`*^9}, {
   3.5751160666775923`*^9, 3.5751161989291563`*^9}, {3.575116236266292*^9, 
   3.5751163100125103`*^9}, {3.575116352949966*^9, 3.575116401054717*^9}, {
   3.575116432723529*^9, 3.5751164731378403`*^9}, {3.5751166938264627`*^9, 
   3.57511669482652*^9}, {3.5751188421913424`*^9, 3.5751188518058925`*^9}, {
   3.575119323206855*^9, 3.5751193336204505`*^9}, {3.575119485086114*^9, 
   3.575119516178892*^9}, {3.575119769054356*^9, 3.5751198128268595`*^9}, {
   3.5751203168096857`*^9, 3.575120325156163*^9}, {3.5752007867287407`*^9, 
   3.575200930523264*^9}, {3.575200993859744*^9, 3.5752010037255783`*^9}, {
   3.575201059024069*^9, 3.575201406569312*^9}, 3.575201452730028*^9, {
   3.575201490874508*^9, 3.575201493512888*^9}, {3.575201636586318*^9, 
   3.57520173080519*^9}, {3.575201788019074*^9, 3.575201789284211*^9}, {
   3.575201837146035*^9, 3.5752018420160637`*^9}, {3.575201872378064*^9, 
   3.5752019153731403`*^9}, {3.5752019712790956`*^9, 
   3.5752020624356833`*^9}, {3.575204470227686*^9, 3.575204471241847*^9}, {
   3.575204509645301*^9, 3.575204551080563*^9}, {3.575204598988826*^9, 
   3.575204738960697*^9}, {3.575205100526782*^9, 3.575205103886634*^9}, {
   3.5752051656772757`*^9, 3.575205202956105*^9}, {3.57520557430993*^9, 
   3.5752055895270767`*^9}, {3.575205631464884*^9, 3.575205661926387*^9}, {
   3.575283781458016*^9, 3.57528380152071*^9}, {3.5752838806540623`*^9, 
   3.575283979100778*^9}, {3.575284064342329*^9, 3.575284065647543*^9}, {
   3.575284107462329*^9, 3.575284109483384*^9}, {3.575284159053138*^9, 
   3.575284309468638*^9}, {3.575284352349062*^9, 3.575284356928845*^9}, {
   3.575284389117112*^9, 3.575284565913199*^9}, {3.575284598021409*^9, 
   3.575284709642083*^9}, {3.575284752369431*^9, 3.575284791257079*^9}, {
   3.57528488054242*^9, 3.575284885882057*^9}, {3.57528492147311*^9, 
   3.57528492701751*^9}, 3.585914391927726*^9, {3.585914737851542*^9, 
   3.585914774355695*^9}, {3.585915162589676*^9, 3.585915166475917*^9}, {
   3.585930884173903*^9, 3.5859309023877707`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"cv", "[", 
   RowBox[{"\"\<cart\>\"", ",", "3"}], "]"}], "[", 
  RowBox[{"knnd", ",", "featureColumns", ",", "a1", ",", "knnd"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.575204789172112*^9, 3.575204789395969*^9}, {
  3.575204824371477*^9, 3.5752048399966097`*^9}, {3.575205124269883*^9, 
  3.575205146533536*^9}, {3.5859309056422462`*^9, 3.585930905856979*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "12.007001362834693`", ",", "278.328824702763`", ",", 
   "0.6096053363814424`"}], "}"}]], "Output",
 CellChangeTimes->{{3.575205194636039*^9, 3.575205207717312*^9}, 
   3.575205318607133*^9, 3.575205425824239*^9, 3.57528479781806*^9, 
   3.5758024881106358`*^9, {3.5859159992105703`*^9, 3.585916021721816*^9}, {
   3.585925576655478*^9, 3.585925629632226*^9}, 3.5859309061086607`*^9, {
   3.5859313025825853`*^9, 3.5859313046422997`*^9}, {3.585932299921013*^9, 
   3.585932305058011*^9}, 3.5859359473605347`*^9, 3.5860013372636127`*^9, 
   3.58600208683156*^9, 3.586086604668591*^9, 3.5860901114394283`*^9, 
   3.586092287827544*^9}]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[TextData[{
 StyleBox["k",
  FontSlant->"Italic"],
 "-Fold CV Code"
}], "Title",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGCQBGIQbZiQwrVk2yvHJQcPgGnXJ7fWHgXSwiH+60A0x35T
m1NA+l0bkx2IXr5vXzqIDjm6IANEn5oTuPw0kJ60fjuY/rnwzi8Q3RNl+BtE
57wx2HQGSM8427gZRPcYb8o/B6SDf8QVgOji6wcvgui2v/svgegfK1++AdEn
uIPfguhnvgYzzwPpe6nLwPSsJDn2C0Ba2ec2mJ6xJX39eyD9oPwumL5QbHX+
A5Bet+8zmGZal1X6CUh/9+YoA9FHPSWmgegPVYpg+o6CutNXkLrLlWBazdy4
7zuQjgjqB9NVb3L0fwDpoHUHwTTjPfc+2e2vHC8xVvaD6F/hgmtUgPQX51Yw
7fKcTV8VSK9aFQum44q8z4BovljZsyDaYeskw+lAOsfrJpiO0c+xANG75swF
0wAsROjr
  "]],

Cell[TextData[{
 "Here is the code that partitions the training set and runs the extended \
models to collect the error measurements.  ",
 StyleBox["n",
  FontSlant->"Italic"],
 " is the number of times to run the ",
 StyleBox["k-",
  FontSlant->"Italic"],
 "fold cycle for each test.  The full ",
 StyleBox["n",
  FontSlant->"Italic"],
 " x ",
 StyleBox["k",
  FontSlant->"Italic"],
 " list of MAE, MSE, and NMSE is returned for each test."
}], "Text",
 CellChangeTimes->{{3.585682341692582*^9, 3.585682351172099*^9}, {
  3.585913800774098*^9, 3.585913834348152*^9}, {3.58591388518139*^9, 
  3.5859139066668158`*^9}, {3.58591394463378*^9, 3.585913995696838*^9}, {
  3.585915353237781*^9, 3.5859153643644533`*^9}, {3.585915458299107*^9, 
  3.58591549783431*^9}, {3.585916586595639*^9, 3.5859165954676332`*^9}, {
  3.58591733689398*^9, 3.585917399307212*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "@", "kFoldCV"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"kFoldCV", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"set_", ",", "featureCols_", ",", "respCol_"}], "}"}], ",", 
    "tests_List", ",", 
    RowBox[{"{", 
     RowBox[{"n_", ",", "k_"}], "}"}], ",", 
    RowBox[{"o", ":", 
     RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"len", "=", 
       RowBox[{"Length", "@", 
        RowBox[{"set", "[", "All", "]"}]}]}], ",", "\[IndentingNewLine]", 
      "rowSets", ",", "\[IndentingNewLine]", "runKTests", ",", "runNReps"}], 
     "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rowSets", "=", 
      RowBox[{"Table", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Partition", "[", 
         RowBox[{
          RowBox[{"RandomSample", "[", 
           RowBox[{"Range", "[", "len", "]"}], "]"}], ",", 
          RowBox[{"Ceiling", "[", 
           RowBox[{"len", "/", "k"}], "]"}], ",", 
          RowBox[{"Ceiling", "[", 
           RowBox[{"len", "/", "k"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "1"}], "}"}], ",", 
          RowBox[{"{", "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", "n", "}"}]}], "\[IndentingNewLine]", "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"runNReps", "[", "test_", "]"}], ":=", 
      RowBox[{"Table", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"PrintTemporary", "[", 
          RowBox[{"StringForm", "[", 
           RowBox[{"\"\<\\tn=``\>\"", ",", "i"}], "]"}], "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"runKTests", "[", 
          RowBox[{"test", ",", 
           RowBox[{"rowSets", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{"Length", "@", "rowSets"}]}], "}"}]}], 
       "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"runKTests", "[", 
       RowBox[{"test_", ",", "rowSet_"}], "]"}], ":=", 
      RowBox[{"Table", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"PrintTemporary", "[", 
          RowBox[{"StringForm", "[", 
           RowBox[{"\"\<\\t\\tk=``\>\"", ",", "i"}], "]"}], "]"}], ";", 
         RowBox[{"test", "[", 
          RowBox[{
           RowBox[{"columnize", "@", 
            RowBox[{
             RowBox[{"set", "[", "All", "]"}], "[", 
             RowBox[{"[", 
              RowBox[{"Join", "@@", 
               RowBox[{"rowSet", "[", 
                RowBox[{"[", 
                 RowBox[{"Complement", "[", 
                  RowBox[{
                   RowBox[{"Range", "[", "k", "]"}], ",", 
                   RowBox[{"{", "i", "}"}]}], "]"}], "]"}], "]"}]}], "]"}], 
             "]"}]}], ",", "featureCols", ",", "respCol", ",", 
           RowBox[{"columnize", "@", 
            RowBox[{
             RowBox[{"set", "[", "All", "]"}], "[", 
             RowBox[{"[", 
              RowBox[{"rowSet", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "]"}], "]"}]}]}], "]"}]}], ",",
         "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{"Length", "@", "rowSet"}]}], "}"}]}], "\[IndentingNewLine]",
        "]"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"Flatten", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"PrintTemporary", "[", "i", "]"}], ";", 
          RowBox[{"Rule", "[", 
           RowBox[{"i", ",", 
            RowBox[{"runNReps", "[", "i", "]"}]}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "tests"}], "}"}]}], "]"}], ",", "1"}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]}], "Input",
 CellChangeTimes->{{3.575116481107296*^9, 3.5751164885357213`*^9}, {
   3.5751166085805874`*^9, 3.575116637547244*^9}, {3.5751166805307026`*^9, 
   3.5751168389287624`*^9}, {3.5751168760708866`*^9, 
   3.5751169493230762`*^9}, {3.575116990971459*^9, 3.575117029144642*^9}, {
   3.5751170947513943`*^9, 3.575117107631131*^9}, {3.575117155429865*^9, 
   3.575117226875952*^9}, {3.575117293937787*^9, 3.575117375037426*^9}, {
   3.5751175386077814`*^9, 3.5751178935030804`*^9}, {3.575117939542714*^9, 
   3.5751179567877007`*^9}, {3.57511800433142*^9, 3.575118012362879*^9}, {
   3.5751180670650077`*^9, 3.5751181120805826`*^9}, {3.5751182480813613`*^9, 
   3.5751182625821905`*^9}, {3.575118389065425*^9, 3.5751184147518945`*^9}, {
   3.5751189474173613`*^9, 3.5751189593030405`*^9}, {3.57511900019238*^9, 
   3.5751190661581526`*^9}, {3.5751191142609043`*^9, 3.575119117966116*^9}, {
   3.57511916384274*^9, 3.575119164390771*^9}, {3.575119418490305*^9, 
   3.5751194218584976`*^9}, {3.5751195295466566`*^9, 3.575119531051743*^9}, {
   3.575119574612234*^9, 3.575119575091262*^9}, {3.5751196339486284`*^9, 
   3.575119637836851*^9}, {3.5751198355901613`*^9, 3.5751198813837805`*^9}, {
   3.5751199161157675`*^9, 3.5751200253040123`*^9}, {3.575120071383648*^9, 
   3.5751200732037525`*^9}, {3.575120129012944*^9, 3.575120174986574*^9}, {
   3.5751202371301284`*^9, 3.575120280256595*^9}, {3.575199516415925*^9, 
   3.575199587035076*^9}, {3.575199617586554*^9, 3.575199651849677*^9}, {
   3.575200101159553*^9, 3.575200158900522*^9}, {3.575200196173571*^9, 
   3.575200270817779*^9}, {3.575200391339127*^9, 3.575200540694903*^9}, {
   3.575200623172915*^9, 3.575200650892511*^9}, {3.575205514836486*^9, 
   3.575205520099257*^9}, {3.575205556644393*^9, 3.575205557459525*^9}, {
   3.5752056163985777`*^9, 3.575205616577387*^9}, {3.5859153053259783`*^9, 
   3.585915310588962*^9}, {3.585915384271233*^9, 3.585915386945084*^9}, {
   3.585915600367258*^9, 3.585915626518285*^9}, {3.5859158154044437`*^9, 
   3.585915817961484*^9}, {3.58591585120928*^9, 3.585915852135866*^9}, {
   3.585915904614317*^9, 3.5859159191178217`*^9}, {3.585916696046438*^9, 
   3.585916700975851*^9}, {3.585916785079624*^9, 3.5859167877578497`*^9}, {
   3.5859170011382627`*^9, 3.5859170144567957`*^9}, 3.5859174472573233`*^9}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Display code", "Subsubsection",
 FontColor->GrayLevel[0.5]]], "Subsubsection",
 CellChangeTimes->{{3.585916143060746*^9, 3.585916155084043*^9}, {
  3.5859161904038277`*^9, 3.585916195931849*^9}, {3.586015911625136*^9, 
  3.58601591600878*^9}},
 FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{"kFoldSummary", "[", "exp_", "]"}], ":=", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"nmses", "=", 
       RowBox[{"Flatten", "@", 
        RowBox[{"exp", "[", 
         RowBox[{"[", 
          RowBox[{"2", ",", "All", ",", "All", ",", 
           RowBox[{"-", "1"}]}], "]"}], "]"}]}]}], ",", "stats"}], "}"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"stats", "=", 
      RowBox[{"Through", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Mean", ",", "StandardDeviation", ",", "Min", ",", "Max"}], 
         "}"}], "[", "nmses", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Labeled", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"TableForm", "[", 
        RowBox[{
         RowBox[{"List", "/@", "stats"}], ",", 
         RowBox[{"TableHeadings", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "\[Mu]", ",", "\[Sigma]", ",", "\"\<min\>\"", ",", 
              "\"\<max\>\""}], "}"}], ",", 
            RowBox[{"{", "\"\<nmse\>\"", "}"}]}], "}"}]}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"First", "@", "exp"}], ",", "Top"}], "\[IndentingNewLine]", 
      "]"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.575202329077186*^9, 3.5752023783305893`*^9}, {
  3.5752024131509943`*^9, 3.575202414503291*^9}, {3.57520245297442*^9, 
  3.575202501301868*^9}, {3.57520264147648*^9, 3.575202720209605*^9}, {
  3.575202769027657*^9, 3.5752027979689074`*^9}, {3.585916096870625*^9, 
  3.585916127718877*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"kFoldPlot", "[", 
   RowBox[{"exps_", ",", "on_", ",", 
    RowBox[{"o", ":", 
     RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
  RowBox[{"BoxWhiskerChart", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Reverse", "[", 
     RowBox[{"Flatten", "/@", 
      RowBox[{"exps", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2", ",", "All", ",", "All", ",", 
         RowBox[{"-", "1"}]}], "]"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"\"\<Outliers\>\"", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<MedianMarker\>\"", ",", "White"}], "}"}]}], "}"}], ",", 
    "\[IndentingNewLine]", "o", ",", "\[IndentingNewLine]", 
    RowBox[{"BarOrigin", "\[Rule]", "Left"}], ",", "\[IndentingNewLine]", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<nmse\>\"", ",", "None"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"None", ",", "None"}], "}"}]}], "}"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"ChartLabels", "\[Rule]", 
     RowBox[{"Reverse", "@", 
      RowBox[{"exps", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "1"}], "]"}], "]"}]}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"PlotLabel", "\[Rule]", 
     RowBox[{"Style", "[", 
      RowBox[{"on", ",", 
       RowBox[{"{", 
        RowBox[{"Bold", ",", "14"}], "}"}]}], "]"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.5752040302150373`*^9, 3.575204059982134*^9}, {
  3.575204106827948*^9, 3.575204147995029*^9}, {3.5752041883478413`*^9, 
  3.5752042250622597`*^9}, {3.575204305968876*^9, 3.575204336207652*^9}, {
  3.575204378660935*^9, 3.575204403917767*^9}, {3.575205772739799*^9, 
  3.575205804728078*^9}, {3.585916166623145*^9, 3.585916170206801*^9}}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[TextData[{
 StyleBox["k",
  FontSlant->"Italic"],
 "-Fold CV Usage"
}], "Title",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGCQAmIQbZiQwrVk2yvHJQcPgGnXJ7fWHgXSwiH+60A0x35T
m1NA+l0bkx2IXr5vXzqIDjm6IANEn5oTuPw0kJ60fjuY/rnwzi8Q3RNl+BtE
57wx2HQGSM8427gZRPcYb8o/B6SDf8QVgOji6wcvgui2v/svgegfK1++AdEn
uIPfguhnvgYzzwPpe6nLwPSsJDn2C0Ba2ec2mJ6xJX39eyD9oPwumL5QbHX+
A5Bet+8zmGZal1X6CUh/9+YoA9FHPSWmgegPVYpg+o6CutNXkLrLlWBazdy4
7zuQjgjqB9NVb3L0fwDpoHUHwTTjPfc+2e2vHC8xVvaD6F/hgmtUgPQX51Yw
7fKcTV8VSK9aFQum44q8z4BovljZsyDaYeskw+lAOsfrJpiO0c+xANG75swF
0zxy9ctAdFPUATANAP6I8W8=
  "]],

Cell["\<\
Run a 10-fold cross-validation using a linear model (with no backward \
elimination) and three different carts, running three trials of each:\
\>", "Text",
 CellChangeTimes->{{3.585916252202721*^9, 3.585916316097372*^9}, {
  3.5860014374816847`*^9, 3.586001458822781*^9}}],

Cell[BoxData[
 RowBox[{"res", "=", 
  RowBox[{"kFoldCV", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"knnd", ",", "featureColumns", ",", "a1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"cv", "[", "\"\<lm\>\"", "]"}], ",", 
      RowBox[{"cv", "[", 
       RowBox[{"\"\<cart\>\"", ",", "3"}], "]"}], ",", 
      RowBox[{"cv", "[", 
       RowBox[{"\"\<cart\>\"", ",", "4"}], "]"}], ",", 
      RowBox[{"cv", "[", 
       RowBox[{"\"\<cart\>\"", ",", "5"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"3", ",", "10"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5859162432698517`*^9, 3.585916245075495*^9}, {
  3.5859164809221992`*^9, 3.585916481246986*^9}, {3.585930921963593*^9, 
  3.585930925913803*^9}, {3.585932328821278*^9, 3.585932330981736*^9}, {
  3.586001449838482*^9, 3.586001449937509*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"stylize", "@", 
  RowBox[{"Row", "[", 
   RowBox[{
    RowBox[{"kFoldSummary", "/@", "res"}], ",", 
    RowBox[{"Spacer", "[", "16", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.575202380448728*^9, 3.5752023832084837`*^9}, {
  3.575202738048008*^9, 3.575202759343534*^9}, {3.5859176354320097`*^9, 
  3.585917636854928*^9}}],

Cell[BoxData[
 StyleBox[
  TemplateBox[{InterpretationBox[
     StyleBox[
      GraphicsBox[{}, ImageSize -> {16, 0}, BaselinePosition -> Baseline], 
      "CacheGraphics" -> False], 
     Spacer[16]],TemplateBox[{
      TagBox[
       TagBox[
        GridBox[{{
           StyleBox["\[Null]", ShowStringCharacters -> False], 
           TagBox["\"nmse\"", HoldForm]}, {
           TagBox["\[Mu]", HoldForm], "0.7617280234013598`"}, {
           TagBox["\[Sigma]", HoldForm], "0.1948843200794089`"}, {
           TagBox["\"min\"", HoldForm], "0.32585044906255745`"}, {
           TagBox["\"max\"", HoldForm], "1.369198865623719`"}}, 
         GridBoxAlignment -> {
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
         GridBoxDividers -> {
          "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
           "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}}, 
         GridBoxSpacings -> {"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[2.0999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}], {
        OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}], 
       Function[BoxForm`e$, 
        TableForm[
        BoxForm`e$, 
         TableHeadings -> {{$CellContext`\[Mu], $CellContext`\[Sigma], "min", 
            "max"}, {"nmse"}}]]], 
      RowBox[{"cv", "[", "\"lm\"", "]"}]}, "Labeled", 
     DisplayFunction -> (GridBox[{{
         ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
         TagBox[
          ItemBox[
           PaneBox[
            TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
            BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
          "SkipImageSizeLevel"]}}, 
       GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
       AutoDelete -> False, 
       GridBoxItemSize -> {
        "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
       BaselinePosition -> {2, 1}]& ), 
     InterpretationFunction -> (RowBox[{"Labeled", "[", 
        RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )],TemplateBox[{
      TagBox[
       TagBox[
        GridBox[{{
           StyleBox["\[Null]", ShowStringCharacters -> False], 
           TagBox["\"nmse\"", HoldForm]}, {
           TagBox["\[Mu]", HoldForm], "0.6626557636553905`"}, {
           TagBox["\[Sigma]", HoldForm], "0.24372491431047663`"}, {
           TagBox["\"min\"", HoldForm], "0.2715645034353851`"}, {
           TagBox["\"max\"", HoldForm], "1.3772276847194604`"}}, 
         GridBoxAlignment -> {
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
         GridBoxDividers -> {
          "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
           "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}}, 
         GridBoxSpacings -> {"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[2.0999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}], {
        OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}], 
       Function[BoxForm`e$, 
        TableForm[
        BoxForm`e$, 
         TableHeadings -> {{$CellContext`\[Mu], $CellContext`\[Sigma], "min", 
            "max"}, {"nmse"}}]]], 
      RowBox[{"cv", "[", 
        RowBox[{"\"cart\"", ",", "3"}], "]"}]}, "Labeled", 
     DisplayFunction -> (GridBox[{{
         ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
         TagBox[
          ItemBox[
           PaneBox[
            TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
            BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
          "SkipImageSizeLevel"]}}, 
       GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
       AutoDelete -> False, 
       GridBoxItemSize -> {
        "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
       BaselinePosition -> {2, 1}]& ), 
     InterpretationFunction -> (RowBox[{"Labeled", "[", 
        RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )],TemplateBox[{
      TagBox[
       TagBox[
        GridBox[{{
           StyleBox["\[Null]", ShowStringCharacters -> False], 
           TagBox["\"nmse\"", HoldForm]}, {
           TagBox["\[Mu]", HoldForm], "0.6968573798854937`"}, {
           TagBox["\[Sigma]", HoldForm], "0.27161119476860324`"}, {
           TagBox["\"min\"", HoldForm], "0.34923989935545124`"}, {
           TagBox["\"max\"", HoldForm], "1.3567794013628733`"}}, 
         GridBoxAlignment -> {
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
         GridBoxDividers -> {
          "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
           "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}}, 
         GridBoxSpacings -> {"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[2.0999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}], {
        OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}], 
       Function[BoxForm`e$, 
        TableForm[
        BoxForm`e$, 
         TableHeadings -> {{$CellContext`\[Mu], $CellContext`\[Sigma], "min", 
            "max"}, {"nmse"}}]]], 
      RowBox[{"cv", "[", 
        RowBox[{"\"cart\"", ",", "4"}], "]"}]}, "Labeled", 
     DisplayFunction -> (GridBox[{{
         ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
         TagBox[
          ItemBox[
           PaneBox[
            TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
            BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
          "SkipImageSizeLevel"]}}, 
       GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
       AutoDelete -> False, 
       GridBoxItemSize -> {
        "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
       BaselinePosition -> {2, 1}]& ), 
     InterpretationFunction -> (RowBox[{"Labeled", "[", 
        RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )],TemplateBox[{
      TagBox[
       TagBox[
        GridBox[{{
           StyleBox["\[Null]", ShowStringCharacters -> False], 
           TagBox["\"nmse\"", HoldForm]}, {
           TagBox["\[Mu]", HoldForm], "0.6900605628330886`"}, {
           TagBox["\[Sigma]", HoldForm], "0.18083734934489754`"}, {
           TagBox["\"min\"", HoldForm], "0.35987651474202303`"}, {
           TagBox["\"max\"", HoldForm], "1.198364446335784`"}}, 
         GridBoxAlignment -> {
          "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
         GridBoxDividers -> {
          "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
           "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}}, 
         GridBoxSpacings -> {"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[2.0999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}], {
        OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}], 
       Function[BoxForm`e$, 
        TableForm[
        BoxForm`e$, 
         TableHeadings -> {{$CellContext`\[Mu], $CellContext`\[Sigma], "min", 
            "max"}, {"nmse"}}]]], 
      RowBox[{"cv", "[", 
        RowBox[{"\"cart\"", ",", "5"}], "]"}]}, "Labeled", 
     DisplayFunction -> (GridBox[{{
         ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
         TagBox[
          ItemBox[
           PaneBox[
            TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
            BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
          "SkipImageSizeLevel"]}}, 
       GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
       AutoDelete -> False, 
       GridBoxItemSize -> {
        "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
       BaselinePosition -> {2, 1}]& ), 
     InterpretationFunction -> (RowBox[{"Labeled", "[", 
        RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )]},
   "RowWithSeparator"],
  StripOnInput->False,
  FontFamily->"Verdana"]], "Output",
 CellChangeTimes->{
  3.575202383554494*^9, 3.5752024152790747`*^9, {3.575202455072196*^9, 
   3.575202502240987*^9}, {3.5752026599957533`*^9, 3.575202798928913*^9}, 
   3.575205710085339*^9, 3.575287203640963*^9, 3.575802668539609*^9, 
   3.5758091986076803`*^9, {3.585917632903892*^9, 3.585917637278246*^9}, 
   3.5859256443560753`*^9, 3.585930931737535*^9, 3.5859323378733788`*^9, 
   3.585935990222251*^9, 3.586001476894022*^9, 3.5860021183993483`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"kFoldPlot", "[", 
  RowBox[{"res", ",", "a1"}], "]"}]], "Input",
 CellChangeTimes->{{3.575204352019581*^9, 3.575204360620916*^9}}],

Cell[BoxData[
 GraphicsBox[{
   {Opacity[0], 
    PointBox[{{0.2162813443711813, 0.5161520709916578}, {1.4325108437836642`, 
     4.483847929008342}}]}, 
   {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], {}, 
    {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
     {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
      TagBox[
       TooltipBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          GraphicsGroupBox[{Antialiasing -> False, 
            
            PolygonBox[{{0.7848978705650616, 0.7312248802544821}, {
             0.7848978705650616, 1.268775119745518}, {0.5972851704302709, 
             1.268775119745518}, {0.5972851704302709, 
             0.7312248802544821}}], {}, {{
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox["\"\[FilledSmallCircle]\"", 10, 
                  GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
               1.198364446335784, 1.}]}, {}}, {}, {
             GrayLevel[0], 
             GrayLevel[1], 
             
             LineBox[{{0.6762407113304832, 1.268775119745518}, {
              0.6762407113304832, 0.7312248802544821}}]}, {}, {
             GrayLevel[0], 
             GrayLevel[0.5], 
             
             LineBox[{{{0.5972851704302709, 1.}, {0.35987651474202303`, 
              1.}}, {{0.7848978705650616, 1.}, {0.9459098081966116, 1.}}}]}, {
             GrayLevel[0], 
             GrayLevel[0.5], 
             
             LineBox[{{{0.35987651474202303`, 1.134387559872759}, {
              0.35987651474202303`, 0.865612440127241}}, {{0.9459098081966116,
               1.134387559872759}, {0.9459098081966116, 
              0.865612440127241}}}]}, {}}]},
         ImageSizeCache->{{83.5857864376269, 295.21595928897443`}, {
          80.58578643762688, 124.4142135623731}}],
        StyleBox[
         TagBox[
          GridBox[{{
             StyleBox["\"max\"", Bold, StripOnInput -> False], 
             "1.198364446335784`"}, {
             StyleBox["\"75%\"", Bold, StripOnInput -> False], 
             "0.7848978705650616`"}, {
             StyleBox["\"median\"", Bold, StripOnInput -> False], 
             "0.6762407113304832`"}, {
             StyleBox["\"25%\"", Bold, StripOnInput -> False], 
             "0.5972851704302709`"}, {
             StyleBox["\"min\"", Bold, StripOnInput -> False], 
             "0.35987651474202303`"}}, 
           GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
           AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}, "Rows" -> {
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}}, 
           GridBoxFrame -> {
            "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, BaseStyle -> 
           Directive[
             AbsoluteThickness[1], 
             Dashing[{}]]], "Grid"], {
          GrayLevel[0]}, StripOnInput -> False]],
       Annotation[#, 
        Style[
         Grid[{{
            Style["max", Bold], 1.198364446335784}, {
            Style["75%", Bold], 0.7848978705650616}, {
            Style["median", Bold], 0.6762407113304832}, {
            Style["25%", Bold], 0.5972851704302709}, {
            Style["min", Bold], 0.35987651474202303`}}, Dividers -> {{
             Directive[
              GrayLevel[0.3]], {
              Directive[
               GrayLevel[0.3]]}, 
             Directive[
              GrayLevel[0.3]]}, {
             Directive[
              GrayLevel[0.3]], {
              Directive[
               GrayLevel[0.3]]}, 
             Directive[
              GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, Frame -> 
          GrayLevel[0], BaseStyle -> Directive[
            AbsoluteThickness[1], 
            Dashing[{}]]], {
          GrayLevel[0]}], "Tooltip"]& ]}, 
     {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
      TagBox[
       TooltipBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          GraphicsGroupBox[{Antialiasing -> False, 
            
            PolygonBox[{{0.7765354383580564, 1.731224880254482}, {
             0.7765354383580564, 2.2687751197455177`}, {0.46700897895650656`, 
             2.2687751197455177`}, {0.46700897895650656`, 
             1.731224880254482}}], {}, {{
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox["\"\[FilledSmallCircle]\"", 10, 
                  GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
               1.299752439832302, 2.}], 
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox["\"\[FilledSmallCircle]\"", 10, 
                  GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
               1.3567794013628733`, 2.}]}, {}}, {}, {
             GrayLevel[0], 
             GrayLevel[1], 
             
             LineBox[{{0.6582218343898603, 2.2687751197455177`}, {
              0.6582218343898603, 1.7312248802544823`}}]}, {}, {
             GrayLevel[0], 
             GrayLevel[0.5], 
             
             LineBox[{{{0.46700897895650656`, 2.}, {0.34923989935545124`, 
              2.}}, {{0.7765354383580564, 2.}, {1.2121041077280112`, 2.}}}]}, {
             GrayLevel[0], 
             GrayLevel[0.5], 
             
             LineBox[{{{0.34923989935545124`, 2.134387559872759}, {
              0.34923989935545124`, 1.8656124401272411`}}, {{
              1.2121041077280112`, 2.134387559872759}, {1.2121041077280112`, 
              1.8656124401272411`}}}]}, {}}]},
         ImageSizeCache->{{80.5857864376269, 334.10366016757916`}, {
          5.585786437626886, 49.41421356237311}}],
        StyleBox[
         TagBox[
          GridBox[{{
             StyleBox["\"max\"", Bold, StripOnInput -> False], 
             "1.3567794013628733`"}, {
             StyleBox["\"75%\"", Bold, StripOnInput -> False], 
             "0.7765354383580564`"}, {
             StyleBox["\"median\"", Bold, StripOnInput -> False], 
             "0.6582218343898603`"}, {
             StyleBox["\"25%\"", Bold, StripOnInput -> False], 
             "0.46700897895650656`"}, {
             StyleBox["\"min\"", Bold, StripOnInput -> False], 
             "0.34923989935545124`"}}, 
           GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
           AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}, "Rows" -> {
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}}, 
           GridBoxFrame -> {
            "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, BaseStyle -> 
           Directive[
             AbsoluteThickness[1], 
             Dashing[{}]]], "Grid"], {
          GrayLevel[0]}, StripOnInput -> False]],
       Annotation[#, 
        Style[
         Grid[{{
            Style["max", Bold], 1.3567794013628733`}, {
            Style["75%", Bold], 0.7765354383580564}, {
            Style["median", Bold], 0.6582218343898603}, {
            Style["25%", Bold], 0.46700897895650656`}, {
            Style["min", Bold], 0.34923989935545124`}}, Dividers -> {{
             Directive[
              GrayLevel[0.3]], {
              Directive[
               GrayLevel[0.3]]}, 
             Directive[
              GrayLevel[0.3]]}, {
             Directive[
              GrayLevel[0.3]], {
              Directive[
               GrayLevel[0.3]]}, 
             Directive[
              GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, Frame -> 
          GrayLevel[0], BaseStyle -> Directive[
            AbsoluteThickness[1], 
            Dashing[{}]]], {
          GrayLevel[0]}], "Tooltip"]& ]}, 
     {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
      TagBox[
       TooltipBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          GraphicsGroupBox[{Antialiasing -> False, 
            
            PolygonBox[{{0.8168908300264969, 2.7312248802544823`}, {
             0.8168908300264969, 3.2687751197455177`}, {0.4881473659942235, 
             3.2687751197455177`}, {0.4881473659942235, 
             2.7312248802544823`}}], {}, {{
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox["\"\[FilledSmallCircle]\"", 10, 
                  GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
               1.3772276847194604`, 3.}]}, {}}, {}, {
             GrayLevel[0], 
             GrayLevel[1], 
             
             LineBox[{{0.5954883794786959, 3.2687751197455177`}, {
              0.5954883794786959, 2.7312248802544823`}}]}, {}, {
             GrayLevel[0], 
             GrayLevel[0.5], 
             
             LineBox[{{{0.4881473659942235, 3.}, {0.2715645034353851, 3.}}, {{
              0.8168908300264969, 3.}, {1.0012485913332356`, 3.}}}]}, {
             GrayLevel[0], 
             GrayLevel[0.5], 
             
             LineBox[{{{0.2715645034353851, 3.134387559872759}, {
              0.2715645034353851, 2.865612440127241}}, {{1.0012485913332356`, 
              3.134387559872759}, {1.0012485913332356`, 
              2.865612440127241}}}]}, {}}]},
         ImageSizeCache->{{61.58578643762689, 
          339.12330447146405`}, {-69.4142135623731, -25.585786437626894`}}],
        StyleBox[
         TagBox[
          GridBox[{{
             StyleBox["\"max\"", Bold, StripOnInput -> False], 
             "1.3772276847194604`"}, {
             StyleBox["\"75%\"", Bold, StripOnInput -> False], 
             "0.8168908300264969`"}, {
             StyleBox["\"median\"", Bold, StripOnInput -> False], 
             "0.5954883794786959`"}, {
             StyleBox["\"25%\"", Bold, StripOnInput -> False], 
             "0.4881473659942235`"}, {
             StyleBox["\"min\"", Bold, StripOnInput -> False], 
             "0.2715645034353851`"}}, 
           GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
           AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}, "Rows" -> {
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}}, 
           GridBoxFrame -> {
            "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, BaseStyle -> 
           Directive[
             AbsoluteThickness[1], 
             Dashing[{}]]], "Grid"], {
          GrayLevel[0]}, StripOnInput -> False]],
       Annotation[#, 
        Style[
         Grid[{{
            Style["max", Bold], 1.3772276847194604`}, {
            Style["75%", Bold], 0.8168908300264969}, {
            Style["median", Bold], 0.5954883794786959}, {
            Style["25%", Bold], 0.4881473659942235}, {
            Style["min", Bold], 0.2715645034353851}}, Dividers -> {{
             Directive[
              GrayLevel[0.3]], {
              Directive[
               GrayLevel[0.3]]}, 
             Directive[
              GrayLevel[0.3]]}, {
             Directive[
              GrayLevel[0.3]], {
              Directive[
               GrayLevel[0.3]]}, 
             Directive[
              GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, Frame -> 
          GrayLevel[0], BaseStyle -> Directive[
            AbsoluteThickness[1], 
            Dashing[{}]]], {
          GrayLevel[0]}], "Tooltip"]& ]}, 
     {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
      TagBox[
       TooltipBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          GraphicsGroupBox[{Antialiasing -> False, 
            
            PolygonBox[{{0.841328479581149, 3.7312248802544823`}, {
             0.841328479581149, 4.268775119745518}, {0.6430011580704299, 
             4.268775119745518}, {0.6430011580704299, 
             3.7312248802544823`}}], {}, {{
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox["\"\[FilledSmallCircle]\"", 10, 
                  GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
               0.32585044906255745`, 4.}], 
              InsetBox[
               BoxData[
                FormBox[
                 StyleBox["\"\[FilledSmallCircle]\"", 10, 
                  GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
               1.369198865623719, 4.}]}, {}}, {}, {
             GrayLevel[0], 
             GrayLevel[1], 
             LineBox[{{0.7402003209604644, 4.268775119745518}, {
              0.7402003209604644, 3.731224880254482}}]}, {}, {
             GrayLevel[0], 
             GrayLevel[0.5], 
             
             LineBox[{{{0.6430011580704299, 4.}, {0.4273679238227365, 4.}}, {{
              0.841328479581149, 4.}, {1.1153997500648378`, 4.}}}]}, {
             GrayLevel[0], 
             GrayLevel[0.5], 
             
             LineBox[{{{0.4273679238227365, 4.134387559872759}, {
              0.4273679238227365, 3.865612440127241}}, {{1.1153997500648378`, 
              4.134387559872759}, {1.1153997500648378`, 
              3.865612440127241}}}]}, {}}]},
         ImageSizeCache->{{73.2028086792842, 
          337.1523900754701}, {-145.4142135623731, -101.5857864376269}}],
        StyleBox[
         TagBox[
          GridBox[{{
             StyleBox["\"max\"", Bold, StripOnInput -> False], 
             "1.369198865623719`"}, {
             StyleBox["\"75%\"", Bold, StripOnInput -> False], 
             "0.841328479581149`"}, {
             StyleBox["\"median\"", Bold, StripOnInput -> False], 
             "0.7402003209604644`"}, {
             StyleBox["\"25%\"", Bold, StripOnInput -> False], 
             "0.6430011580704299`"}, {
             StyleBox["\"min\"", Bold, StripOnInput -> False], 
             "0.32585044906255745`"}}, 
           GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
           AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}, "Rows" -> {
               Directive[
                GrayLevel[0.3]], {
                Directive[
                 GrayLevel[0.3]]}, 
               Directive[
                GrayLevel[0.3]]}}, 
           GridBoxFrame -> {
            "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
           GridBoxItemSize -> {
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, BaseStyle -> 
           Directive[
             AbsoluteThickness[1], 
             Dashing[{}]]], "Grid"], {
          GrayLevel[0]}, StripOnInput -> False]],
       Annotation[#, 
        Style[
         Grid[{{
            Style["max", Bold], 1.369198865623719}, {
            Style["75%", Bold], 0.841328479581149}, {
            Style["median", Bold], 0.7402003209604644}, {
            Style["25%", Bold], 0.6430011580704299}, {
            Style["min", Bold], 0.32585044906255745`}}, Dividers -> {{
             Directive[
              GrayLevel[0.3]], {
              Directive[
               GrayLevel[0.3]]}, 
             Directive[
              GrayLevel[0.3]]}, {
             Directive[
              GrayLevel[0.3]], {
              Directive[
               GrayLevel[0.3]]}, 
             Directive[
              GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, Frame -> 
          GrayLevel[0], BaseStyle -> Directive[
            AbsoluteThickness[1], 
            Dashing[{}]]], {
          GrayLevel[0]}], 
        "Tooltip"]& ]}}, {}, {}}, {{{{{{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, \
{}}, {}}, {{{}, {}}, {}}}, {}}, {}}, {}}, {}},
  AspectRatio->1,
  Axes->{False, False},
  Frame->True,
  FrameLabel->{{None, None}, {
     FormBox["\"nmse\"", TraditionalForm], None}},
  FrameTicks->{{{{0.7312248802544821, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0, 0}}, {4.268775119745518, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0, 0}}, {1., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.008, 0}}, {1., 
       FormBox[
        RowBox[{"cv", "(", 
          RowBox[{"\"cart\"", ",", "5"}], ")"}], TraditionalForm], 0}, {2., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.008, 0}}, {2., 
       FormBox[
        RowBox[{"cv", "(", 
          RowBox[{"\"cart\"", ",", "4"}], ")"}], TraditionalForm], 0}, {3., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.008, 0}}, {3., 
       FormBox[
        RowBox[{"cv", "(", 
          RowBox[{"\"cart\"", ",", "3"}], ")"}], TraditionalForm], 0}, {4., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.008, 0}}, {4., 
       FormBox[
        RowBox[{"cv", "(", "\"lm\"", ")"}], TraditionalForm], 0}}, {{
      0.7312248802544821, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0, 0}}, {4.268775119745518, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0, 0}}, {1., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.008, 0}}, {2., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.008, 0}}, {3., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.008, 0}}, {4., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.008, 0}}}}, {Automatic, Automatic}},
  PlotLabel->FormBox[
    StyleBox["a1", {Bold, 14}, StripOnInput -> False], TraditionalForm],
  PlotRangePadding->Scaled[0.02],
  Ticks->{Automatic, None}]], "Output",
 CellChangeTimes->{{3.5752043555829287`*^9, 3.575204405019704*^9}, 
   3.575205731510289*^9, {3.5752057844302053`*^9, 3.575205805625552*^9}, 
   3.5752185130187063`*^9, 3.575802680029696*^9, 3.585917669731484*^9, 
   3.585925648222267*^9, 3.585930932710834*^9, 3.585932338718549*^9, 
   3.585935991192631*^9, 3.586001479166417*^9, 3.586002119773347*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[TextData[{
 StyleBox["k",
  FontSlant->"Italic"],
 "-Fold CV Evaluation"
}], "Title",
 CellChangeTimes->CompressedData["
1:eJwdyk0ow3EYwPGZYiElxQ62vMtpW0tekrwmb8m2omVLy0y2miw0F1F20lY7
MExRy7L4r2asHGY7rDQbMwdhloOI5iUvbSbleX6Hb5/Lt0imFsjpNBqtAEJ5
Q8MZloPnJovXQ2y7v971gbmiXgplHFXV+8FXHb0BtbrdClTk2xhF/eY+6wlo
tLuIP5uRJLoo5v2iqhjXEQBNwbk9dJHvUJ+CwoR0HNVces9R3d9RGE1sP8XQ
40zhC/rQw105A6PyLeKqjJ0eAku6b4gmp8L+Bt5N3xJDmrqzd5ByfxLp1Njk
BxjvYkyhvg7mEvo+U0SMFFY0f+N3oSWWV/P1cXBAYCDOxFScBCigvMSUaLue
5XpuCqdoDWiyP2enFPxqWSC2PqZxykCbTUKUTnQF0GwJK4g27ht5y6Cq84o4
yFHVoIfmdWIWe3YLnRd7iMq62hETyHcyFWjxmjLPDDpTK/PRfyLEAE8=
  "]],

Cell["\<\
So far we have only run the cv for a1.  Run for all seven response columns \
(this can take a while):\
\>", "Text",
 CellChangeTimes->{{3.585916252202721*^9, 3.585916316097372*^9}, {
  3.5859177547645617`*^9, 3.585917788066825*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"resAll7", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"kFoldCV", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"knnd", ",", "featureColumns", ",", "i"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"cv", "[", "\"\<lm\>\"", "]"}], ",", 
         RowBox[{"cv", "[", 
          RowBox[{"\"\<cart\>\"", ",", "3"}], "]"}], ",", 
         RowBox[{"cv", "[", 
          RowBox[{"\"\<cart\>\"", ",", "4"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "10"}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "responseColumns"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5752059712648687`*^9, 3.57520600549887*^9}, {
  3.575287566768364*^9, 3.57528757104804*^9}, {3.585917815637092*^9, 
  3.585917817571607*^9}, {3.585930959169977*^9, 3.585930966679776*^9}, {
  3.585935826758726*^9, 3.585935826909891*^9}, {3.586001597562798*^9, 
  3.586001599462123*^9}, {3.586001957640867*^9, 3.586001959550753*^9}}],

Cell[CellGroupData[{

Cell["Canned cv results", "Subsubsection",
 CellChangeTimes->{{3.586086763535236*^9, 3.586086780494688*^9}},
 FontColor->GrayLevel[0.5]],

Cell[BoxData[
 RowBox[{
  RowBox[{"resAll7", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"cv", "[", "\"\<lm\>\"", "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "9.860512858722718`", ",", "192.33295229862918`", ",", 
              "0.46050844494620624`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "13.074630280794882`", ",", "285.58580457813093`", ",", 
              "0.5624145059703256`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "13.757435156633104`", ",", "431.41445843707`", ",", 
              "0.6970647004904658`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "11.310430942747404`", ",", "215.29301208585383`", ",", 
              "0.545022281542521`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "15.689255824724322`", ",", "464.64949700255255`", ",", 
              "0.75081763021978`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "13.169247151722413`", ",", "323.26653211055185`", ",", 
              "0.856683587969258`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "14.829626281168254`", ",", "430.2328338302092`", ",", 
              "0.6623098723710807`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "12.526132542730348`", ",", "301.27250217113925`", ",", 
              "1.442040303134387`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "10.524735282069297`", ",", "238.88996411195004`", ",", 
              "1.0728802807388453`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "16.549501364367732`", ",", "331.1468024562553`", ",", 
              "0.8188920503664064`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "13.704530001744484`", ",", "383.5149938744836`", ",", 
              "0.6203260173031578`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "12.10619427628725`", ",", "209.62299318821516`", ",", 
              "0.674927373378759`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "18.857074146475433`", ",", "769.5093105631806`", ",", 
              "0.8070905963841527`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "11.358448966251492`", ",", "194.7011790405645`", ",", 
              "0.5649079644883785`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "12.191987178989303`", ",", "301.53281686091793`", ",", 
              "0.5292906891899103`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "12.359915591288706`", ",", "224.91113985339425`", ",", 
              "1.882979656022813`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "16.5645536207764`", ",", "385.5933998179979`", ",", 
              "1.004778511906928`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "12.260991226941538`", ",", "266.7841092716807`", ",", 
              "0.9595994953949811`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "11.855540541356271`", ",", "273.37043416137425`", ",", 
              "1.1187640133242027`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "10.986966261966781`", ",", "263.2242567188682`", ",", 
              "0.5722943803662303`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "12.750378664537658`", ",", "320.74379161793865`", ",", 
              "0.8641810281257332`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "17.721372778648064`", ",", "494.986560238086`", ",", 
              "0.8408693657206829`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.990256193064043`", ",", "216.58904507614346`", ",", 
              "0.5990720830006938`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "13.06490655522219`", ",", "318.57276630390527`", ",", 
              "0.7137252548019944`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "10.96065877047391`", ",", "219.78732061231273`", ",", 
              "0.5991743038417323`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "17.321950490872577`", ",", "409.61534180339123`", ",", 
              "1.0855528341869318`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.27510114511266`", ",", "144.41303889126007`", ",", 
              "0.45279420015242827`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "12.87193922970736`", ",", "255.6469737715168`", ",", 
              "2.0191453718670984`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "15.653663532767728`", ",", "494.70993572610615`", ",", 
              "0.6183874969560698`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "13.987504338995949`", ",", "358.3182603318479`", ",", 
              "0.6210380616994303`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<cart\>\"", ",", "3"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "11.837075036075031`", ",", "340.8111994834385`", ",", 
              "0.8160142795015378`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "16.293802503052504`", ",", "444.75030871458`", ",", 
              "0.8758629495795835`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "14.651981906981911`", ",", "553.8174277300136`", ",", 
              "0.8948392244098474`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.10803175990676`", ",", "146.11865058562867`", ",", 
              "0.36990480808701776`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "14.38470833333333`", ",", "361.7719439779384`", ",", 
              "0.5845798938980161`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "11.192977106227106`", ",", "229.83990909933573`", ",", 
              "0.6090951534642951`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "12.814917124542125`", ",", "395.36292140593343`", ",", 
              "0.6086303634370249`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.30878354978355`", ",", "126.91879589498637`", ",", 
              "0.6074965939038507`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "11.02112644300144`", ",", "302.0101159050597`", ",", 
              "1.3563596074146804`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.962464387464387`", ",", "188.69395119045032`", ",", 
              "0.46662077192334867`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "18.833442488067487`", ",", "635.9799068076729`", ",", 
              "1.0286817698813457`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "10.13696581196581`", ",", "184.55625769669072`", ",", 
              "0.5942195002243849`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "17.17499630924631`", ",", "638.9280109708232`", ",", 
              "0.6701319689602934`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.701804334554334`", ",", "134.6166658639003`", ",", 
              "0.39057815198717666`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "11.810804653679655`", ",", "267.626486952778`", ",", 
              "0.46977376857142394`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "11.126188034188033`", ",", "238.30793646301086`", ",", 
              "1.9951390425619886`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "13.281717032967032`", ",", "250.84647308173663`", ",", 
              "0.6536552390656459`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.905320374070374`", ",", "185.7814798222806`", ",", 
              "0.6682400041662355`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "11.713170260295259`", ",", "258.6634052838489`", ",", 
              "1.0585757391182864`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "15.028401320901322`", ",", "479.20723506400896`", ",", 
              "1.0418781729180702`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "12.218549783549783`", ",", "326.3702128527662`", ",", 
              "0.879340312933258`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "16.94779725829726`", ",", "544.6767203209702`", ",", 
              "0.925281624048175`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "11.608000915750917`", ",", "326.72893914326147`", ",", 
              "0.9037123095507845`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "12.930488344988342`", ",", "353.46600977518943`", ",", 
              "0.7918995111150804`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "11.794744047619048`", ",", "216.65405261991367`", ",", 
              "0.5906325296262541`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "16.545302197802197`", ",", "415.10401630890146`", ",", 
              "1.1000987887870555`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.35054079254079`", ",", "185.87549656746063`", ",", 
              "0.5827960372717589`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "11.701607142857142`", ",", "217.2635647911943`", ",", 
              "1.7159863653053118`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "15.764105436230437`", ",", "559.5445230101411`", ",", 
              "0.699430741191519`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "11.598650115316781`", ",", "271.68913258480853`", ",", 
              "0.4708922512880153`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<cart\>\"", ",", "4"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "11.356462759462756`", ",", "224.65400939149717`", ",", 
              "0.5378957026312237`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "13.433359307359307`", ",", "323.6263533120136`", ",", 
              "0.6373291413619931`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "14.864481060606062`", ",", "655.8127327791108`", ",", 
              "1.0596397436670237`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.274865426240424`", ",", "133.09645786545144`", ",", 
              "0.3369386420313953`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "14.971178751803752`", ",", "344.8903057523369`", ",", 
              "0.5573011995519762`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "14.975076479076478`", ",", "366.58950121866906`", ",", 
              "0.9714931117845188`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "12.783248348873347`", ",", "363.7203579515482`", ",", 
              "0.5599191063802508`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.451222319347318`", ",", "149.94826550486277`", ",", 
              "0.7177271097920399`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "11.030804112554113`", ",", "322.6768686277665`", ",", 
              "1.449176195777962`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "10.571657046657045`", ",", "175.28723063452503`", ",", 
              "0.43346732818390205`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "13.491350871350871`", ",", "419.1152631746183`", ",", 
              "0.6779085724120723`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "11.1411254023754`", ",", "172.4638318801097`", ",", 
              "0.5552852732580018`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "17.935580808080807`", ",", "791.0264254082256`", ",", 
              "0.8296585638075018`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.578647435897437`", ",", "125.25840304176711`", ",", 
              "0.36342599385413776`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "13.224952020202021`", ",", "423.32135648599353`", ",", 
              "0.7430702066058268`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.802803030303028`", ",", "207.41273612947666`", ",", 
              "1.7364811844642758`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "12.716753246753246`", ",", "257.487443493514`", ",", 
              "0.6709602665145419`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "14.10492216117216`", ",", "304.04166786712227`", ",", 
              "1.0936117292024534`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.398337121212121`", ",", "190.14466653782137`", ",", 
              "0.7781639258123637`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "12.265730719897384`", ",", "266.67346669593667`", ",", 
              "0.5797935505080142`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "12.502303113553113`", ",", "319.4210093583305`", ",", 
              "0.8606170516343149`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "15.833110139860143`", ",", "530.7721048991681`", ",", 
              "0.9016608511029521`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "10.723344155844158`", ",", "260.56143690646024`", ",", 
              "0.7206970357264867`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.8220260989011`", ",", "244.5217795015135`", ",", 
              "0.5478226259079177`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.347076465201465`", ",", "120.63312730331901`", ",", 
              "0.3288646036124798`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "13.520224622599619`", ",", "280.25704219761144`", ",", 
              "0.7427305459776724`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.455846681096681`", ",", "81.47231545396501`", ",", 
              "0.2554491768456028`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.689237762237763`", ",", "173.40306374612183`", ",", 
              "1.3695683092399158`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "15.88257683982684`", ",", "573.814449415186`", ",", 
              "0.7172681514275014`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "15.05603280978281`", ",", "397.63224662318345`", ",", 
              "0.689177156317263`"}], "}"}]}], "}"}]}], "}"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"cv", "[", "\"\<lm\>\"", "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "7.450740930403645`", ",", "235.07138330550805`", ",", 
              "0.8884330279771728`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.798678117409008`", ",", "127.94994322412325`", ",", 
              "0.918288231204361`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.05876696052582`", ",", "88.33179554284963`", ",", 
              "1.091681802701028`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.827475193597434`", ",", "29.491124046215713`", ",", 
              "3.3160312639810776`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.525663378443599`", ",", "157.43902777773405`", ",", 
              "1.2056939045435433`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.423241917127591`", ",", "170.57912808507382`", ",", 
              "8.291246370802774`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.306936220325777`", ",", "148.2054697391962`", ",", 
              "0.8012437186619029`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.600437010238692`", ",", "57.570762248984146`", ",", 
              "0.7145088204615161`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.152859584077362`", ",", "130.0784825251051`", ",", 
              "0.7476785727789064`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.184807823135277`", ",", "49.73237341049975`", ",", 
              "0.7077199066317483`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "6.524916661704519`", ",", "87.29687708919923`", ",", 
              "1.0092092434295639`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.973595900259356`", ",", "127.79895839672724`", ",", 
              "0.8122838815265231`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.692250196991902`", ",", "117.3589193500608`", ",", 
              "0.7911200363480456`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.811065631302458`", ",", "109.10383981433071`", ",", 
              "0.9769914942884114`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.788820228478796`", ",", "50.848490720217214`", ",", 
              "0.9446932251356646`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.579612756825054`", ",", "31.05209013823056`", ",", 
              "0.628713363222654`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.639904135935879`", ",", "137.4382093632626`", ",", 
              "3.816151225382917`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.830303781171862`", ",", "96.56197234768305`", ",", 
              "1.1740589144940983`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "11.52435355277073`", ",", "389.523319667866`", ",", 
              "1.0029389105616562`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.6629875556904414`", ",", "26.939679974431368`", ",", 
              "0.7379261631972447`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "9.48200537825117`", ",", "318.66865360929444`", ",", 
              "1.1087355912927843`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.17468028555121`", ",", "95.51475102773381`", ",", 
              "1.0684302293077035`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.365752485562624`", ",", "162.06171974283822`", ",", 
              "0.8182518811317625`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.626789677195521`", ",", "115.1580684958299`", ",", 
              "1.3314014257752922`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.660836027394629`", ",", "49.94758005258408`", ",", 
              "0.7003365150658037`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.685238380787804`", ",", "38.435684287202506`", ",", 
              "0.745360064212155`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.968618819762147`", ",", "99.11662970224427`", ",", 
              "0.8270160219130341`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.351547120649859`", ",", "136.27982706576535`", ",", 
              "1.139432235996592`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.587947317292955`", ",", "38.93275832777296`", ",", 
              "0.5438867310437782`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.8124105443536465`", ",", "58.36071701886907`", ",", 
              "0.6552484795704687`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<cart\>\"", ",", "3"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "8.194717712842714`", ",", "191.7082670131074`", ",", 
              "0.72454568376516`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.948268398268397`", ",", "89.88814543596263`", ",", 
              "0.645121240374791`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.799122904872904`", ",", "55.203982922185574`", ",", 
              "0.6822592388437724`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.8652457264957265`", ",", "44.077176847925344`", ",", 
              "4.956111412596317`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.070525793650793`", ",", "142.51497578860182`", ",", 
              "1.0914030659352751`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.762572011322012`", ",", "63.240721165396714`", ",", 
              "3.0739071405502596`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.818573717948718`", ",", "155.04625288126937`", ",", 
              "0.838227067069757`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.96558694083694`", ",", "75.07204733424223`", ",", 
              "0.9317166890797421`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.975802128427127`", ",", "141.02816073933585`", ",", 
              "0.8106162671667869`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.936101891935226`", ",", "76.16748820302072`", ",", 
              "1.0839065973078188`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "7.255751498501496`", ",", "89.06156327551705`", ",", 
              "1.0296101749447275`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.82238553113553`", ",", "170.8521990993262`", ",", 
              "1.0859281577313467`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.998499000998999`", ",", "125.20264803535072`", ",", 
              "0.8439948494170154`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.4180517399267405`", ",", "92.66387323401378`", ",", 
              "0.8297766250162697`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.187474358974359`", ",", "64.53489998191979`", ",", 
              "1.1989674016713256`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.478052156177156`", ",", "55.00026265941938`", ",", 
              "1.1135933188651805`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.568097222222223`", ",", "53.6629948431426`", ",", 
              "1.4900230763855933`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.61887665112665`", ",", "64.78872122237385`", ",", 
              "0.7877404930785483`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "12.061497113997117`", ",", "387.69995518444597`", ",", 
              "0.9982441385256264`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.932192868859535`", ",", "55.91217809858827`", ",", 
              "1.531534862309111`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "10.78743512043512`", ",", "294.98270953624194`", ",", 
              "1.0263256996711199`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.042970071595072`", ",", "52.09877327208037`", ",", 
              "0.5827780910780601`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.11850015262515`", ",", "177.66031247777195`", ",", 
              "0.8970093931995178`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.516178418803419`", ",", "84.93471936566405`", ",", 
              "0.9819738029503715`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.298235389610388`", ",", "77.82063499615239`", ",", 
              "1.0911566137145348`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.976460705960706`", ",", "39.39181540988178`", ",", 
              "0.7639017389139827`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.375664987789987`", ",", "112.9975176491743`", ",", 
              "0.9428363112527425`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.161619769119769`", ",", "108.69801540203623`", ",", 
              "0.9088213964210945`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.007821095571094`", ",", "94.52310188308562`", ",", 
              "1.3204782578848475`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.273549382716051`", ",", "100.75031188341592`", ",", 
              "1.1311802193334002`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<cart\>\"", ",", "4"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "10.474795412920413`", ",", "321.56000772376433`", ",", 
              "1.215309695808869`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.99238961038961`", ",", "114.13290697419464`", ",", 
              "0.8191242811570482`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.097958333333333`", ",", "87.47625079459367`", ",", 
              "1.0811082303273702`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.409435786435784`", ",", "99.5460761104059`", ",", 
              "11.193127127723159`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.076584415584414`", ",", "149.52642782500325`", ",", 
              "1.1450979159455479`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.428258075258076`", ",", "68.84606726187788`", ",", 
              "3.346363132096682`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.194279914529915`", ",", "165.1713080804458`", ",", 
              "0.8929661863055135`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.632585678210677`", ",", "82.92097609467626`", ",", 
              "1.0291294835508304`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.189847222222223`", ",", "157.24620792115456`", ",", 
              "0.9038360382985948`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.2299505741172405`", ",", "62.91464152919308`", ",", 
              "0.8953110655163283`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "6.750312298812299`", ",", "96.28545127608967`", ",", 
              "1.1131230655173023`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.04130586080586`", ",", "136.45038904627228`", ",", 
              "0.867271948385055`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.488047161172162`", ",", "126.27417022331974`", ",", 
              "0.8512180129991991`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.255466006216004`", ",", "112.17370600905129`", ",", 
              "1.0044812065290578`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.006672161172162`", ",", "71.12413980281698`", ",", 
              "1.3213861820407644`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.931598484848485`", ",", "55.80518708446296`", ",", 
              "1.1298906676155036`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.9162402181152185`", ",", "56.98292749360007`", ",", 
              "1.5822053385885713`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.11081105006105`", ",", "91.39983932751568`", ",", 
              "1.1112945762895123`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "12.491854256854257`", ",", "435.31170686811026`", ",", 
              "1.1208341760213603`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.335008016674685`", ",", "48.22940801861088`", ",", 
              "1.321090007239374`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "10.793233405483404`", ",", "323.32194642178064`", ",", 
              "1.124925672430278`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.797678418803419`", ",", "89.8805311489352`", ",", 
              "1.0054057145358761`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.196472763347765`", ",", "158.30274694798624`", ",", 
              "0.7992727751134414`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.786261322011322`", ",", "89.85008928836189`", ",", 
              "1.0388029127884708`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.329718115218116`", ",", "63.015162149136515`", ",", 
              "0.883562707329794`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.715279040404041`", ",", "33.083394925138016`", ",", 
              "0.6415663418790073`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.541654761904763`", ",", "131.88370150706973`", ",", 
              "1.1004201263017037`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.532358058608059`", ",", "119.39364409449679`", ",", 
              "0.9982472812261766`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.205673076923077`", ",", "93.73428330882892`", ",", 
              "1.3094585414772115`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.46590708674042`", ",", "121.82148856602106`", ",", 
              "1.3677581297722614`"}], "}"}]}], "}"}]}], "}"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"cv", "[", "\"\<lm\>\"", "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "4.582648544754285`", ",", "47.289700318232185`", ",", 
              "0.9640944471606471`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.09415934609497`", ",", "28.516603886814032`", ",", 
              "0.8980730664663935`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.581839108576264`", ",", "51.8389185007213`", ",", 
              "1.2608128326553762`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.141629514203153`", ",", "26.369482913098505`", ",", 
              "0.7412722869372727`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.71089596719297`", ",", "45.66867798328046`", ",", 
              "0.9295008644136173`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.669600695932348`", ",", "26.195988914803763`", ",", 
              "0.9289357771207005`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.864257882874885`", ",", "41.67814223224882`", ",", 
              "1.2602520535494568`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.037368824363636`", ",", "107.54067401254254`", ",", 
              "1.0042561931004512`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.021824082395752`", ",", "17.365617669225294`", ",", 
              "0.7263244092879761`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.364175003607569`", ",", "62.55135159430641`", ",", 
              "0.7687484321513532`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "4.402947358972449`", ",", "39.73395057469093`", ",", 
              "0.9565019191854517`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.148638645831036`", ",", "30.770473298963406`", ",", 
              "0.7370367434582324`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.518214106239408`", ",", "80.31836023985117`", ",", 
              "0.9513789500723282`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.276819419864961`", ",", "124.50183592244204`", ",", 
              "1.0763993280811763`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.531363925937682`", ",", "18.320242892727403`", ",", 
              "1.4020799712797374`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.056520508445336`", ",", "34.47041506318907`", ",", 
              "0.9206970734282215`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.616260292862388`", ",", "28.593446885773755`", ",", 
              "0.6475364905505097`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.8640860717222916`", ",", "24.793783875771865`", ",", 
              "1.2260266592050768`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.9428679032967455`", ",", "40.06220379133151`", ",", 
              "1.3160401653116842`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.226712338401652`", ",", "34.81520516464284`", ",", 
              "1.1534237254293627`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "5.47998387115924`", ",", "60.04033268539823`", ",", 
              "0.9480641326997925`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.8628807082268657`", ",", "12.266120848017868`", ",", 
              "3.09026732791703`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.532530416801968`", ",", "112.07688451049066`", ",", 
              "0.9977919812124537`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.5027556366495367`", ",", "20.09468562491154`", ",", 
              "1.8388423782164498`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.044622554187241`", ",", "44.56831328129046`", ",", 
              "0.9104330089150118`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.129250748140193`", ",", "38.441335320806814`", ",", 
              "1.0860392113438793`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.200662434627115`", ",", "30.64841043374568`", ",", 
              "0.7136752849754406`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.287429242364106`", ",", "17.32945196567667`", ",", 
              "1.1697332556418245`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.5467417965878596`", ",", "25.87380204557103`", ",", 
              "0.6827202958874202`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.977012738924647`", ",", "90.87388261973129`", ",", 
              "0.9652146052087496`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<cart\>\"", ",", "3"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "5.320664835164836`", ",", "56.860594874285525`", ",", 
              "1.1592161382214297`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.745211538461539`", ",", "45.728297604372116`", ",", 
              "1.4401207316568185`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.034869047619048`", ",", "43.9179025255102`", ",", 
              "1.068159920942424`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.563944638694639`", ",", "46.702236100874515`", ",", 
              "1.3128461211646811`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.347013888888889`", ",", "45.86212411538403`", ",", 
              "0.9334381000628202`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.305513236763237`", ",", "39.7940127334253`", ",", 
              "1.4111352033129534`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.138194638694638`", ",", "29.16032667587851`", ",", 
              "0.8817418341409125`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.6583442668442645`", ",", "118.33663059675715`", ",", 
              "1.1050729897189717`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.705928571428572`", ",", "35.68373761211892`", ",", 
              "1.4924876348187879`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.044732967649636`", ",", "87.93712891769334`", ",", 
              "1.080736519041444`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "5.078426587301587`", ",", "40.93071568239796`", ",", 
              "0.9853112398238353`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.586658563658564`", ",", "46.14006423774903`", ",", 
              "1.1051803577519175`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.338682567432569`", ",", "93.79577619206539`", ",", 
              "1.1110202799004703`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.205213952713953`", ",", "128.948195930912`", ",", 
              "1.114841001571883`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.8812884615384617`", ",", "28.077402093847297`", ",", 
              "2.1488122920563737`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.814988705738705`", ",", "34.68221572424641`", ",", 
              "0.9263542216937177`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.785906940281941`", ",", "47.848731854477116`", ",", 
              "1.0835979315860664`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.459468253968255`", ",", "35.15473389019551`", ",", 
              "1.7383647918604803`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.8052644161394147`", ",", "36.95445605480637`", ",", 
              "1.2139509026683615`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.719679487179487`", ",", "44.4495088291694`", ",", 
              "1.472607092929417`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "5.63813492063492`", ",", "56.65822577727387`", ",", 
              "0.894659127944902`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.5063049450549455`", ",", "17.15321528273949`", ",", 
              "4.321498329730113`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.746099067599069`", ",", "115.7684498005079`", ",", 
              "1.0306570475514154`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.402668137418138`", ",", "19.61753102608996`", ",", 
              "1.7951784904775814`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.216741758241758`", ",", "58.41998649740369`", ",", 
              "1.1933923492216483`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.154871406371407`", ",", "40.551772239183435`", ",", 
              "1.1456629790225261`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.301171883671884`", ",", "40.502819773630456`", ",", 
              "0.9431439032292387`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.5136107503607503`", ",", "18.41122496689477`", ",", 
              "1.242752636582811`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.4733318070818076`", ",", "55.66220258873877`", ",", 
              "1.4687333293420723`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.875432191265524`", ",", "81.54833010148928`", ",", 
              "0.8661634891701132`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<cart\>\"", ",", "4"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "4.631318043068042`", ",", "50.41756106761433`", ",", 
              "1.027862099729349`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.078026515151515`", ",", "36.29923738754077`", ",", 
              "1.143171450584062`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.6428963675213675`", ",", "56.058129403056284`", ",", 
              "1.3634313942148617`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.435407897657898`", ",", "38.06017911935473`", ",", 
              "1.0699093383826688`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.810021561771562`", ",", "71.86961590643526`", ",", 
              "1.4627721462522545`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.1071822899322905`", ",", "39.73854713060058`", ",", 
              "1.4091683379645592`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.08072360972361`", ",", "38.34389151948506`", ",", 
              "1.1594319093982635`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.176643148518148`", ",", "128.44842900941063`", ",", 
              "1.1995008540831675`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.453768231768232`", ",", "17.85926600980965`", ",", 
              "0.7469714629200696`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.239249084249085`", ",", "68.98167868125327`", ",", 
              "0.8477763626487133`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "5.245622557997558`", ",", "40.800499038635316`", ",", 
              "0.9821765787124332`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.000879287379286`", ",", "33.88301308376903`", ",", 
              "0.8115905588834442`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.854446733821733`", ",", "85.33728668788895`", ",", 
              "1.0108286320673956`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.280001665001666`", ",", "141.48610213277925`", ",", 
              "1.2232393533812644`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.349026875901876`", ",", "23.369710099783518`", ",", 
              "1.7885244566559475`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.457438186813187`", ",", "32.620279139844044`", ",", 
              "0.8712803568918644`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.4227226107226105`", ",", "56.54581296526319`", ",", 
              "1.2805548568217398`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.409187062937063`", ",", "37.54089556221341`", ",", 
              "1.8563579887732784`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.254870879120879`", ",", "32.47058899030914`", ",", 
              "1.066656231023928`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.8652106227106224`", ",", "36.89216026462853`", ",", 
              "1.2222330079726091`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "5.958005328005328`", ",", "69.09974007229091`", ",", 
              "1.091116291521646`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.8072874902874894`", ",", "20.616516480147055`", ",", 
              "5.1940257301766835`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.2006926684426675`", ",", "118.47103685753602`", ",", 
              "1.0547174923595402`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.819346320346321`", ",", "11.78692879949776`", ",", 
              "1.0786087719962445`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.291273726273727`", ",", "39.94731788098175`", ",", 
              "0.8160361956469717`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.69740897990898`", ",", "39.684298707078796`", ",", 
              "1.1211552385185515`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.9773076923076927`", ",", "42.41966011690141`", ",", 
              "0.9877792222841568`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.8554257409257415`", ",", "11.055396591490986`", ",", 
              "0.7462362383409233`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.928099206349207`", ",", "53.63522763384983`", ",", 
              "1.4152484592591674`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.4152490719157385`", ",", "104.96241990870837`", ",", 
              "1.1148556413935087`"}], "}"}]}], "}"}]}], "}"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"cv", "[", "\"\<lm\>\"", "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "2.9785238258491176`", ",", "41.20994429043255`", ",", 
              "1.062789220461558`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.032237289703134`", ",", "8.27732570958644`", ",", 
              "0.911110577700457`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.2552882237428684`", ",", "16.818655396642026`", ",", 
              "4.187625448118475`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.4820140004882054`", ",", "10.952716233216481`", ",", 
              "1.023570509155318`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.822135425160597`", ",", "77.87632134771815`", ",", 
              "0.8312118500003538`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.9502859031664643`", ",", "36.920280764832064`", ",", 
              "5.840453496190693`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.9542015281542695`", ",", "6.983142280623811`", ",", 
              "2.4208355684059533`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.5904851519568655`", ",", "4.89776530247927`", ",", 
              "0.6987225094840317`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.56476363107955`", ",", "6.3585776797287705`", ",", 
              "0.8025999046672622`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.4171029731447446`", ",", "11.546053865536756`", ",", 
              "0.9651898562463643`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "1.16006379213714`", ",", "3.1733189430140554`", ",", 
              "1.4954377676786312`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.0046123763402823`", ",", "7.970279374195988`", ",", 
              "1.338215781694788`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.363501722742737`", ",", "7.734514019029353`", ",", 
              "0.9174333996428905`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.8985595513381306`", ",", "9.699800923897952`", ",", 
              "1.4101827349235214`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.2385086576083433`", ",", "7.714721838075635`", ",", 
              "0.9659582097608036`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.5941732041397318`", ",", "4.993092849590242`", ",", 
              "2.279456670169822`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.964957133027115`", ",", "109.3960002787085`", ",", 
              "0.8829378553568078`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.132586989927127`", ",", "15.135485740509173`", ",", 
              "0.7623211261193847`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.6304108474482604`", ",", "37.73328224148885`", ",", 
              "14.166936893152307`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.0307874032370896`", ",", "12.842334501496468`", ",", 
              "5.347946607481437`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "5.1598060799159065`", ",", "119.87282459235655`", ",", 
              "0.9797205372959027`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.1128108283209244`", ",", "6.361972982631476`", ",", 
              "1.2562889719064547`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.325000849542185`", ",", "97.78349508763306`", ",", 
              "11.26113074705489`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.251480345439515`", ",", "11.355077875555796`", ",", 
              "0.984788386909975`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.4513614471153222`", ",", "5.678326768793651`", ",", 
              "1.142917163158974`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.740532093787025`", ",", "8.021214861895867`", ",", 
              "2.3126056442372707`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.146859626452716`", ",", "2.7130345152393227`", ",", 
              "1.693238997824545`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.159821226481262`", ",", "7.750874436104906`", ",", 
              "1.1495592399089218`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.8541028921023974`", ",", "19.35902766718532`", ",", 
              "2.3406192394038516`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.4634891597119142`", ",", "3.362949472149368`", ",", 
              "1.564319740680797`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<cart\>\"", ",", "3"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "2.848959290709291`", ",", "37.23074574269965`", ",", 
              "0.9601671617467483`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.6750378787878786`", ",", "11.947071856060603`", ",", 
              "1.315050769114666`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.573753663003663`", ",", "10.03734529352668`", ",", 
              "2.499167834256041`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.6635860805860805`", ",", "14.072637656784607`", ",", 
              "1.315138325945947`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.4351190476190476`", ",", "83.42942750566894`", ",", 
              "0.8904828525710714`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.8675555555555556`", ",", "18.70035507936508`", ",", 
              "2.95822653405496`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.058244463869464`", ",", "11.532614458654932`", ",", 
              "3.997994334970164`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.9829626623376622`", ",", "10.157938026762405`", ",", 
              "1.4491466027679758`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.1361686507936506`", ",", "11.519170743715442`", ",", 
              "1.4539863797254566`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.3790657644824313`", ",", "11.207235209763923`", ",", 
              "0.9368663845678642`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "1.5612376373626375`", ",", "3.6112968358667437`", ",", 
              "1.7018363976751856`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.4610965700965703`", ",", "13.106471724672264`", ",", 
              "2.2005862631461683`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.6599572510822513`", ",", "11.321652287491096`", ",", 
              "1.342923669429352`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.1118979353979355`", ",", "9.71620000312763`", ",", 
              "1.4125668764723813`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.4826633089133088`", ",", "3.5783855941702782`", ",", 
              "0.44804868081164423`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.0343603063603064`", ",", "7.81557051627499`", ",", 
              "3.567979783505856`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.843928391053391`", ",", "123.6263366684008`", ",", 
              "0.9977912564035576`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.348873001998002`", ",", "19.80826659999435`", ",", 
              "0.9976726455871712`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.9661153846153847`", ",", "7.812518916495593`", ",", 
              "2.9332052737478636`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.440277777777778`", ",", "20.292718835733886`", ",", 
              "8.450517843269989`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "4.958189393939394`", ",", "118.2502438094535`", ",", 
              "0.9664591853436342`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.496276168276168`", ",", "10.637474063091947`", ",", 
              "2.1005655621121124`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.332397366522366`", ",", "10.048612592587606`", ",", 
              "1.1572376312609707`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.9994166666666664`", ",", "11.79135826388889`", ",", 
              "1.0226255435174083`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.158040265290265`", ",", "7.2219282831995`", ",", 
              "1.453608804504481`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.7399155844155847`", ",", "5.081197939360215`", ",", 
              "1.4649659978406115`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.7961923076923079`", ",", "5.674412459730442`", ",", 
              "3.5414722564668626`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.8326885753135749`", ",", "8.557541853429349`", ",", 
              "1.2691989000225214`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.268568792318793`", ",", "11.812022748824896`", ",", 
              "1.4281423725138611`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.515034271284271`", ",", "4.944686162315017`", ",", 
              "2.3000851601367724`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<cart\>\"", ",", "4"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "2.392172619047619`", ",", "29.417115238803852`", ",", 
              "0.7586565211672606`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.0723214285714286`", ",", "7.835421225965592`", ",", 
              "0.8624687985212335`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.9475761738261737`", ",", "21.406413736757884`", ",", 
              "5.329917333040663`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.3007458374958376`", ",", "9.49484951399347`", ",", 
              "0.8873276495484762`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.5973067765567768`", ",", "97.32479420172946`", ",", 
              "1.0387948588135723`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.8250992063492066`", ",", "5.8870816959561605`", ",", 
              "0.9312829198812239`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.8194840159840158`", ",", "5.283972839097367`", ",", 
              "1.8317870204178632`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.875692307692308`", ",", "7.8447275316990694`", ",", 
              "1.1191405403588033`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.86409693084693`", ",", "17.328320837371532`", ",", 
              "2.1872357864646492`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.8701180763680774`", ",", "28.027041409800447`", ",", 
              "2.3429144177198604`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "1.6117662337662337`", ",", "3.71401410693203`", ",", 
              "1.7502422747087796`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.285226898101898`", ",", "4.418093959913871`", ",", 
              "0.7418012323769491`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.2569665057165054`", ",", "8.609758682591796`", ",", 
              "1.0212510002362578`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.860073717948718`", ",", "20.585998385313935`", ",", 
              "2.992846939014005`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.4760653235653236`", ",", "11.46237033676675`", ",", 
              "1.4352002525188126`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.0420059523809524`", ",", "10.171591531320862`", ",", 
              "4.643555179274295`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.549566544566545`", ",", "120.93337169536719`", ",", 
              "0.9760562687277415`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.8069808802308804`", ",", "20.411677199606682`", ",", 
              "1.0280643129373443`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.4607812187812188`", ",", "3.2845855113218456`", ",", 
              "1.2331955476668055`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.3708344895844893`", ",", "12.790173058406307`", ",", 
              "5.326224963913996`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "5.960670634920635`", ",", "137.31996133881327`", ",", 
              "1.1223159774687839`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.223540182040182`", ",", "7.854695748213719`", ",", 
              "1.55105462929518`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.5634806859806862`", ",", "13.746874496758931`", ",", 
              "1.5831439746822402`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.0189166666666662`", ",", "9.558412423469388`", ",", 
              "0.8289695284426172`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.7860298035298032`", ",", "5.022994951442443`", ",", 
              "1.0110138733146703`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.4999264069264069`", ",", "4.550292340848186`", ",", 
              "1.3118999966406524`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.7207539682539683`", ",", "5.748836658301213`", ",", 
              "3.5879213357889337`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.0550888278388277`", ",", "10.323455846256156`", ",", 
              "1.531107767734572`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.0387658730158726`", ",", "10.75183618963418`", ",", 
              "1.299959640381842`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.753145773979107`", ",", "4.896831092400036`", ",", 
              "2.2778247511774254`"}], "}"}]}], "}"}]}], "}"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"cv", "[", "\"\<lm\>\"", "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "2.780957325881996`", ",", "17.82120765210856`", ",", 
              "1.2258974018245203`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.319558757850205`", ",", "28.51428029024671`", ",", 
              "0.9142239813991428`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.724063396836897`", ",", "86.12977587133413`", ",", 
              "0.8430053848671097`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.097599692409912`", ",", "7.918310888785835`", ",", 
              "0.7412153459425328`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.688995338488916`", ",", "82.93208383199551`", ",", 
              "1.6748381994476689`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.708781902248657`", ",", "117.95453051338855`", ",", 
              "0.9688010450114909`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.373389288489919`", ",", "50.47892677497846`", ",", 
              "1.0078153625228354`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.83260227827845`", ",", "80.07143461672676`", ",", 
              "0.9148211291300732`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.148645913236022`", ",", "26.577710542148928`", ",", 
              "0.9371721635237935`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.5680653877240567`", ",", "24.257400672252864`", ",", 
              "0.6035601888389583`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "2.864694313793733`", ",", "13.25968303553913`", ",", 
              "0.47098190301267384`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.376640968667593`", ",", "18.137427038004006`", ",", 
              "0.5332514145516558`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.812756677760066`", ",", "19.014749954821482`", ",", 
              "0.6593580911070956`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.1742821511471835`", ",", "71.9064859263131`", ",", 
              "1.1306500128552759`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.9933664961446524`", ",", "85.2291848973156`", ",", 
              "4.310496531026875`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.1266572271698525`", ",", "32.81776451761571`", ",", 
              "0.833944104344535`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.8129260596756738`", ",", "25.680435964338187`", ",", 
              "0.7372317522259595`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.672864376778313`", ",", "126.50451180363916`", ",", 
              "0.9345533939969026`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.8478526194055`", ",", "25.00003787163471`", ",", 
              "0.652469930880956`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.614691159635323`", ",", "121.81650121682881`", ",", 
              "1.0398083540297822`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "4.990778850914521`", ",", "40.57888597152631`", ",", 
              "0.9757055387843695`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.455622252087946`", ",", "85.80665538135135`", ",", 
              "0.87439946135211`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.181947850558116`", ",", "34.4464529664036`", ",", 
              "1.238212511598109`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.62635850597894`", ",", "58.10732376940001`", ",", 
              "1.6184768256060345`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.8712976275309985`", ",", "33.48764970614348`", ",", 
              "0.7915490408062474`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.2423955516865113`", ",", "19.148752967261224`", ",", 
              "1.2590822873564926`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.691798887950695`", ",", "72.60509917164916`", ",", 
              "0.718510404647319`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.1054313016353685`", ",", "24.11362554222235`", ",", 
              "1.2066299899407082`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.050408121543031`", ",", "41.678938043789046`", ",", 
              "0.5594706108531613`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.143193315452655`", ",", "106.64290080153745`", ",", 
              "1.2365367772627702`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<cart\>\"", ",", "3"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "3.574541666666667`", ",", "24.31869021990741`", ",", 
              "1.6728506697374443`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.7328092740592744`", ",", "12.231161768686002`", ",", 
              "0.3921551340410265`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.063537698412699`", ",", "108.2580890672111`", ",", 
              "1.0595888717441349`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.382146728271728`", ",", "21.52223155439504`", ",", 
              "2.014647887801275`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.044589285714286`", ",", "37.052764568326594`", ",", 
              "0.7482916457265303`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.977215034965035`", ",", "123.8128034002804`", ",", 
              "1.0169170509849885`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.479188311688312`", ",", "46.532765837850526`", ",", 
              "0.9290299788090839`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.0586560939060945`", ",", "114.6279233366364`", ",", 
              "1.3096311657035216`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.3623463897213903`", ",", "30.252184663382355`", ",", 
              "1.0667399401216828`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.282967372134038`", ",", "39.295681354067824`", ",", 
              "0.9777349675287367`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "4.047209554334556`", ",", "30.33573756703067`", ",", 
              "1.0775207348711893`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.784386766011766`", ",", "19.566541726081947`", ",", 
              "0.5752682578104764`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.7036201437451446`", ",", "31.074793966091466`", ",", 
              "1.0775538400300109`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.465638056388057`", ",", "77.73358464507558`", ",", 
              "1.2222746995077332`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.6282287712287697`", ",", "24.08511157193456`", ",", 
              "1.2181131381850052`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.82011013986014`", ",", "35.663412095518126`", ",", 
              "0.9062558859517255`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.243675213675213`", ",", "47.09779184845551`", ",", 
              "1.3520793672906475`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.041396492396492`", ",", "134.63159305939942`", ",", 
              "0.9945922911284819`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.00363455988456`", ",", "49.25136979690485`", ",", 
              "1.2853995666798423`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.919740059323393`", ",", "107.14343127693357`", ",", 
              "0.9145611128895271`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "5.905983391608392`", ",", "53.98012543180066`", ",", 
              "1.2979337925895715`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.610100108225107`", ",", "97.57404624946186`", ",", 
              "0.994313239495149`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.518255952380952`", ",", "39.002665997445476`", ",", 
              "1.4019901866476923`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.93269517982018`", ",", "25.96485172039225`", ",", 
              "0.7232050637286774`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.2468046536796535`", ",", "42.21021525895175`", ",", 
              "0.9977247042905787`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.7079153069153055`", ",", "50.393201113046736`", ",", 
              "3.3134892404278347`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.4121301615051625`", ",", "108.86995754258896`", ",", 
              "1.0773926093390287`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.867442307692308`", ",", "46.15929722920775`", ",", 
              "2.309780926714016`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.3605202020202025`", ",", "72.24954716652715`", ",", 
              "0.9698303312011762`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.646198092031426`", ",", "72.27421444764708`", ",", 
              "0.838027881280246`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<cart\>\"", ",", "4"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "3.240530303030303`", ",", "17.13976170811912`", ",", 
              "1.179021632879554`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.7132566738816735`", ",", "26.948660775988724`", ",", 
              "0.8640271364810296`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.1440022893772905`", ",", "106.8472147687603`", ",", 
              "1.0457797724061615`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.031457972582972`", ",", "20.709713016625876`", ",", 
              "1.9385898474545362`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.7475470779220785`", ",", "39.11218135567759`", ",", 
              "0.7898821827619512`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.843134476634477`", ",", "121.59640608683053`", ",", 
              "0.9987130191085939`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.871759768009769`", ",", "42.44546628784787`", ",", 
              "0.8474267526531906`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.010196067821068`", ",", "106.79907143859161`", ",", 
              "1.220186045012936`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.2959707792207795`", ",", "22.991295469181097`", ",", 
              "0.8107094884225149`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.422957351290685`", ",", "36.70215980285458`", ",", 
              "0.9132042959057579`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "3.7523985181485173`", ",", "32.05744590489001`", ",", 
              "1.1386755503539117`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.9332634032634033`", ",", "19.71464709678972`", ",", 
              "0.5796226460192964`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.910765345765346`", ",", "24.60094903073699`", ",", 
              "0.8530659004651626`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.282259018759019`", ",", "78.70359012694455`", ",", 
              "1.2375269635617536`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.376469474969474`", ",", "32.869501164220566`", ",", 
              "1.6623867858839405`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.180641025641026`", ",", "45.96108606837607`", ",", 
              "1.1679338102209853`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.8555876068376067`", ",", "25.915295275768738`", ",", 
              "0.7439740731870589`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.585632034632036`", ",", "134.0740920934192`", ",", 
              "0.9904737469557485`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.8793159340659336`", ",", "31.68510021952863`", ",", 
              "0.82694175330224`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.42028044486378`", ",", "92.37238748413648`", ",", 
              "0.7884775808551303`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "5.916982045732046`", ",", "62.23882369587138`", ",", 
              "1.4965113889547577`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.771973137973139`", ",", "105.36658252146442`", ",", 
              "1.0737218761390461`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.8071024531024533`", ",", "30.043627072216708`", ",", 
              "1.0799484919648703`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.219802655677656`", ",", "45.27718774611644`", ",", 
              "1.2611160580465954`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.86027614052614`", ",", "46.88422405784206`", ",", 
              "1.1082044547044412`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.534074342324343`", ",", "16.339005035067196`", ",", 
              "1.0743337630316725`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.017765456765457`", ",", "91.99866026335262`", ",", 
              "0.910431847996762`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.521068722943723`", ",", "20.986907348795235`", ",", 
              "1.0501710644391768`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.24184002109002`", ",", "44.330313466757474`", ",", 
              "0.595060928099986`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.1961780503447175`", ",", "96.8796548666103`", ",", 
              "1.1233308106840307`"}], "}"}]}], "}"}]}], "}"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"cv", "[", "\"\<lm\>\"", "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "5.344831421050119`", ",", "45.42915434120225`", ",", 
              "0.7198864504358101`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.3755784768259405`", ",", "51.63443205502542`", ",", 
              "1.7789089073904827`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.408147021062696`", ",", "99.24671818426454`", ",", 
              "0.9313407286353067`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.653272358391675`", ",", "81.3198085341926`", ",", 
              "3.0804824737178245`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.484931509411817`", ",", "84.7842290697162`", ",", 
              "0.8714456129862996`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.269178748216245`", ",", "155.52114080374488`", ",", 
              "1.1019075699881524`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.395739331171417`", ",", "204.94137424032365`", ",", 
              "0.9961314702954225`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.45581212154431`", ",", "41.07663624633828`", ",", 
              "0.13108470062767616`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.950879261608142`", ",", "218.72143573981378`", ",", 
              "0.7617572499455643`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.545026976850202`", ",", "43.41688110603894`", ",", 
              "2.4818356845447727`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "6.003103894827065`", ",", "55.7250251170323`", ",", 
              "0.17636728535353774`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.007175543195505`", ",", "103.62307988950185`", ",", 
              "0.7988143786130538`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.448126599738363`", ",", "97.92034488374705`", ",", 
              "1.2806389686360573`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.4251063233487664`", ",", "36.96649980099026`", ",", 
              "5.759928294176851`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.604476909087252`", ",", "129.7388395496793`", ",", 
              "0.6781287136277669`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.12425623068631`", ",", "253.40024990976931`", ",", 
              "1.088364688183263`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.132788200173264`", ",", "42.36912133006955`", ",", 
              "1.4115512170199076`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.4525680387504964`", ",", "161.076626656939`", ",", 
              "0.8101899904983213`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.5820199481942625`", ",", "28.375571122870042`", ",", 
              "0.8537447008078457`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.900636733934973`", ",", "65.48745276472101`", ",", 
              "0.9484028760488252`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "5.5177549584598635`", ",", "60.3179605617049`", ",", 
              "0.8492201160424877`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.422205192493094`", ",", "84.40768192929099`", ",", 
              "0.5859675076522262`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.085476394844581`", ",", "71.93216743059557`", ",", 
              "0.6217014853714459`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.153968220352599`", ",", "168.472220819773`", ",", 
              "1.0394617650674185`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.4876322969542235`", ",", "30.64079209517837`", ",", 
              "0.8482285201211235`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.29124256471317`", ",", "169.51492790236105`", ",", 
              "0.8060735402550063`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.10804292917929`", ",", "117.00623545680564`", ",", 
              "1.8255724964357312`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.396315060854712`", ",", "83.59719846487354`", ",", 
              "0.8790729304276006`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.057258900545453`", ",", "52.904092694416434`", ",", 
              "0.17891870843339938`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.236213121623889`", ",", "111.87989337338561`", ",", 
              "0.7473662243173114`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<cart\>\"", ",", "3"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "5.122743575868576`", ",", "73.61909723782671`", ",", 
              "1.1665942578808146`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.358632756132755`", ",", "27.93818444299207`", ",", 
              "0.9625260351269751`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.633530219780218`", ",", "140.4839342332347`", ",", 
              "1.3183147217766602`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.926047619047618`", ",", "35.58406523359757`", ",", 
              "1.347962953572852`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.646084415584416`", ",", "123.3532401738278`", ",", 
              "1.2678730605515833`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "10.306993506493509`", ",", "212.59352854619686`", ",", 
              "1.506280221614127`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.997382617382618`", ",", "205.1598518234413`", ",", 
              "0.9971933954284234`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.121407758907758`", ",", "306.8567440320736`", ",", 
              "0.9792482564979637`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.842249999999998`", ",", "323.3029913798488`", ",", 
              "1.1259911347036669`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.020990028490028`", ",", "43.54179979987097`", ",", 
              "2.488976401798549`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "10.775354978354978`", ",", "330.51399220195924`", ",", 
              "1.046062437003784`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.160517094017095`", ",", "146.31531265030316`", ",", 
              "1.127922232006228`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.708083943833945`", ",", "57.317364154000074`", ",", 
              "0.7496179696084739`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.5580329670329665`", ",", "37.69505018680648`", ",", 
              "5.873447237100517`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.36618025030525`", ",", "190.44177265169657`", ",", 
              "0.995415364878727`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "10.336363247863247`", ",", "302.61461250971547`", ",", 
              "1.299742437117217`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.432237914862915`", ",", "59.37885648558678`", ",", 
              "1.9782401547703485`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.549844655344655`", ",", "146.33908401748596`", ",", 
              "0.7360624787739957`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.073781926406927`", ",", "63.47286312378385`", ",", 
              "1.9097279241493974`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.270109211775878`", ",", "110.35104808220402`", ",", 
              "1.5981267702100146`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "7.5094047619047615`", ",", "100.69469100481858`", ",", 
              "1.417686479842041`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.558059523809524`", ",", "101.98915075113379`", ",", 
              "0.7080200179324013`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.970873015873015`", ",", "106.83793394494835`", ",", 
              "0.9233880279178022`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.23456501831502`", ",", "164.09748126065858`", ",", 
              "1.0124699293707073`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.104453907203908`", ",", "32.170211657447666`", ",", 
              "0.8905674155360408`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.446044566544566`", ",", "204.91307868909234`", ",", 
              "0.9743980239817496`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.045870268620268`", ",", "108.43895980168978`", ",", 
              "1.6919028441791495`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.50141441891442`", ",", "99.66647462458351`", ",", 
              "1.0480506706266601`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "10.041530885780887`", ",", "254.66390172202455`", ",", 
              "0.8612591967865594`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.951378621378622`", ",", "107.10104246496718`", ",", 
              "0.715443135616463`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<cart\>\"", ",", "4"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "4.151285714285715`", ",", "37.68811456774377`", ",", 
              "0.5972191957617937`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.0295236430236425`", ",", "28.169557591847262`", ",", 
              "0.9704973004057499`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.18387085137085`", ",", "169.758366288112`", ",", 
              "1.5930288017904108`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.176001443001443`", ",", "61.29581950644352`", ",", 
              "2.3219520693088795`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.491769841269841`", ",", "69.54562458121711`", ",", 
              "0.7148172497252934`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.844195526695525`", ",", "200.3109488763902`", ",", 
              "1.4192549628795494`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.840799145299146`", ",", "201.4872796068011`", ",", 
              "0.979342608707154`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.517937839937839`", ",", "266.35671249164545`", ",", 
              "0.8500036299893429`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.213924603174602`", ",", "277.68525726033005`", ",", 
              "0.9671148929942354`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.900853174603175`", ",", "96.81571093303447`", ",", 
              "5.534268701414282`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "10.102062770562771`", ",", "334.5273767216693`", ",", 
              "1.058764624779108`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.198447940947942`", ",", "83.5218426421849`", ",", 
              "0.6438570336065981`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.950871212121212`", ",", "83.46665871556473`", ",", 
              "1.0916082440263184`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.417971916971918`", ",", "65.79395019865495`", ",", 
              "10.251672118677124`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.66218849206349`", ",", "218.61779678865545`", ",", 
              "1.1426879246569763`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.588377233877235`", ",", "212.2808962257625`", ",", 
              "0.9117553416394969`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.90237567987568`", ",", "63.80352807610201`", ",", 
              "2.125650588889326`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.389678571428573`", ",", "188.8572278697574`", ",", 
              "0.949922026733396`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.77045183982684`", ",", "68.9425334743832`", ",", 
              "2.074295610091983`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.338463743047075`", ",", "85.29136423241091`", ",", 
              "1.2352072301661314`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "8.164713314463311`", ",", "168.71810877276977`", ",", 
              "2.375392181304062`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.411190476190475`", ",", "108.2181154421769`", ",", 
              "0.7512621830036073`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.138686868686868`", ",", "131.75052604198547`", ",", 
              "1.1387047084018826`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.897408105783107`", ",", "198.18820991003957`", ",", 
              "1.2228073298150717`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.075095390720391`", ",", "58.79756137423809`", ",", 
              "1.6276918793835307`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.450373196248195`", ",", "184.92287198305505`", ",", 
              "0.8793410464673792`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.547294955044955`", ",", "67.20804911127522`", ",", 
              "1.048603653622714`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.987114357864357`", ",", "204.04484582624974`", ",", 
              "2.1456496611486138`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.729058608058608`", ",", "258.98598224536755`", ",", 
              "0.8758762334957684`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.57065527065527`", ",", "161.32368101212649`", ",", 
              "1.077654498370164`"}], "}"}]}], "}"}]}], "}"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"cv", "[", "\"\<lm\>\"", "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "2.4659295139683297`", ",", "13.755904421693135`", ",", 
              "1.2008148437051398`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.747900296330033`", ",", "46.575109475471876`", ",", 
              "0.993742254386151`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.8913401853294705`", ",", "58.33174907079565`", ",", 
              "1.0528265382808315`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.974853815075588`", ",", "54.924166274655725`", ",", 
              "0.993338899636085`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.9657579239778125`", ",", "11.724372942787891`", ",", 
              "5.209906213467782`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.8887330034762297`", ",", "31.003018378229086`", ",", 
              "5.811794615845739`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.118477456628999`", ",", "38.677789165149285`", ",", 
              "0.8850853937722237`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.4115517389665895`", ",", "9.303288675659545`", ",", 
              "3.7310535199508883`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.505624026000942`", ",", "27.798940111516856`", ",", 
              "1.2474787005765031`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.3193920977713276`", ",", "7.536895357026684`", ",", 
              "13.874739179980939`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "3.3723910564981283`", ",", "46.53654503149812`", ",", 
              "0.9862388910134257`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.4029533048945466`", ",", "8.030553834824785`", ",", 
              "2.7518153137811847`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.0806490292764215`", ",", "36.518163467969984`", ",", 
              "1.0906120656660918`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.418885914307096`", ",", "90.64274837837971`", ",", 
              "1.0502850234450678`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.1913846824759338`", ",", "6.298039397658599`", ",", 
              "1.3036450078985318`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.2625721492014286`", ",", "8.023113037996193`", ",", 
              "35.189092271913125`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.005822370548719`", ",", "22.516976029817094`", ",", 
              "0.8693653699330647`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.154262943972859`", ",", "7.3630916159045485`", ",", 
              "2.2844750755187704`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.0887687795067995`", ",", "39.37435956694207`", ",", 
              "1.1269329057437185`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.0415182243127306`", ",", "5.621126878715621`", ",", 
              "1.8869877623439224`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "1.6200376369753016`", ",", "3.8784008176545077`", ",", 
              "2.199543926871593`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.9024521487461974`", ",", "56.3144404169448`", ",", 
              "0.9224333451451749`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.141817338329812`", ",", "14.910901782220005`", ",", 
              "1.0256166332589907`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.316492289563783`", ",", "66.92045075228798`", ",", 
              "0.9499269071128772`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.5154488060627775`", ",", "9.768532204354585`", ",", 
              "1.4952883997251725`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.968712325434061`", ",", "29.677962142512364`", ",", 
              "1.2377950529638893`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.503020324642872`", ",", "46.12694170574133`", ",", 
              "0.9916552196112944`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.7429355601465395`", ",", "20.234035425125143`", ",", 
              "0.9321315284910314`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.8800697106159547`", ",", "11.03668002887248`", ",", 
              "1.2659791955485242`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.3594294802147275`", ",", "36.61911850820766`", ",", 
              "10.18726174958939`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<cart\>\"", ",", "3"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "2.5969722222222225`", ",", "15.560073495370371`", ",", 
              "1.3583088868310023`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.4554619963369975`", ",", "52.41157561117403`", ",", 
              "1.1182710656044166`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.763321581196582`", ",", "59.10238405957794`", ",", 
              "1.0667356869081603`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.1787146464646465`", ",", "30.595275780306146`", ",", 
              "0.5533352554810786`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.7077548840048837`", ",", "4.890001494859012`", ",", 
              "2.172947695902513`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.516765873015874`", ",", "19.901491347001766`", ",", 
              "3.730713533977274`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.3153738344988346`", ",", "51.103068072482834`", ",", 
              "1.1694199721388767`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.548611388611389`", ",", "35.389486043849885`", ",", 
              "14.192837723999588`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.4529570429570433`", ",", "27.649674059900583`", ",", 
              "1.2407803797281731`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.6387126762126762`", ",", "5.510346523577773`", ",", 
              "10.144047009313626`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "3.6774130730380734`", ",", "47.800705021731524`", ",", 
              "1.013029959108134`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.710594821844822`", ",", "19.385333226390802`", ",", 
              "6.642736968377143`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.494540293040294`", ",", "31.581437681074185`", ",", 
              "0.943177140226979`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.684823232323233`", ",", "92.12808401917547`", ",", 
              "1.0674957303822052`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.287219516594517`", ",", "10.280038297304495`", ",", 
              "2.1278877061755073`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.221690476190476`", ",", "8.959526088435378`", ",", 
              "39.29616705454113`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.387503274503274`", ",", "28.472920557498476`", ",", 
              "1.0993204007840967`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.9106143856143856`", ",", "5.7785053090366185`", ",", 
              "1.7928408392654958`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.2427522893772895`", ",", "33.02855711252344`", ",", 
              "0.9453097967487548`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.431468531468531`", ",", "10.155977756417048`", ",", 
              "3.4093174117028493`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "0.8507992007992007`", ",", "1.1447886926038773`", ",", 
              "0.6492400179233968`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.234572510822511`", ",", "58.264925250329796`", ",", 
              "0.9543823840807174`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.821174825174825`", ",", "18.742037238821784`", ",", 
              "1.2891336428904534`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.771448884448884`", ",", "79.60711595449284`", ",", 
              "1.130012434057643`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.508054029304029`", ",", "10.479972737541761`", ",", 
              "1.604189998667013`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.78153373015873`", ",", "31.730814301855002`", ",", 
              "1.3234144844834366`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.056043956043956`", ",", "51.183492755571656`", ",", 
              "1.1003629521504124`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.450447191697191`", ",", "21.681490954127902`", ",", 
              "0.998812193337391`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.5474856393606387`", ",", "16.461537089347203`", ",", 
              "1.8882456886804395`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.0595179511846182`", ",", "6.04358056817831`", ",", 
              "1.681294898973745`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<cart\>\"", ",", "4"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "2.499270451770452`", ",", "15.238977758820763`", ",", 
              "1.330278994002498`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.4721004273504272`", ",", "53.73547220046906`", ",", 
              "1.1465181700350144`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.578714285714286`", ",", "50.44712487811792`", ",", 
              "0.9105173888612363`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.047192307692308`", ",", "69.83384391461934`", ",", 
              "1.2629900165369583`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.7141406510156507`", ",", "14.312229783315567`", ",", 
              "6.3598603729628405`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.7414992784992787`", ",", "6.658528026232226`", ",", 
              "1.2482009609583329`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.848636904761906`", ",", "51.24369906463005`", ",", 
              "1.1726381094664713`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.171494616494616`", ",", "9.643402116933029`", ",", 
              "3.86745490407284`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.443655844155844`", ",", "24.197863071027996`", ",", 
              "1.0858802047660885`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.8590446127946127`", ",", "7.328952648033883`", ",", 
              "13.491935556607828`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "3.898353535353535`", ",", "49.34871607999183`", ",", 
              "1.0458366212344654`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.025636904761904`", ",", "16.44669664246887`", ",", 
              "5.63575970135401`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.401088994338996`", ",", "48.09145210166831`", ",", 
              "1.4362474159875376`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.420997474747474`", ",", "74.8535664603818`", ",", 
              "0.8673344664771998`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.3788095238095237`", ",", "8.642529478458053`", ",", 
              "1.7889361591476167`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.3796190476190473`", ",", "11.136167043650794`", ",", 
              "48.84283791074909`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.940676379176379`", ",", "24.072742016365314`", ",", 
              "0.9294324531254857`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.0982943722943723`", ",", "18.596981136597886`", ",", 
              "5.769905102726533`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.496012265512266`", ",", "45.51955592769584`", ",", 
              "1.302814470989652`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.3386257261257257`", ",", "10.886908590405193`", ",", 
              "3.6546877028588844`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "1.4923730158730162`", ",", "4.356409109347444`", ",", 
              "2.4706351019253634`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.6598924963924957`", ",", "46.75576877876894`", ",", 
              "0.7658618265601516`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.74246312021312`", ",", "18.36929134174524`", ",", 
              "1.2634950599526593`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.569154456654457`", ",", "73.74336390522919`", ",", 
              "1.046777252799642`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.989409340659341`", ",", "12.848134385450257`", ",", 
              "1.9666891507108675`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.0207750582750585`", ",", "32.18519622088285`", ",", 
              "1.3423656405240074`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.3814786324786326`", ",", "52.47138370954781`", ",", 
              "1.1280505407824084`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.642146825396826`", ",", "25.30739384448223`", ",", 
              "1.165848492935306`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.5935906593406597`", ",", "10.027058385007852`", ",", 
              "1.1501690068718213`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.2951516076516076`", ",", "2.919788409405511`", ",", 
              "0.8122710210341179`"}], "}"}]}], "}"}]}], "}"}]}]}], "}"}]}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.586086790193047*^9, 3.586086802341343*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Visualizing cv results", "Subsubsection",
 CellChangeTimes->{{3.586086768423133*^9, 3.586086776758816*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"resAll7Panels", "=", 
   RowBox[{"MapThread", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"kFoldPlot", "[", 
       RowBox[{"#1", ",", "#2"}], "]"}], "&"}], ",", 
     RowBox[{"{", 
      RowBox[{"resAll7", ",", "responseColumns"}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.575218790602067*^9, 3.575218876756999*^9}, {
  3.575218938500106*^9, 3.575218940795947*^9}, {3.5752189871547413`*^9, 
  3.575218991020404*^9}, {3.575219077809449*^9, 3.575219132856144*^9}, {
  3.585917965896331*^9, 3.585917985370694*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Labeled", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Grid", "[", 
    RowBox[{
     RowBox[{"Partition", "[", 
      RowBox[{"resAll7Panels", ",", "3", ",", "3", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Dividers", "\[Rule]", "White"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Spacings", "\[Rule]", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", 
          RowBox[{"{", "0", "}"}], ",", "1"}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"1", ",", 
          RowBox[{"{", "0", "}"}], ",", "1"}], "}"}]}], "\[IndentingNewLine]",
        "}"}]}]}], "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Style", "[", 
    RowBox[{
     RowBox[{"Column", "[", 
      RowBox[{
       RowBox[{"{", "\"\<10-fold cross validation results\>\"", "}"}], ",", 
       "Center"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"Bold", ",", "14", ",", 
       RowBox[{"FontFamily", "\[Rule]", "\"\<Verdana\>\""}]}], "}"}]}], "]"}],
    ",", "\[IndentingNewLine]", "Top"}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{{3.5747213808265514`*^9, 3.5747214212398624`*^9}, {
   3.5747215696883535`*^9, 3.5747216017921896`*^9}, {3.5747217048540845`*^9, 
   3.5747217107544217`*^9}, {3.574723022086426*^9, 3.5747230238475266`*^9}, 
   3.574727050257824*^9, {3.574727327199664*^9, 3.5747273340050535`*^9}, {
   3.574728349266123*^9, 3.57472847562035*^9}, {3.574728666087244*^9, 
   3.574728666677278*^9}, {3.574728697498041*^9, 3.5747286982590847`*^9}, {
   3.5747628142221327`*^9, 3.574762818468376*^9}, {3.5747628965788436`*^9, 
   3.57476290613139*^9}, {3.5752189360260487`*^9, 3.5752190311073513`*^9}, {
   3.585917973405488*^9, 3.585918006399705*^9}, {3.5859180813294086`*^9, 
   3.585918081493992*^9}}],

Cell[BoxData[
 TemplateBox[{TagBox[
    GridBox[{{
       GraphicsBox[{{
          Opacity[0], 
          
          PointBox[{{0.16726436709452802`, 0.4990857618568485}, {
           2.107330181618173, 3.5009142381431513`}}]}, {
          RGBColor[
          0.798413061722744, 0.824719615472648, 0.968322270542458], {}, {
           RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{0.8606170516343149, 0.7509076238812251}, {
                   0.8606170516343149, 1.2490923761187749`}, {
                   0.5552852732580018, 1.2490923761187749`}, {
                   0.5552852732580018, 0.7509076238812251}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.449176195777962, 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.7364811844642758`, 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.3695683092399158`, 1.}]}, {}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{0.689177156317263, 1.2490923761187749`}, {
                    0.689177156317263, 0.7509076238812251}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.5552852732580018, 1.}, {0.2554491768456028, 
                    1.}}, {{0.8606170516343149, 1.}, {1.0936117292024534`, 
                    1.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.2554491768456028, 1.1245461880593874`}, {
                    0.2554491768456028, 0.8754538119406126}}, {{
                    1.0936117292024534`, 1.1245461880593874`}, {
                    1.0936117292024534`, 0.8754538119406126}}}]}, {}}]}, 
               ImageSizeCache -> {{50.58578643762689, 152.25483843760423`}, {
                19.585786437626883`, 43.41421356237311}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "1.7364811844642758`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "0.8606170516343149`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "0.689177156317263`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.5552852732580018`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.2554491768456028`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
             Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 1.7364811844642758`}, {
                  Style["75%", Bold], 0.8606170516343149}, {
                  Style["median", Bold], 0.689177156317263}, {
                  Style["25%", Bold], 0.5552852732580018}, {
                  Style["min", Bold], 0.2554491768456028}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{0.925281624048175, 1.7509076238812251`}, {
                   0.925281624048175, 2.249092376118775}, {0.5906325296262541,
                    2.249092376118775}, {0.5906325296262541, 
                   1.7509076238812251`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.7159863653053118`, 2.}]}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1.9951390425619886`, 2.}]}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{0.6701319689602934, 2.249092376118775}, {
                    0.6701319689602934, 1.7509076238812251`}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.5906325296262541, 2.}, {0.36990480808701776`, 
                    2.}}, {{0.925281624048175, 2.}, {1.3563596074146804`, 
                    2.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.36990480808701776`, 2.124546188059387}, {
                    0.36990480808701776`, 1.8754538119406126`}}, {{
                    1.3563596074146804`, 2.124546188059387}, {
                    1.3563596074146804`, 1.8754538119406126`}}}]}, {}}]}, 
               ImageSizeCache -> {{57.58578643762689, 
                169.0216986084564}, {-21.414213562373106`, 
                2.4142135623731065`}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "1.9951390425619886`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "0.925281624048175`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "0.6701319689602934`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.5906325296262541`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.36990480808701776`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
             Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 1.9951390425619886`}, {
                  Style["75%", Bold], 0.925281624048175}, {
                  Style["median", Bold], 0.6701319689602934}, {
                  Style["25%", Bold], 0.5906325296262541}, {
                  Style["min", Bold], 0.36990480808701776`}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{0.9595994953949811, 2.750907623881225}, {
                   0.9595994953949811, 3.249092376118775}, {
                   0.5990720830006938, 3.249092376118775}, {
                   0.5990720830006938, 2.750907623881225}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.882979656022813, 3.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    2.0191453718670984`, 3.}]}, {}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{0.6970647004904658, 3.249092376118775}, {
                    0.6970647004904658, 2.750907623881225}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.5990720830006938, 3.}, {0.45279420015242827`, 
                    3.}}, {{0.9595994953949811, 3.}, {1.442040303134387, 
                    3.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.45279420015242827`, 3.124546188059387}, {
                    0.45279420015242827`, 2.875453811940613}}, {{
                    1.442040303134387, 3.124546188059387}, {1.442040303134387,
                     2.875453811940613}}}]}, {}}]}, 
               ImageSizeCache -> {{63.58578643762689, 
                170.57784992600946`}, {-63.414213562373114`, \
-39.58578643762689}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "2.0191453718670984`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "0.9595994953949811`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "0.6970647004904658`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.5990720830006938`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.45279420015242827`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
             Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 2.0191453718670984`}, {
                  Style["75%", Bold], 0.9595994953949811}, {
                  Style["median", Bold], 0.6970647004904658}, {
                  Style["25%", Bold], 0.5990720830006938}, {
                  Style["min", Bold], 0.45279420015242827`}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {}], 
              "Tooltip"]& ]}}, {}, {}}, {{{{{{{}, {}}, {}}, {{{}, {}}, {}}, \
{{{}, {}}, {}}}, {}}, {}}, {}}, {}}, AspectRatio -> 1, Axes -> {False, False},
         Frame -> True, FrameLabel -> {{None, None}, {
           FormBox["\"nmse\"", TraditionalForm], None}}, 
        FrameTicks -> {{{{0.7509076238812251, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {3.249092376118775, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {1., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {1., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"cart\"", ",", "4"}], ")"}], TraditionalForm], 0}, {
            2., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {2., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"cart\"", ",", "3"}], ")"}], TraditionalForm], 0}, {
            3., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {3., 
             FormBox[
              RowBox[{"cv", "(", "\"lm\"", ")"}], TraditionalForm], 0}}, {{
            0.7509076238812251, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {3.249092376118775, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {1., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {2., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {3., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}}}, {
          Automatic, Automatic}}, PlotLabel -> FormBox[
          StyleBox["a1", {Bold, 14}, StripOnInput -> False], TraditionalForm],
         PlotRangePadding -> Scaled[0.02], Ticks -> {Automatic, None}], 
       GraphicsBox[{{
          Opacity[0], 
          
          PointBox[{{0.011424711209809146`, 0.4990857618568485}, {
           11.725589147557129`, 3.5009142381431513`}}]}, {
          RGBColor[
          0.798413061722744, 0.824719615472648, 0.968322270542458], {}, {
           RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{1.215309695808869, 0.7509076238812251}, {
                   1.215309695808869, 1.2490923761187749`}, {
                   0.8953110655163283, 1.2490923761187749`}, {
                   0.8953110655163283, 0.7509076238812251}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {11.193127127723159`, 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3.346363132096682, 1.}]}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{1.0811082303273702`, 1.2490923761187749`}, {
                    1.0811082303273702`, 0.7509076238812251}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.8953110655163283, 1.}, {0.6415663418790073, 
                    1.}}, {{1.215309695808869, 1.}, {1.5822053385885713`, 
                    1.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.6415663418790073, 1.1245461880593874`}, {
                    0.6415663418790073, 0.8754538119406126}}, {{
                    1.5822053385885713`, 1.1245461880593874`}, {
                    1.5822053385885713`, 0.8754538119406126}}}]}, {}}]}, 
               ImageSizeCache -> {{51.58578643762689, 170.57784992600943`}, {
                19.585786437626883`, 43.41421356237311}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "11.193127127723159`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "1.215309695808869`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "1.0811082303273702`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.8953110655163283`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.6415663418790073`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
             Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 11.193127127723159`}, {
                  Style["75%", Bold], 1.215309695808869}, {
                  Style["median", Bold], 1.0811082303273702`}, {
                  Style["25%", Bold], 0.8953110655163283}, {
                  Style["min", Bold], 0.6415663418790073}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  PolygonBox[{{1.1135933188651805`, 1.7509076238812251`}, {
                   1.1135933188651805`, 2.249092376118775}, {
                   0.8297766250162697, 2.249092376118775}, {
                   0.8297766250162697, 1.7509076238812251`}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4.956111412596317, 2.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3.0739071405502596`, 2.}]}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{0.9819738029503715, 2.249092376118775}, {
                    0.9819738029503715, 1.7509076238812251`}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.8297766250162697, 2.}, {0.5827780910780601, 
                    2.}}, {{1.1135933188651805`, 2.}, {1.531534862309111, 
                    2.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.5827780910780601, 2.124546188059387}, {
                    0.5827780910780601, 1.8754538119406126`}}, {{
                    1.531534862309111, 2.124546188059387}, {1.531534862309111,
                     1.8754538119406126`}}}]}, {}}]}, 
               ImageSizeCache -> {{50.58578643762691, 
                103.61898994103461`}, {-21.414213562373096`, 
                2.414213562373096}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "4.956111412596317`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "1.1135933188651805`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "0.9819738029503715`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.8297766250162697`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.5827780910780601`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
             Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 4.956111412596317}, {
                  Style["75%", Bold], 1.1135933188651805`}, {
                  Style["median", Bold], 0.9819738029503715}, {
                  Style["25%", Bold], 0.8297766250162697}, {
                  Style["min", Bold], 0.5827780910780601}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{1.1087355912927843`, 2.750907623881225}, {
                   1.1087355912927843`, 3.249092376118775}, {
                   0.745360064212155, 3.249092376118775}, {0.745360064212155, 
                   2.750907623881225}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3.3160312639810776`, 3.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8.291246370802774, 3.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3.816151225382917, 3.}]}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{0.8884330279771728, 3.249092376118775}, {
                    0.8884330279771728, 2.750907623881225}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.745360064212155, 3.}, {0.5438867310437782, 
                    3.}}, {{1.1087355912927843`, 3.}, {1.3314014257752922`, 
                    3.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.5438867310437782, 3.124546188059387}, {
                    0.5438867310437782, 2.875453811940613}}, {{
                    1.3314014257752922`, 3.124546188059387}, {
                    1.3314014257752922`, 2.875453811940613}}}]}, {}}]}, 
               ImageSizeCache -> {{50.58578643762689, 
                139.42406802604302`}, {-63.414213562373114`, \
-39.58578643762689}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "8.291246370802774`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "1.1087355912927843`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "0.8884330279771728`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.745360064212155`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.5438867310437782`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
             Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 8.291246370802774}, {
                  Style["75%", Bold], 1.1087355912927843`}, {
                  Style["median", Bold], 0.8884330279771728}, {
                  Style["25%", Bold], 0.745360064212155}, {
                  Style["min", Bold], 0.5438867310437782}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {}], 
              "Tooltip"]& ]}}, {}, {}}, {{{{{{{}, {}}, {}}, {{{}, {}}, {}}, \
{{{}, {}}, {}}}, {}}, {}}, {}}, {}}, AspectRatio -> 1, Axes -> {False, False},
         Frame -> True, FrameLabel -> {{None, None}, {
           FormBox["\"nmse\"", TraditionalForm], None}}, 
        FrameTicks -> {{{{0.7509076238812251, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {3.249092376118775, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {1., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {1., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"cart\"", ",", "4"}], ")"}], TraditionalForm], 0}, {
            2., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {2., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"cart\"", ",", "3"}], ")"}], TraditionalForm], 0}, {
            3., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {3., 
             FormBox[
              RowBox[{"cv", "(", "\"lm\"", ")"}], TraditionalForm], 0}}, {{
            0.7509076238812251, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {3.249092376118775, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {1., 
             FormBox[
              InterpretationBox[
               StyleBox[
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {2., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {3., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}}}, {
          Automatic, Automatic}}, PlotLabel -> FormBox[
          StyleBox["a2", {Bold, 14}, StripOnInput -> False], TraditionalForm],
         PlotRangePadding -> Scaled[0.02], Ticks -> {Automatic, None}], 
       GraphicsBox[{{
          Opacity[0], 
          
          PointBox[{{0.4202120285692009, 0.4990857618568485}, {
           5.421350192157992, 3.5009142381431513`}}]}, {
          RGBColor[
          0.798413061722744, 0.824719615472648, 0.968322270542458], {}, {
           RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{1.2805548568217398`, 0.7509076238812251}, {
                   1.2805548568217398`, 1.2490923761187749`}, {
                   0.9877792222841568, 1.2490923761187749`}, {
                   0.9877792222841568, 0.7509076238812251}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.7885244566559475`, 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.8563579887732784`, 1.}]}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5.1940257301766835`, 1.}]}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{1.091116291521646, 1.2490923761187749`}, {
                    1.091116291521646, 0.7509076238812251}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.9877792222841568, 1.}, {0.7462362383409233, 
                    1.}}, {{1.2805548568217398`, 1.}, {1.4627721462522545`, 
                    1.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.7462362383409233, 1.1245461880593874`}, {
                    0.7462362383409233, 0.8754538119406126}}, {{
                    1.4627721462522545`, 1.1245461880593874`}, {
                    1.4627721462522545`, 0.8754538119406126}}}]}, {}}]}, 
               ImageSizeCache -> {{52.58578643762689, 170.5778499260095}, {
                19.585786437626883`, 43.41421356237311}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "5.1940257301766835`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "1.2805548568217398`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "1.091116291521646`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.9877792222841568`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.7462362383409233`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
             Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 5.1940257301766835`}, {
                  Style["75%", Bold], 1.2805548568217398`}, {
                  Style["median", Bold], 1.091116291521646}, {
                  Style["25%", Bold], 0.9877792222841568}, {
                  Style["min", Bold], 0.7462362383409233}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{1.4401207316568185`, 1.7509076238812251`}, {
                   1.4401207316568185`, 2.249092376118775}, {
                   1.0306570475514154`, 2.249092376118775}, {
                   1.0306570475514154`, 1.7509076238812251`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    2.1488122920563737`, 2.}]}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4.321498329730113, 2.}]}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{1.114841001571883, 2.249092376118775}, {
                    1.114841001571883, 1.7509076238812251`}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{1.0306570475514154`, 2.}, {0.8661634891701132, 
                    2.}}, {{1.4401207316568185`, 2.}, {1.7951784904775814`, 
                    2.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.8661634891701132, 2.124546188059387}, {
                    0.8661634891701132, 1.8754538119406126`}}, {{
                    1.7951784904775814`, 2.124546188059387}, {
                    1.7951784904775814`, 1.8754538119406126`}}}]}, {}}]}, 
               ImageSizeCache -> {{55.58578643762689, 
                148.63703519726386`}, {-21.414213562373106`, 
                2.4142135623731065`}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "4.321498329730113`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "1.4401207316568185`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "1.114841001571883`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "1.0306570475514154`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.8661634891701132`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
             Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 4.321498329730113}, {
                  Style["75%", Bold], 1.4401207316568185`}, {
                  Style["median", Bold], 1.114841001571883}, {
                  Style["25%", Bold], 1.0306570475514154`}, {
                  Style["min", Bold], 0.8661634891701132}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{1.1697332556418245`, 2.750907623881225}, {
                   1.1697332556418245`, 3.249092376118775}, {
                   0.8980730664663935, 3.249092376118775}, {
                   0.8980730664663935, 2.750907623881225}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.8388423782164498`, 3.}]}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3.09026732791703, 3.}]}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{0.9565019191854517, 3.249092376118775}, {
                    0.9565019191854517, 2.750907623881225}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.8980730664663935, 3.}, {0.6475364905505097, 
                    3.}}, {{1.1697332556418245`, 3.}, {1.4020799712797374`, 
                    3.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.6475364905505097, 3.124546188059387}, {
                    0.6475364905505097, 2.875453811940613}}, {{
                    1.4020799712797374`, 3.124546188059387}, {
                    1.4020799712797374`, 2.875453811940613}}}]}, {}}]}, 
               ImageSizeCache -> {{50.58578643762691, 
                117.67616074765631`}, {-63.4142135623731, \
-39.58578643762691}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "3.09026732791703`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "1.1697332556418245`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "0.9565019191854517`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.8980730664663935`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.6475364905505097`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
             Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 3.09026732791703}, {
                  Style["75%", Bold], 1.1697332556418245`}, {
                  Style["median", Bold], 0.9565019191854517}, {
                  Style["25%", Bold], 0.8980730664663935}, {
                  Style["min", Bold], 0.6475364905505097}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {}], 
              "Tooltip"]& ]}}, {}, {}}, {{{{{{{}, {}}, {}}, {{{}, {}}, {}}, \
{{{}, {}}, {}}}, {}}, {}}, {}}, {}}, AspectRatio -> 1, Axes -> {False, False},
         Frame -> True, FrameLabel -> {{None, None}, {
           FormBox["\"nmse\"", TraditionalForm], None}}, 
        FrameTicks -> {{{{0.7509076238812251, 
             FormBox[
              InterpretationBox[
               StyleBox[
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {3.249092376118775, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {1., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {1., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"cart\"", ",", "4"}], ")"}], TraditionalForm], 0}, {
            2., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {2., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"cart\"", ",", "3"}], ")"}], TraditionalForm], 0}, {
            3., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {3., 
             FormBox[
              RowBox[{"cv", "(", "\"lm\"", ")"}], TraditionalForm], 0}}, {{
            0.7509076238812251, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {3.249092376118775, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {1., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {2., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {3., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}}}, {
          Automatic, Automatic}}, PlotLabel -> FormBox[
          StyleBox["a3", {Bold, 14}, StripOnInput -> False], TraditionalForm],
         PlotRangePadding -> Scaled[0.02], Ticks -> {Automatic, None}]}, {
       GraphicsBox[{{
          Opacity[0], 
          
          PointBox[{{-0.23789572980538903`, 0.4990857618568485}, {
           14.85288130376934, 3.5009142381431513`}}]}, {
          RGBColor[
          0.798413061722744, 0.824719615472648, 0.968322270542458], {}, {
           RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{2.1872357864646492`, 0.7509076238812251}, {
                   2.1872357864646492`, 1.2490923761187749`}, {
                   1.0110138733146703`, 1.2490923761187749`}, {
                   1.0110138733146703`, 0.7509076238812251}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    5.329917333040663, 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    4.643555179274295, 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    5.326224963913996, 1.}]}, {}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{1.299959640381842, 1.2490923761187749`}, {
                    1.299959640381842, 0.7509076238812251}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{1.0110138733146703`, 1.}, {0.7418012323769491, 
                    1.}}, {{2.1872357864646492`, 1.}, {3.5879213357889337`, 
                    1.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.7418012323769491, 1.1245461880593874`}, {
                    0.7418012323769491, 0.8754538119406126}}, {{
                    3.5879213357889337`, 1.1245461880593874`}, {
                    3.5879213357889337`, 0.8754538119406126}}}]}, {}}]}, 
               ImageSizeCache -> {{52.58578643762691, 96.93395621483299}, {
                19.585786437626886`, 43.41421356237309}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "5.329917333040663`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "2.1872357864646492`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "1.299959640381842`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "1.0110138733146703`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.7418012323769491`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
             Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 5.329917333040663}, {
                  Style["75%", Bold], 2.1872357864646492`}, {
                  Style["median", Bold], 1.299959640381842}, {
                  Style["25%", Bold], 1.0110138733146703`}, {
                  Style["min", Bold], 0.7418012323769491}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{2.3000851601367724`, 1.7509076238812251`}, {
                   2.3000851601367724`, 2.249092376118775}, {
                   1.0226255435174083`, 2.249092376118775}, {
                   1.0226255435174083`, 1.7509076238812251`}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {8.450517843269989, 2.}]}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{1.4281423725138611`, 2.249092376118775}, {
                    1.4281423725138611`, 1.7509076238812251`}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{1.0226255435174083`, 2.}, {0.44804868081164423`,
                     2.}}, {{2.3000851601367724`, 2.}, {3.997994334970164, 
                    2.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.44804868081164423`, 2.124546188059387}, {
                    0.44804868081164423`, 1.8754538119406126`}}, {{
                    3.997994334970164, 2.124546188059387}, {3.997994334970164,
                     1.8754538119406126`}}}]}, {}}]}, 
               ImageSizeCache -> {{50.58578643762691, 
                122.9396893386678}, {-21.414213562373096`, 
                2.414213562373096}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "8.450517843269989`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "2.3000851601367724`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "1.4281423725138611`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "1.0226255435174083`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.44804868081164423`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
             Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 8.450517843269989}, {
                  Style["75%", Bold], 2.3000851601367724`}, {
                  Style["median", Bold], 1.4281423725138611`}, {
                  Style["25%", Bold], 1.0226255435174083`}, {
                  Style["min", Bold], 0.44804868081164423`}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{2.3126056442372707`, 2.750907623881225}, {
                   2.3126056442372707`, 3.249092376118775}, {
                   0.9651898562463643, 3.249092376118775}, {
                   0.9651898562463643, 2.750907623881225}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    5.840453496190693, 3.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    5.347946607481437, 3.}]}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {14.166936893152307`, 3.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {11.26113074705489, 3.}]}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{1.1495592399089218`, 3.249092376118775}, {
                    1.1495592399089218`, 2.750907623881225}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.9651898562463643, 3.}, {0.6987225094840317, 
                    3.}}, {{2.3126056442372707`, 3.}, {4.187625448118475, 
                    3.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.6987225094840317, 3.124546188059387}, {
                    0.6987225094840317, 2.875453811940613}}, {{
                    4.187625448118475, 3.124546188059387}, {4.187625448118475,
                     2.875453811940613}}}]}, {}}]}, 
               ImageSizeCache -> {{52.58578643762689, 
                170.5778499260095}, {-63.414213562373114`, \
-39.58578643762689}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "14.166936893152307`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "2.3126056442372707`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "1.1495592399089218`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.9651898562463643`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.6987225094840317`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
             Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 14.166936893152307`}, {
                  Style["75%", Bold], 2.3126056442372707`}, {
                  Style["median", Bold], 1.1495592399089218`}, {
                  Style["25%", Bold], 0.9651898562463643}, {
                  Style["min", Bold], 0.6987225094840317}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {}], 
              "Tooltip"]& ]}}, {}, {}}, {{{{{{{}, {}}, {}}, {{{}, {}}, {}}, \
{{{}, {}}, {}}}, {}}, {}}, {}}, {}}, AspectRatio -> 1, Axes -> {False, False},
         Frame -> True, FrameLabel -> {{None, None}, {
           FormBox["\"nmse\"", TraditionalForm], None}}, 
        FrameTicks -> {{{{0.7509076238812251, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {3.249092376118775, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {1., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {1., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"cart\"", ",", "4"}], ")"}], TraditionalForm], 0}, {
            2., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {2., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"cart\"", ",", "3"}], ")"}], TraditionalForm], 0}, {
            3., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {3., 
             FormBox[
              RowBox[{"cv", "(", "\"lm\"", ")"}], TraditionalForm], 0}}, {{
            0.7509076238812251, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {3.249092376118775, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {1., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {2., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {3., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}}}, {
          Automatic, Automatic}}, PlotLabel -> FormBox[
          StyleBox["a4", {Bold, 14}, StripOnInput -> False], TraditionalForm],
         PlotRangePadding -> Scaled[0.02], Ticks -> {Automatic, None}], 
       GraphicsBox[{{
          Opacity[0], 
          
          PointBox[{{0.19623806419173406`, 0.4990857618568485}, {
           4.506413600876167, 3.5009142381431513`}}]}, {
          RGBColor[
          0.798413061722744, 0.824719615472648, 0.968322270542458], {}, {
           RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{1.1679338102209853`, 0.7509076238812251}, {
                   1.1679338102209853`, 1.2490923761187749`}, {
                   0.8474267526531906, 1.2490923761187749`}, {
                   0.8474267526531906, 0.7509076238812251}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.9385898474545362`, 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.6623867858839405`, 1.}]}, {}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{1.0457797724061615`, 1.2490923761187749`}, {
                    1.0457797724061615`, 0.7509076238812251}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.8474267526531906, 1.}, {0.5796226460192964, 
                    1.}}, {{1.1679338102209853`, 1.}, {1.4965113889547577`, 
                    1.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.5796226460192964, 1.1245461880593874`}, {
                    0.5796226460192964, 0.8754538119406126}}, {{
                    1.4965113889547577`, 1.1245461880593874`}, {
                    1.4965113889547577`, 0.8754538119406126}}}]}, {}}]}, 
               ImageSizeCache -> {{55.58578643762691, 101.37162340756117`}, {
                19.585786437626886`, 43.41421356237309}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "1.9385898474545362`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "1.1679338102209853`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "1.0457797724061615`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.8474267526531906`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.5796226460192964`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
             Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 1.9385898474545362`}, {
                  Style["75%", Bold], 1.1679338102209853`}, {
                  Style["median", Bold], 1.0457797724061615`}, {
                  Style["25%", Bold], 0.8474267526531906}, {
                  Style["min", Bold], 0.5796226460192964}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{1.2979337925895715`, 1.7509076238812251`}, {
                   1.2979337925895715`, 2.249092376118775}, {
                   0.9290299788090839, 2.249092376118775}, {
                   0.9290299788090839, 1.7509076238812251`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    2.014647887801275, 2.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    2.309780926714016, 2.}]}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3.3134892404278347`, 2.}]}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{1.0595888717441349`, 2.249092376118775}, {
                    1.0595888717441349`, 1.7509076238812251`}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.9290299788090839, 2.}, {0.3921551340410265, 
                    2.}}, {{1.2979337925895715`, 2.}, {1.6728506697374443`, 
                    2.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.3921551340410265, 2.124546188059387}, {
                    0.3921551340410265, 1.8754538119406126`}}, {{
                    1.6728506697374443`, 2.124546188059387}, {
                    1.6728506697374443`, 1.8754538119406126`}}}]}, {}}]}, 
               ImageSizeCache -> {{50.58578643762689, 
                141.48770364343238`}, {-21.414213562373106`, 
                2.4142135623731065`}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "3.3134892404278347`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "1.2979337925895715`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "1.0595888717441349`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.9290299788090839`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.3921551340410265`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
             Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 3.3134892404278347`}, {
                  Style["75%", Bold], 1.2979337925895715`}, {
                  Style["median", Bold], 1.0595888717441349`}, {
                  Style["25%", Bold], 0.9290299788090839}, {
                  Style["min", Bold], 0.3921551340410265}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{1.2066299899407082`, 2.750907623881225}, {
                   1.2066299899407082`, 3.249092376118775}, {
                   0.7372317522259595, 3.249092376118775}, {
                   0.7372317522259595, 2.750907623881225}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4.310496531026875, 3.}]}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{0.9148211291300732, 3.249092376118775}, {
                    0.9148211291300732, 2.750907623881225}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.7372317522259595, 3.}, {0.47098190301267384`, 
                    3.}}, {{1.2066299899407082`, 3.}, {1.6748381994476689`, 
                    3.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.47098190301267384`, 3.124546188059387}, {
                    0.47098190301267384`, 2.875453811940613}}, {{
                    1.6748381994476689`, 3.124546188059387}, {
                    1.6748381994476689`, 2.875453811940613}}}]}, {}}]}, 
               ImageSizeCache -> {{52.58578643762689, 
                170.5778499260095}, {-63.414213562373114`, \
-39.58578643762689}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "4.310496531026875`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "1.2066299899407082`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "0.9148211291300732`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.7372317522259595`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.47098190301267384`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
             Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 4.310496531026875}, {
                  Style["75%", Bold], 1.2066299899407082`}, {
                  Style["median", Bold], 0.9148211291300732}, {
                  Style["25%", Bold], 0.7372317522259595}, {
                  Style["min", Bold], 0.47098190301267384`}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {}], 
              "Tooltip"]& ]}}, {}, {}}, {{{{{{{}, {}}, {}}, {{{}, {}}, {}}, \
{{{}, {}}, {}}}, {}}, {}}, {}}, {}}, AspectRatio -> 1, Axes -> {False, False},
         Frame -> True, FrameLabel -> {{None, None}, {
           FormBox["\"nmse\"", TraditionalForm], None}}, 
        FrameTicks -> {{{{0.7509076238812251, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {3.249092376118775, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {1., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {1., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"cart\"", ",", "4"}], ")"}], TraditionalForm], 0}, {
            2., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {2., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"cart\"", ",", "3"}], ")"}], TraditionalForm], 0}, {
            3., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {3., 
             FormBox[
              RowBox[{"cv", "(", "\"lm\"", ")"}], TraditionalForm], 0}}, {{
            0.7509076238812251, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {3.249092376118775, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {1., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {2., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {3., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}}}, {
          Automatic, Automatic}}, PlotLabel -> FormBox[
          StyleBox["a5", {Bold, 14}, StripOnInput -> False], TraditionalForm],
         PlotRangePadding -> Scaled[0.02], Ticks -> {Automatic, None}], 
       GraphicsBox[{{
          Opacity[0], 
          
          PointBox[{{-0.3749446702747963, 0.4990857618568485}, {
           10.757701489579597`, 3.5009142381431513`}}]}, {
          RGBColor[
          0.798413061722744, 0.824719615472648, 0.968322270542458], {}, {
           RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{1.6276918793835307`, 0.7509076238812251}, {
                   1.6276918793835307`, 1.2490923761187749`}, {
                   0.9117553416394969, 1.2490923761187749`}, {
                   0.9117553416394969, 0.7509076238812251}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5.534268701414282, 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {10.251672118677124`, 1.}]}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{1.077654498370164, 1.2490923761187749`}, {
                    1.077654498370164, 0.7509076238812251}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.9117553416394969, 1.}, {0.5972191957617937, 
                    1.}}, {{1.6276918793835307`, 1.}, {2.375392181304062, 
                    1.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.5972191957617937, 1.1245461880593874`}, {
                    0.5972191957617937, 0.8754538119406126}}, {{
                    2.375392181304062, 1.1245461880593874`}, {
                    2.375392181304062, 0.8754538119406126}}}]}, {}}]}, 
               ImageSizeCache -> {{55.58578643762689, 170.57784992600943`}, {
                19.585786437626883`, 43.41421356237311}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "10.251672118677124`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "1.6276918793835307`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "1.077654498370164`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.9117553416394969`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.5972191957617937`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
             Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 10.251672118677124`}, {
                  Style["75%", Bold], 1.6276918793835307`}, {
                  Style["median", Bold], 1.077654498370164}, {
                  Style["25%", Bold], 0.9117553416394969}, {
                  Style["min", Bold], 0.5972191957617937}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{1.417686479842041, 1.7509076238812251`}, {
                   1.417686479842041, 2.249092376118775}, {0.9625260351269751,
                    2.249092376118775}, {0.9625260351269751, 
                   1.7509076238812251`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    2.488976401798549, 2.}]}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5.873447237100517, 2.}]}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{1.0480506706266601`, 2.249092376118775}, {
                    1.0480506706266601`, 1.7509076238812251`}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.9625260351269751, 2.}, {0.7080200179324013, 
                    2.}}, {{1.417686479842041, 2.}, {1.9782401547703485`, 
                    2.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.7080200179324013, 2.124546188059387}, {
                    0.7080200179324013, 1.8754538119406126`}}, {{
                    1.9782401547703485`, 2.124546188059387}, {
                    1.9782401547703485`, 1.8754538119406126`}}}]}, {}}]}, 
               ImageSizeCache -> {{56.58578643762691, 
                121.11920791036529`}, {-21.414213562373096`, 
                2.414213562373096}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "5.873447237100517`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "1.417686479842041`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "1.0480506706266601`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.9625260351269751`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.7080200179324013`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
             Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 5.873447237100517}, {
                  Style["75%", Bold], 1.417686479842041}, {
                  Style["median", Bold], 1.0480506706266601`}, {
                  Style["25%", Bold], 0.9625260351269751}, {
                  Style["min", Bold], 0.7080200179324013}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{1.1019075699881524`, 2.750907623881225}, {
                   1.1019075699881524`, 3.249092376118775}, {
                   0.7473662243173114, 3.249092376118775}, {
                   0.7473662243173114, 2.750907623881225}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    0.13108470062767616`, 3.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    0.17636728535353774`, 3.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    0.17891870843339938`, 3.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.7789089073904827`, 3.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.8255724964357312`, 3.}]}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {3.0804824737178245`, 3.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2.4818356845447727`, 3.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {5.759928294176851, 3.}]}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{0.8537447008078457, 3.249092376118775}, {
                    0.8537447008078457, 2.750907623881225}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.7473662243173114, 3.}, {0.5859675076522262, 
                    3.}}, {{1.1019075699881524`, 3.}, {1.4115512170199076`, 
                    3.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.5859675076522262, 3.124546188059387}, {
                    0.5859675076522262, 2.875453811940613}}, {{
                    1.4115512170199076`, 3.124546188059387}, {
                    1.4115512170199076`, 2.875453811940613}}}]}, {}}]}, 
               ImageSizeCache -> {{48.42215007399055, 
                119.83684053273664`}, {-63.4142135623731, \
-39.58578643762691}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "5.759928294176851`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "1.1019075699881524`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "0.8537447008078457`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.7473662243173114`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.13108470062767616`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
             Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 5.759928294176851}, {
                  Style["75%", Bold], 1.1019075699881524`}, {
                  Style["median", Bold], 0.8537447008078457}, {
                  Style["25%", Bold], 0.7473662243173114}, {
                  Style["min", Bold], 0.13108470062767616`}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {}], 
              "Tooltip"]& ]}}, {}, {}}, {{{{{{{}, {}}, {}}, {{{}, {}}, {}}, \
{{{}, {}}, {}}}, {}}, {}}, {}}, {}}, AspectRatio -> 1, Axes -> {False, False},
         Frame -> True, FrameLabel -> {{None, None}, {
           FormBox["\"nmse\"", TraditionalForm], None}}, 
        FrameTicks -> {{{{0.7509076238812251, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {3.249092376118775, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {1., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {1., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"cart\"", ",", "4"}], ")"}], TraditionalForm], 0}, {
            2., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {2., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"cart\"", ",", "3"}], ")"}], TraditionalForm], 0}, {
            3., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {3., 
             FormBox[
              RowBox[{"cv", "(", "\"lm\"", ")"}], TraditionalForm], 0}}, {{
            0.7509076238812251, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {3.249092376118775, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {1., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {2., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {3., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}}}, {
          Automatic, Automatic}}, PlotLabel -> FormBox[
          StyleBox["a6", {Bold, 14}, StripOnInput -> False], TraditionalForm],
         PlotRangePadding -> Scaled[0.02], Ticks -> {Automatic, None}]}, {
       GraphicsBox[{{
          Opacity[0], 
          
          PointBox[{{-1.861139877282322, 0.4990857618568485}, {
           51.25731304351249, 3.5009142381431513`}}]}, {
          RGBColor[
          0.798413061722744, 0.824719615472648, 0.968322270542458], {}, {
           RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{2.4706351019253634`, 0.7509076238812251}, {
                   2.4706351019253634`, 1.2490923761187749`}, {
                   1.0858802047660885`, 1.2490923761187749`}, {
                   1.0858802047660885`, 0.7509076238812251}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    6.3598603729628405`, 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    5.63575970135401, 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    5.769905102726533, 1.}]}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {13.491935556607828`, 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {48.84283791074909, 1.}]}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{1.2629900165369583`, 1.2490923761187749`}, {
                    1.2629900165369583`, 0.7509076238812251}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{1.0858802047660885`, 1.}, {0.7658618265601516, 
                    1.}}, {{2.4706351019253634`, 1.}, {3.86745490407284, 
                    1.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.7658618265601516, 1.1245461880593874`}, {
                    0.7658618265601516, 0.8754538119406126}}, {{
                    3.86745490407284, 1.1245461880593874`}, {3.86745490407284,
                     0.8754538119406126}}}]}, {}}]}, 
               ImageSizeCache -> {{50.58578643762689, 170.5778499260095}, {
                19.585786437626883`, 43.41421356237311}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "48.84283791074909`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "2.4706351019253634`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "1.2629900165369583`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "1.0858802047660885`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.7658618265601516`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
             Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 48.84283791074909}, {
                  Style["75%", Bold], 2.4706351019253634`}, {
                  Style["median", Bold], 1.2629900165369583`}, {
                  Style["25%", Bold], 1.0858802047660885`}, {
                  Style["min", Bold], 0.7658618265601516}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{2.1278877061755073`, 1.7509076238812251`}, {
                   2.1278877061755073`, 2.249092376118775}, {
                   1.0667356869081603`, 2.249092376118775}, {
                   1.0667356869081603`, 1.7509076238812251`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    3.730713533977274, 2.}]}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {14.192837723999588`, 2.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {10.144047009313626`, 2.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6.642736968377143, 2.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {39.29616705454113, 2.}]}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{1.2407803797281731`, 2.249092376118775}, {
                    1.2407803797281731`, 1.7509076238812251`}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{1.0667356869081603`, 2.}, {0.5533352554810786, 
                    2.}}, {{2.1278877061755073`, 2.}, {3.4093174117028493`, 
                    2.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.5533352554810786, 2.124546188059387}, {
                    0.5533352554810786, 1.8754538119406126`}}, {{
                    3.4093174117028493`, 2.124546188059387}, {
                    3.4093174117028493`, 1.8754538119406126`}}}]}, {}}]}, 
               ImageSizeCache -> {{50.58578643762689, 
                147.97573595505258`}, {-21.414213562373106`, 
                2.4142135623731065`}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "39.29616705454113`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "2.1278877061755073`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "1.2407803797281731`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "1.0667356869081603`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.5533352554810786`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
             Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 39.29616705454113}, {
                  Style["75%", Bold], 2.1278877061755073`}, {
                  Style["median", Bold], 1.2407803797281731`}, {
                  Style["25%", Bold], 1.0667356869081603`}, {
                  Style["min", Bold], 0.5533352554810786}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{2.2844750755187704`, 2.750907623881225}, {
                   2.2844750755187704`, 3.249092376118775}, {
                   0.993338899636085, 3.249092376118775}, {0.993338899636085, 
                   2.750907623881225}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    5.209906213467782, 3.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    5.811794615845739, 3.}]}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {13.874739179980939`, 3.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {35.189092271913125`, 3.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {10.18726174958939, 3.}]}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{1.2008148437051398`, 3.249092376118775}, {
                    1.2008148437051398`, 2.750907623881225}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.993338899636085, 3.}, {0.8693653699330647, 
                    3.}}, {{2.2844750755187704`, 3.}, {3.7310535199508883`, 
                    3.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.8693653699330647, 3.124546188059387}, {
                    0.8693653699330647, 2.875453811940613}}, {{
                    3.7310535199508883`, 3.124546188059387}, {
                    3.7310535199508883`, 2.875453811940613}}}]}, {}}]}, 
               ImageSizeCache -> {{51.58578643762689, 
                138.25207692015067`}, {-63.414213562373114`, \
-39.58578643762689}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "35.189092271913125`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "2.2844750755187704`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "1.2008148437051398`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.993338899636085`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.8693653699330647`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {}, StripOnInput -> False]], 
             Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 35.189092271913125`}, {
                  Style["75%", Bold], 2.2844750755187704`}, {
                  Style["median", Bold], 1.2008148437051398`}, {
                  Style["25%", Bold], 0.993338899636085}, {
                  Style["min", Bold], 0.8693653699330647}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {}], 
              "Tooltip"]& ]}}, {}, {}}, {{{{{{{}, {}}, {}}, {{{}, {}}, {}}, \
{{{}, {}}, {}}}, {}}, {}}, {}}, {}}, AspectRatio -> 1, Axes -> {False, False},
         Frame -> True, FrameLabel -> {{None, None}, {
           FormBox["\"nmse\"", TraditionalForm], None}}, 
        FrameTicks -> {{{{0.7509076238812251, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {3.249092376118775, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {1., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {1., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"cart\"", ",", "4"}], ")"}], TraditionalForm], 0}, {
            2., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {2., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"cart\"", ",", "3"}], ")"}], TraditionalForm], 0}, {
            3., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {3., 
             FormBox[
              RowBox[{"cv", "(", "\"lm\"", ")"}], TraditionalForm], 0}}, {{
            0.7509076238812251, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {3.249092376118775, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {1., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {2., 
             FormBox[
              InterpretationBox[
               StyleBox[
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {3., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}}}, {
          Automatic, Automatic}}, PlotLabel -> FormBox[
          StyleBox["a7", {Bold, 14}, StripOnInput -> False], TraditionalForm],
         PlotRangePadding -> Scaled[0.02], Ticks -> {Automatic, None}], "", 
       ""}}, AutoDelete -> False, GridBoxDividers -> {"Columns" -> {{
          GrayLevel[1]}}, "Rows" -> {{
          GrayLevel[1]}}}, 
     GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      GridBoxSpacings -> {"Columns" -> {1, {0}, 1}, "Rows" -> {1, {0}, 1}}], 
    "Grid"],StyleBox[
    TagBox[
     GridBox[{{"\"10-fold cross validation results\""}}, DefaultBaseStyle -> 
      "Column", GridBoxAlignment -> {"Columns" -> {{Center}}}, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Column"], 
    StripOnInput -> False, FontFamily -> "Verdana", FontSize -> 14, 
    FontWeight -> Bold]},
  "Labeled",
  DisplayFunction->(GridBox[{{
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, 
    GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
    BaselinePosition -> {2, 1}]& ),
  InterpretationFunction->(RowBox[{"Labeled", "[", 
     RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.575218970171356*^9, 3.575218982151779*^9}, {
   3.575219019963194*^9, 3.5752190315449038`*^9}, {3.575219083830494*^9, 
   3.575219134544524*^9}, 3.5752877835009527`*^9, {3.58591797550194*^9, 
   3.585918007086615*^9}, 3.585918082166914*^9, 3.5859310107214212`*^9, 
   3.585932473805023*^9, 3.585935888648602*^9, 3.585936091633753*^9, 
   3.585936126428566*^9, {3.586001728190404*^9, 3.586001745703561*^9}, 
   3.586002025242426*^9, 3.586002245921308*^9, 3.586086821768732*^9}]
}, {2}]],

Cell["\<\
For overall evaluation of a model, consider the median over all folds:\
\>", "Text",
 CellChangeTimes->{{3.575219333386137*^9, 3.575219335209622*^9}, {
  3.575286015560985*^9, 3.5752860313837767`*^9}, {3.5859251917106447`*^9, 
  3.585925215827861*^9}, {3.5859324966556673`*^9, 3.585932497247902*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"bestScore", "[", "trials_", "]"}], ":=", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"nmses", "=", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Last", "/@", 
          RowBox[{"Flatten", "[", 
           RowBox[{"#", ",", "1"}], "]"}]}], "&"}], ")"}], "/@", 
       RowBox[{"trials", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2"}], "]"}], "]"}]}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Rule", "@@", 
     RowBox[{"First", "@", 
      RowBox[{"SortBy", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"trials", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", "1"}], "]"}], "]"}], ",", 
           RowBox[{"Median", "/@", "nmses"}]}], "}"}], "]"}], ",", "Last"}], 
       "]"}]}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.575219390286964*^9, 3.5752194464816103`*^9}, {
  3.5752194767855988`*^9, 3.575219529375197*^9}, {3.5752196515027*^9, 
  3.575219732868506*^9}, {3.5752229751248302`*^9, 3.575223004786614*^9}, {
  3.5752230850024967`*^9, 3.57522314000099*^9}, {3.575285773479364*^9, 
  3.5752858068803387`*^9}, {3.575286072435936*^9, 3.575286076354331*^9}, {
  3.575286231689416*^9, 3.5752862414932203`*^9}, {3.575286293908504*^9, 
  3.5752862958433857`*^9}, {3.575286406977828*^9, 3.5752864078576117`*^9}, {
  3.575287812979145*^9, 3.5752878153011427`*^9}, {3.585918142768031*^9, 
  3.5859181466053*^9}, {3.585925277551754*^9, 3.585925286370008*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MapThread", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"#1", ",", 
       RowBox[{"bestScore", "[", "#2", "]"}]}], "}"}], "&"}], ",", 
    RowBox[{"{", 
     RowBox[{"responseColumns", ",", "resAll7"}], "}"}]}], "]"}], "//", 
  "TableForm"}]], "Input",
 CellChangeTimes->{{3.5752195092257338`*^9, 3.575219516153816*^9}, {
  3.575219741014235*^9, 3.5752197934889593`*^9}, {3.57521985049048*^9, 
  3.5752198523803263`*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {"a1", 
     RowBox[{
      RowBox[{"cv", "[", 
       RowBox[{"\<\"cart\"\>", ",", "3"}], "]"}], "\[Rule]", 
      "0.6847813550759062`"}]},
    {"a2", 
     RowBox[{
      RowBox[{"cv", "[", "\<\"lm\"\>", "]"}], "\[Rule]", 
      "0.9033606295907669`"}]},
    {"a3", 
     RowBox[{
      RowBox[{"cv", "[", "\<\"lm\"\>", "]"}], "\[Rule]", 
      "0.9602981831730494`"}]},
    {"a4", 
     RowBox[{
      RowBox[{"cv", "[", "\<\"lm\"\>", "]"}], "\[Rule]", 
      "1.2029241059076883`"}]},
    {"a5", 
     RowBox[{
      RowBox[{"cv", "[", "\<\"lm\"\>", "]"}], "\[Rule]", 
      "0.9246872615634879`"}]},
    {"a6", 
     RowBox[{
      RowBox[{"cv", "[", "\<\"lm\"\>", "]"}], "\[Rule]", 
      "0.8625951568970727`"}]},
    {"a7", 
     RowBox[{
      RowBox[{"cv", "[", "\<\"lm\"\>", "]"}], "\[Rule]", 
      "1.2193049483345146`"}]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.5752197468532887`*^9, {3.575219793909046*^9, 3.575219852743121*^9}, 
   3.575222881081718*^9, 3.575223204988183*^9, 3.575285810626685*^9, 
   3.575286257705612*^9, 3.575286410116963*^9, {3.575287805314272*^9, 
   3.575287817371784*^9}, 3.575802725513578*^9, 3.58591816565676*^9, {
   3.5859252556087217`*^9, 3.5859252793663187`*^9}, 3.585925449754195*^9, 
   3.585931024116982*^9, 3.5859324988895607`*^9, 3.5859360924560537`*^9, 
   3.5859361431585503`*^9, 3.5860017289894657`*^9, 3.586001786263514*^9, 
   3.586002257679311*^9, 3.586086830315013*^9, 3.586090139874917*^9}]
}, Open  ]],

Cell["\<\
On a2-a7, our models don\[CloseCurlyQuote]t perform very well (the cart \
especially), and in fact consistently on a4 and a7 none of the models has any \
predictive value at all.\
\>", "Text",
 CellChangeTimes->{{3.585925461663012*^9, 3.585925481502646*^9}, {
  3.585925667764233*^9, 3.585925686010068*^9}, {3.585936166174226*^9, 
  3.5859361677664557`*^9}, {3.586001807776354*^9, 3.586001808504656*^9}, {
  3.5860022702791653`*^9, 3.586002271143681*^9}}],

Cell["\<\
We might try an ensemble approach called a random forest, where we construct \
a large number of carts (a \[OpenCurlyDoubleQuote]forest\
\[CloseCurlyDoubleQuote]) and conduct a classification by letting the forest \
\[OpenCurlyDoubleQuote]vote.\[CloseCurlyDoubleQuote]\
\>", "Text",
 CellChangeTimes->{{3.585925795623966*^9, 3.585925859215291*^9}, {
  3.586001693338641*^9, 3.586001694290269*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Random Forests", "Title",
 CellChangeTimes->CompressedData["
1:eJwdyk0ow3EYwPGZYiElwsUy707bWsIS5iV5C5uiZbaEib8mC9lFlJ3WVg4M
U5S2iE0zlMNsh9WazetBGDmIaFheMpPyPL/Dt8/ly+pSCHvoNBqNCaFcWXfM
6u6zYNXpIFbfX226wMTWJjPKOCgo8YCvanoparLb5Wira7kP9RhaTIfgjGWP
+LPiD6MaMfcXpQIcqxfU+ya3UQ3PqjgCRaHOIVR54TxF1X8HZ2ho7SmAumNF
L+hDI2f+GLztMRIXupjRJ2BmwzVRb5Nb3sC7sRviiZJ/HATN9g8i3dw/8g5+
1zNGUVdt6iwaVLGI/vTcii/8zseJOYU87TfYLtQRVQGKHQKFZicx4rZGm7b3
LDiLGNeh4baEjSzws3KaWPUYxc4G19clxM7hei8aL0nzoeU7M9w5kKq7JHaw
qSJ037BEjGNOGNEpsYM4wC/u1YM8W6oczVgcSDaAtsj8FLTbuiVFhwbLZGhS
nnsOlTY/EP8BSYMRsQ==
  "]],

Cell["\<\
Construct a large number of carts (typically hundreds) and conduct a \
classification by tallying the decisions of every tree in the forest.\
\>", "Text",
 CellChangeTimes->{{3.586015806160285*^9, 3.5860158191875*^9}, {
  3.586086237954508*^9, 3.5860862532251387`*^9}}],

Cell["\<\
The carts are independent, so the forest construction can be parallelized \
trivially.  Note we effectively remove the split length requirement on the \
nodes to avoid splintered voting.\
\>", "Text",
 CellChangeTimes->{{3.585926047540291*^9, 3.5859260659387913`*^9}, {
  3.5859352537702837`*^9, 3.585935278607502*^9}, {3.585935349326535*^9, 
  3.5859353550866737`*^9}, {3.58593539248564*^9, 3.5859354268048162`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"randomForest", "[", 
   RowBox[{"x_", ",", "y_", ",", "m_", ",", "ntree_"}], "]"}], ":=", 
  RowBox[{"ParallelTable", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"boot", "=", 
      RowBox[{"RandomChoice", "[", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"Length", "[", "y", "]"}], "]"}], ",", 
        RowBox[{"Length", "[", "y", "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"cart", "[", 
      RowBox[{
       RowBox[{"x", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "boot"}], "]"}], "]"}], ",", 
       RowBox[{"y", "[", 
        RowBox[{"[", "boot", "]"}], "]"}], ",", "m", ",", 
       RowBox[{"\"\<MinSplit\>\"", "\[Rule]", "1"}]}], "]"}]}], ",", 
    RowBox[{"{", "ntree", "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.571597203004287*^9, 3.571597203007347*^9}, {
   3.572018982994432*^9, 3.572018985225662*^9}, {3.572103599982379*^9, 
   3.572103601715974*^9}, {3.5721131713055143`*^9, 3.572113257908746*^9}, {
   3.5721132991827297`*^9, 3.572113300873817*^9}, {3.5752850174305353`*^9, 
   3.575285139004065*^9}, {3.575285201435759*^9, 3.575285202890244*^9}, 
   3.585925977620852*^9, {3.585930070434334*^9, 3.585930163416624*^9}, {
   3.585930194815906*^9, 3.585930307205666*^9}, {3.585930378413766*^9, 
   3.5859303825726757`*^9}, {3.5859304302461767`*^9, 3.585930493681993*^9}, {
   3.585930568411549*^9, 3.58593064163939*^9}, {3.585930700945087*^9, 
   3.5859307259095707`*^9}, {3.585932520376671*^9, 3.585932521369412*^9}, {
   3.585933859094516*^9, 3.585933862654347*^9}, {3.585934367356532*^9, 
   3.585934367524314*^9}, {3.585934471522657*^9, 3.5859344737695417`*^9}, 
   3.585934581752348*^9, {3.585934647605302*^9, 3.585934647735764*^9}, {
   3.5859348550348*^9, 3.585934882065181*^9}}],

Cell["\<\
To let the forest vote, tally the classifications.  For a nominal variable, \
one would generally take the commonest member, but we will use a weighted \
average:\
\>", "Text",
 CellChangeTimes->{{3.58592608084217*^9, 3.585926108209413*^9}, {
  3.585935439614265*^9, 3.58593547131595*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"rfClassify", "[", 
   RowBox[{"input_", ",", "forest_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"First", "[", "#", "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"maxI", "[", 
       RowBox[{"Last", "[", "#", "]"}], "]"}], "]"}], "]"}], "&"}], "[", 
   RowBox[{"Transpose", "[", 
    RowBox[{"Tally", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"classify", "[", 
        RowBox[{"input", ",", "#"}], "]"}], "&"}], "/@", "forest"}], "]"}], 
    "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.571597203004287*^9, 3.571597203007347*^9}, {
   3.572018982994432*^9, 3.572018985225662*^9}, {3.572103599982379*^9, 
   3.572103601715974*^9}, {3.5721131713055143`*^9, 3.572113257908746*^9}, {
   3.5721132991827297`*^9, 3.572113300873817*^9}, {3.5752850174305353`*^9, 
   3.575285139004065*^9}, {3.575285201435759*^9, 3.575285202890244*^9}, 
   3.585925977620852*^9, 3.585926026593856*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"rfClassifyAve", "[", 
   RowBox[{"input_", ",", "forest_"}], "]"}], ":=", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"t", "=", 
      RowBox[{"Tally", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"classify", "[", 
          RowBox[{"input", ",", "#"}], "]"}], "&"}], "/@", "forest"}], 
       "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Total", "[", 
      RowBox[{"Times", "@@@", "t"}], "]"}], "/", 
     RowBox[{"Total", "[", 
      RowBox[{"t", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.5859350841623573`*^9, 3.5859351370764437`*^9}}],

Cell[CellGroupData[{

Cell["Extended model definition for random forest", "Subsubsection",
 CellChangeTimes->{{3.585926299170279*^9, 3.5859263065176888`*^9}},
 FontColor->GrayLevel[0.5]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"extModel", "[", "\"\<rf\>\"", "]"}], "[", 
    RowBox[{
    "nVar_", ",", "nTrees_", ",", "train_", ",", "featureCols_", ",", 
     "respCol_", ",", "test_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"sym", ",", "denomTrain", ",", "denomTest"}], "}"}], ",", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"denomTrain", "=", 
       RowBox[{"Transpose", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"train", "[", "#", "]"}], "/.", 
           RowBox[{
            RowBox[{"x_List", "/;", 
             RowBox[{"train", "[", 
              RowBox[{"#", ",", "\"\<factorized\>\""}], "]"}]}], 
            "\[RuleDelayed]", 
            RowBox[{"denominalizeVect", "[", 
             RowBox[{"train", ",", "#"}], "]"}]}]}], "&"}], "/@", 
         RowBox[{"Append", "[", 
          RowBox[{"featureCols", ",", "respCol"}], "]"}]}], 
        "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"model", "[", "sym", "]"}], "^=", 
       RowBox[{"randomForest", "[", 
        RowBox[{
         RowBox[{"Transpose", "@", 
          RowBox[{"denomTrain", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", 
             RowBox[{"1", ";;", 
              RowBox[{"-", "2"}]}]}], "]"}], "]"}]}], ",", 
         RowBox[{"denomTrain", "[", 
          RowBox[{"[", 
           RowBox[{"All", ",", 
            RowBox[{"-", "1"}]}], "]"}], "]"}], ",", "nVar", ",", "nTrees"}], 
        "]"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"denomTest", "=", 
       RowBox[{"Transpose", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"test", "[", "#", "]"}], "/.", 
           RowBox[{
            RowBox[{"x_List", "/;", 
             RowBox[{"test", "[", 
              RowBox[{"#", ",", "\"\<factorized\>\""}], "]"}]}], 
            "\[RuleDelayed]", 
            RowBox[{"denominalizeVect", "[", 
             RowBox[{"test", ",", "#"}], "]"}]}]}], "&"}], "/@", 
         RowBox[{"Append", "[", 
          RowBox[{"featureCols", ",", "respCol"}], "]"}]}], 
        "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"predictions", "[", "sym", "]"}], "^=", 
       RowBox[{"With", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"dat", "=", "denomTest"}], "}"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"rfClassifyAve", "[", 
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", 
               RowBox[{"1", ";;", 
                RowBox[{"-", "2"}]}], "]"}], "]"}], ",", 
             RowBox[{"model", "[", "sym", "]"}]}], "]"}], "&"}], "/@", 
          "dat"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"errors", "[", "sym", "]"}], "^=", 
       RowBox[{"With", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"errFns", "=", 
           RowBox[{"{", 
            RowBox[{"MAE", ",", "MSE", ",", "NMSE"}], "}"}]}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Rule", "@@@", 
          RowBox[{"Transpose", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"ToString", "/@", "errFns"}], ",", 
             RowBox[{"Through", "[", 
              RowBox[{"errFns", "[", 
               RowBox[{
                RowBox[{"predictions", "[", "sym", "]"}], ",", 
                RowBox[{"test", "[", "respCol", "]"}]}], "]"}], "]"}]}], 
            "}"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", "sym"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.571597203004287*^9, 3.571597203007347*^9}, {
   3.572018982994432*^9, 3.572018985225662*^9}, {3.572103599982379*^9, 
   3.572103601715974*^9}, {3.5721131713055143`*^9, 3.572113257908746*^9}, {
   3.5721132991827297`*^9, 3.572113300873817*^9}, {3.5752850174305353`*^9, 
   3.575285139004065*^9}, {3.575285201435759*^9, 3.575285202890244*^9}, 
   3.585925977620852*^9, 3.585926026593856*^9, {3.585926233411834*^9, 
   3.585926239114326*^9}, 3.585926286623116*^9, {3.5859351484462013`*^9, 
   3.585935148921289*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"cv", "[", 
     RowBox[{"\"\<rf\>\"", ",", "3", ",", "700"}], "]"}], "[", "args__", 
    "]"}], ":=", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"em", "=", 
       RowBox[{
        RowBox[{"extModel", "[", "\"\<rf\>\"", "]"}], "[", 
        RowBox[{"3", ",", "700", ",", "args"}], "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"errors", "[", "em", "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", 
        RowBox[{"-", "1"}]}], "]"}], "]"}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"cv", "[", 
     RowBox[{"\"\<rf\>\"", ",", "3", ",", "500"}], "]"}], "[", "args__", 
    "]"}], ":=", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"em", "=", 
       RowBox[{
        RowBox[{"extModel", "[", "\"\<rf\>\"", "]"}], "[", 
        RowBox[{"3", ",", "500", ",", "args"}], "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"errors", "[", "em", "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", 
        RowBox[{"-", "1"}]}], "]"}], "]"}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"cv", "[", 
      RowBox[{"\"\<rf\>\"", ",", "3", ",", "300"}], "]"}], "[", "args__", 
     "]"}], ":=", 
    RowBox[{"With", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"em", "=", 
        RowBox[{
         RowBox[{"extModel", "[", "\"\<rf\>\"", "]"}], "[", 
         RowBox[{"3", ",", "300", ",", "args"}], "]"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"errors", "[", "em", "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", 
         RowBox[{"-", "1"}]}], "]"}], "]"}]}], "\[IndentingNewLine]", "]"}]}],
    ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"cv", "[", 
     RowBox[{"\"\<rf\>\"", ",", "4", ",", "700"}], "]"}], "[", "args__", 
    "]"}], ":=", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"em", "=", 
       RowBox[{
        RowBox[{"extModel", "[", "\"\<rf\>\"", "]"}], "[", 
        RowBox[{"4", ",", "700", ",", "args"}], "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"errors", "[", "em", "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", 
        RowBox[{"-", "1"}]}], "]"}], "]"}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"cv", "[", 
     RowBox[{"\"\<rf\>\"", ",", "4", ",", "500"}], "]"}], "[", "args__", 
    "]"}], ":=", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"em", "=", 
       RowBox[{
        RowBox[{"extModel", "[", "\"\<rf\>\"", "]"}], "[", 
        RowBox[{"4", ",", "500", ",", "args"}], "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"errors", "[", "em", "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", 
        RowBox[{"-", "1"}]}], "]"}], "]"}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"cv", "[", 
     RowBox[{"\"\<rf\>\"", ",", "4", ",", "300"}], "]"}], "[", "args__", 
    "]"}], ":=", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"em", "=", 
       RowBox[{
        RowBox[{"extModel", "[", "\"\<rf\>\"", "]"}], "[", 
        RowBox[{"4", ",", "300", ",", "args"}], "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"errors", "[", "em", "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", 
        RowBox[{"-", "1"}]}], "]"}], "]"}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.571597203004287*^9, 3.571597203007347*^9}, {
   3.572018982994432*^9, 3.572018985225662*^9}, {3.572103599982379*^9, 
   3.572103601715974*^9}, {3.5721131713055143`*^9, 3.572113257908746*^9}, {
   3.5721132991827297`*^9, 3.572113300873817*^9}, {3.5752850174305353`*^9, 
   3.575285139004065*^9}, {3.575285201435759*^9, 3.575285202890244*^9}, 
   3.585925977620852*^9, 3.585926026593856*^9, {3.585926233411834*^9, 
   3.585926239114326*^9}, 3.585926286623116*^9, {3.585926667248522*^9, 
   3.585926683735824*^9}, {3.585931059191309*^9, 3.5859310956325617`*^9}, {
   3.585931151846669*^9, 3.585931163630117*^9}, {3.585931567239349*^9, 
   3.5859315692301893`*^9}, {3.585931665212166*^9, 3.585931687197648*^9}, {
   3.5859318943296022`*^9, 3.585931895384295*^9}, {3.585932531556439*^9, 
   3.5859325436926737`*^9}, {3.585932629906378*^9, 3.585932686218547*^9}, {
   3.585933367451992*^9, 3.585933372138315*^9}, 3.5859354912395277`*^9, {
   3.5860022827548523`*^9, 3.586002283611496*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Usage", "Subsubsection",
 CellChangeTimes->{{3.5859263133015623`*^9, 3.585926314117491*^9}}],

Cell["Construct using raw function:", "Text",
 CellChangeTimes->{{3.586023529126893*^9, 3.586023541630003*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"forest", "=", 
    RowBox[{"randomForest", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"knnd", "[", "All", "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"train", ",", 
          RowBox[{"1", ";;", 
           RowBox[{"-", "2"}]}]}], "]"}], "]"}], "\[Transpose]"}], ",", 
      RowBox[{"knnd", "[", "a1", "]"}], ",", "3", ",", "100"}], "]"}]}], 
   ";"}], "//", "Timing"}]], "Input",
 CellChangeTimes->{{3.57159724263174*^9, 3.5715972589724293`*^9}, {
  3.5720189920564747`*^9, 3.572019003285481*^9}, {3.572355361148364*^9, 
  3.572355362474414*^9}, {3.575220440037059*^9, 3.575220460330901*^9}, {
  3.585926492629582*^9, 3.585926504618469*^9}, {3.585926579995625*^9, 
  3.5859266082960463`*^9}, {3.585928837185994*^9, 3.585928853347025*^9}, {
  3.585928925955296*^9, 3.585928926145308*^9}, {3.585929042064905*^9, 
  3.585929042174947*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.62952399999999997248778527136892080307`5.819612205100595", ",", "Null"}],
   "}"}]], "Output",
 CellChangeTimes->{
  3.571597263537879*^9, 3.571597400103668*^9, 3.571597560941894*^9, {
   3.5720189742251787`*^9, 3.572019008338868*^9}, 3.572024017868705*^9, 
   3.5720278858364277`*^9, 3.572028154030468*^9, {3.572103629395074*^9, 
   3.572103642577944*^9}, 3.5721051786266813`*^9, 3.5721053025141573`*^9, 
   3.5721101286522512`*^9, 3.57211024861355*^9, 3.5721114137460117`*^9, 
   3.572113205593804*^9, 3.572113246084598*^9, {3.572113297103484*^9, 
   3.5721133036665173`*^9}, 3.5721142174828377`*^9, 3.572173635942492*^9, 
   3.5721859511663113`*^9, 3.5723555510898037`*^9, 3.5723774466227493`*^9, 
   3.572609854826166*^9, 3.5729813472928257`*^9, 3.573222140212674*^9, 
   3.573229633290822*^9, 3.573229689855711*^9, 3.5732304254546824`*^9, 
   3.5732304695927773`*^9, {3.573230860246778*^9, 3.573230912332632*^9}, 
   3.5732328635316057`*^9, 3.57324184443795*^9, {3.575220502854679*^9, 
   3.575220509609836*^9}, 3.575285158747602*^9, 3.585926373843794*^9, {
   3.5859264992175207`*^9, 3.585926507474606*^9}, {3.585926572876274*^9, 
   3.5859266104504623`*^9}, {3.585928843040063*^9, 3.585928855764472*^9}, {
   3.585928922430099*^9, 3.585928928029282*^9}, 3.585929044287002*^9, 
   3.585929127818595*^9, {3.585930081497097*^9, 3.58593009932955*^9}, 
   3.585930259864064*^9, 3.585931099611305*^9, 3.585932551323341*^9, 
   3.5859326895901423`*^9, 3.585934589303815*^9, {3.5859348732741833`*^9, 
   3.585934886402899*^9}, 3.585935498496295*^9, 3.586001886157896*^9, 
   3.586002299009495*^9}]
}, Open  ]],

Cell["Construct using extended model:", "Text",
 CellChangeTimes->{{3.586023544566078*^9, 3.5860235494782133`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"em", "=", 
   RowBox[{
    RowBox[{"extModel", "[", "\"\<rf\>\"", "]"}], "[", 
    RowBox[{
    "3", ",", "300", ",", "knnd", ",", "featureColumns", ",", "a3", ",", 
     "knnd"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5859356768279657`*^9, 3.585935682144577*^9}, {
  3.585935761301272*^9, 3.585935761368197*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"errors", "@", "em"}]], "Input",
 CellChangeTimes->{{3.585935692687579*^9, 3.58593569413614*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\<\"MAE\"\>", "\[Rule]", "3.882090872347817`"}], ",", 
   RowBox[{"\<\"MSE\"\>", "\[Rule]", "33.43767931932126`"}], ",", 
   RowBox[{"\<\"NMSE\"\>", "\[Rule]", "0.6904370431568223`"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.585935694592741*^9, 3.585935768419203*^9, 
  3.58600189516996*^9, 3.586002307249968*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"predictions", "@", "em"}], ",", 
          RowBox[{"knnd", "[", "a3", "]"}]}], "}"}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotMarkers", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Automatic", ",", "Medium"}], "}"}]}]}], 
      "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Plot", "[", 
      RowBox[{"x", ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", "100"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"Directive", "[", "Dashed", "]"}]}]}], "]"}]}], 
    "\[IndentingNewLine]", "}"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<RF (a3)\>\""}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Predicted\>\"", ",", "\"\<Actual\>\""}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.5859356993634577`*^9, 3.585935712689013*^9}, {
  3.585935765760353*^9, 3.585935765962669*^9}, {3.5860019156964083`*^9, 
  3.586001915807845*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, GraphicsComplexBox[CompressedData["
1:eJztV3lQlMcS34UFlmNhlz1YFlyWG0F4KiAK+r4WFUQhCkYRFNGgiEc8OAyJ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     "], {
      {RGBColor[0.24720000000000014`, 0.24, 0.6], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 32], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 66], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 73], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 77], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 82], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 98], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 118], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 119], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 130], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 141], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 149], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 219], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 220], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 221], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 222], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 223], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 224], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 225], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 226], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 227], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 228], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 229], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 230], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 231], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 232], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 233], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 234], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 235], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 236], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 237], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 238], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 239], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 240], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 241], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 242], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 243], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 244], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 245], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 246], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 247], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 248], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 249], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 250], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 251], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 252], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 253], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 254], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 255], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 256], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 257], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 258], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 259], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 260], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 261], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 262], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 263], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 264], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 265], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 266], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 267], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 268], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 269], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 270], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 271], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 272], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 273], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 274], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 275], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 276], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 277], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 278], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 279], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 280], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 281], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 282], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 283], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 284], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 285], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 286], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 287], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 288], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 289], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 290], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 291], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 292], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 293], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 294], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 295], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 296], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 297], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 298], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 299], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 300], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 301], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 302], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 303], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 304], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 305], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 306], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 307], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 308], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 309], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 310], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 311], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 312], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 313], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 314], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 315], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 316], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 317], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 318], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 319], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 320], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 321], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 322], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 323], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 324], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 325], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 326], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 327], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 328], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 329], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 330], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 331], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 332], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 333], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 334], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 335], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 336], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 337], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 338], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 339], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 340], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 341], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 342], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 343], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 344], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 345], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 346], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 347], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 348], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 349], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 350], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 351], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 352], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 353], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 354], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 355], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 356], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 357], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 358], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 359], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 360], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 361], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 362], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 363], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 364], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 365], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 366], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 367], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 368], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 369], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 370], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 371], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 372], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 373], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 374], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 375], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 376], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 377], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 378], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 379], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 380], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 381], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 382], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 383], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 384], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 385], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 386], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 387], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 388], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 389], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 390], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 391], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 392], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 393], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 394], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 395], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 396], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 397], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 398], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 399], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 400], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 401], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 402], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 403], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 404], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 405]}, {}}], {}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJxFxW0w03EcAPBxsurahR483M7DUpnT2WonLQw1zxtb5Ok40ew/D2EItTR0
wlaeLtVhOI9xhyZJbmnOQ5Sj5U24Q3d5uLoePLTQrHrh+3vxuY9VdBKXp4vD
4Vj//J9UrKmXmStddu/ZS7ZIxGoYuysz2xtssA54mJLC18f64TdSldcGfwIe
pef1fuXPwWOlMynL/O+wjwLPXuRr4XGCwz69CAPX3d2Lma+b/U1gnv0WgUqw
hFlk3s+jntawfOpW+qijDXzeyLZD77YdzN8uq24MocBJw0tnOlin4aIw/eOa
BBocM3Izloo5wEq8KSc+1BGmGoorVtLocNSasx07wQmukw0R1fdc4K779BkV
1xVOe+kcUO3nBvePNa4WhrvDAs9zCkHIBbiqhdodH3cRLl1T5CRnMOHF1vTr
mNADHvQoe5Sb6wnr+E9/KhZ7wTi35zq1Wd5wgbGapbrrAyeHxQyo83zhhRza
VcYDP/hw+ePpwjoW3GRgmzVSyYaVQgvmyTZ/WGZZS3QODIAVoi0cNom28sX/
ORbMgZ9NkCUfp9DS4R2KZQQXLk9diYuaRYuOmB8khV6Cn5D3jKXNo/XXdUyV
kYFwM+VptmwJTY5uZWsSg+AZ71550Be0qv7GKUbqZfh3F8eJtIrWvhB2518L
hn0pHkzRBnokwl4QnxoCG8VgfdXp6EisjjCZgf4lPCSnidDWBeotzR20WN4v
LalA0/EBnd296PwDhbrLfej3hgOBZq/QGJG2mT2Afkg1cfd6i14Pn/8wPYt2
vWJ6gjCHlsRyMxkLaFLKILHhM5qT38JL/Iaukiz01PxAL5eY7VetosWV0nYH
Nfpd7RBOsIk2btrhVm6jo9vONo5r0O2dyWqtFv0X2IEqcw==
      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"Predicted\"", TraditionalForm], 
    FormBox["\"Actual\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  Method->{"ScalingFunctions" -> None},
  PlotLabel->FormBox["\"RF (a3)\"", TraditionalForm],
  PlotRange->{{0, 12.316277777777778`}, {0, 20.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.5859357146753263`*^9, 3.585935768616437*^9, {3.586001908928932*^9, 
   3.586001916071694*^9}, 3.5860023134156523`*^9}]
}, {2}]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["k-Fold CV Again", "Title",
 CellChangeTimes->CompressedData["
1:eJwdyk0ow3EYwPFtCiElYgfz/nra1pKX5F3yFkaRMK3NZH+RheYiyk5rasqG
KUrkbdMM5TDbYdK8bOYgjBxENC95yUzK8/wO3z6Xb7ywhy9m0Gi0WAjltouC
FrafChesFmLp3eW6DQxvqNGjgXsZuXbwRcHIQ5fMZgnaYJvrRO26uqVDUG3Y
If7Mu32ospn7i1IejvEI1B6PbKJKnrHnBKz3tvWisnPrKar423Oh3uVHD3oQ
XP+M3ldzphzgjXiROC2MCXCCiVVXRK1JYngFbweviU5ZjuMN1Js/iAx9V/87
+F0ZOIDaypmT6NtQPNEdl1r0hd+ZnJiSyVN9g038ceKQh2J7Qb7eSqTflKlY
O0+FLrp8HPU1hq0lgZ/FY8SSB392Mriy0kps66s8QkNbWcdowZaaqwGpigti
C5vKQnd1s8SQmOFFdLTZQpTmZHdoQZ6JKUETZqSROtDklx6FiowbArS3O78d
jUg70KCC2ntiVPTqFTqxH+5G/wGuKxqv
  "]],

Cell["\<\
Rerun the cross-validation with various random forests, for all response \
columns.  (This takes hours to evaluate;  canned results are available below).\
\>", "Text",
 CellChangeTimes->{{3.585926910258062*^9, 3.585926936960848*^9}, {
  3.585927146524518*^9, 3.585927155300201*^9}, {3.5859272070281677`*^9, 
  3.5859272102520113`*^9}, {3.585927778584833*^9, 3.5859277987829943`*^9}, {
  3.585928137036302*^9, 3.585928148273044*^9}, {3.586009181622636*^9, 
  3.5860091899528913`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"resAll7RF", "=", 
   RowBox[{"Table", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"kFoldCV", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"knnd", ",", "featureColumns", ",", "i"}], "}"}], ",", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"cv", "[", 
          RowBox[{"\"\<rf\>\"", ",", "3", ",", "300"}], "]"}], ",", 
         RowBox[{"cv", "[", 
          RowBox[{"\"\<rf\>\"", ",", "3", ",", "500"}], "]"}], ",", 
         RowBox[{"cv", "[", 
          RowBox[{"\"\<rf\>\"", ",", "3", ",", "700"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"cv", "[", 
          RowBox[{"\"\<rf\>\"", ",", "4", ",", "300"}], "]"}], ",", 
         RowBox[{"cv", "[", 
          RowBox[{"\"\<rf\>\"", ",", "4", ",", "500"}], "]"}], ",", 
         RowBox[{"cv", "[", 
          RowBox[{"\"\<rf\>\"", ",", "4", ",", "700"}], "]"}]}], 
        "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"3", ",", "10"}], "}"}]}], "\[IndentingNewLine]", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"Take", "[", 
        RowBox[{"responseColumns", ",", "All"}], "]"}]}], "}"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5752059712648687`*^9, 3.57520600549887*^9}, {
  3.5752211258768387`*^9, 3.575221159779647*^9}, {3.5752223703218203`*^9, 
  3.575222412512066*^9}, {3.575222447175984*^9, 3.57522244729478*^9}, {
  3.575287883755217*^9, 3.575287885065241*^9}, {3.575287945632496*^9, 
  3.575287945911137*^9}, {3.575301981782489*^9, 3.575301982451887*^9}, {
  3.585926944512937*^9, 3.585926952841661*^9}, {3.5859294935020647`*^9, 
  3.585929504645851*^9}, {3.585932713139516*^9, 3.5859327903633432`*^9}, {
  3.585935817353716*^9, 3.5859358174619827`*^9}, {3.5860023971601267`*^9, 
  3.5860023993117933`*^9}}],

Cell[CellGroupData[{

Cell["RF canned results", "Subsubsection",
 CellChangeTimes->{{3.5859278158800077`*^9, 3.585927822072303*^9}},
 FontColor->GrayLevel[0.5]],

Cell[BoxData[
 RowBox[{
  RowBox[{"resAll7RF", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<rf\>\"", ",", "3", ",", "300"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "10.611613817293817`", ",", "230.6574871620647`", ",", 
              "0.3763837696838869`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.9824543638768635`", ",", "54.44827773056901`", ",", 
              "1.046871379862787`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "14.352261291486295`", ",", "486.83361100781286`", ",", 
              "0.7134248531717358`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.065157664995823`", ",", "124.43278305523113`", ",", 
              "0.41135008291026603`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "11.30476952380952`", ",", "333.749440214822`", ",", 
              "0.5390826320001717`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "15.305165833333334`", ",", "325.56735978398`", ",", 
              "0.7493619882179556`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "14.048142023809522`", ",", "298.2084223702407`", ",", 
              "1.4318324398609101`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.573200075757578`", ",", "215.73505754271727`", ",", 
              "0.5818074416848455`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.965892976190476`", ",", "97.10000462014105`", ",", 
              "0.3504038065187953`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "12.345992901234569`", ",", "333.95104073849274`", ",", 
              "0.4883989472229709`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "11.950786944444443`", ",", "332.8396327421134`", ",", 
              "0.5646471008847023`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "13.862721801346803`", ",", "365.18863283358235`", ",", 
              "0.47424348256397403`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.250385555555555`", ",", "97.86348799475309`", ",", 
              "0.3379548829209129`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.160463313492064`", ",", "107.83832019755953`", ",", 
              "0.5001107003632609`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "12.476654391534394`", ",", "460.28807778979456`", ",", 
              "0.6725084877208057`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.803820873015876`", ",", "75.97776297695134`", ",", 
              "0.4288715175146584`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "13.860107962962962`", ",", "348.5482999261451`", ",", 
              "0.560783572245213`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "13.204912987012989`", ",", "347.31351867644497`", ",", 
              "1.126577264124387`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "13.364032606209154`", ",", "287.5109355723202`", ",", 
              "0.8730466455553905`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.07752237654321`", ",", "112.53829185230323`", ",", 
              "0.32403608347232`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "9.303429049564272`", ",", "144.72523272624866`", ",", 
              "0.5249669308590869`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "10.203555135756055`", ",", "209.660007106194`", ",", 
              "0.5311908192773006`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.020186481481478`", ",", "149.99721619533057`", ",", 
              "0.6239150719167207`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.692839930555557`", ",", "146.42872024486275`", ",", 
              "0.41508398343749336`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "14.27396861111111`", ",", "321.6297876958689`", ",", 
              "1.4089805548064203`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.035006933760682`", ",", "82.23542665417584`", ",", 
              "0.261129942485427`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "11.340269682539681`", ",", "410.92926513954615`", ",", 
              "0.5722338065756264`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "10.955258614163613`", ",", "329.5592194870875`", ",", 
              "0.6105796750133766`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "16.061508560606057`", ",", "442.3180404358692`", ",", 
              "0.489949741698153`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "14.682534001492336`", ",", "350.92303098782395`", ",", 
              "0.8322465024684325`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<rf\>\"", ",", "3", ",", "500"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "10.69516215909091`", ",", "226.10892773753076`", ",", 
              "0.3689614918991889`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.061202738095238`", ",", "54.3907396335798`", ",", 
              "1.0457651008490074`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "14.48168667857143`", ",", "498.1834953563354`", ",", 
              "0.7300574138490858`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.947325937229438`", ",", "122.60293756909383`", ",", 
              "0.4053009769274684`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "11.48633523058314`", ",", "341.4563882341478`", ",", 
              "0.551531137742301`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "15.518600937062939`", ",", "333.02150807232965`", ",", 
              "0.766519283671454`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "14.011093179487181`", ",", "290.8073752883323`", ",", 
              "1.3962966920219118`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.727409912698409`", ",", "220.37531467802333`", ",", 
              "0.5943215697241314`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.931619842132507`", ",", "95.62898704023466`", ",", 
              "0.3450953602270395`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "12.125214484126984`", ",", "330.64773387629543`", ",", 
              "0.48356790495317026`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "11.91716058041958`", ",", "324.5924051339804`", ",", 
              "0.5506560592503165`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "13.933647857142853`", ",", "370.3444760134416`", ",", 
              "0.48093899497956555`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.306897954545454`", ",", "101.32789740593263`", ",", 
              "0.34991863059571543`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.02006853174603`", ",", "106.68917222232217`", ",", 
              "0.4947814148396722`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "12.559552509199133`", ",", "451.1946817989648`", ",", 
              "0.6592224907960013`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.001819666666668`", ",", "78.9324184147511`", ",", 
              "0.44554965479709624`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "14.140462490079367`", ",", "353.5485248150625`", ",", 
              "0.5688284945008392`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "13.62306695261438`", ",", "366.8166490273269`", ",", 
              "1.1898393660900366`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "13.371963714285716`", ",", "282.2142959507735`", ",", 
              "0.8569630366133439`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.91067537758538`", ",", "126.87685697286058`", ",", 
              "0.36532169753136373`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "8.922473834457211`", ",", "138.45782800480228`", ",", 
              "0.5022329531062721`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "10.36786396422205`", ",", "222.83556285158323`", ",", 
              "0.5645721701005988`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.850690073232325`", ",", "141.07723941627404`", ",", 
              "0.5868123303141484`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.407622004578757`", ",", "137.4655172114264`", ",", 
              "0.3896758393708357`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "13.767960047619045`", ",", "300.7961750568844`", ",", 
              "1.3177136503788505`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.26957294047619`", ",", "91.14018029281075`", ",", 
              "0.2894060504854766`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "11.359335219780222`", ",", "411.4122839530105`", ",", 
              "0.5729064276754707`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "11.168193974025973`", ",", "335.2520903203678`", ",", 
              "0.6211269485161093`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "16.607035176767678`", ",", "454.29262028549203`", ",", 
              "0.5032138226713939`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "14.322292301587302`", ",", "343.7164728692371`", ",", 
              "0.8151554817618506`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<rf\>\"", ",", "3", ",", "700"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "10.5953281827245`", ",", "221.4676090501279`", ",", 
              "0.36138785080319646`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.010637714646464`", ",", "53.68448261074366`", ",", 
              "1.032185970436602`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "14.145048027210885`", ",", "483.45506499854537`", ",", 
              "0.7084738008283985`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.900151418105705`", ",", "125.13700343449663`", ",", 
              "0.4136780957079014`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "11.682409162028447`", ",", "347.8880756529019`", ",", 
              "0.5619198023035737`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "15.630197459286745`", ",", "337.1549730374594`", ",", 
              "0.7760333256397709`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "14.291695773809526`", ",", "292.01114607155`", ",", 
              "1.402076535675784`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.788103894557826`", ",", "225.48640331359266`", ",", 
              "0.6081054648274865`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.663916718354008`", ",", "89.17700450160837`", ",", 
              "0.32181215596796875`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "11.942509502262444`", ",", "316.2371156874406`", ",", 
              "0.46249256787170795`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "11.98186598407545`", ",", "325.7726462955635`", ",", 
              "0.5526582839996421`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "14.097975204081635`", ",", "376.0769771765791`", ",", 
              "0.4883833704912405`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.19869054370233`", ",", "99.09437108967558`", ",", 
              "0.3422055279853537`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.038130879120878`", ",", "110.67779852446503`", ",", 
              "0.5132790573270329`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "12.534410017046449`", ",", "458.4567692148227`", ",", 
              "0.6698328360588766`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.685437023809524`", ",", "70.33559523347535`", ",", 
              "0.39702318522102575`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "14.280338599257888`", ",", "365.50001402851234`", ",", 
              "0.5880573899399755`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "13.316764791121576`", ",", "355.18958894232486`", ",", 
              "1.1521247916896828`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "13.841531145124716`", ",", "298.7643409345938`", ",", 
              "0.9072183816079717`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.405957860922147`", ",", "116.34141436295191`", ",", 
              "0.33498656888517275`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "8.919119253663002`", ",", "138.94079928476634`", ",", 
              "0.5039848518302176`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "10.237126599670173`", ",", "209.94893859513382`", ",", 
              "0.5319228508957448`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.064168401360542`", ",", "144.92093034686826`", ",", 
              "0.6028002050508663`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.738807591218306`", ",", "143.52850236842204`", ",", 
              "0.406862686502189`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "13.578639229024944`", ",", "295.1886334357895`", ",", 
              "1.2931483973872293`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.151305901875901`", ",", "87.98498262231041`", ",", 
              "0.2793870523510993`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "11.285536709750568`", ",", "407.43928886217293`", ",", 
              "0.5673738888732897`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "11.05854703183138`", ",", "333.90117339409505`", ",", 
              "0.6186240829640625`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "16.304471092300552`", ",", "445.28286683423147`", ",", 
              "0.4932338400058458`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "14.661729625753432`", ",", "353.9044321362414`", ",", 
              "0.8393171717010594`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<rf\>\"", ",", "4", ",", "300"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "10.612061011904764`", ",", "217.55331695578326`", ",", 
              "0.3550005618743176`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.097505787545788`", ",", "54.43235452846528`", ",", 
              "1.0465652261100338`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "14.264528968253973`", ",", "484.9241134808555`", ",", 
              "0.7106266014446596`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.394905046296296`", ",", "139.01064512283352`", ",", 
              "0.4595416014387956`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "11.52396717948718`", ",", "345.76867417727107`", ",", 
              "0.5584964781325648`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "15.545102314814816`", ",", "348.9777016355732`", ",", 
              "0.8032458306474053`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "14.137205555555557`", ",", "298.5421752558642`", ",", 
              "1.4334349372174053`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.369015000000001`", ",", "215.82327236699015`", ",", 
              "0.5820453447953251`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.760256335978835`", ",", "92.43664060479668`", ",", 
              "0.33357517186988933`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "12.361363552188553`", ",", "326.5622557366602`", ",", 
              "0.4775929476124539`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "12.095945972222223`", ",", "339.13268199342014`", ",", 
              "0.575322968978296`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "13.815504999999998`", ",", "358.3601167428117`", ",", 
              "0.4653757934836654`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.8253684259259275`", ",", "89.08611744992945`", ",", 
              "0.30764372913301213`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.696702674963926`", ",", "103.26790499085666`", ",", 
              "0.47891495523492766`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "12.019076388888891`", ",", "447.2826187713348`", ",", 
              "0.6535067320841682`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.827168584656086`", ",", "79.01573700648038`", ",", 
              "0.44601996307509806`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "14.838622486772488`", ",", "378.88812295984`", ",", 
              "0.609597680205941`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "13.212579520757018`", ",", "350.31780550727115`", ",", 
              "1.1363222382083646`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "13.680531038961039`", ",", "292.82595609698575`", ",", 
              "0.8891860693685417`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.404505026455027`", ",", "126.71741689900124`", ",", 
              "0.3648626152382921`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "9.064087248677248`", ",", "144.12304736592688`", ",", 
              "0.522782602705237`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "10.584999465811967`", ",", "223.85156535158322`", ",", 
              "0.5671462957424501`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.590117507122507`", ",", "141.5038708071116`", ",", 
              "0.588586908280647`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.18844398148148`", ",", "126.80047661713395`", ",", 
              "0.35944346742905614`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "14.282050560428848`", ",", "325.16695764464293`", ",", 
              "1.4244760215434156`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.107566666666668`", ",", "90.94962622252866`", ",", 
              "0.2888009660901298`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "10.895371884920634`", ",", "401.0250870914945`", ",", 
              "0.5584418818181752`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "10.489755238095238`", ",", "325.1707239875171`", ",", 
              "0.6024490387043828`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "15.981954743589743`", ",", "444.8639635572358`", ",", 
              "0.4927698264825487`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "15.045156663706665`", ",", "366.22230440428933`", ",", 
              "0.8685301477889454`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<rf\>\"", ",", "4", ",", "500"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "10.531610232142857`", ",", "227.9752460838839`", ",", 
              "0.37200692494917714`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.090656091269841`", ",", "55.41110988803488`", ",", 
              "1.0653836537358072`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "14.472079904761904`", ",", "486.38251235050785`", ",", 
              "0.7127637957055358`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.134946582972583`", ",", "130.39189922132772`", ",", 
              "0.43104973816838005`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "11.295768`", ",", "344.26868592649`", ",", 
              "0.5560736497566433`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "15.392646169191917`", ",", "336.43051976507957`", ",", 
              "0.7743658435404543`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "14.030770619047619`", ",", "289.8201954996797`", ",", 
              "1.3915567989158313`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.628900869047623`", ",", "215.24639506711782`", ",", 
              "0.5804895869605636`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.749828753246753`", ",", "90.89008130039194`", ",", 
              "0.327994118919475`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "12.782421111111113`", ",", "353.07126292165685`", ",", 
              "0.5163620173912091`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "12.392144166666666`", ",", "357.13270753431004`", ",", 
              "0.6058591829314852`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "13.638018011904762`", ",", "351.51956547020353`", ",", 
              "0.45649247520235003`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.085857488095238`", ",", "92.74512206807843`", ",", 
              "0.3202794782021636`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.105700253968255`", ",", "108.98365983767083`", ",", 
              "0.50542232436223`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "12.316531833333332`", ",", "458.8652715256385`", ",", 
              "0.670429682435164`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.6061438809523825`", ",", "74.78346452944407`", ",", 
              "0.42213006360131766`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "14.609399880952381`", ",", "378.4905318565526`", ",", 
              "0.608957991074645`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "13.020636022408961`", ",", "346.2595036164961`", ",", 
              "1.1231583663886806`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "13.71948811904762`", ",", "303.8566630153847`", ",", 
              "0.9226815663451792`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.74126171957672`", ",", "129.10177658550174`", ",", 
              "0.3717279991150699`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "9.029793047619048`", ",", "140.38047449008528`", ",", 
              "0.5092070363776751`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "10.488092611111114`", ",", "215.1467334581123`", ",", 
              "0.5450918903792854`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.028186858585856`", ",", "139.48977888312191`", ",", 
              "0.5802092707519176`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.767144833333331`", ",", "147.11782602213057`", ",", 
              "0.4170374033032123`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "14.037087240079364`", ",", "323.31492893456357`", ",", 
              "1.4163627418060534`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.729707738095239`", ",", "83.3521444439433`", ",", 
              "0.26467596229804047`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "11.255839658730157`", ",", "423.058685841247`", ",", 
              "0.589124461898835`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "11.013697442661913`", ",", "336.2203955702872`", ",", 
              "0.6229209432516525`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "16.1733565`", ",", "445.3917865332672`", ",", 
              "0.4933544888908784`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "14.7160298989899`", ",", "366.89515162532206`", ",", 
              "0.87012586735407`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<rf\>\"", ",", "4", ",", "700"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "10.322239478775193`", ",", "215.181804502651`", ",", 
              "0.35113075990974907`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.224317475778189`", ",", "59.65319037603192`", ",", 
              "1.1469456946130927`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "14.21750261054422`", ",", "482.4077632350669`", ",", 
              "0.7069390442094186`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.9438166905095375`", ",", "127.14932149247761`", ",", 
              "0.420330419795396`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "11.572326037414967`", ",", "350.0750427525309`", ",", 
              "0.5654522606034497`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "15.752363388159457`", ",", "346.1030375311946`", ",", 
              "0.79662918452494`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "14.098897413003664`", ",", "293.694524289943`", ",", 
              "1.4101591898224795`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.331700969387756`", ",", "218.03574888288307`", ",", 
              "0.5880120862056523`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.703196445578231`", ",", "89.24918992375702`", ",", 
              "0.3220726507722173`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "12.35503463936857`", ",", "331.1224821712004`", ",", 
              "0.48426221800850533`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "12.402509614512471`", ",", "346.7965696429062`", ",", 
              "0.5883244012510606`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "13.94718793341579`", ",", "366.8475704670126`", ",", 
              "0.4763978222391438`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.072711469681114`", ",", "93.380767429111`", ",", 
              "0.3224745711624564`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.805855528383766`", ",", "103.36886617157317`", ",", 
              "0.4793831725319435`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "12.554230274725274`", ",", "468.8848907181485`", ",", 
              "0.6850689470084483`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.585473898809523`", ",", "76.70956445913723`", ",", 
              "0.4330023157888817`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "14.484538486394559`", ",", "367.75413418775577`", ",", 
              "0.5916840711070858`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "13.30581266134659`", ",", "357.5544782602607`", ",", 
              "1.1597957586820133`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "13.525391340603841`", ",", "289.054211520945`", ",", 
              "0.8777329086619785`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.606134832351746`", ",", "125.05573178895558`", ",", 
              "0.36007805767871826`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "9.162483233082707`", ",", "143.3101005529404`", ",", 
              "0.5198337721155332`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "10.435274131880025`", ",", "223.2796409079724`", ",", 
              "0.5656972782690677`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.001697854526427`", ",", "137.133844923868`", ",", 
              "0.5704097375145487`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.561006226412477`", ",", "138.3505853773558`", ",", 
              "0.39218475715222006`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "14.395500292267258`", ",", "334.6214367504935`", ",", 
              "1.4658937562358363`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.167159607713714`", ",", "94.52508272572045`", ",", 
              "0.3001544519176421`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "11.075393358843538`", ",", "406.5060304118398`", ",", 
              "0.5660742928579715`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "10.85420428880643`", ",", "332.85277838978135`", ",", 
              "0.6166817046503384`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "16.308759997665735`", ",", "453.06594820962226`", ",", 
              "0.5018550545186672`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "14.55577598525813`", ",", "351.083408752055`", ",", 
              "0.8326268532051148`"}], "}"}]}], "}"}]}], "}"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<rf\>\"", ",", "3", ",", "300"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "9.602430060690942`", ",", "169.13666285629927`", ",", 
              "0.8347675803628292`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.921483690476189`", ",", "107.19423096216192`", ",", 
              "0.9258339136631718`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.261753536653013`", ",", "74.09241422729535`", ",", 
              "0.8355928422318182`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.8853424532923215`", ",", "71.64944916047713`", ",", 
              "0.7074190130858927`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.894569866707366`", ",", "34.860806876062085`", ",", 
              "0.6189433265580566`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.087810389433551`", ",", "116.37691950763164`", ",", 
              "0.8297980799101561`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.066837774725276`", ",", "276.92226942964294`", ",", 
              "1.018540411514403`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.338594938408475`", ",", "115.57821992484828`", ",", 
              "1.0153503601272351`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.39242925925926`", ",", "28.627188846205893`", ",", 
              "1.3775075081630457`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.2406512827707274`", ",", "36.16886006872165`", ",", 
              "0.7425153041679723`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "7.28266`", ",", "112.7420467581286`", ",", 
              "0.8454629968219117`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.712888346104727`", ",", "45.77698301374361`", ",", 
              "1.404784746240384`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.438287873080267`", ",", "316.2721351598822`", ",", 
              "0.9714415711031096`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.370396773226774`", ",", "41.46527170156011`", ",", 
              "1.2859492152337424`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.676399999999999`", ",", "57.88789051111112`", ",", 
              "0.6551486956657332`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.721266666666668`", ",", "79.918554`", ",", 
              "0.8898783855407735`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.153483333333334`", ",", "127.51061401666666`", ",", 
              "0.8115678186151585`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.7598666666666665`", ",", "52.317228044444434`", ",", 
              "0.9004612792656933`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.173083333333333`", ",", "131.06394836111113`", ",", 
              "0.7271196234753985`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.338722222222223`", ",", "72.05271019135802`", ",", 
              "0.7931909853441079`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "11.79975`", ",", "377.8953783944444`", ",", 
              "1.1703958044078513`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.418766666666667`", ",", "117.16987534444448`", ",", 
              "0.9859010226888698`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.463033333333334`", ",", "53.121140077777774`", ",", 
              "0.6696520938032072`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.7886`", ",", "85.2356487`", ",", "0.754681962653997`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.2443`", ",", "48.94638232222222`", ",", 
              "0.5860220983443171`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.30645`", ",", "28.43713300555556`", ",", 
              "0.7863272824332028`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.6491833333333314`", ",", "67.97267430555556`", ",", 
              "0.9575989865875987`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.013700000000001`", ",", "31.323901288888898`", ",", 
              "0.7472505235145`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.701250000000002`", ",", "156.6216108277778`", ",", 
              "0.8241511957635094`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.677092592592594`", ",", "64.75890369753087`", ",", 
              "1.2071062599923943`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<rf\>\"", ",", "3", ",", "500"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "9.555470000000001`", ",", "171.79386735399999`", ",", 
              "0.847882112313595`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.690699999999998`", ",", "100.550556048`", ",", 
              "0.8684526582385625`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.128759999999999`", ",", "70.96438274399999`", ",", 
              "0.8003158068567922`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.058769999999998`", ",", "72.19473328199999`", ",", 
              "0.7128027858799463`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.72189`", ",", "32.415803022000006`", ",", 
              "0.575533005498632`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.06948`", ",", "110.94769062`", ",", "0.7910862483424366`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.059650000000001`", ",", "275.12503992999984`", ",", 
              "1.0119300696378808`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.490519999999999`", ",", "115.49709392800003`", ",", 
              "1.0146376712644967`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.588970000000001`", ",", "30.826568341999995`", ",", 
              "1.4833391280623138`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.3721000000000005`", ",", "39.394725335555556`", ",", 
              "0.808739518181271`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "7.289`", ",", "111.97361618000002`", ",", 
              "0.8397004651124426`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.61435`", ",", "44.51175153799999`", ",", 
              "1.3659578563805996`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.4041`", ",", "317.475131536`", ",", "0.9751366190056269`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.618430000000001`", ",", "45.211490442000006`", ",", 
              "1.402129499401068`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.739789999999999`", ",", "59.415096842000004`", ",", 
              "0.6724329191338911`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.57085`", ",", "76.72812488999999`", ",", 
              "0.8543535447686407`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.070950000000002`", ",", "126.518961626`", ",", 
              "0.8052562407616266`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.5899100000000015`", ",", "52.480321978000006`", ",", 
              "0.903268380817885`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.070660000000001`", ",", "126.18839069600001`", ",", 
              "0.7000708911732051`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.369055555555557`", ",", "71.23650972666664`", ",", 
              "0.784205856969235`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "11.823690000000003`", ",", "370.61691641`", ",", 
              "1.147853371088532`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.229340000000002`", ",", "114.938780208`", ",", 
              "0.9671279466719286`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.70661`", ",", "54.05570847800002`", ",", 
              "0.6814333862433698`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.00797`", ",", "86.910965054`", ",", "0.7695153223266976`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.056679999999999`", ",", "49.42234072000001`", ",", 
              "0.591720622438583`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.46396`", ",", "29.779945820000002`", ",", 
              "0.8234579717678941`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.671269999999998`", ",", "66.93033403800001`", ",", 
              "0.9429144976501219`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.01677`", ",", "32.419122894000004`", ",", 
              "0.773377694272568`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.958039999999999`", ",", "157.25234206800002`", ",", 
              "0.8274701368923051`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.057277777777777`", ",", "70.71413848222224`", ",", 
              "1.3181118635137445`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<rf\>\"", ",", "3", ",", "700"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "9.533228571428571`", ",", "171.25291897346943`", ",", 
              "0.8452122821118466`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.0183285714285715`", ",", "107.84299386530616`", ",", 
              "0.9314372627638293`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.142078571428572`", ",", "73.73012956224488`", ",", 
              "0.8315071004440306`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.771992857142857`", ",", "68.78787472551019`", ",", 
              "0.679165730103603`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.925342857142857`", ",", "34.468652979591845`", ",", 
              "0.6119807499869829`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.083392857142856`", ",", "111.8714547377551`", ",", 
              "0.7976729297432346`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.09532142857143`", ",", "275.67446067653054`", ",", 
              "1.013950879428363`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.628278571428571`", ",", "119.87758577040817`", ",", 
              "1.053120129054689`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.746885714285714`", ",", "31.587198210204082`", ",", 
              "1.519939765310112`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.370531746031746`", ",", "40.62078318707482`", ",", 
              "0.8339094217065312`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "7.313757142857145`", ",", "110.1585172`", ",", 
              "0.8260888706161011`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.655221428571428`", ",", "45.16490961326531`", ",", 
              "1.3860016958957764`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.33595`", ",", "313.7779336193878`", ",", 
              "0.9637805387395697`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.443378571428571`", ",", "43.07618896428571`", ",", 
              "1.3359080773079668`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.717907142857143`", ",", "59.93735246020409`", ",", 
              "0.6783435696006728`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.610307142857144`", ",", "78.29421524387755`", ",", 
              "0.8717916725370628`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.981992857142856`", ",", "124.43498525408168`", ",", 
              "0.7919923397817268`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.686107142857143`", ",", "51.95452682959183`", ",", 
              "0.8942186243673882`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.202807142857141`", ",", "130.38127695204076`", ",", 
              "0.7233322831417087`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.328174603174603`", ",", "73.77937827891157`", ",", 
              "0.8121989804367491`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "11.494142857142858`", ",", "372.4628047489797`", ",", 
              "1.1535703501543415`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.344435714285714`", ",", "116.52469673775508`", ",", 
              "0.9804723043746942`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.628378571428573`", ",", "53.661481388775506`", ",", 
              "0.6764637075929002`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.938771428571431`", ",", "86.16834984897959`", ",", 
              "0.7629401591295`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.004971428571428`", ",", "47.7619635632653`", ",", 
              "0.5718413656014361`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.401200000000001`", ",", "29.561459693877545`", ",", 
              "0.817416518792671`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.731750000000001`", ",", "67.99540377040816`", ",", 
              "0.9579191992720472`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.001828571428571`", ",", "33.099771277551014`", ",", 
              "0.7896149712403064`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.874921428571428`", ",", "157.97645926020408`", ",", 
              "0.8312804798371501`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.817698412698413`", ",", "66.57849380952379`", ",", 
              "1.2410234279708057`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<rf\>\"", ",", "4", ",", "300"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "9.64765`", ",", "176.7146637722222`", ",", 
              "0.8721685162790522`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.113633333333334`", ",", "109.3520488`", ",", 
              "0.9444709327997989`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.076700000000001`", ",", "75.09056057777778`", ",", 
              "0.8468496484063923`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.416683333333333`", ",", "62.00776461666668`", ",", 
              "0.6122234317606101`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.746916666666667`", ",", "32.06726149444444`", ",", 
              "0.5693447536524877`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.001000000000001`", ",", "111.87672990000003`", ",", 
              "0.7977105430390717`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.019716666666666`", ",", "269.89888275`", ",", 
              "0.9927078803364587`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.548549999999999`", ",", "119.24084056111113`", ",", 
              "1.0475263460911737`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.217316666666667`", ",", "27.364303961111112`", ",", 
              "1.3167389353035333`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.633722222222222`", ",", "42.56801284567902`", ",", 
              "0.8738843564845764`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "7.3799166666666665`", ",", "111.00997408333333`", ",", 
              "0.8324740242384407`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.747283333333331`", ",", "47.39521686111111`", ",", 
              "1.4544444239860592`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.1646`", ",", "315.48454258888887`", ",", 
              "0.9690224513657095`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.505566666666667`", ",", "42.922832711111106`", ",", 
              "1.331152088854775`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.67165`", ",", "56.632207638888886`", ",", 
              "0.6409374506429371`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.774300000000002`", ",", "85.4448443111111`", ",", 
              "0.951412610748116`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.1104`", ",", "129.68098456666667`", ",", 
              "0.825381593307043`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.549166666666666`", ",", "51.01180426666667`", ",", 
              "0.8779928953535522`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.019016666666667`", ",", "130.0344967166667`", ",", 
              "0.7214084076799443`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.33924074074074`", ",", "77.02048956172837`", ",", 
              "0.8478786966500569`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "12.012249999999998`", ",", "380.20430550555545`", ",", 
              "1.1775468804940672`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.414666666666666`", ",", "121.64693522222224`", ",", 
              "1.023572291853958`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.711383333333332`", ",", "55.77713707222223`", ",", 
              "0.7031339420064011`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.790549999999999`", ",", "89.17652196111109`", ",", 
              "0.7895747101443552`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.222666666666667`", ",", "48.989815466666656`", ",", 
              "0.5865421119027749`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.5422166666666675`", ",", "33.59992896111112`", ",", 
              "0.9290859533827682`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.517066666666667`", ",", "64.1036228222222`", ",", 
              "0.9030917920811667`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.144933333333333`", ",", "33.626601733333324`", ",", 
              "0.8021828289364472`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.070666666666666`", ",", "165.42254522222223`", ",", 
              "0.8704621777964636`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.9696851851851855`", ",", "69.92303129012346`", ",", 
              "1.3033656218483864`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<rf\>\"", ",", "4", ",", "500"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "9.851919999999998`", ",", "177.71889493600003`", ",", 
              "0.8771248610747634`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.03434`", ",", "106.19101812`", ",", "0.9171691892320242`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.0363`", ",", "72.59794616399999`", ",", 
              "0.8187386631683209`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.67609`", ",", "65.73449613400001`", ",", 
              "0.6490187004321563`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.872879999999999`", ",", "34.19996606`", ",", 
              "0.6072102931124174`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.923540000000001`", ",", "110.90687336800002`", ",", 
              "0.7907952105878707`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.06509`", ",", "272.49425200999997`", ",", 
              "1.002253838772943`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.64096`", ",", "120.65822078800002`", ",", 
              "1.059977978628382`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.587680000000001`", ",", "30.48243450800001`", ",", 
              "1.4667798024961662`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.29771111111111`", ",", "39.73138318222222`", ",", 
              "0.815650811568546`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "7.446599999999999`", ",", "111.16816489600001`", ",", 
              "0.8336603117185127`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.8967600000000004`", ",", "46.769523968`", ",", 
              "1.4352434243961647`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.143699999999999`", ",", "316.500573188`", ",", 
              "0.9721432269629349`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.62738`", ",", "47.139884496000015`", ",", 
              "1.4619341677088227`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.481300000000002`", ",", "55.47797576000001`", ",", 
              "0.6278743816094452`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.605900000000001`", ",", "79.47310000399997`", ",", 
              "0.8849183373047508`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.99169`", ",", "124.79254337`", ",", "0.7942680927643456`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.8572299999999995`", ",", "53.978203042000004`", ",", 
              "0.9290492554837116`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.154230000000001`", ",", "131.57362620600003`", ",", 
              "0.7299472260869747`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.398233333333333`", ",", "77.64128574444443`", ",", 
              "0.8547127204440081`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "11.764029999999998`", ",", "373.577318062`", ",", 
              "1.1570221566068515`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.721850000000001`", ",", "126.39681985800003`", ",", 
              "1.063539186982088`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.498190000000001`", ",", "53.79229601799999`", ",", 
              "0.6781127740517903`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.6574100000000005`", ",", "85.41048386999998`", ",", 
              "0.7562299645903808`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.147520000000001`", ",", "48.411142772`", ",", 
              "0.5796138166806548`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.515`", ",", "33.161887824000004`", ",", 
              "0.916973491241411`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.566950000000001`", ",", "65.88391795800001`", ",", 
              "0.9281725886698676`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.86544`", ",", "29.629103120000003`", ",", 
              "0.7068200928579308`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.85763`", ",", "161.51621181399997`", ",", 
              "0.8499068448994128`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.832366666666666`", ",", "68.51683976666669`", ",", 
              "1.2771542054439171`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<rf\>\"", ",", "4", ",", "700"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "9.793800000000001`", ",", "178.19173183265306`", ",", 
              "0.8794585296328374`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.989114285714284`", ",", "108.35118425918367`", ",", 
              "0.9358264905891189`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.887628571428571`", ",", "70.44416734693877`", ",", 
              "0.7944489678998425`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.811421428571428`", ",", "70.8324087234694`", ",", 
              "0.6993520991546394`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.801664285714287`", ",", "34.114911574489795`", ",", 
              "0.60570017585129`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.067942857142858`", ",", "112.05969296734695`", ",", 
              "0.7990151178862259`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.90667857142857`", ",", "267.17477433163276`", ",", 
              "0.9826884098360607`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.473421428571427`", ",", "116.96729242551021`", ",", 
              "1.0275533103431753`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.638635714285714`", ",", "30.7978246622449`", ",", 
              "1.4819560151451638`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.4013888888888895`", ",", "39.6456134138322`", ",", 
              "0.8138900326680353`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "7.497592857142857`", ",", "113.10785075408162`", ",", 
              "0.8482061946931672`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.726307142857143`", ",", "45.18892750510205`", ",", 
              "1.3867387468298447`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.123999999999999`", ",", "312.6927029244898`", ",", 
              "0.9604472124864426`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.744064285714285`", ",", "46.50438030510204`", ",", 
              "1.4422254794010536`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.676228571428571`", ",", "58.559835902040824`", ",", 
              "0.6627534665865478`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.762178571428573`", ",", "81.92317921734693`", ",", 
              "0.9121995182783228`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.024814285714285`", ",", "124.05485927959187`", ",", 
              "0.7895729489702659`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.794214285714286`", ",", "54.45136899183673`", ",", 
              "0.9371931811544868`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.102378571428572`", ",", "132.43620448673468`", ",", 
              "0.7347326579509512`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.37686507936508`", ",", "78.07122961564625`", ",", 
              "0.8594457499433222`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "11.868828571428569`", ",", "375.3352305857142`", ",", 
              "1.1624666620438129`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.618778571428569`", ",", "122.75508513571428`", ",", 
              "1.0328965838683746`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.717264285714285`", ",", "54.4671092642857`", ",", 
              "0.6866195587826851`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.734214285714286`", ",", "85.76577968163267`", ",", 
              "0.7593757767538976`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.3673571428571405`", ",", "52.31187118571428`", ",", 
              "0.6263162069620773`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.549314285714286`", ",", "32.29876931224489`", ",", 
              "0.8931070334788231`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.604049999999999`", ",", "66.30724337244898`", ",", 
              "0.9341363968032778`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.835628571428571`", ",", "30.402269679591836`", ",", 
              "0.7252644466148441`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.737692857142858`", ",", "160.24353625408162`", ",", 
              "0.8432099588248656`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.995198412698412`", ",", "70.4343367585034`", ",", 
              "1.312896358108724`"}], "}"}]}], "}"}]}], "}"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<rf\>\"", ",", "3", ",", "300"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "4.842599999999999`", ",", "52.13741334444444`", ",", 
              "1.0871382978674107`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.589333333333333`", ",", "73.47021650000002`", ",", 
              "0.9098129545491137`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.535983333333332`", ",", "33.93901397222223`", ",", 
              "0.8866853938169855`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.916216666666667`", ",", "63.29368513888888`", ",", 
              "1.0356760569513215`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.6808666666666685`", ",", "45.88292038888889`", ",", 
              "0.9741927621509203`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.7271`", ",", "34.293171055555554`", ",", 
              "1.1095070544747212`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.11645`", ",", "96.12407342777777`", ",", 
              "1.1450392926808535`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.253566666666667`", ",", "31.59355781111111`", ",", 
              "0.8051775781413714`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.6371`", ",", "17.791252500000002`", ",", 
              "2.569913258894394`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.3602222222222218`", ",", "19.541333827160493`", ",", 
              "0.8090481220282324`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "3.140916666666667`", ",", "15.53510516111111`", ",", 
              "1.0163312007713932`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.033199999999999`", ",", "96.60158321111109`", ",", 
              "1.0161912934147581`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.463933333333334`", ",", "61.88674071111111`", ",", 
              "0.8849192707948549`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.20415`", ",", "34.87015016111111`", ",", 
              "1.2781657158764261`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.646283333333333`", ",", "29.577691072222223`", ",", 
              "0.855606346162082`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.3323666666666667`", ",", "13.930770388888888`", ",", 
              "0.6491119651040719`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.113350000000001`", ",", "46.00212737222221`", ",", 
              "1.025737058271372`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.321050000000001`", ",", "48.15216843888888`", ",", 
              "1.0301251163548022`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.154966666666666`", ",", "44.904679422222216`", ",", 
              "1.0223436076253927`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.6412962962962965`", ",", "73.26249316049383`", ",", 
              "0.9611242010319405`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "4.944633333333333`", ",", "31.109765733333337`", ",", 
              "2.1974091943184315`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.879100000000001`", ",", "44.91801025555555`", ",", 
              "0.7961998077754435`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.796116666666666`", ",", "111.95272202777774`", ",", 
              "1.1142515179033845`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.0029666666666675`", ",", "103.8922699222222`", ",", 
              "1.0844580064552725`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.365066666666666`", ",", "26.972200166666664`", ",", 
              "1.179814016931013`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.019400000000001`", ",", "19.883602800000006`", ",", 
              "4.531255623162647`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.107333333333334`", ",", "15.304402055555553`", ",", 
              "1.1238032408767222`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.181116666666665`", ",", "59.39035825`", ",", 
              "0.9703438826346825`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.381716666666667`", ",", "34.91685519444444`", ",", 
              "0.7508758899055826`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.488388888888889`", ",", "32.981791327160494`", ",", 
              "1.1486910344679322`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<rf\>\"", ",", "3", ",", "500"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "4.768669999999999`", ",", "52.560954342`", ",", 
              "1.095969722551211`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.72009`", ",", "76.64096323000001`", ",", 
              "0.9490776605480165`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.550879999999999`", ",", "34.14260849599999`", ",", 
              "0.892004472640036`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.9716700000000005`", ",", "64.53286391399999`", ",", 
              "1.0559527683617667`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.802370000000001`", ",", "47.01291721800001`", ",", 
              "0.9981850172829656`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.739320000000001`", ",", "34.193928652`", ",", 
              "1.1062962068494158`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.069229999999999`", ",", "97.33101263799998`", ",", 
              "1.1594164697011342`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.296830000000001`", ",", "34.61816270999999`", ",", 
              "0.8822611425149093`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.58108`", ",", "16.815135724000005`", ",", 
              "2.4289150101835943`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.267055555555556`", ",", "18.425856975555558`", ",", 
              "0.7628652739207716`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "3.1886500000000004`", ",", "15.775163414000005`", ",", 
              "1.032036192136653`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.10885`", ",", "96.75603755399997`", ",", 
              "1.0178160613870466`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.4488`", ",", "61.13719563599999`", ",", 
              "0.8742015164960553`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.08075`", ",", "32.387777174`", ",", "1.1871743082833`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.6928799999999997`", ",", "29.095479015999995`", ",", 
              "0.8416571946041674`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.43922`", ",", "15.734695820000004`", ",", 
              "0.7331668700950903`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.207500000000001`", ",", "47.8991894`", ",", 
              "1.0680369894894686`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.10263`", ",", "47.33455067399999`", ",", 
              "1.0126337214187915`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.09436`", ",", "44.974880584`", ",", "1.023941875554589`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.7678111111111106`", ",", "73.61620877555555`", ",", 
              "0.9657645650606934`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "4.83561`", ",", "29.737596598`", ",", "2.1004873113319995`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.8052399999999995`", ",", "45.151358744`", ",", 
              "0.8003360555875598`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.853930000000001`", ",", "114.46710544599996`", ",", 
              "1.1392768633313417`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.04114`", ",", "104.07400808399996`", ",", 
              "1.086355042729154`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.397639999999998`", ",", "27.358216200000005`", ",", 
              "1.1966990735475518`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.05971`", ",", "20.07364959`", ",", "4.574565208176661`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.9915400000000005`", ",", "14.353156788000001`", ",", 
              "1.0539532388533164`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.189579999999999`", ",", "60.810931296000014`", ",", 
              "0.9935537841345077`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.48672`", ",", "36.654968591999996`", ",", 
              "0.7882534669204221`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.5012`", ",", "33.33252607111112`", ",", 
              "1.160906436956417`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<rf\>\"", ",", "3", ",", "700"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "4.807642857142857`", ",", "53.06496480816325`", ",", 
              "1.1064790486789227`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.7072714285714286`", ",", "74.0205472244898`", ",", 
              "0.9166279340915682`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.573621428571428`", ",", "33.60496286632653`", ",", 
              "0.8779580266451357`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.879100000000001`", ",", "63.594443318367325`", ",", 
              "1.0405973701081486`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.690571428571429`", ",", "46.89077867959184`", ",", 
              "0.9955917542759808`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.904214285714286`", ",", "35.48060868775511`", ",", 
              "1.1479249198724657`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.2418642857142865`", ",", "97.58147164591837`", ",", 
              "1.1623999617135476`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.346964285714287`", ",", "34.32524342959183`", ",", 
              "0.8747959485598615`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.610428571428571`", ",", "17.206973802040814`", ",", 
              "2.4855152901299764`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.248539682539682`", ",", "18.4984030430839`", ",", 
              "0.7658688181114329`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "3.2134785714285705`", ",", "16.37485174387755`", ",", 
              "1.0712687531056477`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.084921428571429`", ",", "95.50528879285713`", ",", 
              "1.0046589271137394`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.461214285714286`", ",", "61.47274186122449`", ",", 
              "0.878999496120313`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.075507142857143`", ",", "32.28649644795918`", ",", 
              "1.1834618622196513`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.855200000000001`", ",", "30.265696742857138`", ",", 
              "0.8755085764123524`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.471142857142857`", ",", "15.687686904081627`", ",", 
              "0.7309764636109285`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.267292857142857`", ",", "48.107526041836735`", ",", 
              "1.0726823966985444`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.1476`", ",", "47.59409735918368`", ",", 
              "1.0181862347934212`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.045057142857143`", ",", "44.75364879999999`", ",", 
              "1.0189050975820904`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.58102380952381`", ",", "71.60485159977324`", ",", 
              "0.9393777472611857`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "4.636428571428571`", ",", "28.37563027346938`", ",", 
              "2.0042860943402254`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.816271428571428`", ",", "44.33260695306122`", ",", 
              "0.7858231683324832`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.883121428571427`", ",", "115.35319588877546`", ",", 
              "1.1480960112982603`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.988771428571429`", ",", "102.55500346938774`", ",", 
              "1.0704992267248261`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.62435`", ",", "29.31438443571428`", ",", 
              "1.2822654971136622`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.9902285714285712`", ",", "19.166441616326534`", ",", 
              "4.36782243256228`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.984578571428572`", ",", "13.79310513367347`", ",", 
              "1.0128286093574481`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.151592857142857`", ",", "60.29766077857143`", ",", 
              "0.9851677611940994`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.454592857142858`", ",", "36.91633290918368`", ",", 
              "0.7938740236160918`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.474158730158729`", ",", "33.09275912244897`", ",", 
              "1.152555824900269`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<rf\>\"", ",", "4", ",", "300"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "4.9075500000000005`", ",", "55.224994938888905`", ",", 
              "1.1515187107761915`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.638133333333332`", ",", "73.70839426666669`", ",", 
              "0.9127624111850405`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.475983333333334`", ",", "34.63439539444444`", ",", 
              "0.9048528205642907`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.224233333333332`", ",", "66.99302475555554`", ",", 
              "1.0962084380112307`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.735566666666667`", ",", "47.48523312222221`", ",", 
              "1.0082132964648953`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.793816666666666`", ",", "35.334647450000006`", ",", 
              "1.1432025504331744`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.323266666666667`", ",", "98.7984198`", ",", 
              "1.1768963662445715`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.425333333333333`", ",", "35.98234806666666`", ",", 
              "0.9170280867186574`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.6307666666666676`", ",", "17.686169322222224`", ",", 
              "2.5547341897502815`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.628796296296296`", ",", "22.39857145061728`", ",", 
              "0.9273431552072456`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "3.26845`", ",", "17.22451456111111`", ",", 
              "1.1268550412146898`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.1885666666666665`", ",", "97.58159538888887`", ",", 
              "1.026500439594297`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.437500000000002`", ",", "62.65436503333334`", ",", 
              "0.8958955404716863`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.099316666666666`", ",", "33.56415114999999`", ",", 
              "1.2302943085765394`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.7155500000000004`", ",", "28.712221116666672`", ",", 
              "0.8305705316836022`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.8107499999999996`", ",", "18.819775738888886`", ",", 
              "0.876917878312863`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.492333333333334`", ",", "51.647622433333325`", ",", 
              "1.1516180517657375`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.179166666666667`", ",", "48.37571198888888`", ",", 
              "1.034907410339057`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.123466666666667`", ",", "46.015315233333325`", ",", 
              "1.0476294227453058`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.5338518518518525`", ",", "72.49802841975308`", ",", 
              "0.9510952553673157`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "4.952283333333332`", ",", "31.406880272222224`", ",", 
              "2.2183956017737785`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.794666666666666`", ",", "46.1916260111111`", ",", 
              "0.8187754431160068`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.9976`", ",", "118.15793647777772`", ",", 
              "1.17601124553299`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.272749999999999`", ",", "106.70197207222225`", ",", 
              "1.113786502161481`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.489416666666667`", ",", "29.839427783333328`", ",", 
              "1.3052318660857745`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.075616666666667`", ",", "20.277588338888883`", ",", 
              "4.6210406186934865`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.1486000000000005`", ",", "15.4621895`", ",", 
              "1.13538958321095`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.323816666666666`", ",", "62.217746149999996`", ",", 
              "1.0165388986851256`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.4074333333333335`", ",", "36.14740215555554`", ",", 
              "0.7773384117836103`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.356351851851852`", ",", "31.672963820987654`", ",", 
              "1.1031071422198575`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<rf\>\"", ",", "4", ",", "500"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "4.924339999999999`", ",", "55.290612232`", ",", 
              "1.152886923500367`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.74471`", ",", "76.14990783`", ",", "0.9429967125720253`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.6048100000000005`", ",", "34.415737822`", ",", 
              "0.8991402068774981`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.076929999999999`", ",", "64.75051788199998`", ",", 
              "1.0595142453537194`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.68822`", ",", "48.013149907999995`", ",", 
              "1.0194221015575902`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.920030000000001`", ",", "36.667125682000005`", ",", 
              "1.18631299933109`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.38`", ",", "99.55889216`", ",", "1.1859551868099731`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.28291`", ",", "34.184004294`", ",", "0.8711963987461139`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.65197`", ",", "17.482379034`", ",", "2.5252970625027085`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.504422222222222`", ",", "21.392573262222225`", ",", 
              "0.8856929304946632`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "3.26451`", ",", "17.534456322`", ",", "1.147131922429627`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.18473`", ",", "97.514622494`", ",", "1.0257959245085333`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.46285`", ",", "64.09003615400002`", ",", 
              "0.9164242195813537`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.2443100000000005`", ",", "36.159084613999994`", ",", 
              "1.3254116216176595`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.59356`", ",", "29.001509336000005`", ",", 
              "0.8389388940323449`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.698290000000001`", ",", "18.137084662`", ",", 
              "0.8451075093161987`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.46317`", ",", "52.07832893399999`", ",", 
              "1.161221773250126`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.2152899999999995`", ",", "48.520087042`", ",", 
              "1.037996043171316`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.17703`", ",", "46.396557769999994`", ",", 
              "1.0563091611452013`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.709033333333333`", ",", "74.27149736666667`", ",", 
              "0.9743612384252935`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "4.907170000000001`", ",", "31.302254350000005`", ",", 
              "2.2110054476522123`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.764010000000001`", ",", "45.047759873999986`", ",", 
              "0.7984997008623511`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.95894`", ",", "118.44338849199998`", ",", 
              "1.1788523139266358`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.187590000000001`", ",", "107.61500079000002`", ",", 
              "1.1233169638970746`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.551850000000001`", ",", "29.937239465999994`", ",", 
              "1.309510330338474`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.15005`", ",", "21.892400326`", ",", "4.989038610332491`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.0823500000000004`", ",", "14.46428257`", ",", 
              "1.0621132122716326`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.37505`", ",", "61.68735015`", ",", "1.0078730726295317`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.523819999999999`", ",", "37.58234624799999`", ",", 
              "0.8081964291044377`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.367066666666666`", ",", "31.64219093333333`", ",", 
              "1.1020353829632856`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<rf\>\"", ",", "4", ",", "700"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "4.890392857142858`", ",", "54.395642762244904`", ",", 
              "1.1342255530260579`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.745078571428571`", ",", "76.91486576428572`", ",", 
              "0.9524695121832566`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.670614285714285`", ",", "35.5784383`", ",", 
              "0.9295167385018529`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.2239`", ",", "67.13813919183673`", ",", 
              "1.0985829489414225`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.632228571428572`", ",", "47.012838769387756`", ",", 
              "0.9981833516507518`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.78955`", ",", "34.02315370510204`", ",", 
              "1.1007710249406366`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.427657142857143`", ",", "99.48545674285715`", ",", 
              "1.1850804169931681`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.5003714285714285`", ",", "36.149072887755096`", ",", 
              "0.9212771519383026`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.672757142857143`", ",", "18.283694271428576`", ",", 
              "2.6410455548149727`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.4990396825396832`", ",", "21.689185216553287`", ",", 
              "0.8979732255218702`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "3.2298785714285714`", ",", "17.077730533673467`", ",", 
              "1.117252197506029`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.238471428571428`", ",", "97.60168053265306`", ",", 
              "1.026711723380149`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.492057142857144`", ",", "62.145948059183674`", ",", 
              "0.8886256798706177`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.009335714285715`", ",", "32.30131814183672`", ",", 
              "1.1840051515624834`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.6912785714285725`", ",", "30.403767954081637`", ",", 
              "0.879502620580895`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.5307357142857136`", ",", "17.589938229591834`", ",", 
              "0.819612918132396`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.4647`", ",", "51.899943730612236`", ",", 
              "1.1572442112499697`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.130485714285714`", ",", "48.26344181632653`", ",", 
              "1.0325056010680842`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.122599999999999`", ",", "45.94518411224491`", ",", 
              "1.0460327494305675`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.704960317460317`", ",", "75.76070463605443`", ",", 
              "0.9938980175494456`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "4.922264285714285`", ",", "31.31601539489796`", ",", 
              "2.2119774461828796`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.755942857142858`", ",", "45.274536967346926`", ",", 
              "0.8025194665889146`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.006342857142856`", ",", "118.6745617877551`", ",", 
              "1.1811531529864485`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.208528571428572`", ",", "109.12418313469388`", ",", 
              "1.1390702521650993`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.494007142857143`", ",", "28.732133162244896`", ",", 
              "1.2567967474540007`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.131371428571429`", ",", "21.248450434693876`", ",", 
              "4.8422894725949455`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.1059785714285715`", ",", "14.855848035714285`", ",", 
              "1.0908658899514103`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.320171428571429`", ",", "59.9008710265306`", ",", 
              "0.9786848484801498`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.557907142857141`", ",", "38.14816282346938`", ",", 
              "0.8203641349949871`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.51581746031746`", ",", "32.41511770634921`", ",", 
              "1.1289549048793805`"}], "}"}]}], "}"}]}], "}"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<rf\>\"", ",", "3", ",", "300"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "1.9387833333333337`", ",", "4.5749431055555565`", ",", 
              "0.9034470846052786`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.57325`", ",", "3.0667739277777772`", ",", 
              "0.8373215551187073`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.8419666666666668`", ",", "5.968996355555556`", ",", 
              "0.7876639732328098`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.245216666666666`", ",", "98.06038910555557`", ",", 
              "0.993818950089635`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.0700333333333334`", ",", "1.6076351666666664`", ",", 
              "0.8676436169016617`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.3070500000000003`", ",", "2.4029373833333336`", ",", 
              "1.6396986528827397`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.6076000000000001`", ",", "3.2839654777777776`", ",", 
              "0.6048403349822549`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.2927499999999994`", ",", "9.776942794444448`", ",", 
              "0.8926860213466556`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.012383333333333`", ",", "41.034413449999995`", ",", 
              "1.003799336335682`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.0928888888888886`", ",", "6.367461345679012`", ",", 
              "0.8778332954637327`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "1.4567166666666667`", ",", "2.4992599277777776`", ",", 
              "2.156207339986004`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.4401`", ",", "10.774128055555554`", ",", 
              "0.9071517596636789`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.443083333333333`", ",", "36.19815488333332`", ",", 
              "0.942854256040522`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.2324499999999996`", ",", "10.34238526111111`", ",", 
              "1.1524223156353006`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.765083333333334`", ",", "89.46465119444444`", ",", 
              "0.957946669947934`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.9629500000000004`", ",", "7.235113383333333`", ",", 
              "0.9453215981150485`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.4121666666666668`", ",", "2.926888200000001`", ",", 
              "0.8109745365880693`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.5501666666666667`", ",", "3.4659419000000007`", ",", 
              "0.6928973631074952`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.8545666666666663`", ",", "3.9907986777777773`", ",", 
              "0.7150815599236287`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.7055925925925928`", ",", "7.523626802469137`", ",", 
              "0.6769139364588337`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "2.4060333333333337`", ",", "11.696458844444447`", ",", 
              "0.8840125797888645`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.656866666666667`", ",", "3.061468277777778`", ",", 
              "1.3661779989190865`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.7001833333333334`", ",", "4.067679672222222`", ",", 
              "1.4064796072826742`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.890383333333333`", ",", "5.0140380388888905`", ",", 
              "0.7340123025748634`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.9025666666666665`", ",", "8.431186022222219`", ",", 
              "0.8453588030503052`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.5811333333333333`", ",", "3.2535759222222227`", ",", 
              "1.1547843094338803`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.3267833333333336`", ",", "87.66846238333333`", ",", 
              "0.9378324733888797`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.1283166666666657`", ",", "40.022960972222215`", ",", 
              "1.0551385352724147`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.540433333333333`", ",", "3.3999437111111113`", ",", 
              "1.0987053517890164`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.117296296296297`", ",", "11.530499814814814`", ",", 
              "0.7348485684162489`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<rf\>\"", ",", "3", ",", "500"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "1.86108`", ",", "4.2704445479999995`", ",", 
              "0.8433155534052477`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.5853300000000001`", ",", "2.923688534`", ",", 
              "0.79825493747611`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.7944499999999999`", ",", "5.523096386000001`", ",", 
              "0.7288233707657592`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.29722`", ",", "98.71843341199998`", ",", 
              "1.0004880741641793`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.1426500000000002`", ",", "1.7850554740000006`", ",", 
              "0.9633976787424952`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.39345`", ",", "2.6776944819999997`", ",", 
              "1.8271853712959953`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.6303900000000002`", ",", "3.3788787339999997`", ",", 
              "0.6223214461803398`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.26048`", ",", "9.877224419999997`", ",", 
              "0.9018422583435854`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.04939`", ",", "40.96627152199999`", ",", 
              "1.0021324227294626`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.0854000000000004`", ",", "6.471069008888889`", ",", 
              "0.8921168931949607`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "1.47303`", ",", "2.619731482`", ",", "2.260142767664567`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.6406299999999994`", ",", "12.149066118`", ",", 
              "1.02291773871494`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.4445`", ",", "36.30641388400001`", ",", 
              "0.9456740809697831`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.3462799999999993`", ",", "10.574365108`", ",", 
              "1.178271164385661`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.7162800000000002`", ",", "89.91743222400001`", ",", 
              "0.9627948426472904`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.09281`", ",", "7.568882662000002`", ",", 
              "0.9889310470889521`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.4073399999999998`", ",", "2.978145632`", ",", 
              "0.8251768119475769`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.6450999999999998`", ",", "3.8538192679999996`", ",", 
              "0.7704402686871515`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.91598`", ",", "4.238587072`", ",", "0.7594809209984056`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.7329555555555554`", ",", "7.771577964444447`", ",", 
              "0.6992225386142684`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "2.34889`", ",", "10.515390742000001`", ",", 
              "0.7947480362176992`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.65244`", ",", "3.084933216`", ",", "1.376649210585034`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.6351499999999999`", ",", "3.8044022060000002`", ",", 
              "1.3154462867812318`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.9483600000000003`", ",", "5.134676963999999`", ",", 
              "0.7516728098375055`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.8775999999999997`", ",", "8.422686355999996`", ",", 
              "0.8445065780317839`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.6596800000000003`", ",", "3.4883271119999995`", ",", 
              "1.2381040158297762`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.27321`", ",", "87.34228286600002`", ",", 
              "0.93434317136175`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.1479800000000004`", ",", "40.496071736`", ",", 
              "1.0676113105540979`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.4755399999999999`", ",", "3.0734866480000003`", ",", 
              "0.9932094516076911`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.173811111111111`", ",", "11.98205594`", ",", 
              "0.7636266246567582`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<rf\>\"", ",", "3", ",", "700"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "1.9434785714285716`", ",", "4.450469190816327`", ",", 
              "0.878866320913594`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.648835714285714`", ",", "3.3327244948979597`", ",", 
              "0.909934061840758`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.8083642857142859`", ",", "5.571698264285714`", ",", 
              "0.7352368356561293`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.245264285714287`", ",", "98.65602169081633`", ",", 
              "0.9998555460681173`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.0303357142857144`", ",", "1.5212238581632653`", ",", 
              "0.8210072768876829`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.4566142857142859`", ",", "2.8567029326530613`", ",", 
              "1.9493358349020355`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.631657142857143`", ",", "3.2738627795918362`", ",", 
              "0.6029796213431017`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.184107142857143`", ",", "9.569671021428572`", ",", 
              "0.8737610242099078`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.0892785714285713`", ",", "41.43652209693877`", ",", 
              "1.0136358700885968`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.108420634920635`", ",", "6.509341484126985`", ",", 
              "0.8973932272376652`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "1.4846428571428574`", ",", "2.6554007265306128`", ",", 
              "2.2909159921754916`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.523971428571429`", ",", "11.638492293877553`", ",", 
              "0.9799288359840072`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.4115214285714286`", ",", "36.22629638061224`", ",", 
              "0.9435872583321111`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.19695`", ",", "9.827232674489796`", ",", 
              "1.0950203409658839`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.794578571428571`", ",", "90.2829108622449`", ",", 
              "0.9667082211690808`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.0655857142857146`", ",", "7.432510942857144`", ",", 
              "0.9711130635069961`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.341342857142857`", ",", "2.6970339244897956`", ",", 
              "0.7472871143747182`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.6493142857142857`", ",", "3.946313159183674`", ",", 
              "0.7889312806988416`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.876071428571428`", ",", "4.10836157755102`", ",", 
              "0.7361467823381572`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.6712619047619048`", ",", "7.146394753968257`", ",", 
              "0.6429737055551216`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "2.436671428571429`", ",", "11.175441881632654`", ",", 
              "0.8446343751942508`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.6722642857142858`", ",", "3.1282519581632644`", ",", 
              "1.3959801678625852`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.5712857142857142`", ",", "3.3668067224489797`", ",", 
              "1.1641391108360637`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.9192142857142855`", ",", "5.013578510204081`", ",", 
              "0.7339450315040378`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.8834071428571424`", ",", "8.341902641836734`", ",", 
              "0.8364067420501062`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.5716428571428573`", ",", "3.097668981632653`", ",", 
              "1.0994486132557175`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.282407142857143`", ",", "87.85819423163264`", ",", 
              "0.9398621278818847`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.203714285714286`", ",", "40.62219998367348`", ",", 
              "1.0709364711937377`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.4712785714285714`", ",", "3.0075032459183673`", ",", 
              "0.9718866524215115`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.1547460317460314`", ",", "12.048978247165536`", ",", 
              "0.7678916402593361`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<rf\>\"", ",", "4", ",", "300"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "1.8697333333333337`", ",", "4.307805855555557`", ",", 
              "0.8506935608709844`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.7048333333333336`", ",", "3.4474635222222227`", ",", 
              "0.941261268558462`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.8462499999999995`", ",", "6.099569394444444`", ",", 
              "0.8048942867532024`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.27465`", ",", "98.72295816111111`", ",", 
              "1.0005339314308295`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.0792`", ",", "1.6034787888888888`", ",", 
              "0.8654004122722196`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.497066666666667`", ",", "2.947161566666667`", ",", 
              "2.0110623290514447`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.6748999999999998`", ",", "3.475354733333333`", ",", 
              "0.6400903832015681`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.084883333333334`", ",", "8.669618572222223`", ",", 
              "0.791581527328543`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.136816666666667`", ",", "41.79534128333334`", ",", 
              "1.0224134406905565`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.120277777777778`", ",", "6.678977635802468`", ",", 
              "0.9207796687048173`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "1.4591833333333333`", ",", "2.657184405555556`", ",", 
              "2.292454840441338`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.6245499999999997`", ",", "12.05411016111111`", ",", 
              "1.014922709981465`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.32885`", ",", "35.8261697611111`", ",", 
              "0.9331651501509713`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.28015`", ",", "9.863513827777776`", ",", 
              "1.0990630457801465`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.7580666666666667`", ",", "89.83872151111112`", ",", 
              "0.9619520442426193`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.056333333333334`", ",", "7.559801533333333`", ",", 
              "0.987744529807324`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.3846166666666664`", ",", "2.73798355`", ",", 
              "0.7586333296389681`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.6857666666666664`", ",", "4.190967955555556`", ",", 
              "0.8378416975981202`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.8247499999999999`", ",", "3.9569344833333324`", ",", 
              "0.7090136865619048`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.7042962962962964`", ",", "7.045164691358023`", ",", 
              "0.6338658587721073`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "2.4761333333333333`", ",", "10.861662866666668`", ",", 
              "0.8209191122935104`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.620516666666667`", ",", "3.0926435277777777`", ",", 
              "1.3800899316246957`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.5747000000000002`", ",", "3.340332077777778`", ",", 
              "1.1549849859194974`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.9998166666666666`", ",", "5.403977216666666`", ",", 
              "0.7910960645098328`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.820033333333333`", ",", "8.244603655555554`", ",", 
              "0.8266509906808598`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.7567666666666664`", ",", "3.9587896000000002`", ",", 
              "1.405084197730237`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.309266666666667`", ",", "88.42664808888891`", ",", 
              "0.9459431571649927`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.1998999999999995`", ",", "40.48218357777779`", ",", 
              "1.0672451724531618`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.5112166666666667`", ",", "3.1141123722222224`", ",", 
              "1.0063378161971959`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.151240740740741`", ",", "12.101720833333331`", ",", 
              "0.7712529701723879`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<rf\>\"", ",", "4", ",", "500"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "1.93395`", ",", "4.592168430000002`", ",", 
              "0.9068486939349807`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.66173`", ",", "3.26851791`", ",", "0.8924037323213019`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.8210799999999998`", ",", "5.719170644`", ",", 
              "0.7546971726422189`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.31813`", ",", "99.98643454600003`", ",", 
              "1.0133389670394657`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.1105`", ",", "1.68138722`", ",", "0.9074477339270054`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.5038600000000004`", ",", "3.044690908`", ",", 
              "2.077613680206076`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.68763`", ",", "3.761750318`", ",", "0.692838684771548`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.167230000000001`", ",", "8.910501106000002`", ",", 
              "0.8135753627442698`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.164449999999999`", ",", "42.21740155799999`", ",", 
              "1.032738038704374`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.0854222222222223`", ",", "6.5826753644444445`", ",", 
              "0.9075032095890938`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "1.4353500000000001`", ",", "2.545482542`", ",", 
              "2.196085361055991`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.7335199999999995`", ",", "13.384081431999999`", ",", 
              "1.126902609651108`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.43492`", ",", "37.163901136`", ",", "0.9680090731166048`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.2563`", ",", "10.083439643999998`", ",", 
              "1.1235687484783237`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.7607600000000003`", ",", "90.35517238400001`", ",", 
              "0.9674819645773038`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.0574900000000005`", ",", "7.529863510000003`", ",", 
              "0.983832903470263`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.3908999999999998`", ",", "2.974671172`", ",", 
              "0.8242141176470588`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.70896`", ",", "4.248045979999999`", ",", 
              "0.8492525099458227`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.8464700000000005`", ",", "4.098873273999999`", ",", 
              "0.734446643731298`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.6682111111111115`", ",", "6.900340766666668`", ",", 
              "0.6208357955419549`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "2.34647`", ",", "10.672326057999998`", ",", 
              "0.8066091298531487`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.7724299999999995`", ",", "3.4282727700000004`", ",", 
              "1.5298642375831155`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.57238`", ",", "3.3378445040000004`", ",", 
              "1.1541248587531554`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.9406299999999994`", ",", "5.185759546000002`", ",", 
              "0.759150863123994`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.78172`", ",", "8.070559092000003`", ",", 
              "0.8092002899684166`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.74586`", ",", "3.8297483`", ",", "1.3592838623235342`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.2836399999999997`", ",", "88.61185992`", ",", 
              "0.9479244588206815`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.2051299999999996`", ",", "41.029548162000005`", ",", 
              "1.0816755257210537`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.57097`", ",", "3.75965453`", ",", "1.2149473355954112`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.1393222222222215`", ",", "11.701219420000001`", ",", 
              "0.7457286741779902`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<rf\>\"", ",", "4", ",", "700"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "1.9125714285714284`", ",", "4.401295687755103`", ",", 
              "0.8691556738179954`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.7589499999999998`", ",", "3.631693603061225`", ",", 
              "0.9915616237266491`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.808978571428571`", ",", "5.653845284693878`", ",", 
              "0.7460768906050167`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.288185714285714`", ",", "99.68481264285715`", ",", 
              "1.0102821000839122`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.1239357142857143`", ",", "1.8152941112244896`", ",", 
              "0.9797175261280388`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.4842071428571426`", ",", "3.061081456122449`", ",", 
              "2.0887981413005665`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.7099000000000004`", ",", "3.6776822387755104`", ",", 
              "0.6773550368636951`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.126514285714286`", ",", "8.898791579591837`", ",", 
              "0.8125062217294428`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.1566428571428573`", ",", "42.16859144693878`", ",", 
              "1.0315440273131933`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.0944682539682535`", ",", "6.457870776643992`", ",", 
              "0.8902973536521417`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "1.4514428571428575`", ",", "2.636413275510204`", ",", 
              "2.2745347903633886`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.687021428571428`", ",", "12.4992093377551`", ",", 
              "1.0523988286274886`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.3922785714285717`", ",", "36.53394716428572`", ",", 
              "0.9516006460778578`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.353135714285714`", ",", "10.387696168367343`", ",", 
              "1.1574711800263913`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.812471428571429`", ",", "91.36408801632653`", ",", 
              "0.9782849728866418`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.0537857142857145`", ",", "7.3775425142857145`", ",", 
              "0.9639310277889772`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.3807714285714288`", ",", "3.0361596489795923`", ",", 
              "0.8412511842231005`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.7127714285714284`", ",", "4.199737287755102`", ",", 
              "0.8395948277233768`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.8442214285714282`", ",", "4.03253956020408`", ",", 
              "0.7225607984740959`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.6964365079365078`", ",", "6.744747116780047`", ",", 
              "0.6068367611934962`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "2.3335428571428567`", ",", "10.161139516326532`", ",", 
              "0.7679739036305773`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.690364285714286`", ",", "3.1021759969387754`", ",", 
              "1.3843437890752726`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.5851357142857145`", ",", "3.509860419387754`", ",", 
              "1.213602717536653`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.9365571428571429`", ",", "5.145425704081632`", ",", 
              "0.7532463334916751`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.8354285714285716`", ",", "8.388894732653064`", ",", 
              "0.8411184371236842`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.6648785714285712`", ",", "3.458294929591836`", ",", 
              "1.2274447615655277`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.2968071428571433`", ",", "88.7528490602041`", ",", 
              "0.9494326886958723`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.235971428571429`", ",", "41.38746846938776`", ",", 
              "1.0911114969662468`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.5124357142857143`", ",", "3.1665405785714293`", ",", 
              "1.023280199893821`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.1092063492063495`", ",", "11.707731267573699`", ",", 
              "0.7461436797670045`"}], "}"}]}], "}"}]}], "}"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<rf\>\"", ",", "3", ",", "300"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "4.339`", ",", "58.382118922222205`", ",", 
              "0.8644019593025101`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.8962833333333333`", ",", "14.285720961111116`", ",", 
              "0.7776869790201758`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.002666666666667`", ",", "23.308683244444445`", ",", 
              "0.8262004063691013`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.569699999999999`", ",", "49.276214377777784`", ",", 
              "0.8441234758662485`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.9306000000000005`", ",", "23.950465788888884`", ",", 
              "0.7994607763260361`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.6354499999999996`", ",", "13.235849883333334`", ",", 
              "0.5077704757556928`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.084316666666666`", ",", "127.05093205`", ",", 
              "0.9679694888046256`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.568950000000002`", ",", "35.52449677222222`", ",", 
              "0.708841524479268`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.252383333333333`", ",", "59.848065094444436`", ",", 
              "0.8191307092169134`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.194370370370371`", ",", "52.030813950617286`", ",", 
              "0.8957407227143659`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "3.498866666666667`", ",", "25.180878244444443`", ",", 
              "0.981049926197637`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.02165`", ",", "40.699468116666665`", ",", 
              "0.7622012193818253`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.6399333333333335`", ",", "55.23992586666666`", ",", 
              "0.7925443608673762`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.7754999999999996`", ",", "19.173827100000004`", ",", 
              "0.7163741999843082`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.330416666666666`", ",", "118.32168805`", ",", 
              "0.9486111210880974`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.1028166666666674`", ",", "25.340995383333336`", ",", 
              "0.8326158152458433`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.6061000000000005`", ",", "77.23625552222225`", ",", 
              "0.8992242071415443`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.138883333333333`", ",", "24.683795538888894`", ",", 
              "0.7579790294689327`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.270783333333334`", ",", "15.456166716666669`", ",", 
              "1.7483807592712528`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.243`", ",", "62.630619135802476`", ",", 
              "0.9886751708667972`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "3.4041500000000005`", ",", "19.956684816666666`", ",", 
              "0.7963092681762212`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.51295`", ",", "18.22028577222222`", ",", 
              "1.5613629381118022`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.4085833333333335`", ",", "18.325434716666663`", ",", 
              "0.7420285837881901`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.051233333333334`", ",", "76.52925588888888`", ",", 
              "0.9703165685591667`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.794866666666666`", ",", "90.33385923333333`", ",", 
              "0.8458347296937839`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.211933333333333`", ",", "57.54516584444444`", ",", 
              "0.7864856050375447`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.111833333333332`", ",", "39.68316946666666`", ",", 
              "1.2596921799034089`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.051366666666667`", ",", "65.31134164444445`", ",", 
              "0.8989208511624855`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.472016666666667`", ",", "58.21549718333332`", ",", 
              "0.7228515132175007`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.3266851851851857`", ",", "18.42669672222222`", ",", 
              "0.690929954900479`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<rf\>\"", ",", "3", ",", "500"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "4.417610000000001`", ",", "58.49913714599999`", ",", 
              "0.8661345237207762`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.8385500000000006`", ",", "13.959144054000001`", ",", 
              "0.7599087647459106`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.136450000000001`", ",", "23.864863566000004`", ",", 
              "0.8459147936154604`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.3179099999999995`", ",", "46.68100665`", ",", 
              "0.7996664128505745`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.8010400000000004`", ",", "22.367782484000003`", ",", 
              "0.7466311890120508`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.71559`", ",", "14.129554797999997`", ",", 
              "0.542055918224855`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.12183`", ",", "130.233368026`", ",", "0.992215677912706`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.571019999999999`", ",", "36.82998824800001`", ",", 
              "0.734890776459344`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.34894`", ",", "60.190143940000006`", ",", 
              "0.8238126866029133`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.213844444444444`", ",", "50.661910373333335`", ",", 
              "0.8721742514920171`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "3.5814200000000005`", ",", "25.763867295999994`", ",", 
              "1.0037632470139508`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.9571000000000005`", ",", "40.932630108000005`", ",", 
              "0.7665677716325411`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.551360000000001`", ",", "52.380520672`", ",", 
              "0.7515195870844079`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.70622`", ",", "16.787874723999998`", ",", 
              "0.6272300392675537`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.47825`", ",", "119.01462787800001`", ",", 
              "0.9541665728224228`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.08981`", ",", "25.504540721999994`", ",", 
              "0.83798933879627`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.6090599999999995`", ",", "77.16656596800001`", ",", 
              "0.8984128455119854`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.17254`", ",", "25.366810236`", ",", "0.7789527414093693`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.3450699999999998`", ",", "16.219427869999997`", ",", 
              "1.8347198328106313`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.133744444444445`", ",", "60.52778394444445`", ",", 
              "0.9554802101461847`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "3.2932`", ",", "18.157727600000005`", ",", 
              "0.7245274908998773`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.5469999999999997`", ",", "18.263521672000003`", ",", 
              "1.5650679805218322`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.3387300000000004`", ",", "18.243866434000005`", ",", 
              "0.7387257427803242`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.04603`", ",", "75.157358558`", ",", "0.9529222440611436`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.82575`", ",", "93.00257014600001`", ",", 
              "0.8708230163960676`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.25368`", ",", "56.50998604399998`", ",", 
              "0.7723375180570324`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.10676`", ",", "39.493012388000004`", ",", 
              "1.2536558832020863`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.15361`", ",", "67.104347094`", ",", "0.9235991067957557`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.369670000000001`", ",", "57.197867337999995`", ",", 
              "0.7102157837436471`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.224411111111111`", ",", "16.924764486666664`", ",", 
              "0.6346132972043388`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<rf\>\"", ",", "3", ",", "700"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "4.470785714285714`", ",", "58.22743875714285`", ",", 
              "0.862111774563961`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.8630000000000004`", ",", "14.561685524489798`", ",", 
              "0.7927099553330141`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.862785714285714`", ",", "22.203004177551016`", ",", 
              "0.787008467262078`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.352214285714286`", ",", "46.4695524367347`", ",", 
              "0.7960441080988409`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.7894142857142854`", ",", "22.961177306122448`", ",", 
              "0.7664385651751459`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.7339071428571424`", ",", "13.915371735714285`", ",", 
              "0.5338391556902048`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.037964285714287`", ",", "125.86382185000002`", ",", 
              "0.9589251910973368`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.547285714285715`", ",", "35.71158998367347`", ",", 
              "0.7125747071918948`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.317492857142858`", ",", "62.051984760204085`", ",", 
              "0.8492953983513394`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.267777777777777`", ",", "53.06749194557824`", ",", 
              "0.9135877373182454`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "3.5572285714285714`", ",", "25.422101740816323`", ",", 
              "0.9904480214910361`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.921828571428572`", ",", "41.439840728571426`", ",", 
              "0.7760665825844374`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.687221428571428`", ",", "54.48897917448979`", ",", 
              "0.7817702956082495`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.7443499999999994`", ",", "18.161554484693873`", ",", 
              "0.6785535822654829`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.3652`", ",", "116.99502025306121`", ",", 
              "0.9379749321788099`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.021907142857144`", ",", "24.498834807142853`", ",", 
              "0.8049453861997167`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.635442857142857`", ",", "76.61242056122451`", ",", 
              "0.8919611997054968`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.271242857142857`", ",", "26.194721181632655`", ",", 
              "0.8043758629900302`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.281642857142856`", ",", "15.119184387755102`", ",", 
              "1.7102617721456752`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.095309523809523`", ",", "60.9881416791383`", ",", 
              "0.9627473307381335`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "3.3649999999999998`", ",", "19.572960193877552`", ",", 
              "0.7809979338357997`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.5517499999999997`", ",", "18.70472898469388`", ",", 
              "1.602876649094658`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.5090714285714286`", ",", "18.88900832857143`", ",", 
              "0.7648486552117484`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.848214285714286`", ",", "74.0021961755102`", ",", 
              "0.9382759080150502`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.865835714285714`", ",", "90.74095410714284`", ",", 
              "0.8496465338774065`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.188878571428572`", ",", "56.8826923479592`", ",", 
              "0.777431397597897`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.136735714285714`", ",", "39.76470960714285`", ",", 
              "1.26228056885234`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.308085714285715`", ",", "68.39714981632656`", ",", 
              "0.9413927593877603`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.419071428571429`", ",", "58.877554291836724`", ",", 
              "0.7310721590227057`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.2437539682539676`", ",", "16.563709930838996`", ",", 
              "0.6210751459157373`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<rf\>\"", ",", "4", ",", "300"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "4.430266666666666`", ",", "61.65549772222222`", ",", 
              "0.9128673987297575`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.894716666666667`", ",", "14.510609172222223`", ",", 
              "0.789929457645675`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.177466666666667`", ",", "25.456060755555562`", ",", 
              "0.9023164251807062`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.233700000000001`", ",", "45.11303941111112`", ",", 
              "0.7728064364411006`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.079733333333332`", ",", "25.921983611111113`", ",", 
              "0.8652695661252561`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.4624166666666656`", ",", "12.000116172222222`", ",", 
              "0.46036369040159547`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.249816666666666`", ",", "129.24174759444446`", ",", 
              "0.9846607681868703`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.4138`", ",", "34.61625564444444`", ",", 
              "0.6907188462120228`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.443600000000001`", ",", "64.37870006666667`", ",", 
              "0.8811407713992554`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.492500000000001`", ",", "58.080663858024685`", ",", 
              "0.999892407397174`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "3.6661166666666665`", ",", "27.585637649999995`", ",", 
              "1.0747396305217443`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.216933333333335`", ",", "43.99991523333334`", ",", 
              "0.8240104992873387`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.393199999999999`", ",", "54.74202626666666`", ",", 
              "0.7854008407762996`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.8541833333333337`", ",", "18.953167772222223`", ",", 
              "0.7081299069393436`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.519033333333333`", ",", "120.47733712222221`", ",", 
              "0.9658934360784743`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.1409166666666675`", ",", "27.118287883333334`", ",", 
              "0.891011384221444`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.7987833333333345`", ",", "79.51042020555556`", ",", 
              "0.9257012019214287`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.131`", ",", "24.847387899999998`", ",", 
              "0.7630025510302001`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.443533333333334`", ",", "16.424801300000006`", ",", 
              "1.8579513985707472`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.0979074074074076`", ",", "65.85779469753086`", ",", 
              "1.039618757149901`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "3.411950000000001`", ",", "19.61485697222222`", ",", 
              "0.7826696941110696`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.6001666666666674`", ",", "18.96951046666667`", ",", 
              "1.6255667428626115`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.6705166666666678`", ",", "24.47908029444445`", ",", 
              "0.9912003488137723`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.012616666666668`", ",", "74.48951081666668`", ",", 
              "0.9444545839334744`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.9394`", ",", "92.63074568888888`", ",", 
              "0.867341464275486`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.1688833333333335`", ",", "59.618431105555565`", ",", 
              "0.8148214914558081`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.329766666666666`", ",", "44.6797767111111`", ",", 
              "1.4183031768693244`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.304333333333334`", ",", "70.19412368888888`", ",", 
              "0.9661256349093563`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.5007166666666665`", ",", "60.887911383333325`", ",", 
              "0.7560344068090544`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.384611111111111`", ",", "17.7257584382716`", ",", 
              "0.6646474765909529`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<rf\>\"", ",", "4", ",", "500"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "4.30021`", ",", "58.66774090199998`", ",", 
              "0.8686308602656403`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.92292`", ",", "14.868126876000002`", ",", 
              "0.8093920289610499`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.047649999999999`", ",", "25.080812174`", ",", 
              "0.8890153507562413`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.27596`", ",", "46.081934716`", ",", "0.7894040440869129`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.9446799999999995`", ",", "24.31081486`", ",", 
              "0.811489141480943`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.6053`", ",", "13.362757947999992`", ",", 
              "0.512639084038578`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.2577300000000005`", ",", "128.837762178`", ",", 
              "0.9815829036586008`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.605859999999999`", ",", "36.631416412`", ",", 
              "0.7309285538879337`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.5317099999999995`", ",", "64.88139193399999`", ",", 
              "0.888021033027706`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.421188888888888`", ",", "57.892084659999995`", ",", 
              "0.996645906827572`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "3.6115600000000017`", ",", "26.361132171999998`", ",", 
              "1.0270327556002734`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.05072`", ",", "44.200914084`", ",", "0.8277747147958391`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.56101`", ",", "55.56045546600001`", ",", 
              "0.7971430985097092`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.8334899999999994`", ",", "19.73617497`", ",", 
              "0.73738469013753`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.4783100000000005`", ",", "118.463394562`", ",", 
              "0.949747213510621`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.06376`", ",", "27.169720992000002`", ",", 
              "0.8927012949394457`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.854559999999999`", ",", "80.91058033200001`", ",", 
              "0.94200258617498`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.32104`", ",", "26.991743424000003`", ",", 
              "0.8288504679908277`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.3685`", ",", "16.048802164`", ",", "1.8154188827836248`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.116455555555556`", ",", "65.32666633555556`", ",", 
              "1.0312344647498926`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "3.372530000000001`", ",", "19.446845990000003`", ",", 
              "0.7759657398457194`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.6351799999999996`", ",", "19.919985804`", ",", 
              "1.7070164513827746`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.7149100000000006`", ",", "23.192263770000004`", ",", 
              "0.9390949195024375`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.0021`", ",", "76.885301604`", ",", "0.9748308821053275`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.834149999999999`", ",", "92.50019012599998`", ",", 
              "0.8661190164559933`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.0919799999999995`", ",", "58.08779113600001`", ",", 
              "0.7939018141052427`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.197640000000001`", ",", "41.809698931999996`", ",", 
              "1.3271961765301075`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.582189999999999`", ",", "72.375547194`", ",", 
              "0.9961499312197223`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.47027`", ",", "58.04290335399999`", ",", 
              "0.7207084462208777`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.524788888888889`", ",", "18.645165659999996`", ",", 
              "0.699121696241938`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<rf\>\"", ",", "4", ",", "700"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "4.33275`", ",", "60.747600623469374`", ",", 
              "0.8994251317224135`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.9678642857142856`", ",", "15.590937190816325`", ",", 
              "0.848740422483809`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.224214285714284`", ",", "26.62213365102041`", ",", 
              "0.9436490860601524`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.2656285714285715`", ",", "45.977374189795924`", ",", 
              "0.7876128757528131`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.131614285714287`", ",", "26.383046034693876`", ",", 
              "0.8806597187152422`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.53165`", ",", "12.76751347653061`", ",", 
              "0.48980355997831004`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.1521928571428575`", ",", "128.6233715459184`", ",", 
              "0.9799495146925218`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.670828571428571`", ",", "37.62520797346939`", ",", 
              "0.7507582711099217`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.570485714285714`", ",", "64.96067733877553`", ",", 
              "0.889106199436041`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.505722222222223`", ",", "58.02577430498867`", ",", 
              "0.9989474518184931`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "3.5380142857142856`", ",", "26.495169457142858`", ",", 
              "1.0322548637182118`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.152207142857142`", ",", "44.33357885612245`", ",", 
              "0.8302592006075673`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.564300000000001`", ",", "55.670964616326536`", ",", 
              "0.7987286075874538`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.780792857142857`", ",", "19.138973484693874`", ",", 
              "0.7150719961701574`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.465185714285715`", ",", "117.41117900408165`", ",", 
              "0.9413113688529494`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.133671428571429`", ",", "26.64248988367347`", ",", 
              "0.875378338502976`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.974757142857143`", ",", "83.4099005`", ",", 
              "0.9711009568982478`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.22785`", ",", "25.914448443877546`", ",", 
              "0.795769372249353`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.2910999999999992`", ",", "14.985194622448983`", ",", 
              "1.6951050303807278`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.158976190476191`", ",", "64.26208768820862`", ",", 
              "1.0144292265039687`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "3.356321428571429`", ",", "19.39334703571429`", ",", 
              "0.7738310309235304`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.581821428571428`", ",", "19.052366878571426`", ",", 
              "1.632667011889689`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.6159714285714295`", ",", "22.36722515510204`", ",", 
              "0.9056876773579159`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.101821428571428`", ",", "78.34549837653063`", ",", 
              "0.9933447576851473`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.781578571428572`", ",", "91.08209417244896`", ",", 
              "0.852840774856092`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.259321428571429`", ",", "59.28965924387755`", ",", 
              "0.8103280760184431`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.306107142857144`", ",", "42.85732420306122`", ",", 
              "1.360451719853922`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.343621428571429`", ",", "69.35854338469389`", ",", 
              "0.9546250204777821`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.364021428571428`", ",", "58.0210250887755`", ",", 
              "0.7204367876782342`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.3888174603174606`", ",", "18.833260742630387`", ",", 
              "0.7061745353328471`"}], "}"}]}], "}"}]}], "}"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<rf\>\"", ",", "3", ",", "300"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "10.662800000000002`", ",", "243.50547124444444`", ",", 
              "1.0050514411513072`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.676233333333333`", ",", "31.43550436666667`", ",", 
              "1.8091960108352432`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.505816666666666`", ",", "103.10580660555559`", ",", 
              "0.9248808227258101`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.484583333333335`", ",", "126.96335002777774`", ",", 
              "0.8694577470693747`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.453616666666667`", ",", "120.2414957833333`", ",", 
              "0.8265872338636236`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.279633333333333`", ",", "320.9386023333333`", ",", 
              "0.9404433187570919`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.018533333333333`", ",", "39.457714244444446`", ",", 
              "0.7489722957101852`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.344433333333333`", ",", "84.06507594444443`", ",", 
              "0.8692807378662539`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.64995`", ",", "63.23176849444444`", ",", 
              "0.9806035512649859`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.337592592592593`", ",", "78.60542595061729`", ",", 
              "0.8770084242286709`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "8.215166666666665`", ",", "280.4214807222221`", ",", 
              "0.9452007752217344`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.995366666666667`", ",", "81.92879912222226`", ",", 
              "1.3337826409091649`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.612800000000002`", ",", "103.0436574888889`", ",", 
              "0.8083511816745894`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.086033333333335`", ",", "184.47957025555556`", ",", 
              "1.026007842490942`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.9405333333333346`", ",", "37.34249033333333`", ",", 
              "1.177273278745418`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.397333333333334`", ",", "99.75945654444446`", ",", 
              "1.1621274007094935`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.801183333333333`", ",", "125.38279262777777`", ",", 
              "0.9510296090517811`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.6671`", ",", "66.37003077777777`", ",", 
              "1.0029339359362879`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.291133333333331`", ",", "266.92078273333334`", ",", 
              "0.9287896913879241`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.213796296296297`", ",", "50.79771151234568`", ",", 
              "1.121979950399206`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "5.839766666666668`", ",", "77.00989089999999`", ",", 
              "0.9936003697783006`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.392750000000001`", ",", "107.56338460555557`", ",", 
              "1.2018272048486722`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.191483333333332`", ",", "56.42407777222221`", ",", 
              "0.6689416917206926`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.856433333333332`", ",", "306.4465738111111`", ",", 
              "0.8982502209886185`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.457333333333334`", ",", "189.3623819`", ",", 
              "1.1378413997268095`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.025449999999998`", ",", "96.08937102777776`", ",", 
              "0.8060007228619617`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.356166666666668`", ",", "38.41839706666667`", ",", 
              "1.4129917198123783`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.3769833333333334`", ",", "39.433412572222224`", ",", 
              "1.0616647166955342`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.006116666666667`", ",", "189.03143766111106`", ",", 
              "0.8090197879912258`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.712222222222223`", ",", "134.47252208641967`", ",", 
              "0.928455198306114`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<rf\>\"", ",", "3", ",", "500"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "10.75603`", ",", "248.46263387799996`", ",", 
              "1.0255117758756755`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.64342`", ",", "30.437000411999996`", ",", 
              "1.7517294802997347`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.412560000000001`", ",", "102.361527432`", ",", 
              "0.9182044816249716`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.569010000000001`", ",", "125.49265345`", ",", 
              "0.8593862694905499`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.61438`", ",", "120.83887778000003`", ",", 
              "0.8306938721665474`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.566880000000001`", ",", "324.5417806759999`", ",", 
              "0.9510016778139797`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.08097`", ",", "40.94301247`", ",", "0.7771656982706296`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.2321100000000005`", ",", "79.58075897800002`", ",", 
              "0.8229103478128019`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.62758`", ",", "61.70174806799997`", ",", 
              "0.9568758665994648`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.25908888888889`", ",", "76.20017276888889`", ",", 
              "0.8501727792681838`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "8.12942`", ",", "272.662041056`", ",", "0.919046472174371`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.8875399999999996`", ",", "75.959758052`", ",", 
              "1.236607978914432`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.450100000000001`", ",", "101.34776286000002`", ",", 
              "0.795047321343295`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.019389999999998`", ",", "176.87698800199996`", ",", 
              "0.9837250628610628`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.84924`", ",", "35.38194978399999`", ",", 
              "1.1154645461187482`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.495240000000001`", ",", "102.12499748`", ",", 
              "1.1896842863816233`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.691490000000001`", ",", "120.56406788199999`", ",", 
              "0.9144795385432231`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.37759`", ",", "60.32943726999999`", ",", 
              "0.9116530347350905`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.28896`", ",", "258.02873608399995`", ",", 
              "0.897848521582153`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.221722222222223`", ",", "51.37197379777778`", ",", 
              "1.1346638046781266`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "5.834359999999999`", ",", "75.043943112`", ",", 
              "0.9682352325693915`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.480849999999999`", ",", "109.60907844200001`", ",", 
              "1.2246841511454625`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.32343`", ",", "56.570349841999985`", ",", 
              "0.6706758358958731`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.702739999999999`", ",", "309.044174312`", ",", 
              "0.9058642569197294`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.55794`", ",", "190.20717717600002`", ",", 
              "1.1429176087905193`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.14084`", ",", "93.89194442799997`", ",", 
              "0.7875686381379915`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.23661`", ",", "37.617132678000004`", ",", 
              "1.38352198570031`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.5228399999999995`", ",", "41.920546812`", ",", 
              "1.1286257656085938`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.043540000000002`", ",", "185.66022546`", ",", 
              "0.7945916197777149`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.6965666666666674`", ",", "137.07657747777776`", ",", 
              "0.9464346987071677`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<rf\>\"", ",", "3", ",", "700"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "10.676378571428572`", ",", "241.604044805102`", ",", 
              "0.997203439324745`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.6752`", ",", "30.57023498979592`", ",", 
              "1.759397480909558`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.675121428571428`", ",", "109.50531492142859`", ",", 
              "0.9822857615074672`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.740478571428571`", ",", "123.90186091530609`", ",", 
              "0.8484923627610319`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.680950000000001`", ",", "122.82012050714286`", ",", 
              "0.8443137122622859`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.310542857142858`", ",", "320.2097919142857`", ",", 
              "0.9383076925524199`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.153171428571428`", ",", "39.205454461224505`", ",", 
              "0.7441839902401035`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.272135714285715`", ",", "80.80657339285715`", ",", 
              "0.8355859666362273`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.592207142857143`", ",", "61.860371496938775`", ",", 
              "0.9593358119945533`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.264563492063491`", ",", "77.02369291950113`", ",", 
              "0.8593608741213652`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "8.190935714285713`", ",", "278.3634614969388`", ",", 
              "0.9382639265817904`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.6652428571428555`", ",", "73.01575189183673`", ",", 
              "1.1886802129368352`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.633921428571429`", ",", "102.3932860846939`", ",", 
              "0.8032491840755127`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.012457142857143`", ",", "181.01645902653064`", ",", 
              "1.0067472854792585`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.598278571428572`", ",", "32.587762794897955`", ",", 
              "1.0273739648874372`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.59172142857143`", ",", "101.70416884795917`", ",", 
              "1.1847819292393722`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.738528571428572`", ",", "118.18137763265307`", ",", 
              "0.8964068115857452`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.4012`", ",", "63.15403151020407`", ",", 
              "0.9543361762908928`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.307871428571428`", ",", "262.39536011428567`", ",", 
              "0.9130428250903515`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.117`", ",", "48.20084533333332`", ",", "1.064622410069588`"}],
              "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "6.009535714285714`", ",", "80.13339816632654`", ",", 
              "1.0339006213246547`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.478107142857143`", ",", "107.93422857653059`", ",", 
              "1.2059707186912896`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.34235`", ",", "57.355163756122465`", ",", 
              "0.6799802812342334`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.717328571428572`", ",", "301.74619826734687`", ",", 
              "0.8844725718590898`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.706785714285715`", ",", "193.92155666734698`", ",", 
              "1.165236586388629`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.174742857142857`", ",", "98.31454240204083`", ",", 
              "0.8246655316432504`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.199214285714286`", ",", "37.309225483673465`", ",", 
              "1.3721974550256155`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.423321428571429`", ",", "41.02207745408164`", ",", 
              "1.1044362990087402`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.110235714285714`", ",", "188.68987698469385`", ",", 
              "0.8075579711133549`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.949690476190477`", ",", "137.27001009410432`", ",", 
              "0.9477702393467262`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<rf\>\"", ",", "4", ",", "300"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "10.8974`", ",", "256.9317517222222`", ",", 
              "1.060467454904633`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.681016666666666`", ",", "32.55502663888889`", ",", 
              "1.8736274640519877`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.779133333333334`", ",", "112.35953997777776`", ",", 
              "1.00788876201024`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.407833333333334`", ",", "120.15113185555556`", ",", 
              "0.8228069942082578`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.55005`", ",", "118.51234226111112`", ",", 
              "0.8147003539013628`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.571700000000002`", ",", "322.9119281444444`", ",", 
              "0.9462257365195488`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.9415`", ",", "39.706251322222236`", ",", 
              "0.7536899381098217`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.38595`", ",", "81.94192381666669`", ",", 
              "0.8473261362971476`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.748033333333333`", ",", "65.42417212222222`", ",", 
              "1.014603529984449`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.627851851851853`", ",", "83.96827962962963`", ",", 
              "0.9368423071638554`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "8.379983333333332`", ",", "280.3596827611111`", ",", 
              "0.9449924763403549`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.865583333333333`", ",", "77.89250201666667`", ",", 
              "1.2680726211039102`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.629266666666666`", ",", "101.47747632222224`", ",", 
              "0.7960648903331937`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.824666666666667`", ",", "178.2445695333333`", ",", 
              "0.9913310507460629`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.9592`", ",", "39.899433444444455`", ",", 
              "1.257884420988823`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.935849999999999`", ",", "112.10566835000002`", ",", 
              "1.305952071885473`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.641966666666667`", ",", "118.14848839999995`", ",", 
              "0.8961573464604552`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.462833333333333`", ",", "62.99191774444445`", ",", 
              "0.951886435116188`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.514733333333332`", ",", "275.2327247888888`", ",", 
              "0.9577123028742179`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.604851851851851`", ",", "55.00486502469136`", ",", 
              "1.214904252470496`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "6.125616666666668`", ",", "81.38224179444445`", ",", 
              "1.0500135059968914`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.5090666666666674`", ",", "108.55184827777778`", ",", 
              "1.212871507114147`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.319533333333333`", ",", "60.734266088888866`", ",", 
              "0.7200415905232069`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.8696`", ",", "303.5101817333333`", ",", 
              "0.8896431257942734`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.786766666666667`", ",", "195.2903360777778`", ",", 
              "1.1734613133098626`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.486683333333334`", ",", "95.3100685722222`", ",", 
              "0.7994639088960933`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.032366666666666`", ",", "32.32003083333334`", ",", 
              "1.1886996709501991`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.642133333333333`", ",", "44.36481651111111`", ",", 
              "1.1944327736346312`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.887950000000001`", ",", "182.81286800555554`", ",", 
              "0.7824054535366283`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.043296296296297`", ",", "134.13175290123456`", ",", 
              "0.9261023836455522`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<rf\>\"", ",", "4", ",", "500"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "11.03912`", ",", "260.615424136`", ",", "1.0756715497008444`"}],
              "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.84972`", ",", "35.164133527999994`", ",", 
              "2.0237884323814135`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.768839999999999`", ",", "108.407844976`", ",", 
              "0.9724412247208246`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.646979999999999`", ",", "120.71446227599999`", ",", 
              "0.8266647373924767`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.43332`", ",", "113.98358732`", ",", "0.7835679150105108`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.28858`", ",", "322.94741065999995`", ",", 
              "0.946329710595725`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.163270000000001`", ",", "42.517444882000014`", ",", 
              "0.807051014250944`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.254630000000001`", ",", "82.107544854`", ",", 
              "0.849038752100105`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.87985`", ",", "66.935103162`", ",", "1.0380351748458887`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.4394888888888895`", ",", "81.78420529333333`", ",", 
              "0.912474376211139`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "8.318090000000002`", ",", "285.28413170199997`", ",", 
              "0.9615910369944108`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.2151900000000015`", ",", "82.93647302600002`", ",", 
              "1.3501873481056041`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.814019999999999`", ",", "104.05431389200001`", ",", 
              "0.8162795230944381`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.040319999999998`", ",", "178.70059346`", ",", 
              "0.9938672889022737`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.76984`", ",", "37.089043592`", ",", "1.1692830222442203`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.86257`", ",", "106.77086828200004`", ",", 
              "1.2438054087912571`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.72161`", ",", "119.67933222199997`", ",", 
              "0.9077688106099103`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.701930000000002`", ",", "67.84157470200002`", ",", 
              "1.0251707998118655`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.236819999999998`", ",", "260.41934502`", ",", 
              "0.9061669931270044`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.4959`", ",", "52.451468904444454`", ",", 
              "1.1585068446532583`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "6.191460000000001`", ",", "84.60724241600002`", ",", 
              "1.0916232495332616`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.335939999999998`", ",", "104.15082345199998`", ",", 
              "1.1636979766954978`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.2265500000000005`", ",", "56.925254378`", ",", 
              "0.6748834445991929`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.06353`", ",", "306.640075302`", ",", "0.8988174087851436`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.696720000000001`", ",", "192.90148748000001`", ",", 
              "1.1591071907805721`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.5312`", ",", "96.92057006800002`", ",", 
              "0.8129728470427686`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.12301`", ",", "35.307082434`", ",", "1.2985605579380202`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.444579999999999`", ",", "42.321911384`", ",", 
              "1.1394316932934874`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.903319999999999`", ",", "185.663376668`", ",", 
              "0.7946051063684091`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.879700000000001`", ",", "132.44860292222225`", ",", 
              "0.9144812039183027`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<rf\>\"", ",", "4", ",", "700"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "10.72102857142857`", ",", "253.26105613673468`", ",", 
              "1.0453169210403712`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.809278571428572`", ",", "34.25498134591836`", ",", 
              "1.971464331521483`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.74602142857143`", ",", "109.20825466632652`", ",", 
              "0.9796210683909193`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.569278571428572`", ",", "121.49985518673468`", ",", 
              "0.8320431867684757`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.560214285714285`", ",", "117.53665078775512`", ",", 
              "0.8079930677784515`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.535307142857143`", ",", "326.99791184795913`", ",", 
              "0.958198855510482`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.027928571428571`", ",", "41.67127401428572`", ",", 
              "0.7909892998437471`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.346492857142858`", ",", "83.65194836632654`", ",", 
              "0.8650087635427364`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.793257142857142`", ",", "66.66440943061222`", ",", 
              "1.033837233832625`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.6950634920634915`", ",", "82.85347099773243`", ",", 
              "0.9244042782396064`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "8.292421428571426`", ",", "280.9832507479592`", ",", 
              "0.9470943015751916`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.981621428571429`", ",", "77.61250299285715`", ",", 
              "1.2635142992265016`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.770535714285714`", ",", "106.41160141530614`", ",", 
              "0.8347718418013584`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.084271428571428`", ",", "183.50064732040815`", ",", 
              "1.0205634314525591`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.705264285714285`", ",", "35.81091826224489`", ",", 
              "1.1289883663662428`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.792214285714285`", ",", "106.69976385306123`", ",", 
              "1.2429770922782781`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.549371428571429`", ",", "116.56322968775507`", ",", 
              "0.8841331448793989`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.472928571428571`", ",", "62.916538755102046`", ",", 
              "0.9507473645811569`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.513792857142857`", ",", "268.56598803775506`", ",", 
              "0.9345144225659014`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.327055555555554`", ",", "51.17823262698412`", ",", 
              "1.13038460188088`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "6.197564285714285`", ",", "81.37291308469388`", ",", 
              "1.049893144711485`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.411678571428571`", ",", "104.48185053571429`", ",", 
              "1.1673966084948642`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.2774214285714285`", ",", "58.39479781530614`", ",", 
              "0.6923057740695483`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "8.971721428571426`", ",", "310.5957219908163`", ",", 
              "0.9104121232183754`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "9.639771428571429`", ",", "194.833883422449`", ",", 
              "1.1707185788605112`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.513699999999999`", ",", "99.5768691755102`", ",", 
              "0.8352539690637658`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.311714285714286`", ",", "38.57133236122449`", ",", 
              "1.4186165329585978`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.622942857142857`", ",", "44.523394700000004`", ",", 
              "1.198702169991654`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "7.774407142857143`", ",", "184.0369382765306`", ",", 
              "0.7876442491748754`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "6.799873015873017`", ",", "129.7250109478458`", ",", 
              "0.8956763723628305`"}], "}"}]}], "}"}]}], "}"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<rf\>\"", ",", "3", ",", "300"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "2.9206000000000008`", ",", "23.35790208888889`", ",", 
              "0.8976394339248213`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.155433333333334`", ",", "59.319687022222226`", ",", 
              "0.9649619840422918`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.4663166666666663`", ",", "8.200873927777778`", ",", 
              "1.2070270820327078`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.922966666666666`", ",", "25.298851500000005`", ",", 
              "0.7995016792667639`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.41355`", ",", "65.22371763888887`", ",", 
              "1.0147054303775702`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.7611333333333334`", ",", "5.313323199999999`", ",", 
              "2.1200080597699773`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.4114333333333335`", ",", "14.72526206666667`", ",", 
              "1.4823243707573734`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.7214166666666668`", ",", "4.716522805555558`", ",", 
              "1.1656096296845488`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.03535`", ",", "8.69602001666667`", ",", 
              "7.329753891323894`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.270407407407407`", ",", "42.77312704938271`", ",", 
              "0.8716844815743853`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "2.0314833333333335`", ",", "7.265697716666668`", ",", 
              "1.9344243122115732`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.5645833333333337`", ",", "17.40860409444445`", ",", 
              "1.003557067513184`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.0405000000000006`", ",", "5.5999351666666675`", ",", 
              "2.9741012091277645`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.7582833333333334`", ",", "22.221251461111116`", ",", 
              "0.9839116681770372`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.297683333333333`", ",", "28.837468016666662`", ",", 
              "1.0914146875784534`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.6172`", ",", "9.22132207777778`", ",", "1.300559157124058`"}],
              "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.5284166666666672`", ",", "3.772387361111112`", ",", 
              "1.8193551217695472`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.022700000000001`", ",", "54.10594571111112`", ",", 
              "0.9630031309488916`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.5304166666666665`", ",", "103.54849864999998`", ",", 
              "1.0949532671293802`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.956574074074074`", ",", "7.206636956790125`", ",", 
              "1.115578476283301`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "2.5669000000000004`", ",", "8.763602344444447`", ",", 
              "1.7090124748447355`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.5414833333333333`", ",", "20.823244294444443`", ",", 
              "1.058387470809649`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.265083333333333`", ",", "63.095537972222225`", ",", 
              "0.8824319358369583`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.6816166666666668`", ",", "4.064796494444446`", ",", 
              "1.8183754560456489`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.4986333333333333`", ",", "9.893307366666669`", ",", 
              "2.615979472263538`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.8625166666666666`", ",", "4.999229794444445`", ",", 
              "1.71918903485142`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.1352000000000007`", ",", "26.911991988888893`", ",", 
              "0.8800153685184443`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.2895000000000003`", ",", "9.931747422222225`", ",", 
              "2.8114554215654843`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.287516666666667`", ",", "59.08315419444443`", ",", 
              "0.9320656811630708`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.443055555555555`", ",", "42.64562873456791`", ",", 
              "0.8557269656004441`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<rf\>\"", ",", "3", ",", "500"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "2.95543`", ",", "25.089075830000006`", ",", 
              "0.9641680892416746`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.18893`", ",", "59.416091498`", ",", "0.9665302096835064`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.50279`", ",", "8.420801082`", ",", "1.2393965628415098`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.84453`", ",", "25.161587694`", ",", "0.7951638284596018`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.519120000000002`", ",", "67.78475774`", ",", 
              "1.0545483187023341`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.8611199999999997`", ",", "5.600929939999999`", ",", 
              "2.2347627215688624`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.336280000000001`", ",", "14.476040660000004`", ",", 
              "1.4572363985947117`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.7417399999999996`", ",", "4.681997520000001`", ",", 
              "1.1570772835112697`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.00554`", ",", "8.048610612000001`", ",", 
              "6.784061540795683`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.311755555555556`", ",", "42.147462911111106`", ",", 
              "0.8589339122886908`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "1.9803899999999999`", ",", "6.213199506000001`", ",", 
              "1.6542064712460072`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.43419`", ",", "16.04735281`", ",", "0.9250847592365208`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.08847`", ",", "5.893231526000001`", ",", 
              "3.1298696298263327`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.6906100000000004`", ",", "21.119511226000004`", ",", 
              "0.9351288588684327`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.1617299999999995`", ",", "27.731700065999995`", ",", 
              "1.0495645715518442`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.61003`", ",", "9.32467705`", ",", "1.3151361618554993`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.5927`", ",", "3.998404151999999`", ",", 
              "1.9283589876897473`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.13368`", ",", "55.184164792000026`", ",", 
              "0.9821937824955592`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.536489999999999`", ",", "101.07897695799998`", ",", 
              "1.0688397948902317`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.883388888888889`", ",", "6.9908726022222245`", ",", 
              "1.082178421396629`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "2.70493`", ",", "9.45226577`", ",", "1.8433104882626823`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.66461`", ",", "21.04783419`", ",", "1.069802749243945`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.313739999999999`", ",", "67.62353859999999`", ",", 
              "0.9457589552721516`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.7046`", ",", "4.073027136`", ",", "1.8220574107542267`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.52102`", ",", "9.655406684`", ",", "2.553073986845149`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.9137700000000002`", ",", "5.270170258000001`", ",", 
              "1.8123629622751816`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.98745`", ",", "25.432388082`", ",", "0.8316326929469092`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.49393`", ",", "11.512138806000001`", ",", 
              "3.258828852969486`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.3156099999999995`", ",", "61.172375538`", ",", 
              "0.9650241706213849`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.512766666666667`", ",", "44.08131750888888`", ",", 
              "0.8845354891197715`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<rf\>\"", ",", "3", ",", "700"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "2.987971428571429`", ",", "24.809403765306122`", ",", 
              "0.9534203485892372`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.171507142857142`", ",", "59.174331978571445`", ",", 
              "0.9625974723876827`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.538371428571428`", ",", "8.694366442857143`", ",", 
              "1.279660661786157`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.868471428571429`", ",", "25.191086106122448`", ",", 
              "0.7960960458777561`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.476428571428572`", ",", "67.20121550204081`", ",", 
              "1.0454699726781138`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.8671928571428569`", ",", "5.482038231632653`", ",", 
              "2.1873251066354067`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.3585214285714287`", ",", "14.396049360204083`", ",", 
              "1.4491840425416087`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.776642857142857`", ",", "5.05977097755102`", ",", 
              "1.2504376674453888`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.8977928571428575`", ",", "7.616730005102039`", ",", 
              "6.4200354055141915`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.236285714285714`", ",", "40.0122471814059`", ",", 
              "0.8154198055401074`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "1.98675`", ",", "6.2173609683673465`", ",", 
              "1.6553144218230424`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.5810071428571426`", ",", "17.575926305102037`", ",", 
              "1.0132027223943205`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.9532642857142855`", ",", "5.000022356122448`", ",", 
              "2.65549012487251`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.6501642857142853`", ",", "20.785499884693884`", ",", 
              "0.9203395182865264`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.2611499999999998`", ",", "28.632263721428576`", ",", 
              "1.0836482990159209`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.620742857142857`", ",", "9.261175967346936`", ",", 
              "1.30618008008814`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.5873642857142856`", ",", "3.9981560989795915`", ",", 
              "1.9282393561434747`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.9734071428571425`", ",", "54.72473085816328`", ",", 
              "0.9740165607330701`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.575042857142858`", ",", "103.00373318775512`", ",", 
              "1.0891927517140825`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.9174603174603178`", ",", "7.20783449659864`", ",", 
              "1.1157638539626376`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "2.604914285714286`", ",", "8.884573891836734`", ",", 
              "1.7326034452549517`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.673035714285714`", ",", "20.41343855612245`", ",", 
              "1.037558187304503`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.300585714285715`", ",", "66.86189800612243`", ",", 
              "0.9351069186104899`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.7541357142857144`", ",", "4.356021301020408`", ",", 
              "1.9486540668428047`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.4249857142857145`", ",", "9.048747165306121`", ",", 
              "2.3926616203090054`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.9071857142857138`", ",", "5.1540116938775515`", ",", 
              "1.7724171030219578`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.997292857142857`", ",", "25.82712453571429`", ",", 
              "0.8445404756902478`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.3591285714285712`", ",", "10.216842934693876`", ",", 
              "2.8921595806753895`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.290228571428571`", ",", "60.33616885510204`", ",", 
              "0.951832600839525`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.4744444444444436`", ",", "43.633661666666676`", ",", 
              "0.8755528293052709`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<rf\>\"", ",", "4", ",", "300"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "2.9900500000000005`", ",", "26.381888727777785`", ",", 
              "1.0138506263683278`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.1694`", ",", "57.72109722222221`", ",", 
              "0.9389574910566848`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.635383333333333`", ",", "9.683579094444445`", ",", 
              "1.4252556887150496`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.9660166666666665`", ",", "27.49073513888889`", ",", 
              "0.8687702249178979`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.578199999999999`", ",", "68.27844402222222`", ",", 
              "1.062228747994134`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.8125833333333332`", ",", "5.806735716666666`", ",", 
              "2.316878920576021`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.3108166666666667`", ",", "14.180456261111113`", ",", 
              "1.4274812773544243`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.8520500000000002`", ",", "5.700816938888892`", ",", 
              "1.4088614419950802`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.940433333333333`", ",", "7.929528766666666`", ",", 
              "6.683689115531577`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.2800555555555557`", ",", "41.95353648765434`", ",", 
              "0.8549818361709143`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "2.0065500000000003`", ",", "6.382324150000001`", ",", 
              "1.69923433173589`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.670150000000001`", ",", "18.627876538888895`", ",", 
              "1.0738446949535017`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.9541833333333334`", ",", "5.6123411388888895`", ",", 
              "2.9806899670130598`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.6960500000000005`", ",", "22.416254116666668`", ",", 
              "0.992545987826513`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.260483333333333`", ",", "28.6901497388889`", ",", 
              "1.0858391172120645`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.4478999999999997`", ",", "8.455429022222223`", ",", 
              "1.19253893850693`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.807516666666667`", ",", "5.5658919277777805`", ",", 
              "2.684330376675764`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.141050000000001`", ",", "57.26932071666666`", ",", 
              "1.019306370725548`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.593983333333333`", ",", "106.5111526611111`", ",", 
              "1.1262812702499747`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.8277037037037043`", ",", "6.7004787777777794`", ",", 
              "1.0372258169934643`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "2.6989166666666664`", ",", "10.187620238888892`", ",", 
              "1.986713841286867`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.6967666666666665`", ",", "20.25159083333333`", ",", 
              "1.0293319186425742`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.280283333333331`", ",", "69.3281704722222`", ",", 
              "0.9695993352932659`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.7705000000000002`", ",", "4.503345133333333`", ",", 
              "2.0145589752766084`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.6809333333333334`", ",", "11.364933922222225`", ",", 
              "3.005105647918618`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.9618999999999995`", ",", "5.817728300000001`", ",", 
              "2.0006631245916298`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.163233333333334`", ",", "28.229615633333346`", ",", 
              "0.9231013302530172`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.4096666666666664`", ",", "11.191077088888889`", ",", 
              "3.167943466254004`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.2770833333333345`", ",", "61.071549394444425`", ",", 
              "0.963433588848061`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.7569629629629637`", ",", "45.884887567901245`", ",", 
              "0.9207259165948257`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<rf\>\"", ",", "4", ",", "500"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "2.95832`", ",", "25.758749092000006`", ",", 
              "0.9899034967080077`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.3539`", ",", "60.949625624`", ",", "0.9914764325499077`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.56423`", ",", "9.407631517999999`", ",", 
              "1.3846409687567838`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.8953800000000003`", ",", "26.160539028000006`", ",", 
              "0.8267329796931578`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.651579999999999`", ",", "69.88055872399998`", ",", 
              "1.0871533390299006`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.7985100000000003`", ",", "5.6460478940000005`", ",", 
              "2.2527647181574255`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.3510000000000004`", ",", "14.572245183999996`", ",", 
              "1.4669208653197636`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.75884`", ",", "5.313364591999997`", ",", 
              "1.3131090826413598`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.00923`", ",", "9.021991514000003`", ",", 
              "7.604510716453136`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.2603999999999997`", ",", "39.95645045333333`", ",", 
              "0.8142827097666951`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "1.9073`", ",", "5.914363444`", ",", "1.5746441544195957`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.62047`", ",", "18.139723958`", ",", "1.0457040715055719`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.9532600000000002`", ",", "5.4062352680000005`", ",", 
              "2.87122803547719`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.7499300000000004`", ",", "23.284475586000003`", ",", 
              "1.0309890627241574`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.28553`", ",", "29.009638189999997`", ",", 
              "1.0979308302519477`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.41905`", ",", "8.361644914`", ",", "1.1793117917147078`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.64602`", ",", "4.466116663999999`", ",", 
              "2.153928387851312`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.191020000000001`", ",", "56.522916536000004`", ",", 
              "1.0060215172129012`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.6111200000000006`", ",", "105.71597066000001`", ",", 
              "1.117872774313959`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.9120444444444447`", ",", "7.418943546666668`", ",", 
              "1.1484432734778123`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "2.68506`", ",", "9.661933483999999`", ",", 
              "1.8841983246471492`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.70615`", ",", "20.718968617999998`", ",", 
              "1.0530874288037813`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.295299999999999`", ",", "68.46114439600001`", ",", 
              "0.9574734144524182`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.7962`", ",", "4.507141152`", ",", "2.0162571137156653`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.57184`", ",", "10.233341868`", ",", "2.7058910905304905`"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.0504999999999995`", ",", "6.0496533040000005`", ",", 
              "2.080419995185529`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.21361`", ",", "28.86704263400001`", ",", 
              "0.943945032834635`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.3768900000000004`", ",", "10.099633821999998`", ",", 
              "2.8589803040253643`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.35434`", ",", "61.388556768000015`", ",", 
              "0.9684345353546473`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.649455555555556`", ",", "45.10154901111112`", ",", 
              "0.9050074491661466`"}], "}"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"\"\<rf\>\"", ",", "4", ",", "700"}], "]"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "2.982192857142857`", ",", "25.993473621428574`", ",", 
              "0.9989239127078143`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.2603285714285715`", ",", "60.17883387959184`", ",", 
              "0.978937851038362`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.4876571428571426`", ",", "8.855358928571428`", ",", 
              "1.303355976696767`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.838978571428572`", ",", "25.829041037755104`", ",", 
              "0.8162568835796897`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.572842857142857`", ",", "68.73276469795918`", ",", 
              "1.0692967544416572`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.7781428571428566`", ",", "5.45187382244898`", ",", 
              "2.1752895522035613`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.28615`", ",", "14.359816084693879`", ",", 
              "1.445536605431289`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.7693428571428569`", ",", "5.126416736734694`", ",", 
              "1.266908050794458`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.0694928571428575`", ",", "8.595491503061226`", ",", 
              "7.245019810402245`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.283349206349206`", ",", "41.57811033333334`", ",", 
              "0.8473309306778242`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "2.007192857142857`", ",", "6.448296188775511`", ",", 
              "1.7167987723044495`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.7070999999999996`", ",", "18.95622996530612`", ",", 
              "1.0927733465521865`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.8584142857142854`", ",", "4.889977171428571`", ",", 
              "2.5970456059422014`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.7105500000000005`", ",", "22.34772733775511`", ",", 
              "0.989511761897714`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.2526500000000005`", ",", "28.857589813265303`", ",", 
              "1.092176239332426`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.4858214285714277`", ",", "8.579171564285714`", ",", 
              "1.2099913704737424`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.6977428571428579`", ",", "4.650487689795919`", ",", 
              "2.2428472442618883`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.21447142857143`", ",", "57.30603775714286`", ",", 
              "1.0199598779228265`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "5.63855`", ",", "103.86100845816324`", ",", 
              "1.098257840734208`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.9197222222222219`", ",", "7.239605352607711`", ",", 
              "1.1206819431281285`"}], "}"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "2.665164285714286`", ",", "9.276834770408161`", ",", 
              "1.8090992409932307`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.661628571428571`", ",", "20.966404791836737`", ",", 
              "1.065663919888014`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.199207142857143`", ",", "66.6907370357143`", ",", 
              "0.9327131216588976`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "1.8058571428571426`", ",", "4.644147408163265`", ",", 
              "2.077546483029106`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.522642857142857`", ",", "9.930976346938776`", ",", 
              "2.62593987028624`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.070557142857143`", ",", "6.442129253061225`", ",", 
              "2.2153888555525376`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.2233785714285714`", ",", "28.373672011224492`", ",", 
              "0.9278119375737109`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "2.3948857142857145`", ",", "10.940880148979593`", ",", 
              "3.0971183120023773`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "4.310692857142856`", ",", "61.097247964285735`", ",", 
              "0.9638389963678632`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "3.520857142857143`", ",", "43.13878783673471`", ",", 
              "0.8656226935936243`"}], "}"}]}], "}"}]}], "}"}]}]}], "}"}]}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.58601408518577*^9, 3.5860140882860804`*^9}, 
   3.5860141850957603`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["Visualizing RF results", "Subsubsection",
 CellChangeTimes->{{3.5859278341627607`*^9, 3.585927839238206*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"resAll7RFPanels", "=", 
   RowBox[{"MapThread", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"kFoldPlot", "[", 
       RowBox[{"#1", ",", "#2"}], "]"}], "&"}], ",", 
     RowBox[{"{", 
      RowBox[{"resAll7RF", ",", 
       RowBox[{"Take", "[", 
        RowBox[{"responseColumns", ",", "All"}], "]"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.575218790602067*^9, 3.575218876756999*^9}, {
  3.575218938500106*^9, 3.575218940795947*^9}, {3.5752189871547413`*^9, 
  3.575218991020404*^9}, {3.575219077809449*^9, 3.575219132856144*^9}, {
  3.585917965896331*^9, 3.585917985370694*^9}, {3.5859273129232483`*^9, 
  3.585927316292202*^9}, {3.585929919045372*^9, 3.58592992300484*^9}, {
  3.585932803154215*^9, 3.585932804348351*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Labeled", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Grid", "[", 
    RowBox[{
     RowBox[{"Partition", "[", 
      RowBox[{"resAll7RFPanels", ",", "3", ",", "3", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Dividers", "\[Rule]", "White"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Spacings", "\[Rule]", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", 
          RowBox[{"{", "0", "}"}], ",", "1"}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"1", ",", 
          RowBox[{"{", "0", "}"}], ",", "1"}], "}"}]}], "\[IndentingNewLine]",
        "}"}]}]}], "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Style", "[", 
    RowBox[{
     RowBox[{"Column", "[", 
      RowBox[{
       RowBox[{"{", "\"\<10-fold cross validation results (RF)\>\"", "}"}], 
       ",", "Center"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"Bold", ",", "14", ",", 
       RowBox[{"FontFamily", "\[Rule]", "\"\<Verdana\>\""}]}], "}"}]}], "]"}],
    ",", "\[IndentingNewLine]", "Top"}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{{3.5747213808265514`*^9, 3.5747214212398624`*^9}, {
   3.5747215696883535`*^9, 3.5747216017921896`*^9}, {3.5747217048540845`*^9, 
   3.5747217107544217`*^9}, {3.574723022086426*^9, 3.5747230238475266`*^9}, 
   3.574727050257824*^9, {3.574727327199664*^9, 3.5747273340050535`*^9}, {
   3.574728349266123*^9, 3.57472847562035*^9}, {3.574728666087244*^9, 
   3.574728666677278*^9}, {3.574728697498041*^9, 3.5747286982590847`*^9}, {
   3.5747628142221327`*^9, 3.574762818468376*^9}, {3.5747628965788436`*^9, 
   3.57476290613139*^9}, {3.5752189360260487`*^9, 3.5752190311073513`*^9}, {
   3.585917973405488*^9, 3.585918006399705*^9}, {3.5859180813294086`*^9, 
   3.585918081493992*^9}, {3.585927324889824*^9, 3.585927332164035*^9}}],

Cell[BoxData[
 TemplateBox[{TagBox[
    GridBox[{{
       GraphicsBox[{{
          Opacity[0], 
          
          PointBox[{{0.20089175179790653`, 0.5327775812627538}, {
           1.5261319469233567`, 6.467222418737246}}]}, {
          RGBColor[
          0.798413061722744, 0.824719615472648, 0.968322270542458], {}, {
           RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{0.7069390442094186, 0.7014054506919505}, {
                   0.7069390442094186, 1.2985945493080495`}, {
                   0.4330023157888817, 1.2985945493080495`}, {
                   0.4330023157888817, 0.7014054506919505}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.1469456946130927`, 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.4101591898224795`, 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.1597957586820133`, 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.4658937562358363`, 1.}]}, {}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{0.5656972782690677, 1.2985945493080495`}, {
                    0.5656972782690677, 0.7014054506919505}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.4330023157888817, 1.}, {0.3001544519176421, 
                    1.}}, {{0.7069390442094186, 1.}, {0.8777329086619785, 
                    1.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.3001544519176421, 1.1492972746540246`}, {
                    0.3001544519176421, 0.8507027253459752}}, {{
                    0.8777329086619785, 1.1492972746540246`}, {
                    0.8777329086619785, 0.8507027253459752}}}]}, {}}]}, 
               ImageSizeCache -> {{65.5857864376269, 171.4051226532822}, {
                30.585786437626883`, 45.41421356237311}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "1.4658937562358363`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "0.7069390442094186`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "0.5656972782690677`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.4330023157888817`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.3001544519176421`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {
                GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 1.4658937562358363`}, {
                  Style["75%", Bold], 0.7069390442094186}, {
                  Style["median", Bold], 0.5656972782690677}, {
                  Style["25%", Bold], 0.4330023157888817}, {
                  Style["min", Bold], 0.3001544519176421}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {
                GrayLevel[0]}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{0.7127637957055358, 1.7014054506919505`}, {
                   0.7127637957055358, 2.2985945493080493`}, {
                   0.43104973816838005`, 2.2985945493080493`}, {
                   0.43104973816838005`, 1.7014054506919505`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.3915567989158313`, 2.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.4163627418060534`, 2.}]}, {}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{0.5560736497566433, 2.2985945493080493`}, {
                    0.5560736497566433, 1.7014054506919507`}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.43104973816838005`, 2.}, {
                    0.26467596229804047`, 2.}}, {{0.7127637957055358, 2.}, {
                    1.1231583663886806`, 2.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.26467596229804047`, 2.1492972746540246`}, {
                    0.26467596229804047`, 1.8507027253459754`}}, {{
                    1.1231583663886806`, 2.1492972746540246`}, {
                    1.1231583663886806`, 1.8507027253459754`}}}]}, {}}]}, 
               ImageSizeCache -> {{62.58578643762689, 167.1712687940015}, {
                11.585786437626894`, 26.414213562373106`}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "1.4163627418060534`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "0.7127637957055358`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "0.5560736497566433`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.43104973816838005`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.26467596229804047`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {
                GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 1.4163627418060534`}, {
                  Style["75%", Bold], 0.7127637957055358}, {
                  Style["median", Bold], 0.5560736497566433}, {
                  Style["25%", Bold], 0.43104973816838005`}, {
                  Style["min", Bold], 0.26467596229804047`}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {
                GrayLevel[0]}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{0.7106266014446596, 2.7014054506919507`}, {
                   0.7106266014446596, 3.2985945493080493`}, {
                   0.4595416014387956, 3.2985945493080493`}, {
                   0.4595416014387956, 2.7014054506919507`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.4334349372174053`, 3.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.1363222382083646`, 3.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.4244760215434156`, 3.}]}, {}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{0.5584964781325648, 3.2985945493080493`}, {
                    0.5584964781325648, 2.7014054506919507`}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.4595416014387956, 3.}, {0.2888009660901298, 
                    3.}}, {{0.7106266014446596, 3.}, {1.0465652261100338`, 
                    3.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.2888009660901298, 3.1492972746540246`}, {
                    0.2888009660901298, 2.8507027253459754`}}, {{
                    1.0465652261100338`, 3.1492972746540246`}, {
                    1.0465652261100338`, 2.8507027253459754`}}}]}, {}}]}, 
               ImageSizeCache -> {{64.5857864376269, 
                168.63058032357281`}, {-7.4142135623731065`, 
                7.4142135623731065`}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "1.4334349372174053`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "0.7106266014446596`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "0.5584964781325648`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.4595416014387956`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.2888009660901298`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {
                GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 1.4334349372174053`}, {
                  Style["75%", Bold], 0.7106266014446596}, {
                  Style["median", Bold], 0.5584964781325648}, {
                  Style["25%", Bold], 0.4595416014387956}, {
                  Style["min", Bold], 0.2888009660901298}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {
                GrayLevel[0]}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  PolygonBox[{{0.7084738008283985, 3.7014054506919507`}, {
                   0.7084738008283985, 4.298594549308049}, {
                   0.4136780957079014, 4.298594549308049}, {
                   0.4136780957079014, 3.7014054506919507`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.402076535675784, 4.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.1521247916896828`, 4.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.2931483973872293`, 4.}]}, {}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{0.5526582839996421, 4.298594549308049}, {
                    0.5526582839996421, 3.7014054506919507`}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.4136780957079014, 4.}, {0.2793870523510993, 
                    4.}}, {{0.7084738008283985, 4.}, {1.032185970436602, 
                    4.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.2793870523510993, 4.149297274654025}, {
                    0.2793870523510993, 3.8507027253459754`}}, {{
                    1.032185970436602, 4.149297274654025}, {1.032185970436602,
                     3.8507027253459754`}}}]}, {}}]}, 
               ImageSizeCache -> {{64.5857864376269, 
                165.9501004077802}, {-26.414213562373106`, \
-11.585786437626894`}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "1.402076535675784`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "0.7084738008283985`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "0.5526582839996421`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.4136780957079014`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.2793870523510993`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {
                GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 1.402076535675784}, {
                  Style["75%", Bold], 0.7084738008283985}, {
                  Style["median", Bold], 0.5526582839996421}, {
                  Style["25%", Bold], 0.4136780957079014}, {
                  Style["min", Bold], 0.2793870523510993}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {
                GrayLevel[0]}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{0.7300574138490858, 4.701405450691951}, {
                   0.7300574138490858, 5.298594549308049}, {
                   0.44554965479709624`, 5.298594549308049}, {
                   0.44554965479709624`, 4.701405450691951}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.3962966920219118`, 5.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.1898393660900366`, 5.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.3177136503788505`, 5.}]}, {}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{0.551531137742301, 5.298594549308049}, {
                    0.551531137742301, 4.701405450691951}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.44554965479709624`, 5.}, {0.2894060504854766, 
                    5.}}, {{0.7300574138490858, 5.}, {1.0457651008490074`, 
                    5.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.2894060504854766, 5.149297274654025}, {
                    0.2894060504854766, 4.850702725345975}}, {{
                    1.0457651008490074`, 5.149297274654025}, {
                    1.0457651008490074`, 4.850702725345975}}}]}, {}}]}, 
               ImageSizeCache -> {{64.5857864376269, 
                165.45604605331755`}, {-45.41421356237311, \
-30.585786437626894`}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "1.3962966920219118`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "0.7300574138490858`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "0.551531137742301`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.44554965479709624`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.2894060504854766`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {
                GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 1.3962966920219118`}, {
                  Style["75%", Bold], 0.7300574138490858}, {
                  Style["median", Bold], 0.551531137742301}, {
                  Style["25%", Bold], 0.44554965479709624`}, {
                  Style["min", Bold], 0.2894060504854766}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {
                GrayLevel[0]}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{0.7134248531717358, 5.701405450691951}, {
                   0.7134248531717358, 6.298594549308049}, {
                   0.4288715175146584, 6.298594549308049}, {
                   0.4288715175146584, 5.701405450691951}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.4318324398609101`, 6.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.4089805548064203`, 6.}]}, {}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{0.5390826320001717, 6.298594549308049}, {
                    0.5390826320001717, 5.701405450691951}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.4288715175146584, 6.}, {0.261129942485427, 
                    6.}}, {{0.7134248531717358, 6.}, {1.126577264124387, 
                    6.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.261129942485427, 6.149297274654025}, {
                    0.261129942485427, 5.850702725345975}}, {{
                    1.126577264124387, 6.149297274654025}, {1.126577264124387,
                     5.850702725345975}}}]}, {}}]}, 
               ImageSizeCache -> {{62.58578643762689, 
                168.49360070190764`}, {-64.4142135623731, \
-49.58578643762689}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "1.4318324398609101`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "0.7134248531717358`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "0.5390826320001717`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.4288715175146584`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.261129942485427`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {
                GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 1.4318324398609101`}, {
                  Style["75%", Bold], 0.7134248531717358}, {
                  Style["median", Bold], 0.5390826320001717}, {
                  Style["25%", Bold], 0.4288715175146584}, {
                  Style["min", Bold], 0.261129942485427}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {
                GrayLevel[0]}], 
              "Tooltip"]& ]}}, {}, {}}, {{{{{{{}, {}}, {}}, {{{}, {}}, {}}, \
{{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}}, {}}, {}}, \
{}}, {}}, AspectRatio -> 1, Axes -> {False, False}, Frame -> True, 
        FrameLabel -> {{None, None}, {
           FormBox["\"nmse\"", TraditionalForm], None}}, 
        FrameTicks -> {{{{0.7014054506919505, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {6.298594549308049, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {1., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {1., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"rf\"", ",", "4", ",", "700"}], ")"}], 
              TraditionalForm], 0}, {2., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {2., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"rf\"", ",", "4", ",", "500"}], ")"}], 
              TraditionalForm], 0}, {3., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {3., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"rf\"", ",", "4", ",", "300"}], ")"}], 
              TraditionalForm], 0}, {4., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {4., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"rf\"", ",", "3", ",", "700"}], ")"}], 
              TraditionalForm], 0}, {5., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {5., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"rf\"", ",", "3", ",", "500"}], ")"}], 
              TraditionalForm], 0}, {6., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {6., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"rf\"", ",", "3", ",", "300"}], ")"}], 
              TraditionalForm], 0}}, {{0.7014054506919505, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {6.298594549308049, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {1., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {2., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {3., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {4., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {5., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {6., 
             FormBox[
              InterpretationBox[
               StyleBox[
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}}}, {
          Automatic, Automatic}}, PlotLabel -> FormBox[
          StyleBox["a1", {Bold, 14}, StripOnInput -> False], TraditionalForm],
         PlotRangePadding -> Scaled[0.02], Ticks -> {Automatic, None}], 
       GraphicsBox[{{
          Opacity[0], 
          
          PointBox[{{0.5218150030696065, 0.5327775812627538}, {
           1.5674695158929932`, 6.467222418737246}}]}, {
          RGBColor[
          0.798413061722744, 0.824719615472648, 0.968322270542458], {}, {
           RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{0.9826884098360607, 0.7014054506919505}, {
                   0.9826884098360607, 1.2985945493080495`}, {
                   0.7593757767538976, 1.2985945493080495`}, {
                   0.7593757767538976, 0.7014054506919505}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.4819560151451638`, 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.3867387468298447`, 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.4422254794010536`, 1.}]}, {}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{0.8594457499433222, 1.2985945493080495`}, {
                    0.8594457499433222, 0.7014054506919505}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.7593757767538976, 1.}, {0.60570017585129, 
                    1.}}, {{0.9826884098360607, 1.}, {1.312896358108724, 
                    1.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.60570017585129, 1.1492972746540246`}, {
                    0.60570017585129, 0.8507027253459752}}, {{
                    1.312896358108724, 1.1492972746540246`}, {
                    1.312896358108724, 0.8507027253459752}}}]}, {}}]}, 
               ImageSizeCache -> {{66.5857864376269, 167.29018873780828`}, {
                30.585786437626886`, 45.41421356237311}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "1.4819560151451638`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "0.9826884098360607`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "0.8594457499433222`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.7593757767538976`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.60570017585129`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {
                GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 1.4819560151451638`}, {
                  Style["75%", Bold], 0.9826884098360607}, {
                  Style["median", Bold], 0.8594457499433222}, {
                  Style["25%", Bold], 0.7593757767538976}, {
                  Style["min", Bold], 0.60570017585129}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {
                GrayLevel[0]}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{1.002253838772943, 1.7014054506919505`}, {
                   1.002253838772943, 2.2985945493080493`}, {
                   0.7562299645903808, 2.2985945493080493`}, {
                   0.7562299645903808, 1.7014054506919505`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.4667798024961662`, 2.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.4352434243961647`, 2.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.4619341677088227`, 2.}]}, {}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{0.8547127204440081, 2.2985945493080493`}, {
                    0.8547127204440081, 1.7014054506919507`}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.7562299645903808, 2.}, {0.5796138166806548, 
                    2.}}, {{1.002253838772943, 2.}, {1.2771542054439171`, 
                    2.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.5796138166806548, 2.1492972746540246`}, {
                    0.5796138166806548, 1.8507027253459754`}}, {{
                    1.2771542054439171`, 2.1492972746540246`}, {
                    1.2771542054439171`, 1.8507027253459754`}}}]}, {}}]}, 
               ImageSizeCache -> {{63.58578643762689, 165.6460879877082}, {
                11.585786437626894`, 26.414213562373106`}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "1.4667798024961662`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "1.002253838772943`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "0.8547127204440081`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.7562299645903808`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.5796138166806548`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {
                GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 1.4667798024961662`}, {
                  Style["75%", Bold], 1.002253838772943}, {
                  Style["median", Bold], 0.8547127204440081}, {
                  Style["25%", Bold], 0.7562299645903808}, {
                  Style["min", Bold], 0.5796138166806548}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {
                GrayLevel[0]}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{0.9927078803364587, 2.7014054506919507`}, {
                   0.9927078803364587, 3.2985945493080493`}, {
                   0.7977105430390717, 3.2985945493080493`}, {
                   0.7977105430390717, 2.7014054506919507`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.3167389353035333`, 3.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.4544444239860592`, 3.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.331152088854775, 3.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.3033656218483864`, 3.}]}, {}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{0.8721685162790522, 3.2985945493080493`}, {
                    0.8721685162790522, 2.7014054506919507`}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.7977105430390717, 3.}, {0.5693447536524877, 
                    3.}}, {{0.9927078803364587, 3.}, {1.1775468804940672`, 
                    3.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.5693447536524877, 3.1492972746540246`}, {
                    0.5693447536524877, 2.8507027253459754`}}, {{
                    1.1775468804940672`, 3.1492972746540246`}, {
                    1.1775468804940672`, 2.8507027253459754`}}}]}, {}}]}, 
               ImageSizeCache -> {{62.58578643762689, 
                164.30974633710707`}, {-7.4142135623731065`, 
                7.4142135623731065`}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "1.4544444239860592`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "0.9927078803364587`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "0.8721685162790522`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.7977105430390717`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.5693447536524877`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {
                GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 1.4544444239860592`}, {
                  Style["75%", Bold], 0.9927078803364587}, {
                  Style["median", Bold], 0.8721685162790522}, {
                  Style["25%", Bold], 0.7977105430390717}, {
                  Style["min", Bold], 0.5693447536524877}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {
                GrayLevel[0]}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{0.9804723043746942, 3.7014054506919507`}, {
                   0.9804723043746942, 4.298594549308049}, {
                   0.7896149712403064, 4.298594549308049}, {
                   0.7896149712403064, 3.7014054506919507`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.519939765310112, 4.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.3860016958957764`, 4.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.3359080773079668`, 4.}]}, {}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{0.8315071004440306, 4.298594549308049}, {
                    0.8315071004440306, 3.7014054506919507`}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.7896149712403064, 4.}, {0.5718413656014361, 
                    4.}}, {{0.9804723043746942, 4.}, {1.2410234279708057`, 
                    4.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.5718413656014361, 4.149297274654025}, {
                    0.5718413656014361, 3.8507027253459754`}}, {{
                    1.2410234279708057`, 4.149297274654025}, {
                    1.2410234279708057`, 3.8507027253459754`}}}]}, {}}]}, 
               ImageSizeCache -> {{62.58578643762689, 
                171.4051226532822}, {-26.414213562373106`, \
-11.585786437626894`}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "1.519939765310112`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "0.9804723043746942`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "0.8315071004440306`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.7896149712403064`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.5718413656014361`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {
                GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 1.519939765310112}, {
                  Style["75%", Bold], 0.9804723043746942}, {
                  Style["median", Bold], 0.8315071004440306}, {
                  Style["25%", Bold], 0.7896149712403064}, {
                  Style["min", Bold], 0.5718413656014361}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {
                GrayLevel[0]}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{0.9751366190056269, 4.701405450691951}, {
                   0.9751366190056269, 5.298594549308049}, {0.773377694272568,
                    5.298594549308049}, {0.773377694272568, 
                   4.701405450691951}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.4833391280623138`, 5.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.3659578563805996`, 5.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.402129499401068, 5.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.3181118635137445`, 5.}]}, {}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{0.8274701368923051, 5.298594549308049}, {
                    0.8274701368923051, 4.701405450691951}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.773377694272568, 5.}, {0.575533005498632, 
                    5.}}, {{0.9751366190056269, 5.}, {1.147853371088532, 
                    5.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.575533005498632, 5.149297274654025}, {
                    0.575533005498632, 4.850702725345975}}, {{
                    1.147853371088532, 5.149297274654025}, {1.147853371088532,
                     4.850702725345975}}}]}, {}}]}, 
               ImageSizeCache -> {{63.58578643762689, 
                167.44002697723948`}, {-45.41421356237311, \
-30.585786437626894`}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "1.4833391280623138`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "0.9751366190056269`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "0.8274701368923051`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.773377694272568`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.575533005498632`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {
                GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 1.4833391280623138`}, {
                  Style["75%", Bold], 0.9751366190056269}, {
                  Style["median", Bold], 0.8274701368923051}, {
                  Style["25%", Bold], 0.773377694272568}, {
                  Style["min", Bold], 0.575533005498632}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {
                GrayLevel[0]}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{0.9859010226888698, 5.701405450691951}, {
                   0.9859010226888698, 6.298594549308049}, {0.7472505235145, 
                   6.298594549308049}, {0.7472505235145, 
                   5.701405450691951}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.3775075081630457`, 6.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.404784746240384, 6.}]}, {}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{0.8347675803628292, 6.298594549308049}, {
                    0.8347675803628292, 5.701405450691951}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   LineBox[{{{0.7472505235145, 6.}, {0.5860220983443171, 
                    6.}}, {{0.9859010226888698, 6.}, {1.2859492152337424`, 
                    6.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.5860220983443171, 6.149297274654025}, {
                    0.5860220983443171, 5.850702725345975}}, {{
                    1.2859492152337424`, 6.149297274654025}, {
                    1.2859492152337424`, 5.850702725345975}}}]}, {}}]}, 
               ImageSizeCache -> {{64.5857864376269, 
                158.9299117683825}, {-64.4142135623731, -49.58578643762689}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "1.404784746240384`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "0.9859010226888698`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "0.8347675803628292`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.7472505235145`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.5860220983443171`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {
                GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 1.404784746240384}, {
                  Style["75%", Bold], 0.9859010226888698}, {
                  Style["median", Bold], 0.8347675803628292}, {
                  Style["25%", Bold], 0.7472505235145}, {
                  Style["min", Bold], 0.5860220983443171}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {
                GrayLevel[0]}], 
              "Tooltip"]& ]}}, {}, {}}, {{{{{{{}, {}}, {}}, {{{}, {}}, {}}, \
{{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}}, {}}, {}}, \
{}}, {}}, AspectRatio -> 1, Axes -> {False, False}, Frame -> True, 
        FrameLabel -> {{None, None}, {
           FormBox["\"nmse\"", TraditionalForm], None}}, 
        FrameTicks -> {{{{0.7014054506919505, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {6.298594549308049, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {1., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {1., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"rf\"", ",", "4", ",", "700"}], ")"}], 
              TraditionalForm], 0}, {2., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {2., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"rf\"", ",", "4", ",", "500"}], ")"}], 
              TraditionalForm], 0}, {3., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {3., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"rf\"", ",", "4", ",", "300"}], ")"}], 
              TraditionalForm], 0}, {4., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {4., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"rf\"", ",", "3", ",", "700"}], ")"}], 
              TraditionalForm], 0}, {5., 
             FormBox[
              InterpretationBox[
               StyleBox[
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {5., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"rf\"", ",", "3", ",", "500"}], ")"}], 
              TraditionalForm], 0}, {6., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {6., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"rf\"", ",", "3", ",", "300"}], ")"}], 
              TraditionalForm], 0}}, {{0.7014054506919505, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {6.298594549308049, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {1., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {2., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {3., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {4., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {5., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {6., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}}}, {
          Automatic, Automatic}}, PlotLabel -> FormBox[
          StyleBox["a2", {Bold, 14}, StripOnInput -> False], TraditionalForm],
         PlotRangePadding -> Scaled[0.02], Ticks -> {Automatic, None}], 
       GraphicsBox[{{
          Opacity[0], 
          
          PointBox[{{0.43211563284265087`, 0.5327775812627538}, {
           5.206034942593912, 6.467222418737246}}]}, {
          RGBColor[
          0.798413061722744, 0.824719615472648, 0.968322270542458], {}, {
           RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{1.1572442112499697`, 0.7014054506919505}, {
                   1.1572442112499697`, 1.2985945493080495`}, {
                   0.9295167385018529, 1.2985945493080495`}, {
                   0.9295167385018529, 0.7014054506919505}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2.6410455548149727`, 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2.2119774461828796`, 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4.8422894725949455`, 1.}]}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{1.0460327494305675`, 1.2985945493080495`}, {
                    1.0460327494305675`, 0.7014054506919505}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.9295167385018529, 1.}, {0.8025194665889146, 
                    1.}}, {{1.1572442112499697`, 1.}, {1.2567967474540007`, 
                    1.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.8025194665889146, 1.1492972746540246`}, {
                    0.8025194665889146, 0.8507027253459752}}, {{
                    1.2567967474540007`, 1.1492972746540246`}, {
                    1.2567967474540007`, 0.8507027253459752}}}]}, {}}]}, 
               ImageSizeCache -> {{66.5857864376269, 167.9229225480242}, {
                30.585786437626883`, 45.41421356237311}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "4.8422894725949455`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "1.1572442112499697`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "1.0460327494305675`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.9295167385018529`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.8025194665889146`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {
                GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 4.8422894725949455`}, {
                  Style["75%", Bold], 1.1572442112499697`}, {
                  Style["median", Bold], 1.0460327494305675`}, {
                  Style["25%", Bold], 0.9295167385018529}, {
                  Style["min", Bold], 0.8025194665889146}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {
                GrayLevel[0]}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{1.1788523139266358`, 1.7014054506919505`}, {
                   1.1788523139266358`, 2.2985945493080493`}, {
                   0.9164242195813537, 2.2985945493080493`}, {
                   0.9164242195813537, 1.7014054506919505`}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2.5252970625027085`, 2.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2.2110054476522123`, 2.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4.989038610332491, 2.}]}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{1.0563091611452013`, 2.2985945493080493`}, {
                    1.0563091611452013`, 1.7014054506919507`}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.9164242195813537, 2.}, {0.7984997008623511, 
                    2.}}, {{1.1788523139266358`, 2.}, {1.3254116216176595`, 
                    2.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.7984997008623511, 2.1492972746540246`}, {
                    0.7984997008623511, 1.8507027253459754`}}, {{
                    1.3254116216176595`, 2.1492972746540246`}, {
                    1.3254116216176595`, 1.8507027253459754`}}}]}, {}}]}, 
               ImageSizeCache -> {{66.5857864376269, 171.4051226532822}, {
                11.585786437626894`, 26.414213562373106`}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "4.989038610332491`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "1.1788523139266358`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "1.0563091611452013`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.9164242195813537`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.7984997008623511`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {
                GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 4.989038610332491}, {
                  Style["75%", Bold], 1.1788523139266358`}, {
                  Style["median", Bold], 1.0563091611452013`}, {
                  Style["25%", Bold], 0.9164242195813537}, {
                  Style["min", Bold], 0.7984997008623511}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {
                GrayLevel[0]}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{1.1516180517657375`, 2.7014054506919507`}, {
                   1.1516180517657375`, 3.2985945493080493`}, {
                   0.9170280867186574, 3.2985945493080493`}, {
                   0.9170280867186574, 2.7014054506919507`}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2.5547341897502815`, 3.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2.2183956017737785`, 3.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4.6210406186934865`, 3.}]}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{1.0476294227453058`, 3.2985945493080493`}, {
                    1.0476294227453058`, 2.7014054506919507`}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.9170280867186574, 3.}, {0.7773384117836103, 
                    3.}}, {{1.1516180517657375`, 3.}, {1.3052318660857745`, 
                    3.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.7773384117836103, 3.1492972746540246`}, {
                    0.7773384117836103, 2.8507027253459754`}}, {{
                    1.3052318660857745`, 3.1492972746540246`}, {
                    1.3052318660857745`, 2.8507027253459754`}}}]}, {}}]}, 
               ImageSizeCache -> {{65.5857864376269, 
                162.67292384805387`}, {-7.4142135623731065`, 
                7.4142135623731065`}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "4.6210406186934865`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "1.1516180517657375`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "1.0476294227453058`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.9170280867186574`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.7773384117836103`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {
                GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 4.6210406186934865`}, {
                  Style["75%", Bold], 1.1516180517657375`}, {
                  Style["median", Bold], 1.0476294227453058`}, {
                  Style["25%", Bold], 0.9170280867186574}, {
                  Style["min", Bold], 0.7773384117836103}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {
                GrayLevel[0]}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{1.1480960112982603`, 3.7014054506919507`}, {
                   1.1480960112982603`, 4.298594549308049}, {
                   0.878999496120313, 4.298594549308049}, {0.878999496120313, 
                   3.7014054506919507`}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2.4855152901299764`, 4.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2.0042860943402254`, 4.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4.36782243256228, 4.}]}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{1.0181862347934212`, 4.298594549308049}, {
                    1.0181862347934212`, 3.7014054506919507`}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.878999496120313, 4.}, {0.7309764636109285, 
                    4.}}, {{1.1480960112982603`, 4.}, {1.2822654971136622`, 
                    4.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.7309764636109285, 4.149297274654025}, {
                    0.7309764636109285, 3.8507027253459754`}}, {{
                    1.2822654971136622`, 4.149297274654025}, {
                    1.2822654971136622`, 3.8507027253459754`}}}]}, {}}]}, 
               ImageSizeCache -> {{64.5857864376269, 
                156.66432708221583`}, {-26.414213562373106`, \
-11.585786437626894`}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "4.36782243256228`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "1.1480960112982603`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "1.0181862347934212`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.878999496120313`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.7309764636109285`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {
                GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 4.36782243256228}, {
                  Style["75%", Bold], 1.1480960112982603`}, {
                  Style["median", Bold], 1.0181862347934212`}, {
                  Style["25%", Bold], 0.878999496120313}, {
                  Style["min", Bold], 0.7309764636109285}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {
                GrayLevel[0]}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{1.1392768633313417`, 4.701405450691951}, {
                   1.1392768633313417`, 5.298594549308049}, {
                   0.892004472640036, 5.298594549308049}, {0.892004472640036, 
                   4.701405450691951}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2.4289150101835943`, 5.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2.1004873113319995`, 5.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4.574565208176661, 5.}]}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{1.023941875554589, 5.298594549308049}, {
                    1.023941875554589, 4.701405450691951}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.892004472640036, 5.}, {0.7331668700950903, 
                    5.}}, {{1.1392768633313417`, 5.}, {1.1966990735475518`, 
                    5.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.7331668700950903, 5.149297274654025}, {
                    0.7331668700950903, 4.850702725345975}}, {{
                    1.1966990735475518`, 5.149297274654025}, {
                    1.1966990735475518`, 4.850702725345975}}}]}, {}}]}, 
               ImageSizeCache -> {{64.5857864376269, 
                161.5701120572068}, {-45.41421356237311, \
-30.585786437626894`}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "4.574565208176661`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "1.1392768633313417`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "1.023941875554589`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.892004472640036`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.7331668700950903`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {
                GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 4.574565208176661}, {
                  Style["75%", Bold], 1.1392768633313417`}, {
                  Style["median", Bold], 1.023941875554589}, {
                  Style["25%", Bold], 0.892004472640036}, {
                  Style["min", Bold], 0.7331668700950903}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {
                GrayLevel[0]}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{1.1238032408767222`, 5.701405450691951}, {
                   1.1238032408767222`, 6.298594549308049}, {
                   0.8866853938169855, 6.298594549308049}, {
                   0.8866853938169855, 5.701405450691951}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2.569913258894394, 6.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2.1974091943184315`, 6.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {4.531255623162647, 6.}]}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{1.0223436076253927`, 6.298594549308049}, {
                    1.0223436076253927`, 5.701405450691951}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.8866853938169855, 6.}, {0.6491119651040719, 
                    6.}}, {{1.1238032408767222`, 6.}, {1.2781657158764261`, 
                    6.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.6491119651040719, 6.149297274654025}, {
                    0.6491119651040719, 5.850702725345975}}, {{
                    1.2781657158764261`, 6.149297274654025}, {
                    1.2781657158764261`, 5.850702725345975}}}]}, {}}]}, 
               ImageSizeCache -> {{62.58578643762689, 
                160.54242192001362`}, {-64.4142135623731, \
-49.58578643762689}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "4.531255623162647`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "1.1238032408767222`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "1.0223436076253927`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.8866853938169855`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.6491119651040719`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {
                GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 4.531255623162647}, {
                  Style["75%", Bold], 1.1238032408767222`}, {
                  Style["median", Bold], 1.0223436076253927`}, {
                  Style["25%", Bold], 0.8866853938169855}, {
                  Style["min", Bold], 0.6491119651040719}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {
                GrayLevel[0]}], 
              "Tooltip"]& ]}}, {}, {}}, {{{{{{{}, {}}, {}}, {{{}, {}}, {}}, \
{{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}}, {}}, {}}, \
{}}, {}}, AspectRatio -> 1, Axes -> {False, False}, Frame -> True, 
        FrameLabel -> {{None, None}, {
           FormBox["\"nmse\"", TraditionalForm], None}}, 
        FrameTicks -> {{{{0.7014054506919505, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {6.298594549308049, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {1., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {1., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"rf\"", ",", "4", ",", "700"}], ")"}], 
              TraditionalForm], 0}, {2., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {2., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"rf\"", ",", "4", ",", "500"}], ")"}], 
              TraditionalForm], 0}, {3., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {3., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"rf\"", ",", "4", ",", "300"}], ")"}], 
              TraditionalForm], 0}, {4., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {4., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"rf\"", ",", "3", ",", "700"}], ")"}], 
              TraditionalForm], 0}, {5., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {5., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"rf\"", ",", "3", ",", "500"}], ")"}], 
              TraditionalForm], 0}, {6., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {6., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"rf\"", ",", "3", ",", "300"}], ")"}], 
              TraditionalForm], 0}}, {{0.7014054506919505, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {6.298594549308049, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {1., 
             FormBox[
              InterpretationBox[
               StyleBox[
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {2., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {3., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {4., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {5., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {6., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}}}, {
          Automatic, Automatic}}, PlotLabel -> FormBox[
          StyleBox["a3", {Bold, 14}, StripOnInput -> False], TraditionalForm],
         PlotRangePadding -> Scaled[0.02], Ticks -> {Automatic, None}]}, {
       GraphicsBox[{{
          Opacity[0], 
          
          PointBox[{{0.5185058603881898, 0.5327775812627538}, {
           2.37692860139625, 6.467222418737246}}]}, {
          RGBColor[
          0.798413061722744, 0.824719615472648, 0.968322270542458], {}, {
           RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{1.0523988286274886`, 0.7014054506919505}, {
                   1.0523988286274886`, 1.2985945493080495`}, {
                   0.8125062217294428, 1.2985945493080495`}, {
                   0.8125062217294428, 0.7014054506919505}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2.0887981413005665`, 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2.2745347903633886`, 1.}]}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{0.9516006460778578, 1.2985945493080495`}, {
                    0.9516006460778578, 0.7014054506919505}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.8125062217294428, 1.}, {0.6068367611934962, 
                    1.}}, {{1.0523988286274886`, 1.}, {1.3843437890752726`, 
                    1.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.6068367611934962, 1.1492972746540246`}, {
                    0.6068367611934962, 0.8507027253459752}}, {{
                    1.3843437890752726`, 1.1492972746540246`}, {
                    1.3843437890752726`, 0.8507027253459752}}}]}, {}}]}, 
               ImageSizeCache -> {{62.58578643762689, 170.3128075260313}, {
                30.585786437626883`, 45.41421356237311}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "2.2745347903633886`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "1.0523988286274886`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "0.9516006460778578`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.8125062217294428`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.6068367611934962`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {
                GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 2.2745347903633886`}, {
                  Style["75%", Bold], 1.0523988286274886`}, {
                  Style["median", Bold], 0.9516006460778578}, {
                  Style["25%", Bold], 0.8125062217294428}, {
                  Style["min", Bold], 0.6068367611934962}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {
                GrayLevel[0]}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{1.1235687484783237`, 1.7014054506919505`}, {
                   1.1235687484783237`, 2.2985945493080493`}, {
                   0.8092002899684166, 2.2985945493080493`}, {
                   0.8092002899684166, 1.7014054506919505`}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2.077613680206076, 2.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2.196085361055991, 2.}]}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{0.9075032095890938, 2.2985945493080493`}, {
                    0.9075032095890938, 1.7014054506919507`}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.8092002899684166, 2.}, {0.6208357955419549, 
                    2.}}, {{1.1235687484783237`, 2.}, {1.5298642375831155`, 
                    2.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.6208357955419549, 2.1492972746540246`}, {
                    0.6208357955419549, 1.8507027253459754`}}, {{
                    1.5298642375831155`, 2.1492972746540246`}, {
                    1.5298642375831155`, 1.8507027253459754`}}}]}, {}}]}, 
               ImageSizeCache -> {{63.58578643762689, 165.5309292397585}, {
                11.585786437626894`, 26.414213562373106`}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "2.196085361055991`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "1.1235687484783237`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "0.9075032095890938`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.8092002899684166`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.6208357955419549`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {
                GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 2.196085361055991}, {
                  Style["75%", Bold], 1.1235687484783237`}, {
                  Style["median", Bold], 0.9075032095890938}, {
                  Style["25%", Bold], 0.8092002899684166}, {
                  Style["min", Bold], 0.6208357955419549}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {
                GrayLevel[0]}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{1.0224134406905565`, 2.7014054506919507`}, {
                   1.0224134406905565`, 3.2985945493080493`}, {
                   0.8048942867532024, 3.2985945493080493`}, {
                   0.8048942867532024, 2.7014054506919507`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.3800899316246957`, 3.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.405084197730237, 3.}]}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2.0110623290514447`, 3.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2.292454840441338, 3.}]}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{0.9331651501509713, 3.2985945493080493`}, {
                    0.9331651501509713, 2.7014054506919507`}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.8048942867532024, 3.}, {0.6338658587721073, 
                    3.}}, {{1.0224134406905565`, 3.}, {1.1549849859194974`, 
                    3.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.6338658587721073, 3.1492972746540246`}, {
                    0.6338658587721073, 2.8507027253459754`}}, {{
                    1.1549849859194974`, 3.1492972746540246`}, {
                    1.1549849859194974`, 2.8507027253459754`}}}]}, {}}]}, 
               ImageSizeCache -> {{64.5857864376269, 
                171.40512265328215`}, {-7.4142135623731065`, 
                7.4142135623731065`}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "2.292454840441338`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "1.0224134406905565`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "0.9331651501509713`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.8048942867532024`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.6338658587721073`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {
                GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 2.292454840441338}, {
                  Style["75%", Bold], 1.0224134406905565`}, {
                  Style["median", Bold], 0.9331651501509713}, {
                  Style["25%", Bold], 0.8048942867532024}, {
                  Style["min", Bold], 0.6338658587721073}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {
                GrayLevel[0]}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{1.0136358700885968`, 3.7014054506919507`}, {
                   1.0136358700885968`, 4.298594549308049}, {
                   0.7889312806988416, 4.298594549308049}, {
                   0.7889312806988416, 3.7014054506919507`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.3959801678625852`, 4.}]}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1.9493358349020355`, 4.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2.2909159921754916`, 4.}]}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{0.909934061840758, 4.298594549308049}, {
                    0.909934061840758, 3.7014054506919507`}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.7889312806988416, 4.}, {0.6029796213431017, 
                    4.}}, {{1.0136358700885968`, 4.}, {1.1641391108360637`, 
                    4.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.6029796213431017, 4.149297274654025}, {
                    0.6029796213431017, 3.8507027253459754`}}, {{
                    1.1641391108360637`, 4.149297274654025}, {
                    1.1641391108360637`, 3.8507027253459754`}}}]}, {}}]}, 
               ImageSizeCache -> {{62.58578643762689, 
                171.3113222882153}, {-26.414213562373106`, \
-11.585786437626894`}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "2.2909159921754916`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "1.0136358700885968`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "0.909934061840758`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.7889312806988416`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.6029796213431017`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {
                GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 2.2909159921754916`}, {
                  Style["75%", Bold], 1.0136358700885968`}, {
                  Style["median", Bold], 0.909934061840758}, {
                  Style["25%", Bold], 0.7889312806988416}, {
                  Style["min", Bold], 0.6029796213431017}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {
                GrayLevel[0]}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{1.02291773871494, 4.701405450691951}, {
                   1.02291773871494, 5.298594549308049}, {0.7947480362176992, 
                   5.298594549308049}, {0.7947480362176992, 
                   4.701405450691951}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.376649210585034, 5.}]}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1.8271853712959953`, 5.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2.260142767664567, 5.}]}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{0.93434317136175, 5.298594549308049}, {
                    0.93434317136175, 4.701405450691951}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.7947480362176992, 5.}, {0.6223214461803398, 
                    5.}}, {{1.02291773871494, 5.}, {1.3154462867812318`, 
                    5.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.6223214461803398, 5.149297274654025}, {
                    0.6223214461803398, 4.850702725345975}}, {{
                    1.3154462867812318`, 5.149297274654025}, {
                    1.3154462867812318`, 4.850702725345975}}}]}, {}}]}, 
               ImageSizeCache -> {{63.58578643762689, 
                169.43554300738998`}, {-45.41421356237311, \
-30.585786437626894`}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "2.260142767664567`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "1.02291773871494`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "0.93434317136175`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.7947480362176992`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.6223214461803398`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {
                GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 2.260142767664567}, {
                  Style["75%", Bold], 1.02291773871494}, {
                  Style["median", Bold], 0.93434317136175}, {
                  Style["25%", Bold], 0.7947480362176992}, {
                  Style["min", Bold], 0.6223214461803398}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {
                GrayLevel[0]}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{1.0551385352724147`, 5.701405450691951}, {
                   1.0551385352724147`, 6.298594549308049}, {
                   0.8109745365880693, 6.298594549308049}, {
                   0.8109745365880693, 5.701405450691951}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.6396986528827397`, 6.}]}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {2.156207339986004, 6.}]}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{0.9034470846052786, 6.298594549308049}, {
                    0.9034470846052786, 5.701405450691951}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.8109745365880693, 6.}, {0.6048403349822549, 
                    6.}}, {{1.0551385352724147`, 6.}, {1.4064796072826742`, 
                    6.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.6048403349822549, 6.149297274654025}, {
                    0.6048403349822549, 5.850702725345975}}, {{
                    1.4064796072826742`, 6.149297274654025}, {
                    1.4064796072826742`, 5.850702725345975}}}]}, {}}]}, 
               ImageSizeCache -> {{62.58578643762689, 
                163.1001678596229}, {-64.4142135623731, -49.58578643762689}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "2.156207339986004`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "1.0551385352724147`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "0.9034470846052786`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.8109745365880693`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.6048403349822549`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {
                GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 2.156207339986004}, {
                  Style["75%", Bold], 1.0551385352724147`}, {
                  Style["median", Bold], 0.9034470846052786}, {
                  Style["25%", Bold], 0.8109745365880693}, {
                  Style["min", Bold], 0.6048403349822549}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {
                GrayLevel[0]}], 
              "Tooltip"]& ]}}, {}, {}}, {{{{{{{}, {}}, {}}, {{{}, {}}, {}}, \
{{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}}, {}}, {}}, \
{}}, {}}, AspectRatio -> 1, Axes -> {False, False}, Frame -> True, 
        FrameLabel -> {{None, None}, {
           FormBox["\"nmse\"", TraditionalForm], None}}, 
        FrameTicks -> {{{{0.7014054506919505, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {6.298594549308049, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {1., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {1., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"rf\"", ",", "4", ",", "700"}], ")"}], 
              TraditionalForm], 0}, {2., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {2., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"rf\"", ",", "4", ",", "500"}], ")"}], 
              TraditionalForm], 0}, {3., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {3., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"rf\"", ",", "4", ",", "300"}], ")"}], 
              TraditionalForm], 0}, {4., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {4., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"rf\"", ",", "3", ",", "700"}], ")"}], 
              TraditionalForm], 0}, {5., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {5., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"rf\"", ",", "3", ",", "500"}], ")"}], 
              TraditionalForm], 0}, {6., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {6., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"rf\"", ",", "3", ",", "300"}], ")"}], 
              TraditionalForm], 0}}, {{0.7014054506919505, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {6.298594549308049, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {1., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {2., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {3., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {4., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {5., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {6., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}}}, {
          Automatic, Automatic}}, PlotLabel -> FormBox[
          StyleBox["a4", {Bold, 14}, StripOnInput -> False], TraditionalForm],
         PlotRangePadding -> Scaled[0.02], Ticks -> {Automatic, None}], 
       GraphicsBox[{{
          Opacity[0], 
          
          PointBox[{{0.3904843049931379, 0.5327775812627538}, {
           1.9278307839792048`, 6.467222418737246}}]}, {
          RGBColor[
          0.798413061722744, 0.824719615472648, 0.968322270542458], {}, {
           RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{0.9799495146925218, 0.7014054506919505}, {
                   0.9799495146925218, 1.2985945493080495`}, {
                   0.795769372249353, 1.2985945493080495`}, {
                   0.795769372249353, 0.7014054506919505}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    0.48980355997831004`, 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.360451719853922, 1.}]}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1.6951050303807278`, 1.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1.632667011889689, 1.}]}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{0.8806597187152422, 1.2985945493080495`}, {
                    0.8806597187152422, 0.7014054506919505}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.795769372249353, 1.}, {0.7061745353328471, 
                    1.}}, {{0.9799495146925218, 1.}, {1.0322548637182118`, 
                    1.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.7061745353328471, 1.1492972746540246`}, {
                    0.7061745353328471, 0.8507027253459752}}, {{
                    1.0322548637182118`, 1.1492972746540246`}, {
                    1.0322548637182118`, 0.8507027253459752}}}]}, {}}]}, 
               ImageSizeCache -> {{62.76416609927651, 159.4057218410905}, {
                30.585786437626883`, 45.41421356237311}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "1.6951050303807278`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "0.9799495146925218`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "0.8806597187152422`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.795769372249353`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.48980355997831004`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {
                GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 1.6951050303807278`}, {
                  Style["75%", Bold], 0.9799495146925218}, {
                  Style["median", Bold], 0.8806597187152422}, {
                  Style["25%", Bold], 0.795769372249353}, {
                  Style["min", Bold], 0.48980355997831004`}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {
                GrayLevel[0]}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{0.9815829036586008, 1.7014054506919505`}, {
                   0.9815829036586008, 2.2985945493080493`}, {
                   0.7939018141052427, 2.2985945493080493`}, {
                   0.7939018141052427, 1.7014054506919505`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.3271961765301075`, 2.}]}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1.8154188827836248`, 2.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1.7070164513827746`, 2.}]}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{0.8686308602656403, 2.2985945493080493`}, {
                    0.8686308602656403, 1.7014054506919507`}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.7939018141052427, 2.}, {0.512639084038578, 
                    2.}}, {{0.9815829036586008, 2.}, {1.0312344647498926`, 
                    2.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.512639084038578, 2.1492972746540246`}, {
                    0.512639084038578, 1.8507027253459754`}}, {{
                    1.0312344647498926`, 2.1492972746540246`}, {
                    1.0312344647498926`, 1.8507027253459754`}}}]}, {}}]}, 
               ImageSizeCache -> {{66.5857864376269, 168.27109694455385`}, {
                11.585786437626894`, 26.414213562373106`}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "1.8154188827836248`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "0.9815829036586008`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "0.8686308602656403`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.7939018141052427`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.512639084038578`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {
                GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 1.8154188827836248`}, {
                  Style["75%", Bold], 0.9815829036586008}, {
                  Style["median", Bold], 0.8686308602656403}, {
                  Style["25%", Bold], 0.7939018141052427}, {
                  Style["min", Bold], 0.512639084038578}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {
                GrayLevel[0]}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{0.9846607681868703, 2.7014054506919507`}, {
                   0.9846607681868703, 3.2985945493080493`}, {
                   0.7826696941110696, 3.2985945493080493`}, {
                   0.7826696941110696, 2.7014054506919507`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    0.46036369040159547`, 3.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.4183031768693244`, 3.}]}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1.8579513985707472`, 3.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1.6255667428626115`, 3.}]}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{0.8811407713992554, 3.2985945493080493`}, {
                    0.8811407713992554, 2.7014054506919507`}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.7826696941110696, 3.}, {0.6646474765909529, 
                    3.}}, {{0.9846607681868703, 3.}, {1.0747396305217443`, 
                    3.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.6646474765909529, 3.1492972746540246`}, {
                    0.6646474765909529, 2.8507027253459754`}}, {{
                    1.0747396305217443`, 3.1492972746540246`}, {
                    1.0747396305217443`, 2.8507027253459754`}}}]}, {}}]}, 
               ImageSizeCache -> {{60.594877346717794`, 
                171.40512265328215`}, {-7.4142135623731065`, 
                7.4142135623731065`}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "1.8579513985707472`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "0.9846607681868703`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "0.8811407713992554`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.7826696941110696`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.46036369040159547`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {
                GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 1.8579513985707472`}, {
                  Style["75%", Bold], 0.9846607681868703}, {
                  Style["median", Bold], 0.8811407713992554}, {
                  Style["25%", Bold], 0.7826696941110696}, {
                  Style["min", Bold], 0.46036369040159547`}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {
                GrayLevel[0]}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{0.9382759080150502, 3.7014054506919507`}, {
                   0.9382759080150502, 4.298594549308049}, {
                   0.7760665825844374, 4.298594549308049}, {
                   0.7760665825844374, 3.7014054506919507`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.26228056885234, 4.}]}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1.7102617721456752`, 4.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1.602876649094658, 4.}]}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{0.8043758629900302, 4.298594549308049}, {
                    0.8043758629900302, 3.7014054506919507`}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.7760665825844374, 4.}, {0.5338391556902048, 
                    4.}}, {{0.9382759080150502, 4.}, {0.9904480214910361, 
                    4.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.5338391556902048, 4.149297274654025}, {
                    0.5338391556902048, 3.8507027253459754`}}, {{
                    0.9904480214910361, 4.149297274654025}, {
                    0.9904480214910361, 3.8507027253459754`}}}]}, {}}]}, 
               ImageSizeCache -> {{67.5857864376269, 
                160.52255251693504`}, {-26.414213562373106`, \
-11.585786437626894`}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "1.7102617721456752`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "0.9382759080150502`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "0.8043758629900302`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.7760665825844374`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.5338391556902048`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {
                GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 1.7102617721456752`}, {
                  Style["75%", Bold], 0.9382759080150502}, {
                  Style["median", Bold], 0.8043758629900302}, {
                  Style["25%", Bold], 0.7760665825844374}, {
                  Style["min", Bold], 0.5338391556902048}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {
                GrayLevel[0]}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{0.9529222440611436, 4.701405450691951}, {
                   0.9529222440611436, 5.298594549308049}, {
                   0.7466311890120508, 5.298594549308049}, {
                   0.7466311890120508, 4.701405450691951}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.5650679805218322`, 5.}]}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1.8347198328106313`, 5.}]}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   LineBox[{{0.8238126866029133, 5.298594549308049}, {
                    0.8238126866029133, 4.701405450691951}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.7466311890120508, 5.}, {0.542055918224855, 
                    5.}}, {{0.9529222440611436, 5.}, {1.2536558832020863`, 
                    5.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.542055918224855, 5.149297274654025}, {
                    0.542055918224855, 4.850702725345975}}, {{
                    1.2536558832020863`, 5.149297274654025}, {
                    1.2536558832020863`, 4.850702725345975}}}]}, {}}]}, 
               ImageSizeCache -> {{68.5857864376269, 
                169.69329529017426`}, {-45.41421356237311, \
-30.585786437626894`}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "1.8347198328106313`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "0.9529222440611436`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "0.8238126866029133`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.7466311890120508`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.542055918224855`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {
                GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 1.8347198328106313`}, {
                  Style["75%", Bold], 0.9529222440611436}, {
                  Style["median", Bold], 0.8238126866029133}, {
                  Style["25%", Bold], 0.7466311890120508}, {
                  Style["min", Bold], 0.542055918224855}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {
                GrayLevel[0]}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{0.9486111210880974, 5.701405450691951}, {
                   0.9486111210880974, 6.298594549308049}, {
                   0.7622012193818253, 6.298594549308049}, {
                   0.7622012193818253, 5.701405450691951}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.2596921799034089`, 6.}]}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1.7483807592712528`, 6.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1.5613629381118022`, 6.}]}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{0.8262004063691013, 6.298594549308049}, {
                    0.8262004063691013, 5.701405450691951}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.7622012193818253, 6.}, {0.5077704757556928, 
                    6.}}, {{0.9486111210880974, 6.}, {0.9886751708667972, 
                    6.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.5077704757556928, 6.149297274654025}, {
                    0.5077704757556928, 5.850702725345975}}, {{
                    0.9886751708667972, 6.149297274654025}, {
                    0.9886751708667972, 5.850702725345975}}}]}, {}}]}, 
               ImageSizeCache -> {{66.5857864376269, 
                163.33136557281387`}, {-64.4142135623731, \
-49.58578643762689}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "1.7483807592712528`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "0.9486111210880974`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "0.8262004063691013`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.7622012193818253`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.5077704757556928`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {
                GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 1.7483807592712528`}, {
                  Style["75%", Bold], 0.9486111210880974}, {
                  Style["median", Bold], 0.8262004063691013}, {
                  Style["25%", Bold], 0.7622012193818253}, {
                  Style["min", Bold], 0.5077704757556928}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {
                GrayLevel[0]}], 
              "Tooltip"]& ]}}, {}, {}}, {{{{{{{}, {}}, {}}, {{{}, {}}, {}}, \
{{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}}, {}}, {}}, \
{}}, {}}, AspectRatio -> 1, Axes -> {False, False}, Frame -> True, 
        FrameLabel -> {{None, None}, {
           FormBox["\"nmse\"", TraditionalForm], None}}, 
        FrameTicks -> {{{{0.7014054506919505, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {6.298594549308049, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {1., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {1., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"rf\"", ",", "4", ",", "700"}], ")"}], 
              TraditionalForm], 0}, {2., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {2., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"rf\"", ",", "4", ",", "500"}], ")"}], 
              TraditionalForm], 0}, {3., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {3., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"rf\"", ",", "4", ",", "300"}], ")"}], 
              TraditionalForm], 0}, {4., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {4., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"rf\"", ",", "3", ",", "700"}], ")"}], 
              TraditionalForm], 0}, {5., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {5., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"rf\"", ",", "3", ",", "500"}], ")"}], 
              TraditionalForm], 0}, {6., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {6., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"rf\"", ",", "3", ",", "300"}], ")"}], 
              TraditionalForm], 0}}, {{0.7014054506919505, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {6.298594549308049, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {1., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {2., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {3., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {4., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {5., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {6., 
             FormBox[
              InterpretationBox[
               StyleBox[
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}}}, {
          Automatic, Automatic}}, PlotLabel -> FormBox[
          StyleBox["a5", {Bold, 14}, StripOnInput -> False], TraditionalForm],
         PlotRangePadding -> Scaled[0.02], Ticks -> {Automatic, None}], 
       GraphicsBox[{{
          Opacity[0], 
          
          PointBox[{{0.6011993546876566, 0.5327775812627538}, {
           2.0915307694144496`, 6.467222418737246}}]}, {
          RGBColor[
          0.798413061722744, 0.824719615472648, 0.968322270542458], {}, {
           RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{1.13038460188088, 0.7014054506919505}, {
                   1.13038460188088, 1.2985945493080495`}, {
                   0.8650087635427364, 1.2985945493080495`}, {
                   0.8650087635427364, 0.7014054506919505}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1.971464331521483, 1.}]}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{0.9507473645811569, 1.2985945493080495`}, {
                    0.9507473645811569, 0.7014054506919505}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   LineBox[{{{0.8650087635427364, 1.}, {0.6923057740695483, 
                    1.}}, {{1.13038460188088, 1.}, {1.4186165329585978`, 
                    1.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.6923057740695483, 1.1492972746540246`}, {
                    0.6923057740695483, 0.8507027253459752}}, {{
                    1.4186165329585978`, 1.1492972746540246`}, {
                    1.4186165329585978`, 0.8507027253459752}}}]}, {}}]}, 
               ImageSizeCache -> {{64.5857864376269, 167.42797093599148`}, {
                30.585786437626883`, 45.41421356237311}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "1.971464331521483`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "1.13038460188088`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "0.9507473645811569`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.8650087635427364`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.6923057740695483`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {
                GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 1.971464331521483}, {
                  Style["75%", Bold], 1.13038460188088}, {
                  Style["median", Bold], 0.9507473645811569}, {
                  Style["25%", Bold], 0.8650087635427364}, {
                  Style["min", Bold], 0.6923057740695483}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {
                GrayLevel[0]}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{1.1585068446532583`, 1.7014054506919505`}, {
                   1.1585068446532583`, 2.2985945493080493`}, {
                   0.849038752100105, 2.2985945493080493`}, {
                   0.849038752100105, 1.7014054506919505`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    2.0237884323814135`, 2.}]}, {}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{0.9615910369944108, 2.2985945493080493`}, {
                    0.9615910369944108, 1.7014054506919507`}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.849038752100105, 2.}, {0.6748834445991929, 
                    2.}}, {{1.1585068446532583`, 2.}, {1.3501873481056041`, 
                    2.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.6748834445991929, 2.1492972746540246`}, {
                    0.6748834445991929, 1.8507027253459754`}}, {{
                    1.3501873481056041`, 2.1492972746540246`}, {
                    1.3501873481056041`, 1.8507027253459754`}}}]}, {}}]}, 
               ImageSizeCache -> {{62.58578643762689, 171.40512265328215`}, {
                11.585786437626894`, 26.414213562373106`}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "2.0237884323814135`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "1.1585068446532583`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "0.9615910369944108`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.849038752100105`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.6748834445991929`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {
                GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 2.0237884323814135`}, {
                  Style["75%", Bold], 1.1585068446532583`}, {
                  Style["median", Bold], 0.9615910369944108}, {
                  Style["25%", Bold], 0.849038752100105}, {
                  Style["min", Bold], 0.6748834445991929}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {
                GrayLevel[0]}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{1.1886996709501991`, 2.7014054506919507`}, {
                   1.1886996709501991`, 3.2985945493080493`}, {
                   0.8473261362971476, 3.2985945493080493`}, {
                   0.8473261362971476, 2.7014054506919507`}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.8736274640519877`, 3.}]}, {}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{0.951886435116188, 3.2985945493080493`}, {
                    0.951886435116188, 2.7014054506919507`}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.8473261362971476, 3.}, {0.7200415905232069, 
                    3.}}, {{1.1886996709501991`, 3.}, {1.305952071885473, 
                    3.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.7200415905232069, 3.1492972746540246`}, {
                    0.7200415905232069, 2.8507027253459754`}}, {{
                    1.305952071885473, 3.1492972746540246`}, {
                    1.305952071885473, 2.8507027253459754`}}}]}, {}}]}, 
               ImageSizeCache -> {{66.5857864376269, 
                159.99139660264012`}, {-7.4142135623731065`, 
                7.4142135623731065`}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "1.8736274640519877`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "1.1886996709501991`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "0.951886435116188`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.8473261362971476`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.7200415905232069`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {
                GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 1.8736274640519877`}, {
                  Style["75%", Bold], 1.1886996709501991`}, {
                  Style["median", Bold], 0.951886435116188}, {
                  Style["25%", Bold], 0.8473261362971476}, {
                  Style["min", Bold], 0.7200415905232069}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {
                GrayLevel[0]}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{1.064622410069588, 3.7014054506919507`}, {
                   1.064622410069588, 4.298594549308049}, {0.8484923627610319,
                    4.298594549308049}, {0.8484923627610319, 
                   3.7014054506919507`}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {1.759397480909558, 4.}]}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{0.9477702393467262, 4.298594549308049}, {
                    0.9477702393467262, 3.7014054506919507`}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.8484923627610319, 4.}, {0.6799802812342334, 
                    4.}}, {{1.064622410069588, 4.}, {1.3721974550256155`, 
                    4.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.6799802812342334, 4.149297274654025}, {
                    0.6799802812342334, 3.8507027253459754`}}, {{
                    1.3721974550256155`, 4.149297274654025}, {
                    1.3721974550256155`, 3.8507027253459754`}}}]}, {}}]}, 
               ImageSizeCache -> {{63.58578643762689, 
                151.308782546124}, {-26.414213562373106`, \
-11.585786437626894`}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "1.759397480909558`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "1.064622410069588`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "0.9477702393467262`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.8484923627610319`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.6799802812342334`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {
                GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 1.759397480909558}, {
                  Style["75%", Bold], 1.064622410069588}, {
                  Style["median", Bold], 0.9477702393467262}, {
                  Style["25%", Bold], 0.8484923627610319}, {
                  Style["min", Bold], 0.6799802812342334}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {
                GrayLevel[0]}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{1.1286257656085938`, 4.701405450691951}, {
                   1.1286257656085938`, 5.298594549308049}, {
                   0.8501727792681838, 5.298594549308049}, {
                   0.8501727792681838, 4.701405450691951}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.7517294802997347`, 5.}]}, {}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{0.919046472174371, 5.298594549308049}, {
                    0.919046472174371, 4.701405450691951}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.8501727792681838, 5.}, {0.6706758358958731, 
                    5.}}, {{1.1286257656085938`, 5.}, {1.38352198570031, 
                    5.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.6706758358958731, 5.149297274654025}, {
                    0.6706758358958731, 4.850702725345975}}, {{
                    1.38352198570031, 5.149297274654025}, {1.38352198570031, 
                    4.850702725345975}}}]}, {}}]}, 
               ImageSizeCache -> {{62.58578643762689, 
                150.72593828712405`}, {-45.41421356237311, \
-30.585786437626894`}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "1.7517294802997347`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "1.1286257656085938`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "0.919046472174371`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.8501727792681838`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.6706758358958731`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {
                GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 1.7517294802997347`}, {
                  Style["75%", Bold], 1.1286257656085938`}, {
                  Style["median", Bold], 0.919046472174371}, {
                  Style["25%", Bold], 0.8501727792681838}, {
                  Style["min", Bold], 0.6706758358958731}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {
                GrayLevel[0]}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{1.121979950399206, 5.701405450691951}, {
                   1.121979950399206, 6.298594549308049}, {0.8694577470693747,
                    6.298594549308049}, {0.8694577470693747, 
                   5.701405450691951}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    1.8091960108352432`, 6.}]}, {}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{0.9452007752217344, 6.298594549308049}, {
                    0.9452007752217344, 5.701405450691951}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.8694577470693747, 6.}, {0.6689416917206926, 
                    6.}}, {{1.121979950399206, 6.}, {1.4129917198123783`, 
                    6.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.6689416917206926, 6.149297274654025}, {
                    0.6689416917206926, 5.850702725345975}}, {{
                    1.4129917198123783`, 6.149297274654025}, {
                    1.4129917198123783`, 5.850702725345975}}}]}, {}}]}, 
               ImageSizeCache -> {{62.58578643762689, 
                155.09396577063234`}, {-64.4142135623731, \
-49.58578643762689}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "1.8091960108352432`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "1.121979950399206`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "0.9452007752217344`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.8694577470693747`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.6689416917206926`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {
                GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 1.8091960108352432`}, {
                  Style["75%", Bold], 1.121979950399206}, {
                  Style["median", Bold], 0.9452007752217344}, {
                  Style["25%", Bold], 0.8694577470693747}, {
                  Style["min", Bold], 0.6689416917206926}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {
                GrayLevel[0]}], 
              "Tooltip"]& ]}}, {}, {}}, {{{{{{{}, {}}, {}}, {{{}, {}}, {}}, \
{{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}}, {}}, {}}, \
{}}, {}}, AspectRatio -> 1, Axes -> {False, False}, Frame -> True, 
        FrameLabel -> {{None, None}, {
           FormBox["\"nmse\"", TraditionalForm], None}}, 
        FrameTicks -> {{{{0.7014054506919505, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {6.298594549308049, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {1., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {1., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"rf\"", ",", "4", ",", "700"}], ")"}], 
              TraditionalForm], 0}, {2., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {2., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"rf\"", ",", "4", ",", "500"}], ")"}], 
              TraditionalForm], 0}, {3., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {3., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"rf\"", ",", "4", ",", "300"}], ")"}], 
              TraditionalForm], 0}, {4., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {4., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"rf\"", ",", "3", ",", "700"}], ")"}], 
              TraditionalForm], 0}, {5., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {5., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"rf\"", ",", "3", ",", "500"}], ")"}], 
              TraditionalForm], 0}, {6., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {6., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"rf\"", ",", "3", ",", "300"}], ")"}], 
              TraditionalForm], 0}}, {{0.7014054506919505, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {6.298594549308049, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {1., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {2., 
             FormBox[
              InterpretationBox[
               StyleBox[
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {3., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {4., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {5., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {6., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}}}, {
          Automatic, Automatic}}, PlotLabel -> FormBox[
          StyleBox["a6", {Bold, 14}, StripOnInput -> False], TraditionalForm],
         PlotRangePadding -> Scaled[0.02], Ticks -> {Automatic, None}]}, {
       GraphicsBox[{{
          Opacity[0], 
          
          PointBox[{{0.454696484059925, 0.5327775812627538}, {
           7.944978060852813, 6.467222418737246}}]}, {
          RGBColor[
          0.798413061722744, 0.824719615472648, 0.968322270542458], {}, {
           RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{2.077546483029106, 0.7014054506919505}, {
                   2.077546483029106, 1.2985945493080495`}, {
                   0.989511761897714, 1.2985945493080495`}, {
                   0.989511761897714, 0.7014054506919505}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7.245019810402245, 1.}]}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{1.098257840734208, 1.2985945493080495`}, {
                    1.098257840734208, 0.7014054506919505}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.989511761897714, 1.}, {0.8162568835796897, 
                    1.}}, {{2.077546483029106, 1.}, {3.0971183120023773`, 
                    1.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.8162568835796897, 1.1492972746540246`}, {
                    0.8162568835796897, 0.8507027253459752}}, {{
                    3.0971183120023773`, 1.1492972746540246`}, {
                    3.0971183120023773`, 0.8507027253459752}}}]}, {}}]}, 
               ImageSizeCache -> {{62.58578643762689, 165.96832706423288`}, {
                30.585786437626883`, 45.41421356237311}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "7.245019810402245`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "2.077546483029106`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "1.098257840734208`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.989511761897714`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.8162568835796897`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {
                GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 7.245019810402245}, {
                  Style["75%", Bold], 2.077546483029106}, {
                  Style["median", Bold], 1.098257840734208}, {
                  Style["25%", Bold], 0.989511761897714}, {
                  Style["min", Bold], 0.8162568835796897}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {
                GrayLevel[0]}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{2.0162571137156653`, 1.7014054506919505`}, {
                   2.0162571137156653`, 2.2985945493080493`}, {
                   0.9914764325499077, 2.2985945493080493`}, {
                   0.9914764325499077, 1.7014054506919505`}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7.604510716453136, 2.}]}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{1.117872774313959, 2.2985945493080493`}, {
                    1.117872774313959, 1.7014054506919507`}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.9914764325499077, 2.}, {0.8142827097666951, 
                    2.}}, {{2.0162571137156653`, 2.}, {2.87122803547719, 
                    2.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.8142827097666951, 2.1492972746540246`}, {
                    0.8142827097666951, 1.8507027253459754`}}, {{
                    2.87122803547719, 2.1492972746540246`}, {2.87122803547719,
                     1.8507027253459754`}}}]}, {}}]}, 
               ImageSizeCache -> {{62.58578643762689, 171.4051226532822}, {
                11.585786437626894`, 26.414213562373106`}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "7.604510716453136`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "2.0162571137156653`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "1.117872774313959`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.9914764325499077`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.8142827097666951`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {
                GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 7.604510716453136}, {
                  Style["75%", Bold], 2.0162571137156653`}, {
                  Style["median", Bold], 1.117872774313959}, {
                  Style["25%", Bold], 0.9914764325499077}, {
                  Style["min", Bold], 0.8142827097666951}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {
                GrayLevel[0]}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{2.0006631245916298`, 2.7014054506919507`}, {
                   2.0006631245916298`, 3.2985945493080493`}, {
                   0.992545987826513, 3.2985945493080493`}, {
                   0.992545987826513, 2.7014054506919507`}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6.683689115531577, 3.}]}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{1.0858391172120645`, 3.2985945493080493`}, {
                    1.0858391172120645`, 2.7014054506919507`}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.992545987826513, 3.}, {0.8549818361709143, 
                    3.}}, {{2.0006631245916298`, 3.}, {3.167943466254004, 
                    3.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.8549818361709143, 3.1492972746540246`}, {
                    0.8549818361709143, 2.8507027253459754`}}, {{
                    3.167943466254004, 3.1492972746540246`}, {
                    3.167943466254004, 2.8507027253459754`}}}]}, {}}]}, 
               ImageSizeCache -> {{63.58578643762689, 
                157.47898785007538`}, {-7.4142135623731065`, 
                7.4142135623731065`}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "6.683689115531577`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "2.0006631245916298`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "1.0858391172120645`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.992545987826513`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.8549818361709143`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {
                GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 6.683689115531577}, {
                  Style["75%", Bold], 2.0006631245916298`}, {
                  Style["median", Bold], 1.0858391172120645`}, {
                  Style["25%", Bold], 0.992545987826513}, {
                  Style["min", Bold], 0.8549818361709143}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {
                GrayLevel[0]}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{1.7724171030219578`, 3.7014054506919507`}, {
                   1.7724171030219578`, 4.298594549308049}, {
                   0.9534203485892372, 4.298594549308049}, {
                   0.9534203485892372, 3.7014054506919507`}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6.4200354055141915`, 4.}]}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{1.0891927517140825`, 4.298594549308049}, {
                    1.0891927517140825`, 3.7014054506919507`}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.9534203485892372, 4.}, {0.7960960458777561, 
                    4.}}, {{1.7724171030219578`, 4.}, {2.8921595806753895`, 
                    4.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.7960960458777561, 4.149297274654025}, {
                    0.7960960458777561, 3.8507027253459754`}}, {{
                    2.8921595806753895`, 4.149297274654025}, {
                    2.8921595806753895`, 3.8507027253459754`}}}]}, {}}]}, 
               ImageSizeCache -> {{62.58578643762689, 
                153.49159539165225`}, {-26.414213562373106`, \
-11.585786437626894`}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "6.4200354055141915`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "1.7724171030219578`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "1.0891927517140825`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.9534203485892372`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.7960960458777561`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {
                GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 6.4200354055141915`}, {
                  Style["75%", Bold], 1.7724171030219578`}, {
                  Style["median", Bold], 1.0891927517140825`}, {
                  Style["25%", Bold], 0.9534203485892372}, {
                  Style["min", Bold], 0.7960960458777561}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {
                GrayLevel[0]}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{1.8220574107542267`, 4.701405450691951}, {
                   1.8220574107542267`, 5.298594549308049}, {
                   0.9641680892416746, 5.298594549308049}, {
                   0.9641680892416746, 4.701405450691951}}], {}, {{
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    3.1298696298263327`, 5.}], 
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0], StripOnInput -> False], TraditionalForm]], {
                    3.258828852969486, 5.}]}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {6.784061540795683, 5.}]}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{1.069802749243945, 5.298594549308049}, {
                    1.069802749243945, 4.701405450691951}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.9641680892416746, 5.}, {0.7951638284596018, 
                    5.}}, {{1.8220574107542267`, 5.}, {2.553073986845149, 
                    5.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.7951638284596018, 5.149297274654025}, {
                    0.7951638284596018, 4.850702725345975}}, {{
                    2.553073986845149, 5.149297274654025}, {2.553073986845149,
                     4.850702725345975}}}]}, {}}]}, 
               ImageSizeCache -> {{62.58578643762689, 
                158.99697995989754`}, {-45.41421356237311, \
-30.585786437626894`}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "6.784061540795683`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "1.8220574107542267`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "1.069802749243945`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.9641680892416746`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.7951638284596018`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {
                GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 6.784061540795683}, {
                  Style["75%", Bold], 1.8220574107542267`}, {
                  Style["median", Bold], 1.069802749243945}, {
                  Style["25%", Bold], 0.9641680892416746}, {
                  Style["min", Bold], 0.7951638284596018}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {
                GrayLevel[0]}], "Tooltip"]& ]}, {
            RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
            TagBox[
             TooltipBox[
              DynamicBox[{
                FEPrivate`If[
                 CurrentValue["MouseOver"], 
                 EdgeForm[{
                   GrayLevel[0.5], 
                   AbsoluteThickness[1.5], 
                   Opacity[0.66]}], {}, {}], 
                GraphicsGroupBox[{Antialiasing -> False, 
                  
                  PolygonBox[{{1.8183754560456489`, 5.701405450691951}, {
                   1.8183754560456489`, 6.298594549308049}, {
                   0.9630031309488916, 6.298594549308049}, {
                   0.9630031309488916, 5.701405450691951}}], {}, {{}, {
                    InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\[FilledSmallCircle]\"", 10, 
                    GrayLevel[0.5], StripOnInput -> False], 
                    TraditionalForm]], {7.329753891323894, 6.}]}}, {}, {
                   GrayLevel[0], 
                   GrayLevel[1], 
                   
                   LineBox[{{1.0949532671293802`, 6.298594549308049}, {
                    1.0949532671293802`, 5.701405450691951}}]}, {}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.9630031309488916, 6.}, {0.7995016792667639, 
                    6.}}, {{1.8183754560456489`, 6.}, {2.9741012091277645`, 
                    6.}}}]}, {
                   GrayLevel[0], 
                   GrayLevel[0.5], 
                   
                   LineBox[{{{0.7995016792667639, 6.149297274654025}, {
                    0.7995016792667639, 5.850702725345975}}, {{
                    2.9741012091277645`, 6.149297274654025}, {
                    2.9741012091277645`, 5.850702725345975}}}]}, {}}]}, 
               ImageSizeCache -> {{62.58578643762689, 
                167.24981115643897`}, {-64.4142135623731, \
-49.58578643762689}}], 
              StyleBox[
               TagBox[
                GridBox[{{
                   StyleBox["\"max\"", Bold, StripOnInput -> False], 
                   "7.329753891323894`"}, {
                   StyleBox["\"75%\"", Bold, StripOnInput -> False], 
                   "1.8183754560456489`"}, {
                   StyleBox["\"median\"", Bold, StripOnInput -> False], 
                   "1.0949532671293802`"}, {
                   StyleBox["\"25%\"", Bold, StripOnInput -> False], 
                   "0.9630031309488916`"}, {
                   StyleBox["\"min\"", Bold, StripOnInput -> False], 
                   "0.7995016792667639`"}}, 
                 GridBoxAlignment -> {"Columns" -> {Center, ".", {Left}}}, 
                 AutoDelete -> False, GridBoxDividers -> {"Columns" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}, "Rows" -> {
                    Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                    Directive[
                    GrayLevel[0.3]]}}, 
                 GridBoxFrame -> {
                  "ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> GrayLevel[0]}}, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> Directive[
                   AbsoluteThickness[1], 
                   Dashing[{}]]], "Grid"], {
                GrayLevel[0]}, StripOnInput -> False]], Annotation[#, 
              Style[
               Grid[{{
                  Style["max", Bold], 7.329753891323894}, {
                  Style["75%", Bold], 1.8183754560456489`}, {
                  Style["median", Bold], 1.0949532671293802`}, {
                  Style["25%", Bold], 0.9630031309488916}, {
                  Style["min", Bold], 0.7995016792667639}}, Dividers -> {{
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}, {
                   Directive[
                    GrayLevel[0.3]], {
                    Directive[
                    GrayLevel[0.3]]}, 
                   Directive[
                    GrayLevel[0.3]]}}, Alignment -> {{Center, ".", {Left}}}, 
                Frame -> GrayLevel[0], BaseStyle -> Directive[
                  AbsoluteThickness[1], 
                  Dashing[{}]]], {
                GrayLevel[0]}], 
              "Tooltip"]& ]}}, {}, {}}, {{{{{{{}, {}}, {}}, {{{}, {}}, {}}, \
{{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}, {{{}, {}}, {}}}, {}}, {}}, \
{}}, {}}, AspectRatio -> 1, Axes -> {False, False}, Frame -> True, 
        FrameLabel -> {{None, None}, {
           FormBox["\"nmse\"", TraditionalForm], None}}, 
        FrameTicks -> {{{{0.7014054506919505, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {6.298594549308049, 
             FormBox[
              InterpretationBox[
               StyleBox[
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {1., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {1., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"rf\"", ",", "4", ",", "700"}], ")"}], 
              TraditionalForm], 0}, {2., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {2., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"rf\"", ",", "4", ",", "500"}], ")"}], 
              TraditionalForm], 0}, {3., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {3., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"rf\"", ",", "4", ",", "300"}], ")"}], 
              TraditionalForm], 0}, {4., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {4., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"rf\"", ",", "3", ",", "700"}], ")"}], 
              TraditionalForm], 0}, {5., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {5., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"rf\"", ",", "3", ",", "500"}], ")"}], 
              TraditionalForm], 0}, {6., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {6., 
             FormBox[
              RowBox[{"cv", "(", 
                RowBox[{"\"rf\"", ",", "3", ",", "300"}], ")"}], 
              TraditionalForm], 0}}, {{0.7014054506919505, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {6.298594549308049, 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0, 0}}, {1., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {2., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {3., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {4., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {5., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}, {6., 
             FormBox[
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> 
                 Baseline], "CacheGraphics" -> False], 
               Spacer[0]], TraditionalForm], {0.008, 0}}}}, {
          Automatic, Automatic}}, PlotLabel -> FormBox[
          StyleBox["a7", {Bold, 14}, StripOnInput -> False], TraditionalForm],
         PlotRangePadding -> Scaled[0.02], Ticks -> {Automatic, None}], "", 
       ""}}, AutoDelete -> False, GridBoxDividers -> {"Columns" -> {{
          GrayLevel[1]}}, "Rows" -> {{
          GrayLevel[1]}}}, 
     GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      GridBoxSpacings -> {"Columns" -> {1, {0}, 1}, "Rows" -> {1, {0}, 1}}], 
    "Grid"],StyleBox[
    TagBox[
     GridBox[{{"\"10-fold cross validation results (RF)\""}}, 
      DefaultBaseStyle -> "Column", 
      GridBoxAlignment -> {"Columns" -> {{Center}}}, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Column"], 
    StripOnInput -> False, FontFamily -> "Verdana", FontSize -> 14, 
    FontWeight -> Bold]},
  "Labeled",
  DisplayFunction->(GridBox[{{
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, 
    GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
    BaselinePosition -> {2, 1}]& ),
  InterpretationFunction->(RowBox[{"Labeled", "[", 
     RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )]], "Output",
 CellChangeTimes->{3.5860143140490007`*^9}]
}, {2}]],

Cell["Best scores from the random forest runs:", "Text",
 CellChangeTimes->{{3.5860863431995792`*^9, 3.586086350207107*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MapThread", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"#1", ",", 
       RowBox[{"bestScore", "[", "#2", "]"}]}], "}"}], "&"}], ",", 
    RowBox[{"{", 
     RowBox[{"responseColumns", ",", "resAll7RF"}], "}"}]}], "]"}], "//", 
  "TableForm"}]], "Input",
 CellChangeTimes->{{3.5752195092257338`*^9, 3.575219516153816*^9}, {
  3.575219741014235*^9, 3.5752197934889593`*^9}, {3.57521985049048*^9, 
  3.5752198523803263`*^9}, {3.575222567645378*^9, 3.5752226061682253`*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {"a1", 
     RowBox[{
      RowBox[{"cv", "[", 
       RowBox[{"\<\"rf\"\>", ",", "3", ",", "300"}], "]"}], "\[Rule]", 
      "0.5499331021226923`"}]},
    {"a2", 
     RowBox[{
      RowBox[{"cv", "[", 
       RowBox[{"\<\"rf\"\>", ",", "3", ",", "700"}], "]"}], "\[Rule]", 
      "0.832708261075281`"}]},
    {"a3", 
     RowBox[{
      RowBox[{"cv", "[", 
       RowBox[{"\<\"rf\"\>", ",", "3", ",", "700"}], "]"}], "\[Rule]", 
      "1.0185456661877557`"}]},
    {"a4", 
     RowBox[{
      RowBox[{"cv", "[", 
       RowBox[{"\<\"rf\"\>", ",", "3", ",", "300"}], "]"}], "\[Rule]", 
      "0.9052994221344788`"}]},
    {"a5", 
     RowBox[{
      RowBox[{"cv", "[", 
       RowBox[{"\<\"rf\"\>", ",", "3", ",", "700"}], "]"}], "\[Rule]", 
      "0.8046606245948734`"}]},
    {"a6", 
     RowBox[{
      RowBox[{"cv", "[", 
       RowBox[{"\<\"rf\"\>", ",", "3", ",", "500"}], "]"}], "\[Rule]", 
      "0.9327405854407693`"}]},
    {"a7", 
     RowBox[{
      RowBox[{"cv", "[", 
       RowBox[{"\<\"rf\"\>", ",", "3", ",", "500"}], "]"}], "\[Rule]", 
      "1.075990585320287`"}]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.5860143296314793`*^9}]
}, Open  ]],

Cell["Best scores from all models:", "Text",
 CellChangeTimes->{{3.585932995965928*^9, 3.585933000917919*^9}, {
  3.586086356247431*^9, 3.58608635970284*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"resAllAll", "=", 
   RowBox[{"MapThread", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Join", "[", 
       RowBox[{"#1", ",", "#2"}], "]"}], "&"}], ",", 
     RowBox[{"{", 
      RowBox[{"resAll7", ",", "resAll7RF"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"winners", "=", 
   RowBox[{"MapThread", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"#1", ",", 
        RowBox[{"bestScore", "[", "#2", "]"}]}], "}"}], "&"}], ",", 
     RowBox[{"{", 
      RowBox[{"responseColumns", ",", "resAllAll"}], "}"}]}], "]"}]}], ";", 
  RowBox[{"winners", "//", "TableForm"}]}]}], "Input",
 CellChangeTimes->{{3.585933003696225*^9, 3.5859330453396883`*^9}, {
  3.586010008114491*^9, 3.586010021812667*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {"a1", 
     RowBox[{
      RowBox[{"cv", "[", 
       RowBox[{"\<\"rf\"\>", ",", "3", ",", "300"}], "]"}], "\[Rule]", 
      "0.5499331021226923`"}]},
    {"a2", 
     RowBox[{
      RowBox[{"cv", "[", 
       RowBox[{"\<\"rf\"\>", ",", "3", ",", "700"}], "]"}], "\[Rule]", 
      "0.832708261075281`"}]},
    {"a3", 
     RowBox[{
      RowBox[{"cv", "[", "\<\"lm\"\>", "]"}], "\[Rule]", 
      "0.9602981831730494`"}]},
    {"a4", 
     RowBox[{
      RowBox[{"cv", "[", 
       RowBox[{"\<\"rf\"\>", ",", "3", ",", "300"}], "]"}], "\[Rule]", 
      "0.9052994221344788`"}]},
    {"a5", 
     RowBox[{
      RowBox[{"cv", "[", 
       RowBox[{"\<\"rf\"\>", ",", "3", ",", "700"}], "]"}], "\[Rule]", 
      "0.8046606245948734`"}]},
    {"a6", 
     RowBox[{
      RowBox[{"cv", "[", "\<\"lm\"\>", "]"}], "\[Rule]", 
      "0.8625951568970727`"}]},
    {"a7", 
     RowBox[{
      RowBox[{"cv", "[", 
       RowBox[{"\<\"rf\"\>", ",", "3", ",", "500"}], "]"}], "\[Rule]", 
      "1.075990585320287`"}]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.586014352483602*^9, 3.586086851442689*^9, 3.586090161725659*^9, {
   3.5860909700120077`*^9, 3.586090989121566*^9}, 3.586092099668215*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Statistical Significance of Model Differences", "Title",
 CellChangeTimes->CompressedData["
1:eJwdyksowwEcwPGZ8k7JYy5k3k6zltfyfiRG2BTJPBYmJq8QF1GcZEUxbEWJ
iP80QzmMHVZiGA7CLAcRzSOPDCm/3+/w7XP5cmWt4no2i8UKhVB+TZ3H/OZj
xrxxl8y5vVw1gb6lRQzqthOXvA8+D7NT0UWDQY6WmmYb0X11yeIBOKbdIr/n
rD/oSAX/F1XYY3VmUHU4sI6OCHStR6DEUdWGdp4bT9Dhv51T1LH0YEf3PCVP
6F1h7NQxaKtfIKdlwa4WMKzgilTp5doX8KbnmrR0Co9fQcbwTrKZpq438Evk
1o2a8gIn0Nc+LmkNicr8xO+sl4xMEIx+geViJdlnV/AcoJgxkk623NGgrceM
U6deJfpT5rMSDn5kDZHZ9y68CHB5WUpWdYjMqLc06BBN3xjjT4KK/AuykqdI
RLfVGtIruH8BHazYJZuFSQ0qUKAPlKOhM80BalDvHMNB63Rr1WhbS1oN6he9
N4lWF9+R+ZVl3howvl1Jhtu+/dEPqYyDJj9xU1CZsyEdrf11X0VXxh0M+g/O
4zO3
  "]],

Cell[TextData[{
 "In order to tell if the differences between the best scores are \
significant, we can carry out a ",
 StyleBox["SignedRankTest ", "Input"],
 "(or Wilcoxon test) of the NMSE results between each pair of models."
}], "Text",
 CellChangeTimes->{{3.575222728751422*^9, 3.575222744878726*^9}, {
  3.5753002306550827`*^9, 3.575300271334462*^9}, {3.585936677707251*^9, 
  3.585936752801619*^9}, {3.5859367877935038`*^9, 3.585936815408573*^9}, {
  3.585938570966283*^9, 3.585938577381104*^9}, {3.586023717164174*^9, 
  3.586023718690885*^9}}],

Cell[CellGroupData[{

Cell["Rank test code", "Subsubsection",
 CellChangeTimes->{{3.586015574224124*^9, 3.586015575951926*^9}},
 FontColor->GrayLevel[0.5]],

Cell[BoxData[
 RowBox[{
  RowBox[{"compareRes", "[", 
   RowBox[{"res_", ",", "against_", ",", "cols_"}], "]"}], ":=", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"oneCompSet", ",", "\[IndentingNewLine]", 
      RowBox[{"colToNum", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Rule", "[", 
          RowBox[{
           RowBox[{"responseColumns", "[", 
            RowBox[{"[", "i", "]"}], "]"}], ",", "i"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "@", "responseColumns"}]}], "}"}]}], "]"}]}], 
      ",", "\[IndentingNewLine]", "ws"}], "\[IndentingNewLine]", "}"}], ",", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ws", "=", 
      RowBox[{"res", "[", 
       RowBox[{"[", 
        RowBox[{"cols", "/.", "colToNum"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"oneCompSet", "[", "scores_", "]"}], ":=", 
      RowBox[{"Module", "[", 
       RowBox[{
        RowBox[{"{", "\[IndentingNewLine]", 
         RowBox[{"keys", ",", "againstNmses", ",", "nmses"}], 
         "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"keys", "=", 
          RowBox[{"Complement", "[", 
           RowBox[{
            RowBox[{"scores", "[", 
             RowBox[{"[", 
              RowBox[{"All", ",", "1"}], "]"}], "]"}], ",", 
            RowBox[{"{", "against", "}"}]}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"againstNmses", "=", 
          RowBox[{"Flatten", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", 
               RowBox[{"All", ",", "All", ",", 
                RowBox[{"-", "1"}]}], "]"}], "]"}], "&"}], "@", 
            RowBox[{"(", 
             RowBox[{"against", "/.", "scores"}], ")"}]}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"nmses", "=", 
          RowBox[{
           RowBox[{
            RowBox[{"Rule", "[", 
             RowBox[{"#", ",", 
              RowBox[{"Flatten", "[", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"#", "/.", "scores"}], ")"}], "[", 
                RowBox[{"[", 
                 RowBox[{"All", ",", "All", ",", 
                  RowBox[{"-", "1"}]}], "]"}], "]"}], "]"}]}], "]"}], "&"}], "/@",
            "keys"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"Prepend", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Rule", "[", 
              RowBox[{
               RowBox[{"First", "@", "#"}], ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Mean", "@", 
                  RowBox[{"Last", "@", "#"}]}], ",", 
                 RowBox[{"StandardDeviation", "@", 
                  RowBox[{"Last", "@", "#"}]}], ",", 
                 RowBox[{"SignedRankTest", "[", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Last", "@", "#"}], ",", "againstNmses"}], "}"}], 
                  "]"}]}], "}"}]}], "]"}], "&"}], "/@", "nmses"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Rule", "[", 
            RowBox[{"against", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Mean", "@", "againstNmses"}], ",", 
               RowBox[{"StandardDeviation", "@", "againstNmses"}], ",", 
               RowBox[{"Missing", "[", "]"}]}], "}"}]}], "]"}]}], 
          "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", "]"}]}], 
     ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"MapThread", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Rule", "[", 
         RowBox[{"#1", ",", 
          RowBox[{"oneCompSet", "[", "#2", "]"}]}], "]"}], "&"}], ",", 
       RowBox[{"{", 
        RowBox[{"cols", ",", "ws"}], "}"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.5753005215449266`*^9, 3.5753005492007627`*^9}, {
   3.575300602144794*^9, 3.575300703699099*^9}, {3.57530073555089*^9, 
   3.575300801157983*^9}, {3.575300835974947*^9, 3.5753008966585817`*^9}, {
   3.5753009899375*^9, 3.575301009508411*^9}, {3.575301060071377*^9, 
   3.575301143047574*^9}, {3.575301185045972*^9, 3.575301226703388*^9}, 
   3.575301258181151*^9, {3.575301327146097*^9, 3.575301363002976*^9}, {
   3.575301511719687*^9, 3.5753015443837*^9}, {3.575301590758811*^9, 
   3.5753016022620993`*^9}, {3.575301697972097*^9, 3.575301781458741*^9}, {
   3.575302933408373*^9, 3.575302937282008*^9}, {3.57530313546032*^9, 
   3.575303234754698*^9}, 3.575303281674528*^9, {3.5753034159348097`*^9, 
   3.5753034206073427`*^9}, {3.575303699059928*^9, 3.575303728351921*^9}, {
   3.575303766289557*^9, 3.575303804342149*^9}, {3.575303960891095*^9, 
   3.5753039970113773`*^9}, {3.575304042201611*^9, 3.575304067592774*^9}, {
   3.5753042517174683`*^9, 3.575304336931703*^9}, {3.5753044167313747`*^9, 
   3.575304417969329*^9}, {3.585936779092971*^9, 3.585936782580834*^9}, {
   3.585936941707456*^9, 3.585936947073675*^9}, {3.585937208127844*^9, 
   3.585937212837205*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Comparsion", "Subsubsection",
 CellChangeTimes->{{3.586015590824007*^9, 3.586015593127956*^9}}],

Cell["\<\
Compare a high-performing model against the rest, for all response columns.  \
Wilcoxon results greater than ~0.05 indicate a high likelihood that the null \
hypothesis is true, that is, that the models have similar performance.\
\>", "Text",
 CellChangeTimes->{{3.575305307858095*^9, 3.575305397624065*^9}, {
  3.585936982365521*^9, 3.585937003789043*^9}, {3.585937344453732*^9, 
  3.585937356093685*^9}, {3.586015599497114*^9, 3.586015602975865*^9}, {
  3.5860978507395077`*^9, 3.586097851131044*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"compRes", "=", 
   RowBox[{"compareRes", "[", 
    RowBox[{"resAllAll", ",", 
     RowBox[{"cv", "[", 
      RowBox[{"\"\<rf\>\"", ",", "3", ",", "300"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"a1", ",", "a4"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.575300899373695*^9, 3.575300946425009*^9}, {
   3.5753033854206676`*^9, 3.575303386124199*^9}, {3.57530342190711*^9, 
   3.5753034225557117`*^9}, {3.575303722901264*^9, 3.5753037230928173`*^9}, {
   3.575303833811925*^9, 3.575303860985921*^9}, {3.575304431478208*^9, 
   3.575304432741704*^9}, 3.5753052925177593`*^9, {3.5859370211669693`*^9, 
   3.5859370234384747`*^9}, {3.585937309744917*^9, 3.5859373405432053`*^9}, {
   3.585938470541215*^9, 3.585938472423334*^9}, {3.586014487928994*^9, 
   3.5860144936630077`*^9}, {3.586014608694973*^9, 3.586014609012815*^9}, {
   3.586015636761981*^9, 3.58601565870284*^9}}],

Cell["\<\
Green here indicates statistical significance where the reference model is \
losing;  red indicates statistical significance where the reference model is \
winning.\
\>", "Text",
 CellChangeTimes->{{3.5859385154225683`*^9, 3.5859385579490433`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"conf", "=", "0.05"}], "}"}], ",", 
   RowBox[{"Style", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Column", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Labeled", "[", 
          RowBox[{
           RowBox[{"TableForm", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"#", "[", 
                  RowBox[{"[", 
                   RowBox[{"2", ",", "All", ",", "2"}], "]"}], "]"}], "/.", 
                 RowBox[{"{", "\[IndentingNewLine]", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{"x_", ",", "y_", ",", "z_"}], "}"}], 
                    "\[RuleDelayed]", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"x", ",", "y", ",", 
                    RowBox[{"Style", "[", 
                    RowBox[{"z", ",", 
                    RowBox[{"{", 
                    RowBox[{"Red", ",", "Bold"}], "}"}]}], "]"}]}], "}"}], "/;", 
                    RowBox[{
                    RowBox[{"z", "\[GreaterEqual]", "conf"}], "&&", 
                    RowBox[{"x", ">", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", ",", "1", ",", "2", ",", "1"}], "]"}], 
                    "]"}]}]}]}]}], ",", "\[IndentingNewLine]", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{"x_", ",", "y_", ",", "z_"}], "}"}], 
                    "\[RuleDelayed]", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"x", ",", "y", ",", 
                    RowBox[{"Style", "[", 
                    RowBox[{"z", ",", 
                    RowBox[{"{", 
                    RowBox[{"Green", ",", "Bold"}], "}"}]}], "]"}]}], "}"}], "/;", 
                    RowBox[{
                    RowBox[{"z", "\[GreaterEqual]", "conf"}], "&&", 
                    RowBox[{"x", "\[LessEqual]", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", ",", "1", ",", "2", ",", "1"}], "]"}], 
                    "]"}]}]}]}]}]}], "\[IndentingNewLine]", "}"}]}], ")"}], 
               "\[Transpose]"}], "/.", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Missing", "[", "]"}], "\[Rule]", "\"\<n/a\>\""}], 
               "}"}]}], ",", 
             RowBox[{"TableHeadings", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"\[Mu]", ",", "\[Sigma]", ",", "\"\<wil\>\""}], 
                 "}"}], ",", 
                RowBox[{"#", "[", 
                 RowBox[{"[", 
                  RowBox[{"2", ",", "All", ",", "1"}], "]"}], "]"}]}], 
               "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
           RowBox[{"Style", "[", 
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "1", "]"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"14", ",", "Bold"}], "}"}]}], "]"}], ",", 
           "\[IndentingNewLine]", "Left"}], "]"}], "&"}], "/@", "compRes"}], 
       ",", "Left", ",", "1"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"FontFamily", "\[Rule]", "\"\<Verdana\>\""}], ",", "11"}], 
      "}"}]}], "\[IndentingNewLine]", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.575304506818589*^9, 3.575304547443267*^9}, {
   3.575304578507443*^9, 3.575304597642243*^9}, {3.5753046406261663`*^9, 
   3.5753047863755302`*^9}, {3.57530489498139*^9, 3.5753049474692297`*^9}, {
   3.575305040716173*^9, 3.575305111905018*^9}, 3.5753051513123283`*^9, {
   3.575305200017671*^9, 3.575305268134306*^9}, {3.585937233493952*^9, 
   3.585937245594994*^9}, {3.5859373907209044`*^9, 3.58593739487873*^9}, {
   3.5859383787580547`*^9, 3.585938453857995*^9}, {3.586086391234371*^9, 
   3.58608641056962*^9}}],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {
      TemplateBox[{TagBox[
         TagBox[
          GridBox[{{
             StyleBox["\[Null]", ShowStringCharacters -> False], 
             TagBox[
              RowBox[{"cv", "[", 
                RowBox[{"\"rf\"", ",", "3", ",", "300"}], "]"}], HoldForm], 
             TagBox[
              RowBox[{"cv", "[", "\"lm\"", "]"}], HoldForm], 
             TagBox[
              RowBox[{"cv", "[", 
                RowBox[{"\"cart\"", ",", "3"}], "]"}], HoldForm], 
             TagBox[
              RowBox[{"cv", "[", 
                RowBox[{"\"cart\"", ",", "4"}], "]"}], HoldForm], 
             TagBox[
              RowBox[{"cv", "[", 
                RowBox[{"\"rf\"", ",", "3", ",", "500"}], "]"}], HoldForm], 
             TagBox[
              RowBox[{"cv", "[", 
                RowBox[{"\"rf\"", ",", "3", ",", "700"}], "]"}], HoldForm], 
             TagBox[
              RowBox[{"cv", "[", 
                RowBox[{"\"rf\"", ",", "4", ",", "300"}], "]"}], HoldForm], 
             TagBox[
              RowBox[{"cv", "[", 
                RowBox[{"\"rf\"", ",", "4", ",", "500"}], "]"}], HoldForm], 
             TagBox[
              RowBox[{"cv", "[", 
                RowBox[{"\"rf\"", ",", "4", ",", "700"}], "]"}], HoldForm]}, {
             TagBox["\[Mu]", HoldForm], "0.6273991369012661`", 
             "0.833917745195386`", "0.8140115824730422`", 
             "0.7474367351797861`", "0.6270750815413239`", 
             "0.6243529996943323`", "0.6320101534246046`", 
             "0.6347765108004327`", "0.6365762397671192`"}, {
             TagBox["\[Sigma]", HoldForm], "0.29418560692556495`", 
             "0.37792622121820296`", "0.3678141797537116`", 
             "0.3347748241616263`", "0.28399021462455265`", 
             "0.28487053769396486`", "0.2984836285224371`", 
             "0.29344687524378305`", "0.3050400455224411`"}, {
             TagBox["\"wil\"", HoldForm], "\"n/a\"", "0.019037763894019694`", 
             "0.0483180364909149`", 
             StyleBox[
             "0.061245505944533096`", StripOnInput -> False, LineColor -> 
              RGBColor[1, 0, 0], FrontFaceColor -> RGBColor[1, 0, 0], 
              BackFaceColor -> RGBColor[1, 0, 0], GraphicsColor -> 
              RGBColor[1, 0, 0], FontWeight -> Bold, FontColor -> 
              RGBColor[1, 0, 0]], 
             StyleBox[
             "0.8693007747525945`", StripOnInput -> False, LineColor -> 
              RGBColor[0, 1, 0], FrontFaceColor -> RGBColor[0, 1, 0], 
              BackFaceColor -> RGBColor[0, 1, 0], GraphicsColor -> 
              RGBColor[0, 1, 0], FontWeight -> Bold, FontColor -> 
              RGBColor[0, 1, 0]], 
             StyleBox[
             "0.9017824101433668`", StripOnInput -> False, LineColor -> 
              RGBColor[0, 1, 0], FrontFaceColor -> RGBColor[0, 1, 0], 
              BackFaceColor -> RGBColor[0, 1, 0], GraphicsColor -> 
              RGBColor[0, 1, 0], FontWeight -> Bold, FontColor -> 
              RGBColor[0, 1, 0]], 
             StyleBox[
             "0.4466400111310985`", StripOnInput -> False, LineColor -> 
              RGBColor[1, 0, 0], FrontFaceColor -> RGBColor[1, 0, 0], 
              BackFaceColor -> RGBColor[1, 0, 0], GraphicsColor -> 
              RGBColor[1, 0, 0], FontWeight -> Bold, FontColor -> 
              RGBColor[1, 0, 0]], 
             StyleBox[
             "0.10418412202320379`", StripOnInput -> False, LineColor -> 
              RGBColor[1, 0, 0], FrontFaceColor -> RGBColor[1, 0, 0], 
              BackFaceColor -> RGBColor[1, 0, 0], GraphicsColor -> 
              RGBColor[1, 0, 0], FontWeight -> Bold, FontColor -> 
              RGBColor[1, 0, 0]], 
             StyleBox[
             "0.12799477092947156`", StripOnInput -> False, LineColor -> 
              RGBColor[1, 0, 0], FrontFaceColor -> RGBColor[1, 0, 0], 
              BackFaceColor -> RGBColor[1, 0, 0], GraphicsColor -> 
              RGBColor[1, 0, 0], FontWeight -> Bold, FontColor -> 
              RGBColor[1, 0, 0]]}}, 
           GridBoxAlignment -> {
            "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
           GridBoxDividers -> {
            "Columns" -> {False, True, {False}, False}, 
             "ColumnsIndexed" -> {}, "Rows" -> {False, True, {False}, False}, 
             "RowsIndexed" -> {}}, GridBoxSpacings -> {"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[2.0999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], {
          OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}], 
         Function[BoxForm`e$, 
          TableForm[
          BoxForm`e$, 
           TableHeadings -> {{$CellContext`\[Mu], $CellContext`\[Sigma], 
              "wil"}, {
              $CellContext`cv["rf", 3, 300], 
              $CellContext`cv["lm"], 
              $CellContext`cv["cart", 3], 
              $CellContext`cv["cart", 4], 
              $CellContext`cv["rf", 3, 500], 
              $CellContext`cv["rf", 3, 700], 
              $CellContext`cv["rf", 4, 300], 
              $CellContext`cv["rf", 4, 500], 
              $CellContext`cv["rf", 4, 700]}}]]],StyleBox[
        "a1", StripOnInput -> False, FontSize -> 14, FontWeight -> Bold]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"], 
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {1, 2}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Left"}], "]"}]& )]},
     {
      TemplateBox[{TagBox[
         TagBox[
          GridBox[{{
             StyleBox["\[Null]", ShowStringCharacters -> False], 
             TagBox[
              RowBox[{"cv", "[", 
                RowBox[{"\"rf\"", ",", "3", ",", "300"}], "]"}], HoldForm], 
             TagBox[
              RowBox[{"cv", "[", "\"lm\"", "]"}], HoldForm], 
             TagBox[
              RowBox[{"cv", "[", 
                RowBox[{"\"cart\"", ",", "3"}], "]"}], HoldForm], 
             TagBox[
              RowBox[{"cv", "[", 
                RowBox[{"\"cart\"", ",", "4"}], "]"}], HoldForm], 
             TagBox[
              RowBox[{"cv", "[", 
                RowBox[{"\"rf\"", ",", "3", ",", "500"}], "]"}], HoldForm], 
             TagBox[
              RowBox[{"cv", "[", 
                RowBox[{"\"rf\"", ",", "3", ",", "700"}], "]"}], HoldForm], 
             TagBox[
              RowBox[{"cv", "[", 
                RowBox[{"\"rf\"", ",", "4", ",", "300"}], "]"}], HoldForm], 
             TagBox[
              RowBox[{"cv", "[", 
                RowBox[{"\"rf\"", ",", "4", ",", "500"}], "]"}], HoldForm], 
             TagBox[
              RowBox[{"cv", "[", 
                RowBox[{"\"rf\"", ",", "4", ",", "700"}], "]"}], HoldForm]}, {
             TagBox["\[Mu]", HoldForm], "0.9861291562113971`", 
             "2.433204155159749`", "1.9511239094496438`", 
             "1.818105843074517`", "1.002428256116002`", "0.988991638223574`",
              "1.0082324033527987`", "1.0267381413005523`", 
             "1.0161152540117266`"}, {
             TagBox["\[Sigma]", HoldForm], "0.3159614115380702`", 
             "3.098356800271478`", "1.5198468835415258`", 
             "1.3000026555984139`", "0.3391289542038747`", 
             "0.3509570412736162`", "0.3605486428186938`", 
             "0.36130020650835704`", "0.36254010023756844`"}, {
             TagBox["\"wil\"", HoldForm], "\"n/a\"", "0.0005088586376075486`",
              "0.00008545858316095966`", "0.00027200759312066695`", 
             StyleBox[
             "0.06414789866383097`", StripOnInput -> False, LineColor -> 
              RGBColor[1, 0, 0], FrontFaceColor -> RGBColor[1, 0, 0], 
              BackFaceColor -> RGBColor[1, 0, 0], GraphicsColor -> 
              RGBColor[1, 0, 0], FontWeight -> Bold, FontColor -> 
              RGBColor[1, 0, 0]], 
             StyleBox[
             "0.967186933958065`", StripOnInput -> False, LineColor -> 
              RGBColor[1, 0, 0], FrontFaceColor -> RGBColor[1, 0, 0], 
              BackFaceColor -> RGBColor[1, 0, 0], GraphicsColor -> 
              RGBColor[1, 0, 0], FontWeight -> Bold, FontColor -> 
              RGBColor[1, 0, 0]], 
             StyleBox[
             "0.3440753429639739`", StripOnInput -> False, LineColor -> 
              RGBColor[1, 0, 0], FrontFaceColor -> RGBColor[1, 0, 0], 
              BackFaceColor -> RGBColor[1, 0, 0], GraphicsColor -> 
              RGBColor[1, 0, 0], FontWeight -> Bold, FontColor -> 
              RGBColor[1, 0, 0]], "0.039702202566217155`", 
             StyleBox[
             "0.08041056244281557`", StripOnInput -> False, LineColor -> 
              RGBColor[1, 0, 0], FrontFaceColor -> RGBColor[1, 0, 0], 
              BackFaceColor -> RGBColor[1, 0, 0], GraphicsColor -> 
              RGBColor[1, 0, 0], FontWeight -> Bold, FontColor -> 
              RGBColor[1, 0, 0]]}}, 
           GridBoxAlignment -> {
            "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
           GridBoxDividers -> {
            "Columns" -> {False, True, {False}, False}, 
             "ColumnsIndexed" -> {}, "Rows" -> {False, True, {False}, False}, 
             "RowsIndexed" -> {}}, GridBoxSpacings -> {"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[2.0999999999999996`]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], {
          OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}], 
         Function[BoxForm`e$, 
          TableForm[
          BoxForm`e$, 
           TableHeadings -> {{$CellContext`\[Mu], $CellContext`\[Sigma], 
              "wil"}, {
              $CellContext`cv["rf", 3, 300], 
              $CellContext`cv["lm"], 
              $CellContext`cv["cart", 3], 
              $CellContext`cv["cart", 4], 
              $CellContext`cv["rf", 3, 500], 
              $CellContext`cv["rf", 3, 700], 
              $CellContext`cv["rf", 4, 300], 
              $CellContext`cv["rf", 4, 500], 
              $CellContext`cv["rf", 4, 700]}}]]],StyleBox[
        "a4", StripOnInput -> False, FontSize -> 14, FontWeight -> Bold]},
       "Labeled",
       DisplayFunction->(GridBox[{{
           ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"], 
           TagBox[
            ItemBox[
             PaneBox[
              TagBox[#, "SkipImageSizeLevel"], 
              Alignment -> {Center, Baseline}, BaselinePosition -> Baseline], 
             DefaultBaseStyle -> "Labeled"], "SkipImageSizeLevel"]}}, 
         GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
         AutoDelete -> False, 
         GridBoxItemSize -> {
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
         BaselinePosition -> {1, 2}]& ),
       InterpretationFunction->(RowBox[{"Labeled", "[", 
          RowBox[{#, ",", #2, ",", "Left"}], "]"}]& )]}
    },
    DefaultBaseStyle->"Column",
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
   "Column"],
  StripOnInput->False,
  FontFamily->"Verdana",
  FontSize->11]], "Output",
 CellChangeTimes->{{3.575304527480695*^9, 3.5753045404091682`*^9}, {
   3.5753045837259407`*^9, 3.575304598248701*^9}, {3.575304643483485*^9, 
   3.5753046735824547`*^9}, 3.575304713784788*^9, {3.575304762392561*^9, 
   3.575304786867095*^9}, 3.575304918683786*^9, {3.575305065265883*^9, 
   3.575305112700451*^9}, 3.575305151674509*^9, {3.575305201976677*^9, 
   3.575305268333089*^9}, 3.585937261600143*^9, {3.585937362370064*^9, 
   3.585937395017638*^9}, 3.585938416649984*^9, {3.585938454771579*^9, 
   3.58593847375281*^9}, 3.5859418469258633`*^9, 3.5860095201683083`*^9, 
   3.586014498173914*^9, 3.586014612310528*^9, {3.5860156418205137`*^9, 
   3.586015659859309*^9}, 3.5860864123730383`*^9, 3.586086861048627*^9}]
}, {2}]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Test Samples and Solutions", "Title",
 CellChangeTimes->CompressedData["
1:eJwdyk1I0wEYx/E5wZd8gUjTi+LMl7w4x6hM1DSN0CnlFAxxvgxtkZP5Qope
MkHpIA6MdNmEfEFJ9D+ZM8HDdIeB+K4dolrDQIxklqjhX4fQ83sOXz6Xr0xr
UNdKJRJJPAUVVTVXxj4dZI85ltgHe9+mneS1kkcCDFi8lb5C/umWZsIJu10H
S5wfnsEVc9HEKtlnmWfPh10XsKdM4YV6T4p1jTStv5qFPUqrYYMsFisaYPMX
xzbsvlzcgeLH3x64HFR8CPcLU95tku7acXZQG+2/Rd4o+M6abDrLX3K39Qe7
1Zy2eUQK9hNWKjx/cUyeqQJaoDMvsh8etctYV0zi/X/4PrexCXeUvWfkE7WR
bffo5SKpFhysj/thb9T8QfaOT5sRXpRenYojT3O62NxffvJ4cnJSw1Y0qdZg
qCZqHWbN9SkGSH3+V7Zcrk+FC+YhNjj65TjsLFti69LuPjWRSlukDsa+r7tu
Jm2+SRGwxjpTCRvq71XBsJvLA7Dy8T6bX14aOkTebjSyce7zcHiq0UbA9ENZ
BtT62rNgtTdwGk69EQVoEX++HSE7DCH9sCBXeO0kW7a9bOaoywJVeckz8D9U
8lB7
  "]],

Cell["Import test samples (feature measurements):", "Text",
 CellChangeTimes->{{3.5860105554298697`*^9, 3.586010587700816*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"evalRaw", "=", 
   RowBox[{
    RowBox[{"Import", "[", 
     RowBox[{
      RowBox[{"FileNameJoin", "[", 
       RowBox[{"{", 
        RowBox[{"\"\<algae\>\"", ",", "\"\<Eval.txt\>\""}], "}"}], "]"}], 
      ",", "\"\<Data\>\""}], "]"}], "/.", 
    RowBox[{"\"\<XXXXXXX\>\"", "\[Rule]", 
     RowBox[{"Missing", "[", "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Dimensions", "@", "evalRaw"}]}], "Input",
 CellChangeTimes->{{3.5741685507355185`*^9, 3.574168670263502*^9}, {
  3.5751302678824663`*^9, 3.575130284458878*^9}, {3.5752884575597343`*^9, 
  3.57528848097966*^9}, {3.575288889171562*^9, 3.575288893750214*^9}, {
  3.586010430628137*^9, 3.586010434368964*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"140", ",", "11"}], "}"}]], "Output",
 CellChangeTimes->{
  3.5741686714152994`*^9, 3.574617412252535*^9, 3.5746874129830294`*^9, 
   3.574689285584136*^9, 3.5747726802614384`*^9, 3.5750219978942137`*^9, 
   3.5751091998448315`*^9, 3.575130251563386*^9, 3.575130285900194*^9, 
   3.575130411999001*^9, 3.575204921214242*^9, {3.575288465455359*^9, 
   3.5752884813010263`*^9}, 3.575288847940681*^9, 3.5752888944236393`*^9, 
   3.586010446840612*^9, {3.586010499881103*^9, 3.586010525406272*^9}, 
   3.586086972041636*^9, 3.5860901740671587`*^9, 3.586092167472414*^9}]
}, Open  ]],

Cell["Import solutions (a1-a7 measurements):", "Text",
 CellChangeTimes->{{3.586010562030608*^9, 3.586010596733164*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"solsRaw", "=", 
   RowBox[{
    RowBox[{"Import", "[", 
     RowBox[{
      RowBox[{"FileNameJoin", "[", 
       RowBox[{"{", 
        RowBox[{"\"\<algae\>\"", ",", "\"\<Sols.txt\>\""}], "}"}], "]"}], 
      ",", "\"\<Data\>\""}], "]"}], "/.", 
    RowBox[{"\"\<XXXXXXX\>\"", "\[Rule]", 
     RowBox[{"Missing", "[", "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Dimensions", "@", "solsRaw"}]}], "Input",
 CellChangeTimes->{{3.575288740150819*^9, 3.575288752086474*^9}, {
  3.5752888449246483`*^9, 3.575288846219739*^9}, {3.586010479169756*^9, 
  3.586010507610688*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"140", ",", "7"}], "}"}]], "Output",
 CellChangeTimes->{{3.586010509398683*^9, 3.586010526268001*^9}, 
   3.5860105995239563`*^9, 3.586086973216548*^9, 3.586090175507012*^9, 
   3.586092168686276*^9}]
}, Open  ]],

Cell["Construct columnized representation:", "Text",
 CellChangeTimes->{{3.586010607796616*^9, 3.586010616036563*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"testMed", "=", 
   RowBox[{"columnize", "[", 
    RowBox[{"Join", "[", 
     RowBox[{"evalRaw", ",", "solsRaw", ",", "2"}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.5752887649012623`*^9, 3.575288786724833*^9}, {
  3.575288863747169*^9, 3.5752889018048487`*^9}, {3.586010533015088*^9, 
  3.5860105334079037`*^9}, {3.586010618992114*^9, 3.586010626638136*^9}, {
  3.586015491046028*^9, 3.586015496429686*^9}}],

Cell["Glance at the statistical summary:", "Text",
 CellChangeTimes->{{3.586010719107027*^9, 3.5860107252825537`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Style", "[", 
  RowBox[{
   RowBox[{"stylize", "@", 
    RowBox[{"summaryStats", "[", "testMed", "]"}]}], ",", "11"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5860107263726273`*^9, 3.5860107372521677`*^9}, {
  3.58608697609932*^9, 3.5860869808033457`*^9}}],

Cell[BoxData[
 StyleBox[
  StyleBox[
   TagBox[GridBox[{
      {
       StyleBox["\<\"\"\>",
        StripOnInput->False,
        ShowContents->False], 
       StyleBox["season",
        StripOnInput->False,
        FontWeight->Bold], 
       StyleBox["size",
        StripOnInput->False,
        FontWeight->Bold], 
       StyleBox["speed",
        StripOnInput->False,
        FontWeight->Bold], 
       StyleBox["mxPH",
        StripOnInput->False,
        FontWeight->Bold], 
       StyleBox["mnO2",
        StripOnInput->False,
        FontWeight->Bold], 
       StyleBox["Cl",
        StripOnInput->False,
        FontWeight->Bold], 
       StyleBox["NO3",
        StripOnInput->False,
        FontWeight->Bold], 
       StyleBox["NH4",
        StripOnInput->False,
        FontWeight->Bold], 
       StyleBox["oPO4",
        StripOnInput->False,
        FontWeight->Bold], 
       StyleBox["PO4",
        StripOnInput->False,
        FontWeight->Bold], 
       StyleBox["Chla",
        StripOnInput->False,
        FontWeight->Bold], 
       StyleBox["a1",
        StripOnInput->False,
        FontWeight->Bold], 
       StyleBox["a2",
        StripOnInput->False,
        FontWeight->Bold], 
       StyleBox["a3",
        StripOnInput->False,
        FontWeight->Bold], 
       StyleBox["a4",
        StripOnInput->False,
        FontWeight->Bold], 
       StyleBox["a5",
        StripOnInput->False,
        FontWeight->Bold], 
       StyleBox["a6",
        StripOnInput->False,
        FontWeight->Bold], 
       StyleBox["a7",
        StripOnInput->False,
        FontWeight->Bold]},
      {"\<\"Not Missing\"\>", 
       ItemBox[
        FrameBox[
         StyleBox[
          TagBox[GridBox[{
             {"\<\"summer\"\>", "41"},
             {"\<\"winter\"\>", "28"},
             {"\<\"spring\"\>", "31"},
             {"\<\"autumn\"\>", "40"}
            },
            AutoDelete->False,
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Grid"],
          StripOnInput->False,
          LineColor->RGBColor[0.6, 0.4, 0.2],
          FrontFaceColor->RGBColor[0.6, 0.4, 0.2],
          BackFaceColor->RGBColor[0.6, 0.4, 0.2],
          GraphicsColor->RGBColor[0.6, 0.4, 0.2],
          FontSize->Smaller,
          FontColor->RGBColor[0.6, 0.4, 0.2]],
         StripOnInput->False],
        Alignment->Center,
        StripOnInput->False], 
       ItemBox[
        FrameBox[
         StyleBox[
          TagBox[GridBox[{
             {"\<\"small\"\>", "50"},
             {"\<\"medium\"\>", "52"},
             {"\<\"large\"\>", "38"}
            },
            AutoDelete->False,
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Grid"],
          StripOnInput->False,
          LineColor->RGBColor[0.6, 0.4, 0.2],
          FrontFaceColor->RGBColor[0.6, 0.4, 0.2],
          BackFaceColor->RGBColor[0.6, 0.4, 0.2],
          GraphicsColor->RGBColor[0.6, 0.4, 0.2],
          FontSize->Smaller,
          FontColor->RGBColor[0.6, 0.4, 0.2]],
         StripOnInput->False],
        Alignment->Center,
        StripOnInput->False], 
       ItemBox[
        FrameBox[
         StyleBox[
          TagBox[GridBox[{
             {"\<\"medium\"\>", "57"},
             {"\<\"high\"\>", "58"},
             {"\<\"low\"\>", "25"}
            },
            AutoDelete->False,
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
           "Grid"],
          StripOnInput->False,
          LineColor->RGBColor[0.6, 0.4, 0.2],
          FrontFaceColor->RGBColor[0.6, 0.4, 0.2],
          BackFaceColor->RGBColor[0.6, 0.4, 0.2],
          GraphicsColor->RGBColor[0.6, 0.4, 0.2],
          FontSize->Smaller,
          FontColor->RGBColor[0.6, 0.4, 0.2]],
         StripOnInput->False],
        Alignment->Center,
        StripOnInput->False], "139", "140", "134", "140", "140", "140", "135",
        "129", "140", "140", "140", "140", "140", "140", "140"},
      {"\<\"Missing\"\>", "\[SpanFromAbove]", "\[SpanFromAbove]", 
       "\[SpanFromAbove]", "1", "0", "6", "0", "0", "0", "5", "11", "0", "0", 
       "0", "0", "0", "0", "0"},
      {"\[Mu]", "\[SpanFromAbove]", "\[SpanFromAbove]", "\[SpanFromAbove]", 
       "7.976618705035971`", "9.21178571428571`", "40.930556791044786`", 
       "2.892228571428572`", "429.9261215714285`", "72.38655692857147`", 
       "134.93097740740743`", "11.083790697674415`", "16.385`", 
       "6.832857142857144`", "3.3257142857142856`", "1.5492857142857144`", 
       "6.160000000000001`", "7.050714285714286`", "1.7935714285714286`"},
      {"\[Sigma]", "\[SpanFromAbove]", "\[SpanFromAbove]", "\[SpanFromAbove]",
        "0.5499124488377369`", "2.2050883823319123`", "41.06348721128375`", 
       "2.4213553501194123`", "1367.7678217508856`", "140.76364580137084`", 
       "175.7579150900485`", "13.72670530314131`", "20.560813202992367`", 
       "10.38013073521545`", "5.5533951172100116`", "2.7765331218577`", 
       "9.580899763997627`", "13.397795891038346`", "4.615351467388276`"},
      {"Min", "\[SpanFromAbove]", "\[SpanFromAbove]", "\[SpanFromAbove]", 
       "5.9`", "1.8`", "0.5`", "0.`", "5.`", "1.`", "2.`", "0.4`", "0", "0", 
       "0", "0", "0", "0", "0"},
      {
       FractionBox["1", "4"], "\[SpanFromAbove]", "\[SpanFromAbove]", 
       "\[SpanFromAbove]", "7.8`", "8.25`", "11.`", "0.981`", 
       "36.888999999999996`", "11.5`", "31.8985`", "2.275`", "1.45`", "0.`", 
       "0.`", "0.`", "0.`", "0.`", "0.`"},
      {
       FractionBox["1", "2"], "\[SpanFromAbove]", "\[SpanFromAbove]", 
       "\[SpanFromAbove]", "8.03`", "9.4`", "32.177499999999995`", "2.174`", 
       "119.72200000000001`", "34.3865`", "89.167`", "4.5`", "7.4`", "2.25`", 
       "1.`", "0.`", "2.3`", "0.5`", "0.`"},
      {
       FractionBox["3", "4"], "\[SpanFromAbove]", "\[SpanFromAbove]", 
       "\[SpanFromAbove]", "8.344999999999999`", "10.8`", "57.333`", 
       "4.0365`", "285.83349499999997`", "85.34549999999999`", "179.1062475`",
        "16.775`", "27.4`", "8.75`", "3.7`", "2.2`", "8.95`", "8.`", "1.9`"},
      {"Max", "\[SpanFromAbove]", "\[SpanFromAbove]", "\[SpanFromAbove]", 
       "9.13`", "13.2`", "271.5`", "12.13`", "11160.59961`", "1435.`", 
       "1690.`", "63.5`", "83", "55.4`", "24.3`", "19.6`", "61.1`", "70.7`", 
       "30.8`"}
     },
     AutoDelete->False,
     GridBoxAlignment->{"Columns" -> {Center, {Right}}},
     GridBoxBackground->{"Columns" -> {{Automatic}}, "Rows" -> {{
          GrayLevel[1], 
          RGBColor[0.87, 0.94, 1]}}},
     GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}}],
    "Grid"],
   StripOnInput->False,
   FontFamily->"Verdana"],
  StripOnInput->False,
  FontSize->11]], "Output",
 CellChangeTimes->{
  3.586010737685067*^9, {3.586086981188395*^9, 3.586087001175829*^9}}]
}, Open  ]],

Cell["\<\
The test samples evidently have missing data problems as well (matrix is \
transposed to use less vertical space):\
\>", "Text",
 CellChangeTimes->{{3.586010679740528*^9, 3.586010688155147*^9}, {
  3.5860107681851997`*^9, 3.58601078167305*^9}, {3.586023812121784*^9, 
  3.586023821712812*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MatrixPlot", "[", 
  RowBox[{"Transpose", "@", 
   RowBox[{"Replace", "[", 
    RowBox[{
     RowBox[{"testMed", "[", "All", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Except", "[", 
         RowBox[{"Missing", "[", "]"}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{"_", "\[Rule]", "1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"-", "1"}], "}"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.585497180624794*^9, 3.585497254733642*^9}, {
  3.585497297029014*^9, 3.585497298348521*^9}, {3.585498039911702*^9, 
  3.58549804138175*^9}, {3.585573603952903*^9, 3.585573604430615*^9}, {
  3.585574499909071*^9, 3.585574504211855*^9}, {3.5860106676399612`*^9, 
  3.586010668688183*^9}, {3.5860238245375443`*^9, 3.586023826770825*^9}}],

Cell[BoxData[
 GraphicsBox[RasterBox[CompressedData["
1:eJzt3MEJwyAUAFChG2SDTNIdMkIg5yzSITtCRoghOYW09GL/D7wP8sSDyFdR
PNiP8zA9SildLa9atvoey5MkSZIkSZIkSZIkSZIkSZIkSZIkSZIkSZIkSZIk
SZIkSZLkr74PzxE9Ll5rvr7bOj+f+m/dbj2QJMnWRt0r3GeYWeuTJJlB5xF5
330U9V4dnW+SJEmSJEmSJEmSJEmSJElyi2z/M5AkyTw6x0mSJEmSJP+jdxiS
JEmSJEmSJEmSJEmSJEmSJMkoV+dBwGI=
   "], {{0, 0}, {140, 18}}, {0, 1}],
  Frame->True,
  FrameLabel->{None, None},
  FrameTicks->{{{{17.5, 
       FormBox["1", TraditionalForm]}, {13.5, 
       FormBox["5", TraditionalForm]}, {8.5, 
       FormBox["10", TraditionalForm]}, {3.5, 
       FormBox["15", TraditionalForm]}, {0.5, 
       FormBox["18", TraditionalForm]}}, {{17.5, 
       FormBox["1", TraditionalForm]}, {13.5, 
       FormBox["5", TraditionalForm]}, {8.5, 
       FormBox["10", TraditionalForm]}, {3.5, 
       FormBox["15", TraditionalForm]}, {0.5, 
       FormBox["18", TraditionalForm]}}}, {{{0.5, 
       FormBox["1", TraditionalForm]}, {49.5, 
       FormBox["50", TraditionalForm]}, {99.5, 
       FormBox["100", TraditionalForm]}, {139.5, 
       FormBox["140", TraditionalForm]}}, {{0.5, 
       FormBox["1", TraditionalForm]}, {49.5, 
       FormBox["50", TraditionalForm]}, {99.5, 
       FormBox["100", TraditionalForm]}, {139.5, 
       FormBox["140", TraditionalForm]}}}}]], "Output",
 CellChangeTimes->{3.5854972195369463`*^9, 3.5854972554266872`*^9, 
  3.58549729905581*^9, 3.585498041737479*^9, 3.585573604696828*^9, 
  3.585574504900337*^9, 3.585575920891366*^9, 3.585576134360591*^9, 
  3.585576598172202*^9, 3.585576948393236*^9, 3.586000117875361*^9, 
  3.586010669481204*^9, 
  3.58602382718535*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell["\<\
Before we can run our models, it will be necessary to run an imputation on \
the test samples.\
\>", "Text",
 CellChangeTimes->{{3.586010792705078*^9, 3.5860108228084183`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Test Samples Imputation", "Title",
 CellChangeTimes->CompressedData["
1:eJwdym8o3AEcx/FzasxMrf25e0JuY7NH57o2I4zNWvOncRTJYRe7xXFGiCcb
Ne2BXFnjbKdYIhe/0+1QHhz34Fcy5s8erGHXlGg6m/zJj0v5fr4P3r2evFUG
s65cLpPJoimoKS0LGZjYSR3wzLBPNldHRfJq3nMBBk/fS5wj/7XJk+GQ222E
eWLfKzhnyxn6RnY6JtmT/vVT2F6o8UOTL9Y5T1oXWr7Cdq3T/J3MlYprYN1P
zzJsO5tegdLwXx+cvZS7C7eyYnsWSW/5IPvJEBG0RN7KXGOtLqPjP/mn8Te7
VJewuEcK7gNWLlTU75PHGcENUHym7IJ7zSp2PfLOoyN8P5rY23HajmOyQGdh
m30mtUTqBA8b4H3aET65k7oS0GSBp/lXRqLIw8fv2LTtC+po0m7Xs8W1GfMw
TB++AFPGOzXdpCn9F1ukNj2AU7ZeNjTizSBsLZxhKxPiX1pJrUtphDc/V96w
ka7AuwpY5hwrgTVVD0vhtZjZbliSvcWmF+WH9ZL3X1vYKO/JdXioNyhg4q4q
CRoC3Snwhf/iKBz5IAnQIW18/EK+NV/ugplpwnuRbFj2s/ZhxyqsjtGswXNc
31Eb
  "]],

Cell[TextData[{
 "Here, it is important to conduct the imputation without using the test \
samples themselves, the idea being to restrict our inferences to the training \
data alone.  We wrote ",
 StyleBox["knnImpute", "Input"],
 " to accept a source and a destination dataset.  Here, we impute the missing \
test values using the trimmed training set:"
}], "Text",
 CellChangeTimes->{{3.586010865576109*^9, 3.5860109570458193`*^9}, {
  3.5860110002048063`*^9, 3.586011085930893*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"knndTest", "=", 
   RowBox[{"knnImpute", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"trimmed", ",", "testMed"}], "}"}], ",", "columns", ",", 
     "featureColumns"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5752928356058693`*^9, 3.5752928588147707`*^9}, {
  3.575293048746293*^9, 3.5752930572499113`*^9}, {3.575293097929201*^9, 
  3.575293104808391*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MatrixPlot", "[", 
  RowBox[{"Transpose", "@", 
   RowBox[{"Replace", "[", 
    RowBox[{
     RowBox[{"knndTest", "[", "All", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Except", "[", 
         RowBox[{"Missing", "[", "]"}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{"_", "\[Rule]", "1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"-", "1"}], "}"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.585497180624794*^9, 3.585497254733642*^9}, {
  3.585497297029014*^9, 3.585497298348521*^9}, {3.585498039911702*^9, 
  3.58549804138175*^9}, {3.585573603952903*^9, 3.585573604430615*^9}, {
  3.585574499909071*^9, 3.585574504211855*^9}, {3.5860106676399612`*^9, 
  3.586010668688183*^9}, {3.5860111638186283`*^9, 3.586011170885401*^9}, {
  3.586023839089717*^9, 3.586023841706112*^9}}],

Cell[BoxData[
 GraphicsBox[
  RasterBox[SparseArray[
   Automatic, {18, 140}, 1., {
    1, {{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0}, {}}, {}}], {{0, 0}, {140, 18}}, {0, 1}],
  Frame->True,
  FrameLabel->{None, None},
  FrameTicks->{{{{17.5, 
       FormBox["1", TraditionalForm]}, {13.5, 
       FormBox["5", TraditionalForm]}, {8.5, 
       FormBox["10", TraditionalForm]}, {3.5, 
       FormBox["15", TraditionalForm]}, {0.5, 
       FormBox["18", TraditionalForm]}}, {{17.5, 
       FormBox["1", TraditionalForm]}, {13.5, 
       FormBox["5", TraditionalForm]}, {8.5, 
       FormBox["10", TraditionalForm]}, {3.5, 
       FormBox["15", TraditionalForm]}, {0.5, 
       FormBox["18", TraditionalForm]}}}, {{{0.5, 
       FormBox["1", TraditionalForm]}, {49.5, 
       FormBox["50", TraditionalForm]}, {99.5, 
       FormBox["100", TraditionalForm]}, {139.5, 
       FormBox["140", TraditionalForm]}}, {{0.5, 
       FormBox["1", TraditionalForm]}, {49.5, 
       FormBox["50", TraditionalForm]}, {99.5, 
       FormBox["100", TraditionalForm]}, {139.5, 
       FormBox["140", TraditionalForm]}}}}]], "Output",
 CellChangeTimes->{
  3.5854972195369463`*^9, 3.5854972554266872`*^9, 3.58549729905581*^9, 
   3.585498041737479*^9, 3.585573604696828*^9, 3.585574504900337*^9, 
   3.585575920891366*^9, 3.585576134360591*^9, 3.585576598172202*^9, 
   3.585576948393236*^9, 3.586000117875361*^9, 3.586010669481204*^9, {
   3.586011166975569*^9, 3.586011171205845*^9}, 3.586023841930382*^9, 
   3.586087074286599*^9, 3.5860921064070673`*^9, {3.5860921477466173`*^9, 
   3.586092173110865*^9}}]
}, Open  ]],

Cell["\<\
This dataset is suitable for running our final predictions on.\
\>", "Text",
 CellChangeTimes->{{3.586011289071664*^9, 3.5860112992946033`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Solutions Preparation", "Title",
 CellChangeTimes->CompressedData["
1:eJwdyltIkwEYh/E5weygEJmKpLiytKs5RgeHlqeI1MimoMimNrSNXM6SFL2x
BMUL2UBJV01QEcWh32QtBS+mu1iKee4iUhsJYiSzpAw/HYHv/714+N08Mp1J
XSmVSCSJFFSUV5waGN/JGPBMs3e21ka95LnCBwIMnbqWOkf+apXegkNutx4W
ensNcM72cOgT2eGYYA/7No5ge4kiAI3+ZOc8aV149R62K52mRbJALK2BtV88
K7D1/9QqFId/+uHs6YJduH0/+c0S6ascZN/q4k4sk5fy1lmrS+/4TX6v/8Yu
16qW9kjB/ZeVCk9e/CEPckProPdedBfca5SxG/GJmf/wfW5gr9xQmg/IYrWF
bfQb5SKpFjxskO+uOXZiJ2M1qMECj4rOjiSQ+1ktbPaPEPll0m7XsqXPc+dh
uDZ2AaZ/6FB0k8acr6xGbrwJJ2097Jm4pkHYXDLNVqlSHltJpStaDy++q4q0
ka7gq1GwwjlWBmue3i6HEUmz3bAsf5vN0RSF95DXn1nYBN/hebiv1UXB1F1Z
GtQFu9Pho8DJUTjSKQrQIW6+7idfmsK6YF620OYl61YCrH3YsQarkxTr8EK+
KvIjaVg0s5qtmJQZMsYwwx4DhEZhag==
  "]],

Cell["Collect the winning extended models:", "Text",
 CellChangeTimes->{{3.586009801916559*^9, 3.586009823901767*^9}, 
   3.586011343239502*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"winnerEms", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Rule", "[", 
     RowBox[{
      RowBox[{"First", "@", "#"}], ",", 
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "1"}], "]"}], "]"}], "/.", 
       RowBox[{
        RowBox[{"cv", "[", 
         RowBox[{"tag_String", ",", "args___"}], "]"}], "\[RuleDelayed]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"extModel", "[", "tag", "]"}], ",", 
          RowBox[{"{", "args", "}"}]}], "}"}]}]}]}], "]"}], "&"}], "/@", 
   "winners"}]}]], "Input",
 CellChangeTimes->{{3.5752854520748043`*^9, 3.5752854923803873`*^9}, {
   3.5752868159919147`*^9, 3.575286828185996*^9}, {3.575286858328747*^9, 
   3.575286880422285*^9}, {3.575287021349373*^9, 3.575287047899551*^9}, {
   3.575287982883955*^9, 3.575287996081427*^9}, {3.575288030901637*^9, 
   3.5752880755559063`*^9}, 3.575288165474826*^9, {3.575288259194975*^9, 
   3.57528826061726*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a1", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"extModel", "[", "\<\"rf\"\>", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "300"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"a2", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"extModel", "[", "\<\"rf\"\>", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "700"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"a3", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"extModel", "[", "\<\"lm\"\>", "]"}], ",", 
      RowBox[{"{", "}"}]}], "}"}]}], ",", 
   RowBox[{"a4", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"extModel", "[", "\<\"rf\"\>", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "300"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"a5", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"extModel", "[", "\<\"rf\"\>", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "700"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"a6", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"extModel", "[", "\<\"lm\"\>", "]"}], ",", 
      RowBox[{"{", "}"}]}], "}"}]}], ",", 
   RowBox[{"a7", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"extModel", "[", "\<\"rf\"\>", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "500"}], "}"}]}], "}"}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.5752870483248787`*^9, {3.575288231411549*^9, 3.575288261115594*^9}, 
   3.5860095772716923`*^9, 3.586009844283762*^9, 3.586011347343245*^9, 
   3.5860151208556023`*^9, 3.586087076882214*^9, 3.586090199349101*^9, 
   3.5860922033981333`*^9}]
}, Open  ]],

Cell["\<\
Assemble table of results (this can take a couple minutes to run):\
\>", "Text",
 CellChangeTimes->{{3.586013125651396*^9, 3.5860131321220512`*^9}, {
  3.586092495566126*^9, 3.586092504741131*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"finalRes", "=", 
   RowBox[{"MapThread", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"First", "@", "#1"}], ",", 
        RowBox[{"(*", " ", "alga", " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{"#2", "[", 
         RowBox[{"[", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "1"}], "]"}], "]"}], ",", " ", 
        RowBox[{"(*", " ", "model", " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{"#2", "[", 
         RowBox[{"[", 
          RowBox[{
           RowBox[{"-", "1"}], ",", 
           RowBox[{"-", "1"}]}], "]"}], "]"}], ",", 
        RowBox[{"(*", " ", 
         RowBox[{"error", " ", "on", " ", "training", " ", "set"}], " ", 
         "*)"}], "\[IndentingNewLine]", 
        RowBox[{"\"\<NMSE\>\"", "/.", 
         RowBox[{"errors", "[", 
          RowBox[{
           RowBox[{"#1", "[", 
            RowBox[{"[", 
             RowBox[{"2", ",", "1"}], "]"}], "]"}], "[", 
           RowBox[{
            RowBox[{"Sequence", "@@", 
             RowBox[{"#1", "[", 
              RowBox[{"[", 
               RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ",", "knnd", ",", 
            "featureColumns", ",", 
            RowBox[{"First", "@", "#"}], ",", "knndTest"}], "]"}], "]"}]}]}], 
       "\[IndentingNewLine]", "}"}], "&"}], ",", 
     RowBox[{"{", 
      RowBox[{"winnerEms", ",", "winners"}], "}"}]}], "\[IndentingNewLine]", 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5752936320772676`*^9, 3.575293769249732*^9}, {
   3.575293848259447*^9, 3.575293872975727*^9}, {3.575293944362751*^9, 
   3.575293948599522*^9}, 3.586011511631262*^9, {3.586011546581209*^9, 
   3.5860115963978863`*^9}, 3.586011627282407*^9, {3.586011759150363*^9, 
   3.586011788829938*^9}, {3.5860118718047533`*^9, 3.5860118780747337`*^9}, {
   3.5860122063458233`*^9, 3.586012211040235*^9}, {3.586023890112973*^9, 
   3.586023908778123*^9}}],

Cell["\<\
For performance, cache predictions for interactive solution explorer (this \
can take a couple minutes to run):\
\>", "Text",
 CellChangeTimes->{{3.586013138857504*^9, 3.5860131530015163`*^9}, {
  3.586013584681292*^9, 3.5860135876727667`*^9}, {3.586090303290846*^9, 
  3.586090340296496*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"cachedPredictions", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Rule", "[", 
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"predictions", "[", 
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "1"}], "]"}], "]"}], "[", 
         RowBox[{
          RowBox[{"Sequence", "@@", 
           RowBox[{"#", "[", 
            RowBox[{"[", 
             RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ",", "knnd", ",", 
          "featureColumns", ",", 
          RowBox[{"First", "@", "#"}], ",", "knndTest"}], "]"}], "]"}]}], 
      "]"}], "&"}], "/@", "winnerEms"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5860129628572397`*^9, 3.586013001811202*^9}}],

Cell[CellGroupData[{

Cell["Canned results", "Subsubsection",
 CellChangeTimes->{{3.586090479167832*^9, 3.5860904839350443`*^9}, {
  3.586092485870348*^9, 3.586092489637754*^9}},
 FontColor->GrayLevel[0.5]],

Cell[BoxData[
 RowBox[{
  RowBox[{"finalRes", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a1", ",", 
       RowBox[{"cv", "[", 
        RowBox[{"\"\<rf\>\"", ",", "3", ",", "300"}], "]"}], ",", 
       "0.5499331021226923`", ",", "0.5115852378431156`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"a2", ",", 
       RowBox[{"cv", "[", 
        RowBox[{"\"\<rf\>\"", ",", "3", ",", "700"}], "]"}], ",", 
       "0.832708261075281`", ",", "0.866720933832523`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"a3", ",", 
       RowBox[{"cv", "[", "\"\<lm\>\"", "]"}], ",", "0.9602981831730494`", 
       ",", "0.9249388403868604`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"a4", ",", 
       RowBox[{"cv", "[", 
        RowBox[{"\"\<rf\>\"", ",", "3", ",", "300"}], "]"}], ",", 
       "0.9052994221344788`", ",", "0.6186491592731168`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"a5", ",", 
       RowBox[{"cv", "[", 
        RowBox[{"\"\<rf\>\"", ",", "3", ",", "700"}], "]"}], ",", 
       "0.8046606245948734`", ",", "0.7851830537335176`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"a6", ",", 
       RowBox[{"cv", "[", "\"\<lm\>\"", "]"}], ",", "0.8625951568970727`", 
       ",", "0.8391134862311649`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"a7", ",", 
       RowBox[{"cv", "[", 
        RowBox[{"\"\<rf\>\"", ",", "3", ",", "500"}], "]"}], ",", 
       "1.075990585320287`", ",", "1.0256379525279808`"}], "}"}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.5860925157969723`*^9, 3.586092519687355*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"cachedPredictions", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a1", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "3.7050555555555555`", ",", "10.830555555555557`", ",", 
        "13.034055555555556`", ",", "13.87788888888889`", ",", 
        "27.442333333333337`", ",", "39.069`", ",", "38.20466666666667`", ",",
         "35.08288888888889`", ",", "32.72788888888889`", ",", 
        "31.421333333333333`", ",", "3.8736666666666673`", ",", 
        "7.326333333333334`", ",", "33.17055555555556`", ",", 
        "34.431333333333335`", ",", "34.611333333333334`", ",", 
        "23.109666666666666`", ",", "6.419`", ",", "9.287`", ",", 
        "43.28041666666667`", ",", "58.00716666666668`", ",", 
        "6.468133333333333`", ",", "6.730222222222223`", ",", 
        "3.961466666666667`", ",", "7.005416666666667`", ",", 
        "3.678066666666667`", ",", "4.189351851851852`", ",", 
        "26.008333333333336`", ",", "39.89972222222223`", ",", 
        "28.257666666666665`", ",", "27.035222222222227`", ",", 
        "31.78588888888889`", ",", "13.394583333333335`", ",", 
        "40.61116666666666`", ",", "38.38166666666667`", ",", 
        "50.564333333333344`", ",", "39.68677777777778`", ",", 
        "36.12166666666667`", ",", "43.00680555555556`", ",", 
        "42.94111111111111`", ",", "43.48850000000001`", ",", 
        "34.98283333333333`", ",", "10.260333333333334`", ",", 
        "7.876305555555557`", ",", "11.661750000000001`", ",", 
        "10.704166666666667`", ",", "5.635777777777778`", ",", 
        "6.880416666666667`", ",", "8.121805555555557`", ",", 
        "15.309355555555559`", ",", "29.591`", ",", "15.264916666666668`", 
        ",", "4.122916666666667`", ",", "4.927833333333333`", ",", 
        "2.652666666666667`", ",", "4.794844444444445`", ",", 
        "17.275333333333332`", ",", "9.524333333333335`", ",", 
        "9.488972222222223`", ",", "9.683666666666669`", ",", 
        "8.825333333333333`", ",", "6.707416666666668`", ",", 
        "14.080722222222224`", ",", "9.484555555555557`", ",", 
        "4.3444166666666675`", ",", "33.87758333333333`", ",", 
        "16.981333333333332`", ",", "13.738`", ",", "38.70405555555556`", ",",
         "39.57088888888889`", ",", "4.49`", ",", "2.842`", ",", 
        "2.854177777777778`", ",", "15.244333333333335`", ",", 
        "3.2563333333333335`", ",", "14.935333333333336`", ",", 
        "3.8839999999999995`", ",", "13.337333333333335`", ",", 
        "11.186222222222224`", ",", "12.597266666666668`", ",", 
        "9.402555555555555`", ",", "3.1894722222222227`", ",", 
        "7.115166666666668`", ",", "27.329555555555558`", ",", 
        "28.50022222222222`", ",", "4.2746666666666675`", ",", 
        "6.971266666666668`", ",", "6.78275`", ",", "7.647166666666667`", ",",
         "11.87075`", ",", "11.890250000000002`", ",", "13.319333333333335`", 
        ",", "19.31766666666667`", ",", "16.61888888888889`", ",", 
        "15.369222222222225`", ",", "14.54866666666667`", ",", 
        "11.442277777777779`", ",", "13.71588888888889`", ",", 
        "15.392999999999999`", ",", "6.330333333333334`", ",", 
        "5.56138888888889`", ",", "9.370083333333334`", ",", 
        "6.592833333333335`", ",", "3.0287777777777785`", ",", 
        "6.9411666666666685`", ",", "4.472722222222222`", ",", 
        "5.139305555555556`", ",", "3.9076222222222223`", ",", 
        "39.728166666666674`", ",", "50.60516666666667`", ",", "38.7005`", 
        ",", "44.05916666666667`", ",", "36.724722222222226`", ",", 
        "22.808888888888887`", ",", "3.4080000000000004`", ",", 
        "11.009555555555556`", ",", "11.247555555555557`", ",", 
        "16.603333333333335`", ",", "11.530022222222224`", ",", "11.6884`", 
        ",", "3.4233333333333333`", ",", "5.878583333333333`", ",", 
        "27.746999999999996`", ",", "28.685000000000002`", ",", 
        "37.80533333333334`", ",", "29.461000000000006`", ",", 
        "25.191666666666666`", ",", "33.022`", ",", "35.50505555555556`", ",",
         "23.886111111111116`", ",", "31.727666666666668`", ",", 
        "48.53322222222223`", ",", "53.09133333333334`", ",", 
        "45.28694444444445`", ",", "41.51083333333334`", ",", 
        "18.662333333333336`", ",", "25.203333333333337`", ",", 
        "2.989433333333334`", ",", "8.426333333333334`", ",", 
        "12.322466666666667`", ",", "8.658555555555555`"}], "}"}]}], ",", 
     RowBox[{"a2", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "8.340285714285715`", ",", "6.727252380952381`", ",", 
        "6.514179189133847`", ",", "7.076238775510204`", ",", 
        "7.201595238095238`", ",", "4.959775510204081`", ",", 
        "2.943141609977324`", ",", "4.597956436420722`", ",", 
        "2.091619047619048`", ",", "5.100371031746032`", ",", 
        "3.8397556935817803`", ",", "5.858112836438923`", ",", 
        "3.624449546485261`", ",", "1.818748890860692`", ",", 
        "1.6955714285714287`", ",", "3.0747448107448108`", ",", 
        "10.627214285714285`", ",", "9.538446169772255`", ",", 
        "2.166673469387755`", ",", "1.4743988662131517`", ",", 
        "12.177494505494506`", ",", "12.372261904761906`", ",", 
        "10.149119047619049`", ",", "7.144642857142857`", ",", 
        "15.219571428571427`", ",", "14.806285714285716`", ",", 
        "5.473420408163265`", ",", "2.4696520408163267`", ",", 
        "3.495890338827839`", ",", "3.058201530612245`", ",", 
        "3.5644015269151144`", ",", "6.8256476190476185`", ",", 
        "2.1764244010647733`", ",", "1.7009263038548752`", ",", 
        "1.052418707482993`", ",", "2.6350601153504885`", ",", 
        "1.7539383503401362`", ",", "1.6806258503401357`", ",", 
        "1.473988095238095`", ",", "1.780418367346939`", ",", 
        "2.13415943877551`", ",", "8.766047619047619`", ",", 
        "9.56385093167702`", ",", "11.604102632357291`", ",", 
        "6.3468442176870745`", ",", "7.034547619047619`", ",", 
        "10.49240068027211`", ",", "11.99915986394558`", ",", 
        "6.106207482993197`", ",", "2.4607661826268967`", ",", 
        "12.224357142857142`", ",", "9.152190476190475`", ",", 
        "6.71497619047619`", ",", "9.373714285714286`", ",", 
        "11.174666666666667`", ",", "11.836488095238094`", ",", 
        "5.773548299319727`", ",", "7.219638775510203`", ",", "8.059`", ",", 
        "7.055785714285714`", ",", "8.257666666666667`", ",", 
        "8.070179189133848`", ",", "7.03362380952381`", ",", 
        "10.814428571428572`", ",", "4.149429843241645`", ",", 
        "6.425609523809523`", ",", "7.891307760562418`", ",", 
        "2.067809297052154`", ",", "3.1294204081632655`", ",", "14.03`", ",", 
        "7.744428571428572`", ",", "13.999857142857145`", ",", 
        "3.141090358451073`", ",", "15.394761904761905`", ",", 
        "8.268779304029305`", ",", "7.829785714285715`", ",", 
        "6.1373852040816335`", ",", "15.768142857142855`", ",", 
        "10.860269299023958`", ",", "6.766`", ",", "13.297214285714285`", ",",
         "12.012704081632652`", ",", "1.9956971088435376`", ",", 
        "2.768325901151988`", ",", "5.86947619047619`", ",", 
        "13.104952380952382`", ",", "10.188`", ",", "10.729565217391306`", 
        ",", "10.24547619047619`", ",", "9.610071428571429`", ",", 
        "5.9413857142857145`", ",", "10.144779503105589`", ",", 
        "5.887663945578232`", ",", "8.56110989010989`", ",", 
        "9.74797619047619`", ",", "9.496065217391305`", ",", 
        "10.418166666666668`", ",", "13.048214285714286`", ",", 
        "10.441392517006802`", ",", "10.440921768707485`", ",", 
        "8.994571428571428`", ",", "10.981142857142858`", ",", 
        "5.772095238095237`", ",", "9.008999999999999`", ",", 
        "5.510380952380952`", ",", "11.268806122448979`", ",", 
        "8.660238095238094`", ",", "3.2407956916099776`", ",", 
        "2.5783451530612242`", ",", "3.637602972493345`", ",", 
        "1.9609948979591838`", ",", "4.25636507936508`", ",", 
        "4.325280525030525`", ",", "12.664642857142857`", ",", 
        "7.0729945054945045`", ",", "7.022642857142857`", ",", 
        "5.632559752747253`", ",", "6.618416895604396`", ",", 
        "7.161076138147567`", ",", "8.642991836734694`", ",", 
        "11.763653061224488`", ",", "3.4321128364389235`", ",", "3.9898125`", 
        ",", "3.2586679384797397`", ",", "3.308821428571429`", ",", 
        "2.4745497448979594`", ",", "1.7348622448979591`", ",", 
        "2.1607596371882085`", ",", "2.2857261904761907`", ",", 
        "3.9757571428571437`", ",", "2.5799680272108843`", ",", 
        "2.6385632653061224`", ",", "2.888417715419501`", ",", 
        "2.6019142006802722`", ",", "10.609419413919415`", ",", 
        "2.1347122710622712`", ",", "16.37254761904762`", ",", 
        "8.10483328100471`", ",", "9.90660989010989`", ",", 
        "9.421081632653062`"}], "}"}]}], ",", 
     RowBox[{"a3", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "3.10385603099067`", ",", "4.383910998070149`", ",", 
        "3.168967110659576`", ",", "7.225596380072069`", ",", 
        "1.198414637732256`", ",", "0.`", ",", "5.876613018362107`", ",", 
        "0.6339910457900118`", ",", "1.9157336342749698`", ",", 
        "1.515877321199783`", ",", "0.`", ",", "0.`", ",", 
        "2.183234939024814`", ",", "3.0763260789488136`", ",", 
        "2.570071358552669`", ",", "1.8526731427842211`", ",", 
        "2.8777703910529127`", ",", "4.792374713634942`", ",", 
        "1.271246328286539`", ",", "2.0664871650621848`", ",", 
        "2.3965536951238757`", ",", "0.`", ",", "3.2760021726822295`", ",", 
        "6.694045000063893`", ",", "2.267208939002611`", ",", 
        "1.3638547172566646`", ",", "1.539407405357279`", ",", "0.`", ",", 
        "0.9273441883350984`", ",", "0.6696116383074919`", ",", 
        "5.113481405149294`", ",", "2.0477014731221157`", ",", 
        "2.916247923765315`", ",", "1.2339225388212345`", ",", 
        "1.1923894411336402`", ",", "5.0051180111485944`", ",", 
        "1.6730452381565168`", ",", "3.0980280185430082`", ",", 
        "3.2550615640421245`", ",", "3.531588820309633`", ",", 
        "1.8220458999897282`", ",", "1.3262875367785565`", ",", 
        "7.077389190495151`", ",", "7.903899915051028`", ",", 
        "2.7633869206858446`", ",", "4.96138761199947`", ",", 
        "4.497634419324909`", ",", "5.760711156938965`", ",", 
        "3.997345341798429`", ",", "4.456674301083858`", ",", 
        "9.253388827150179`", ",", "7.241572056770727`", ",", 
        "3.167274742726754`", ",", "4.563995027721218`", ",", 
        "5.975578145777229`", ",", "0.`", ",", "6.2767152473705945`", ",", 
        "12.166937522875735`", ",", "3.5523447781654047`", ",", 
        "4.75603490703501`", ",", "2.762113098227654`", ",", 
        "8.807503171383523`", ",", "6.788687209239535`", ",", 
        "13.256362067860879`", ",", "6.304844887521678`", ",", 
        "2.581995604674354`", ",", "8.802075830419113`", ",", 
        "3.6584403605631284`", ",", "6.761936720767741`", ",", 
        "3.905188988009156`", ",", "1.8249817362804022`", ",", 
        "2.524039782819637`", ",", "3.051686445169956`", ",", 
        "0.5247133598673628`", ",", "2.7319756852771953`", ",", 
        "5.461441781573695`", ",", "4.620845329272326`", ",", 
        "2.267693782305784`", ",", "7.075960020345954`", ",", "0.`", ",", 
        "8.507831993442897`", ",", "4.607235546984375`", ",", 
        "4.979597031524241`", ",", "5.454884054287719`", ",", 
        "4.336346936506445`", ",", "11.288567534625859`", ",", 
        "7.322348855007749`", ",", "10.70913808936507`", ",", 
        "6.386283601603203`", ",", "9.470365835804174`", ",", 
        "4.417581699294283`", ",", "4.500868318349461`", ",", 
        "2.9991146999864977`", ",", "0.`", ",", "5.257544156853479`", ",", 
        "3.971015661178093`", ",", "0.`", ",", "3.6724990536422295`", ",", 
        "10.02088643466068`", ",", "4.240147147657538`", ",", 
        "2.0701938762034455`", ",", "5.870867790849594`", ",", 
        "1.9434470913515796`", ",", "8.049809350578986`", ",", 
        "2.9854914284327894`", ",", "10.233882027900254`", ",", 
        "3.188600425529742`", ",", "5.660879458583128`", ",", 
        "2.7287183453531547`", ",", "6.631669627593495`", ",", 
        "0.9347428198363872`", ",", "7.529847521351517`", ",", 
        "3.135101876136872`", ",", "1.4358758422563955`", ",", 
        "5.8060611241923334`", ",", "3.5214613195140103`", ",", 
        "3.016493918957565`", ",", "2.714731147805839`", ",", 
        "5.8969219669580095`", ",", "6.7754280741978405`", ",", 
        "3.4599402475120833`", ",", "2.825359820331032`", ",", 
        "2.367394273337009`", ",", "5.36444134404478`", ",", 
        "6.284766479093587`", ",", "4.737639523872437`", ",", 
        "5.604905474435882`", ",", "1.6848817023238478`", ",", 
        "4.228336942245992`", ",", "4.545162220800801`", ",", 
        "5.3098843357785395`", ",", "2.6255930228485678`", ",", 
        "3.456545215214243`", ",", "2.2073042786968013`", ",", 
        "4.829384517818889`", ",", "4.449019409092278`", ",", 
        "1.232556711455704`", ",", "0.7919362411089619`", ",", 
        "1.8578881724908856`", ",", "0.`"}], "}"}]}], ",", 
     RowBox[{"a4", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "4.248851851851852`", ",", "1.6463333333333334`", ",", 
        "3.142166666666667`", ",", "2.526847222222222`", ",", 
        "1.5198703703703704`", ",", "3.0646666666666667`", ",", 
        "0.9326759259259261`", ",", "1.0694761904761907`", ",", 
        "1.0136203703703703`", ",", "1.1548333333333336`", ",", "14.675`", 
        ",", "3.7952666666666666`", ",", "1.3178703703703705`", ",", 
        "4.6017491582491585`", ",", "3.5514259259259267`", ",", 
        "1.4208703703703702`", ",", "1.8573333333333335`", ",", 
        "3.6618916666666665`", ",", "1.7324444444444447`", ",", 
        "0.3696666666666666`", ",", "2.2278240740740745`", ",", 
        "1.3233560606060606`", ",", "1.6960333333333335`", ",", 
        "5.965666666666668`", ",", "1.3253416666666666`", ",", 
        "1.2727583333333334`", ",", "1.4661712962962965`", ",", 
        "1.328425925925926`", ",", "1.7714074074074075`", ",", 
        "2.156537037037037`", ",", "2.3527491582491584`", ",", 
        "1.345814814814815`", ",", "0.9028703703703703`", ",", 
        "0.9047777777777779`", ",", "2.327397306397306`", ",", 
        "3.8876666666666675`", ",", "3.921333333333334`", ",", 
        "4.685397306397307`", ",", "3.0420639730639736`", ",", 
        "1.0670000000000002`", ",", "1.0136666666666667`", ",", 
        "6.423333333333334`", ",", "2.3053727272727276`", ",", 
        "2.3672037037037037`", ",", "2.389202777777778`", ",", 
        "4.678388888888889`", ",", "1.329811616161616`", ",", 
        "1.2184393939393938`", ",", "2.100282828282828`", ",", 
        "2.31488930976431`", ",", "1.242476851851852`", ",", 
        "2.1978250000000004`", ",", "3.531333333333334`", ",", 
        "2.2115416666666667`", ",", "2.124541666666667`", ",", 
        "2.3096222222222225`", ",", "2.171072222222222`", ",", 
        "3.0996250000000005`", ",", "2.686111111111111`", ",", 
        "2.4532222222222226`", ",", "2.4475277777777777`", ",", 
        "3.8397916666666667`", ",", "2.2847539682539684`", ",", 
        "5.699111111111112`", ",", "1.461537037037037`", ",", 
        "2.586222222222222`", ",", "2.1405`", ",", "0.2693333333333333`", ",",
         "0.7661666666666667`", ",", "1.737963888888889`", ",", 
        "2.4607416666666673`", ",", "0.8322750000000001`", ",", 
        "1.388791245791246`", ",", "1.8251388888888889`", ",", 
        "1.7068095238095238`", ",", "3.141866666666667`", ",", 
        "1.2381064814814815`", ",", "1.307925925925926`", ",", 
        "2.3409015873015875`", ",", "2.822092592592593`", ",", 
        "1.8595833333333334`", ",", "1.2027`", ",", "1.2028703703703705`", 
        ",", "1.3850370370370373`", ",", "3.1627916666666667`", ",", 
        "2.0627592592592596`", ",", "2.3726666666666665`", ",", "2.9076`", 
        ",", "1.8650833333333334`", ",", "2.380559523809524`", ",", 
        "1.9360722222222224`", ",", "1.8220000000000003`", ",", "2.675625`", 
        ",", "2.984944444444445`", ",", "1.470722222222222`", ",", "2.3477`", 
        ",", "1.4917489177489178`", ",", "1.370666666666667`", ",", 
        "1.2834764309764313`", ",", "1.6123393939393942`", ",", 
        "3.038388888888889`", ",", "3.664518518518519`", ",", 
        "3.2931851851851857`", ",", "5.080166666666668`", ",", "3.521875`", 
        ",", "2.1464222222222227`", ",", "1.9089222222222222`", ",", 
        "0.6851666666666667`", ",", "0.138`", ",", "0.8502037037037037`", ",",
         "0.23153703703703704`", ",", "0.7703333333333333`", ",", 
        "0.6215370370370371`", ",", "0.40020000000000006`", ",", 
        "1.657309523809524`", ",", "0.8076060606060607`", ",", 
        "1.4406851851851852`", ",", "0.8816666666666667`", ",", 
        "0.978064393939394`", ",", "1.791222222222222`", ",", 
        "1.4955703703703707`", ",", "2.2462592592592596`", ",", 
        "2.0535370370370374`", ",", "2.9172592592592594`", ",", 
        "3.901333333333334`", ",", "0.805040824915825`", ",", 
        "2.6751481481481485`", ",", "0.6742037037037037`", ",", 
        "0.8607037037037037`", ",", "0.5913425925925926`", ",", 
        "0.5026666666666666`", ",", "0.8343333333333334`", ",", 
        "0.19066666666666668`", ",", "0.7676666666666667`", ",", 
        "0.4723333333333333`", ",", "0.9324259259259259`", ",", 
        "1.0348560606060606`", ",", "0.505625`", ",", "0.9535185185185185`", 
        ",", "0.4610000000000001`"}], "}"}]}], ",", 
     RowBox[{"a5", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "5.712857142857143`", ",", "8.464257142857143`", ",", 
        "6.478142857142857`", ",", "6.600554761904762`", ",", 
        "2.3244976317799844`", ",", "1.7560714285714285`", ",", 
        "0.8612448179271709`", ",", "1.8819821428571433`", ",", 
        "2.5407547746371275`", ",", "4.171802277432713`", ",", 
        "5.033107142857142`", ",", "6.611880952380952`", ",", 
        "3.4427237187365063`", ",", "1.2532077922077924`", ",", 
        "1.0523982683982684`", ",", "5.192753480641269`", ",", 
        "8.442361904761905`", ",", "4.007228571428572`", ",", 
        "0.3718571428571429`", ",", "0.25380672268907567`", ",", 
        "4.524140384615384`", ",", "4.978114285714286`", ",", 
        "8.940057142857144`", ",", "5.937057142857143`", ",", 
        "8.407996031746032`", ",", "8.516424603174602`", ",", 
        "7.224452380952381`", ",", "0.6976805322128852`", ",", 
        "6.075293650793652`", ",", "4.534707792207792`", ",", 
        "4.712969696969697`", ",", "5.787119047619048`", ",", 
        "0.37299999999999994`", ",", "0.20823529411764705`", ",", 
        "0.3130642857142857`", ",", "0.38142857142857145`", ",", 
        "0.35585714285714287`", ",", "0.3054668831168831`", ",", 
        "0.35028571428571426`", ",", "0.17337815126050418`", ",", 
        "0.5222352941176471`", ",", "2.1839857142857144`", ",", 
        "5.69245238095238`", ",", "5.027815476190476`", ",", 
        "9.229047619047618`", ",", "7.883154761904763`", ",", 
        "5.296821428571429`", ",", "6.155876190476191`", ",", 
        "6.671436147186148`", ",", "3.492685714285714`", ",", 
        "6.372046031746033`", ",", "6.729014285714286`", ",", 
        "9.852571428571428`", ",", "8.910357142857142`", ",", 
        "6.6014960317460325`", ",", "6.389992857142857`", ",", 
        "9.263761904761905`", ",", "6.474934523809523`", ",", 
        "11.163904761904764`", ",", "10.056603174603175`", ",", 
        "8.952126984126984`", ",", "6.3299666666666665`", ",", 
        "5.188539285714286`", ",", "2.8414571428571427`", ",", 
        "2.434400432900433`", ",", "6.170997198879552`", ",", 
        "4.114109523809525`", ",", "0.5593781512605042`", ",", 
        "1.0133602941176472`", ",", "6.556746031746032`", ",", 
        "10.803685714285715`", ",", "9.138261904761904`", ",", 
        "10.899964285714285`", ",", "4.6559357142857145`", ",", 
        "7.288628571428571`", ",", "7.980571428571428`", ",", 
        "7.424649999999999`", ",", "6.589095238095238`", ",", 
        "4.372336801242236`", ",", "5.454438095238095`", ",", 
        "4.2374285714285715`", ",", "6.291244047619048`", ",", 
        "4.094950649350649`", ",", "5.28664318652362`", ",", 
        "7.841985714285714`", ",", "2.5440947496947497`", ",", 
        "3.940110714285715`", ",", "5.526785714285714`", ",", 
        "5.643482142857143`", ",", "4.155799138904574`", ",", 
        "8.750857142857143`", ",", "6.2245238095238085`", ",", 
        "6.910685714285714`", ",", "7.908`", ",", "5.245319780219781`", ",", 
        "5.602738095238096`", ",", "5.970067099567099`", ",", 
        "3.985507226107226`", ",", "7.4389345238095235`", ",", 
        "5.908914285714285`", ",", "5.167628571428572`", ",", 
        "4.86224126984127`", ",", "6.878892857142858`", ",", 
        "5.264598412698413`", ",", "7.890033333333332`", ",", 
        "5.381833333333334`", ",", "8.982785714285715`", ",", 
        "0.7431781512605042`", ",", "0.27952100840336136`", ",", 
        "0.5627285714285715`", ",", "0.33180672268907563`", ",", 
        "2.3427769654897532`", ",", "2.9702058615936493`", ",", 
        "8.971828571428572`", ",", "5.286513099943535`", ",", 
        "6.66614935064935`", ",", "8.177046866177301`", ",", 
        "7.775546866177303`", ",", "6.360922222222222`", ",", 
        "6.582257142857142`", ",", "6.276053571428572`", ",", 
        "1.446090909090909`", ",", "9.927448051948051`", ",", 
        "1.1344766233766232`", ",", "0.6742359307359307`", ",", 
        "6.297296248196248`", ",", "0.5107597402597402`", ",", 
        "0.8523567226890756`", ",", "1.1096051948051948`", ",", 
        "0.808883346065699`", ",", "0.1153781512605042`", ",", "0.252`", ",", 
        "0.5830924369747899`", ",", "0.42890196078431375`", ",", 
        "3.0432546583850932`", ",", "1.533160294117647`", ",", 
        "5.128821428571428`", ",", "6.740766378066379`", ",", 
        "6.398318294748729`", ",", "6.482044155844155`"}], "}"}]}], ",", 
     RowBox[{"a6", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "1.1981862492852096`", ",", "9.983340776483793`", ",", 
        "4.550133861594498`", ",", "3.0996550085874297`", ",", "0.`", ",", 
        "1.4985986453839364`", ",", "0.`", ",", "0.7851548895267688`", ",", 
        "4.4438241170949375`", ",", "7.469334284419081`", ",", 
        "3.3884891760777394`", ",", "9.110963742947682`", ",", 
        "7.08976900598981`", ",", "3.6018119948024436`", ",", 
        "5.179760107668708`", ",", "4.637500031176999`", ",", 
        "4.023700357460042`", ",", "0.`", ",", "2.2611597940753043`", ",", 
        "2.3310002981686346`", ",", "0.4645003466728841`", ",", 
        "5.755418941424702`", ",", "12.932010951461928`", ",", 
        "6.8553989516357525`", ",", "13.29877314041175`", ",", 
        "13.945119123843812`", ",", "10.958920750942358`", ",", "0.`", ",", 
        "2.5867095573365875`", ",", "5.247068321204287`", ",", "0.`", ",", 
        "7.836216567872824`", ",", "2.6002934802231437`", ",", 
        "2.4410158174540433`", ",", "5.488727897458052`", ",", 
        "0.5248259672593054`", ",", "1.6982719407947657`", ",", 
        "3.7914725642671243`", ",", "0.2876562771964928`", ",", 
        "0.5072059787269421`", ",", "1.7118644268660885`", ",", 
        "3.9445107272059596`", ",", "3.682952169452653`", ",", 
        "1.0572850795157418`", ",", "14.235067360665724`", ",", 
        "18.077639996772607`", ",", "12.538200313518072`", ",", 
        "11.293977117515169`", ",", "8.187554501030977`", ",", 
        "9.813686568822439`", ",", "5.609470583536481`", ",", 
        "6.191935321063127`", ",", "18.545019981679413`", ",", 
        "10.002162903379698`", ",", "8.982813108386853`", ",", 
        "3.4250813586967475`", ",", "14.584847138949627`", ",", 
        "10.950380699631127`", ",", "16.609517520152366`", ",", 
        "21.22793184212174`", ",", "13.890310901928652`", ",", 
        "2.7201160517640193`", ",", "1.0883211735540885`", ",", "0.`", ",", 
        "2.6223471913833425`", ",", "6.526944783420749`", ",", 
        "0.6583590627682274`", ",", "2.8957760846692144`", ",", 
        "0.026801800846418367`", ",", "4.79087782958177`", ",", 
        "6.782586864558759`", ",", "12.659305624420481`", ",", 
        "7.07705341390224`", ",", "7.875357556775174`", ",", 
        "5.320347671434251`", ",", "21.532234683652383`", ",", 
        "7.315843551127637`", ",", "9.954045606108007`", ",", "0.`", ",", 
        "0.`", ",", "2.8485607938949413`", ",", "13.885676722676806`", ",", 
        "5.490642621728878`", ",", "8.334236301237722`", ",", 
        "19.11694934973674`", ",", "0.`", ",", "7.986368301748515`", ",", 
        "2.0133343873559095`", ",", "10.5864787970412`", ",", 
        "7.1525348930515555`", ",", "11.457887161998832`", ",", 
        "10.44192559059375`", ",", "8.362859099695367`", ",", 
        "9.28950826378706`", ",", "0.`", ",", "2.429663489105366`", ",", 
        "5.395908191239353`", ",", "0.`", ",", "10.305683086877416`", ",", 
        "16.72322504124063`", ",", "4.594261419830269`", ",", "0.`", ",", 
        "5.917631226049386`", ",", "4.274353665100453`", ",", 
        "9.570046441271472`", ",", "6.772227010411657`", ",", 
        "20.015206364134905`", ",", "5.717820892054405`", ",", 
        "4.337606272589764`", ",", "1.6763117666599388`", ",", 
        "6.5509364365427825`", ",", "5.914659618041284`", ",", 
        "8.736966904841983`", ",", "9.503626997429894`", ",", "0.`", ",", 
        "6.918242233003605`", ",", "9.125174215082362`", ",", 
        "9.420924500866395`", ",", "5.763599598454958`", ",", 
        "10.340206584264081`", ",", "12.61909885867236`", ",", 
        "3.0432303124043023`", ",", "5.214226498977485`", ",", 
        "0.5734124767163058`", ",", "0.`", ",", "11.17277250575551`", ",", 
        "0.536382282504061`", ",", "4.538646913814986`", ",", "0.`", ",", 
        "0.`", ",", "1.6257847128084815`", ",", "6.405664409629175`", ",", 
        "4.176049259315773`", ",", "6.998160883294912`", ",", 
        "7.035733265952521`", ",", "5.673709874878631`", ",", 
        "8.915623852214768`", ",", "6.040378182365526`", ",", 
        "6.282365295765588`", ",", "7.17121336211813`"}], "}"}]}], ",", 
     RowBox[{"a7", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "3.984`", ",", "3.1575861837692822`", ",", "1.5641262042505932`", ",", 
        "1.5887849139280124`", ",", "1.2913784132065118`", ",", 
        "0.6692481818181818`", ",", "0.8045619846350833`", ",", 
        "1.4793479437229438`", ",", "1.4268784132065115`", ",", 
        "2.732556984635083`", ",", "2.6506`", ",", "3.3490461388074286`", ",",
         "1.5885779991278368`", ",", "0.7957432749576638`", ",", 
        "0.9334619846350831`", ",", "2.487977999127837`", ",", 
        "2.3209733333333333`", ",", "6.4606`", ",", "0.6440128054740958`", 
        ",", "0.1166`", ",", "2.732609207459207`", ",", "3.8159800000000006`",
         ",", "4.626651282051283`", ",", "4.639461290322581`", ",", 
        "2.1504227106227103`", ",", "1.808289377289377`", ",", 
        "2.386283333333334`", ",", "0.6389264290795277`", ",", 
        "1.577634054834055`", ",", "0.7843178576509563`", ",", 
        "1.550559147973537`", ",", "6.157367136150234`", ",", 
        "0.766093181818182`", ",", "0.48885151515151515`", ",", 
        "0.48711280547409574`", ",", "0.8119681818181819`", ",", 
        "0.5815681818181818`", ",", "0.3621128054740958`", ",", 
        "0.6051294721407625`", ",", "0.17330151515151512`", ",", "0.3038`", 
        ",", "6.7773`", ",", "4.740615649296941`", ",", "3.854074358974359`", 
        ",", "1.7268914285714285`", ",", "4.670833333333334`", ",", 
        "4.809486183769282`", ",", "6.515480000000001`", ",", 
        "1.8169884059915047`", ",", "2.0479178576509565`", ",", 
        "4.522253333333334`", ",", "6.6689046153846165`", ",", 
        "5.132956043956044`", ",", "2.913121428571429`", ",", 
        "3.6443566666666665`", ",", "3.140458150642988`", ",", 
        "2.0237671361502345`", ",", "4.431319517102616`", ",", 
        "2.841833333333334`", ",", "3.5038000000000005`", ",", "3.48575`", 
        ",", "3.6643946236559137`", ",", "2.4402862042505933`", ",", 
        "3.4249746236559147`", ",", "1.5718823225767116`", ",", 
        "1.8281964839763218`", ",", "1.8293431506429885`", ",", 
        "0.8729964285714287`", ",", "1.3273964285714288`", ",", 
        "4.409756043956044`", ",", "1.702656043956044`", ",", 
        "2.742331282051282`", ",", "3.077613274957664`", ",", 
        "3.431541025641026`", ",", "2.4577132749576642`", ",", 
        "4.226021428571429`", ",", "2.64130523138833`", ",", 
        "5.714147692307692`", ",", "3.1235013175230564`", ",", 
        "1.863704347826087`", ",", "2.2258000000000004`", ",", 
        "5.726146666666666`", ",", "2.082517857650956`", ",", 
        "1.5895877194021082`", ",", "5.961033333333333`", ",", 
        "2.641947692307692`", ",", "2.8229376811594205`", ",", 
        "5.490600000000001`", ",", "2.8803671361502348`", ",", 
        "3.1262728709172602`", ",", "2.611652850435949`", ",", 
        "1.7447905315953696`", ",", "1.8626772948803938`", ",", 
        "2.1094415805946793`", ",", "2.2590098173096553`", ",", 
        "2.541844347826087`", ",", "2.2670274740918632`", ",", 
        "1.9693431506429884`", ",", "4.262857692307692`", ",", 
        "7.337200000000001`", ",", "2.6998479569892475`", ",", 
        "3.784333333333333`", ",", "4.842004761904762`", ",", 
        "3.019333333333333`", ",", "3.835754761904762`", ",", 
        "6.291181025641026`", ",", "5.251373333333334`", ",", 
        "0.5383746758327744`", ",", "0.078`", ",", "0.7830646103896104`", ",",
         "0.5256931818181818`", ",", "1.6155975296442686`", ",", 
        "0.9298313324611702`", ",", "2.8380312820512823`", ",", 
        "2.437374386068775`", ",", "2.858113095746195`", ",", 
        "2.4464739165852074`", ",", "1.4872664290795279`", ",", 
        "3.730500469483568`", ",", "3.2821476923076927`", ",", 
        "3.3514076923076925`", ",", "1.1237069846350833`", ",", 
        "1.003483009166108`", ",", "0.9046204178148067`", ",", 
        "1.1379481818181818`", ",", "1.8102338028169016`", ",", 
        "1.0644094721407624`", ",", "1.0998931818181819`", ",", 
        "1.690017943722944`", ",", "1.2158269846350833`", ",", "0.1862`", ",",
         "0.352`", ",", "0.5993964285714285`", ",", "0.3880782472613458`", 
        ",", "0.9997313324611703`", ",", "0.9688757769056147`", ",", 
        "3.3545133333333332`", ",", "3.574700469483568`", ",", 
        "1.2440130957461943`", ",", "0.8660988100319087`"}], "}"}]}]}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5860904652223377`*^9, 3.586090471766255*^9}}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Solutions", "Title",
 CellChangeTimes->CompressedData["
1:eJwdyk9IkwEch/E5oeyfEJUOUWllNU9zjDKHlpZRqZFNQdFNbWgbOZspGXoo
C5IOsoGRrppQIYpD38VaCh6mOyzF/N8hUhsFoiSbSRm+OgR/39/h4XN55AaL
tkoqkUgUFFRVVO7vGljN6vKNsFeW5vv95JHCmwKMGj6bPk6utUgvwB6v1wgL
/W9NcNxxq+cL2eYaZLfeLW7D1hJVGJqDKe4J0j755CNsVbstU2SBWFYL67/5
ZmHLzvAcFHt/B+HYgYIQXL6R8mqaDFR1s68NiXtnyJN5C6zdY3T9IX8+/MHO
1Gum10nB+4+VCncf/CU3c6MaoP+6rB2uN8nZxeNnLv3H97WRPZ2qtm6SxVob
2xQ0K0VSK/jYiMBVa8LgatZcRKMNbhcd7ksiNy4/Y7NX9ihPkU6nni2ry52A
0fqESZj5qU3VQZpzvrM6pfk8HHJ0sgcTH3fDpyUjbLUm7Y6dVHtkRnjiTXWM
g/REJsfCSveHclhbc7ECHlWMdcDy/GU2R1cU3Umeu29jkwJbx+CG3hAL00Py
DGiI9GbC2+F9/bDvhShAl/jr5Xuy2XKoHeZlC8/9ZMNsmHX2uubhPYVqAcbn
a2I+k6YpK6tbiksbJeNMo+yja6nNIVJWWsruAuGVadQ=
  "]],

Cell["Errors for our winning models, by alga:", "Text",
 CellChangeTimes->{{3.586009801916559*^9, 3.586009823901767*^9}, 
   3.586011343239502*^9, {3.586092610644352*^9, 3.586092625954721*^9}, {
   3.58609268367551*^9, 3.5860926869857063`*^9}, {3.586092890805132*^9, 
   3.586092891845318*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{"finalRes", ",", 
   RowBox[{"TableHeadings", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"None", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<alga\>\"", ",", "\"\<model\>\"", ",", 
        RowBox[{"Subscript", "[", 
         RowBox[{"NMSE", ",", "\"\<train\>\""}], "]"}], ",", 
        RowBox[{"Subscript", "[", 
         RowBox[{"NMSE", ",", "\"\<test\>\""}], "]"}]}], "}"}]}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5752854520748043`*^9, 3.5752854923803873`*^9}, {
   3.5752868159919147`*^9, 3.575286828185996*^9}, {3.575286858328747*^9, 
   3.575286880422285*^9}, {3.575287021349373*^9, 3.575287047899551*^9}, {
   3.575287982883955*^9, 3.575287996081427*^9}, {3.575288030901637*^9, 
   3.5752880755559063`*^9}, 3.575288165474826*^9, {3.575288259194975*^9, 
   3.57528826061726*^9}, {3.586092342531176*^9, 3.586092362106327*^9}, {
   3.586092531701769*^9, 3.586092589533106*^9}}],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"alga\"\>",
       HoldForm], 
      TagBox["\<\"model\"\>",
       HoldForm], 
      TagBox[
       SubscriptBox["NMSE", "\<\"train\"\>"],
       HoldForm], 
      TagBox[
       SubscriptBox["NMSE", "\<\"test\"\>"],
       HoldForm]},
     {"a1", 
      RowBox[{"cv", "[", 
       RowBox[{"\<\"rf\"\>", ",", "3", ",", "300"}], "]"}], 
      "0.5499331021226923`", "0.5115852378431156`"},
     {"a2", 
      RowBox[{"cv", "[", 
       RowBox[{"\<\"rf\"\>", ",", "3", ",", "700"}], "]"}], 
      "0.832708261075281`", "0.866720933832523`"},
     {"a3", 
      RowBox[{"cv", "[", "\<\"lm\"\>", "]"}], "0.9602981831730494`", 
      "0.9249388403868604`"},
     {"a4", 
      RowBox[{"cv", "[", 
       RowBox[{"\<\"rf\"\>", ",", "3", ",", "300"}], "]"}], 
      "0.9052994221344788`", "0.6186491592731168`"},
     {"a5", 
      RowBox[{"cv", "[", 
       RowBox[{"\<\"rf\"\>", ",", "3", ",", "700"}], "]"}], 
      "0.8046606245948734`", "0.7851830537335176`"},
     {"a6", 
      RowBox[{"cv", "[", "\<\"lm\"\>", "]"}], "0.8625951568970727`", 
      "0.8391134862311649`"},
     {"a7", 
      RowBox[{"cv", "[", 
       RowBox[{"\<\"rf\"\>", ",", "3", ",", "500"}], "]"}], 
      "1.075990585320287`", "1.0256379525279808`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$, TableHeadings -> {None, {"alga", "model", 
       Subscript[$CellContext`NMSE, "train"], 
       Subscript[$CellContext`NMSE, "test"]}}]]]], "Output",
 CellChangeTimes->{
  3.5752870483248787`*^9, {3.575288231411549*^9, 3.575288261115594*^9}, 
   3.5860095772716923`*^9, 3.586009844283762*^9, 3.586011347343245*^9, 
   3.5860151208556023`*^9, 3.586087076882214*^9, 3.586090199349101*^9, {
   3.586092349679278*^9, 3.586092366690545*^9}, 3.586092527623151*^9, {
   3.586092578265277*^9, 3.586092592207718*^9}}]
}, Open  ]],

Cell["\<\
Although the model performance isn\[CloseCurlyQuote]t stellar (a7 remains \
problematic), it is gratifying to see the test results track the training \
ones.\
\>", "Text",
 CellChangeTimes->{{3.5860926957295847`*^9, 3.586092738224682*^9}}],

Cell["Actual vs. predicted, by alga:", "Text",
 CellChangeTimes->{{3.586092870782816*^9, 3.586092896333219*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Labeled", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"plots", "=", 
       RowBox[{"Table", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Show", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"ListPlot", "[", 
            RowBox[{
             RowBox[{"Transpose", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"alga", "/.", "cachedPredictions"}], ",", 
                RowBox[{"knndTest", "[", "alga", "]"}]}], "}"}], "]"}], 
             "\[IndentingNewLine]", ",", 
             RowBox[{"PlotMarkers", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"Automatic", ",", "Medium"}], "}"}]}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Plot", "[", 
            RowBox[{"x", ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", "0", ",", "100"}], "}"}], ",", 
             RowBox[{"PlotStyle", "\[Rule]", 
              RowBox[{"Directive", "[", "Dashed", "]"}]}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"PlotLabel", "\[Rule]", 
            RowBox[{"StringForm", "[", 
             RowBox[{"\"\<``: ``\>\"", ",", "alga", ",", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"alga", "/.", "winnerEms"}], ")"}], "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "1"}], "]"}], "]"}], "@@", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"alga", "/.", "winnerEms"}], ")"}], "[", 
                 RowBox[{"[", "2", "]"}], "]"}], ")"}]}]}], "]"}]}]}], 
          "\[IndentingNewLine]", 
          RowBox[{"(*", 
           RowBox[{",", 
            RowBox[{"AxesLabel", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"\"\<Pred\>\"", ",", "\"\<Actual\>\""}], "}"}]}]}], 
           "*)"}], "\[IndentingNewLine]", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"alga", ",", "responseColumns"}], "}"}]}], 
        "\[IndentingNewLine]", "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Grid", "[", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{"plots", ",", "3", ",", "3", ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "1"}], "}"}], ",", 
         RowBox[{"{", "}"}]}], "]"}], ",", 
       RowBox[{"Spacings", "\[Rule]", "2"}]}], "]"}]}], "\[IndentingNewLine]",
     "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Style", "[", 
    RowBox[{
     RowBox[{"Column", "[", 
      RowBox[{
       RowBox[{
       "{", "\"\<Actual vs. Predicted Values for Winning Models, by Alga\>\"",
         "}"}], ",", "Center"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"Bold", ",", "14", ",", 
       RowBox[{"FontFamily", "\[Rule]", "\"\<Verdana\>\""}]}], "}"}]}], "]"}],
    ",", "\[IndentingNewLine]", "Top"}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{{3.5860929503607483`*^9, 3.5860929621014347`*^9}, {
  3.586093014462047*^9, 3.58609317282936*^9}, {3.58609320900303*^9, 
  3.586093223089767*^9}, {3.586093276872038*^9, 3.586093394518091*^9}, {
  3.586093452437621*^9, 3.5860934943404217`*^9}, {3.586093679199724*^9, 
  3.5860937317840357`*^9}, {3.586093772142888*^9, 3.586093932754169*^9}}],

Cell[BoxData[
 TemplateBox[{TagBox[
    GridBox[{{
       GraphicsBox[{{{}, 
          GraphicsComplexBox[CompressedData["
1:eJztVvlTk2cQDrcgEgIKJESRK4GEQBLQCIFkE45BQa0BURCFaul4o0WwtYUi
xQGEKoqgIqVWUKSeaIsDLQKiWFSgWjwQRYsoXuMVZVBK7ReyefkbOpP95Ztn
9n33eHbf/dZ5abIqyZBGozkY0Gia77TLF3lvKyaA76io5cWyJ0WyaneCV5y5
Vp/M4AFtVNiQuNe0alMzHz4flUH58z33mwPXS/E8HcJq1SNducGoD4SJ75Kz
xaxgaL+iEQ4sTU9ilW1VaM+fDgL3lG1p/MWgxUUq+PHTBZl3VsnRH42WlGWm
DhmxIrhs/Mwo3pzJBO/46VRLVzFoMcyFGj68mCZRQOlejUyD3M6TfJiD/tQh
kHw5brItW4L+FVDkYBxjdYxJ7K0ZGK5+vdMF83EDh4iMmv6KUK2+KRr8Ni26
8ZQ2G+3LgBvju3DJPSbm6wt0s/aExmcsvO8LihkFyZNq6Ji/HXAaF77JN2ET
f1n1ayXHV0/A+4bgVHg05WGzNdG7ulBiGID35TAwaMbkqXV8ciG8VLV+UBGI
9/0gJa9LZWwuRT0bIhmVRsI2uVb/KBKka/b/ZXpJV09rKOgt+TVgTgjeDwVF
1YQNt4Vov+ATaKfoCgyfifZUsLJk+/zHN4O1+TMDIdHr/YWddCXyqYLloa4G
9zJDtfZao+AFXRyd9mUonveHCEtDfs5Z1D8SwXOLwq/b0xXIbwgkpDivmLXF
jfDLPxwri9nshPFNga2KxId/qriEn7xcSpa7o94UjOatjjbPt8N4aVq+tzii
PXNg8aSRi2VTsT5G0Nev7l5W7o16BZS/rGqN2B2EeidQfQzzqMjxRmwGvXcp
SR+rT/WM4VfMWtux/vF2m109w4TgWT51p58JxvRRvA7ZN2EijJcPrAbBqlRL
V/LeykTeO+I+uBB/dUnHtpkvccXzHKC6237nIWfEVuD59N64pC4WYi/IMqQI
8PRC7Aq7V6z72X7IBbEzLHeStRxPZGC+JqCxFv0K3w9NAKPhDwuRP1+g2Hbp
+YpP+L96wzpjShzWPzYE6muZD2zadP2ihEGP+O3n3jHQnjG49rzPWPm7KWJL
AL9Kj0XXdfiVPP+DRMlM9yb8VEWXpQ9ZWhD9B8vfDPt7BejfGnrnfr97rQ1d
q88Uwt/jkt7WHuVhPrYg29ifvTCBg/F7gNmhppdXRJ6otwdVr1GLY4cL6VfX
7T5GFtnmaP9f+VVqXLxIZROcHdXQtDhaSvopXBBaaJUZiPcDYSBPkwCDzEM1
u7K+qM+R5HO4NUKS5+yI963BbdfVnlMlU0i9NePmWgOX9KNXjl13x0Uu8f86
sfzwtxW6/DygO5568fN80f5U+OXAjszkciGZB8Htb2osGnT9aq+dVw4C4k+8
r1z6RR+HxKeusRjJXctH+1zQtL+kDd8DUwamfzQ8UqrG5uP8tD31d2R2BPtp
HnCDrr9soGvX1tP0BBbJ54JCffNlwDhyvu7odVFziyPpv1Z3VQSjX9cvEyHb
snjyoW0TyfnOvIJ1nUo6wSkn6gr97gZrcZMS/KnnlzZ7Js53BeSvphiNxX6M
DNbOJ7Mw7FcFZBZSP4x4JdoTgtv9fQtsO6djPQOg1810c3HweOJv2fSgjf3G
HIzXAM47WpU2ZnAwP1voAWpglgrJeRPxDzYJdN18GpJ/dB4ZTE3kYn3EsKzN
p+SfpWP2Lz1eE3vkO3tSnyPsuM+kjVLU+0DhuXce8Sew33wl0LGl0nPSgBLf
mwrObqD+YGlBeJ4HDI2I/Ml7ydPMyywg/1vWA5vqg00K5EcGPreyBLf6JFhv
ERjU3YwPr5cjnwDqIfF+CAnX2uOEQ2t3TufJ/FkYD8V7NNUQlWHoLxIuadJr
DkH7Iqg8Qw2wajHmL4TU2xRhfv7oTwwLnhiYxj81Q35fy0f9355K+Ik5fyOW
ddCD4AOr9om85zmj/2G5fn/R7y/6/UW/v2ij0+8v+v1Fv7/o95f/z/7yH6HX
TIk=
           "], {{
             RGBColor[0.24720000000000014`, 0.24, 0.6], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 141], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 142], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 143], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 144], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 145], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 146], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 147], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 148], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 149], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 150], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 151], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 152], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 153], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 154], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 155], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 156], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 157], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 158], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 159], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 160], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 161], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 162], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 163], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 164], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 165], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 166], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 167], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 168], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 169], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 170], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 171], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 172], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 173], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 174], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 175], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 176], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 177], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 178], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 179], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 180], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 181], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 182], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 183], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 184], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 185], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 186], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 187], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 188], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 189], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 190], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 191], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 192], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 193], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 194], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 195], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 196], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 197], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 198], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 199], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 200], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 201], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 202], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 203], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 204], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 205], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 206], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 207], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 208], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 209], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 210], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 211], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 212], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 213], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 214], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 215], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 216], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 217], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 218], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 219], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 220], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 221], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 222], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 223], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 224], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 225], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 226], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 227], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 228], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 229], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 230], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 231], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 232], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 233], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 234], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 235], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 236], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 237], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 238], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 239], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 240], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 241], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 242], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 243], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 244], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 245], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 246], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 247], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 248], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 249], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 250], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 251], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 252], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 253], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 254], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 255], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 256], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 257], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 258], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 259], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 260], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 261], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 262], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 263], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 264], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 265], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 266], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 267], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 268], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 269], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 270], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 271], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 272], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 273], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 274], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 275], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 276], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 277], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 278], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 279], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 280]}, {}}], {}}, {{}, {}, {
           Hue[0.67, 0.6, 0.6], 
           Dashing[{Small, Small}], 
           LineBox[CompressedData["
1:eJxFxW0w03EcAPBxsurahR483M7DUpnT2WonLQw1zxtb5Ok40ew/D2EItTR0
wlaeLtVhOI9xhyZJbmnOQ5Sj5U24Q3d5uLoePLTQrHrh+3vxuY9VdBKXp4vD
4Vj//J9UrKmXmStddu/ZS7ZIxGoYuysz2xtssA54mJLC18f64TdSldcGfwIe
pef1fuXPwWOlMynL/O+wjwLPXuRr4XGCwz69CAPX3d2Lma+b/U1gnv0WgUqw
hFlk3s+jntawfOpW+qijDXzeyLZD77YdzN8uq24MocBJw0tnOlin4aIw/eOa
BBocM3Izloo5wEq8KSc+1BGmGoorVtLocNSasx07wQmukw0R1fdc4K779BkV
1xVOe+kcUO3nBvePNa4WhrvDAs9zCkHIBbiqhdodH3cRLl1T5CRnMOHF1vTr
mNADHvQoe5Sb6wnr+E9/KhZ7wTi35zq1Wd5wgbGapbrrAyeHxQyo83zhhRza
VcYDP/hw+ePpwjoW3GRgmzVSyYaVQgvmyTZ/WGZZS3QODIAVoi0cNom28sX/
ORbMgZ9NkCUfp9DS4R2KZQQXLk9diYuaRYuOmB8khV6Cn5D3jKXNo/XXdUyV
kYFwM+VptmwJTY5uZWsSg+AZ71550Be0qv7GKUbqZfh3F8eJtIrWvhB2518L
hn0pHkzRBnokwl4QnxoCG8VgfdXp6EisjjCZgf4lPCSnidDWBeotzR20WN4v
LalA0/EBnd296PwDhbrLfej3hgOBZq/QGJG2mT2Afkg1cfd6i14Pn/8wPYt2
vWJ6gjCHlsRyMxkLaFLKILHhM5qT38JL/Iaukiz01PxAL5eY7VetosWV0nYH
Nfpd7RBOsIk2btrhVm6jo9vONo5r0O2dyWqtFv0X2IEqcw==
            "]]}}}, AspectRatio -> 
        NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> True, 
        AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, Method -> {}, 
        PlotLabel -> FormBox[
          InterpretationBox[
          "\"\\!\\(TraditionalForm\\`a1\\): \\!\\(TraditionalForm\\`\\(\\\"rf\
\\\"(\\(\\(3, 300\\)\\))\\)\\)\"", 
           StringForm["``: ``", $CellContext`a1, 
            "rf"[3, 300]], Editable -> False], TraditionalForm], 
        PlotRange -> {{0, 58.00716666666668}, {0, 83.}}, PlotRangeClipping -> 
        True, PlotRangePadding -> {{1.1601433333333335`, 
         1.1601433333333335`}, {1.6600000000000001`, 1.6600000000000001`}}], 
       GraphicsBox[{{{}, 
          GraphicsComplexBox[CompressedData["
1:eJztlmlQU1cUgCMIAmoIEAlIgIQEiERJBVmsyjugBRFRY1m1VZDFBQWqUawr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           "], {{
             RGBColor[0.24720000000000014`, 0.24, 0.6], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 4], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 5], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 63], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 79], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 114], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 121], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 152], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 153], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 154], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 155], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 156], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 157], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 158], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 159], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 160], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 161], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 162], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 163], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 164], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 165], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 166], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 167], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 168], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 169], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 170], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 171], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 172], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 173], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 174], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 175], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 176], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 177], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 178], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 179], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 180], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 181], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 182], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 183], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 184], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 185], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 186], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 187], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 188], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 189], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 190], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 191], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 192], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 193], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 194], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 195], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 196], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 197], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 198], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 199], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 200], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 201], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 202], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 203], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 204], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 205], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 206], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 207], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 208], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 209], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 210], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 211], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 212], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 213], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 214], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 215], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 216], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 217], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 218], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 219], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 220], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 221], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 222], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 223], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 224], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 225], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 226], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 227], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 228], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 229], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 230], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 231], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 232], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 233], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 234], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 235], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 236], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 237], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 238], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 239], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 240], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 241], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 242], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 243], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 244], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 245], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 246], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 247], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 248], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 249], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 250], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 251], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 252], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 253], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 254], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 255], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 256], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 257], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 258], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 259], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 260], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 261], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 262], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 263], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 264], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 265], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 266], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 267], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 268], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 269], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 270], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 271], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 272], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 273], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 274], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 275], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 276], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 277], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 278], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 279], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 280], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 281], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 282], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 283], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 284], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 285]}, {}}], {}}, {{}, {}, {
           Hue[0.67, 0.6, 0.6], 
           Dashing[{Small, Small}], 
           LineBox[CompressedData["
1:eJxFxW0w03EcAPBxsurahR483M7DUpnT2WonLQw1zxtb5Ok40ew/D2EItTR0
wlaeLtVhOI9xhyZJbmnOQ5Sj5U24Q3d5uLoePLTQrHrh+3vxuY9VdBKXp4vD
4Vj//J9UrKmXmStddu/ZS7ZIxGoYuysz2xtssA54mJLC18f64TdSldcGfwIe
pef1fuXPwWOlMynL/O+wjwLPXuRr4XGCwz69CAPX3d2Lma+b/U1gnv0WgUqw
hFlk3s+jntawfOpW+qijDXzeyLZD77YdzN8uq24MocBJw0tnOlin4aIw/eOa
BBocM3Izloo5wEq8KSc+1BGmGoorVtLocNSasx07wQmukw0R1fdc4K779BkV
1xVOe+kcUO3nBvePNa4WhrvDAs9zCkHIBbiqhdodH3cRLl1T5CRnMOHF1vTr
mNADHvQoe5Sb6wnr+E9/KhZ7wTi35zq1Wd5wgbGapbrrAyeHxQyo83zhhRza
VcYDP/hw+ePpwjoW3GRgmzVSyYaVQgvmyTZ/WGZZS3QODIAVoi0cNom28sX/
ORbMgZ9NkCUfp9DS4R2KZQQXLk9diYuaRYuOmB8khV6Cn5D3jKXNo/XXdUyV
kYFwM+VptmwJTY5uZWsSg+AZ71550Be0qv7GKUbqZfh3F8eJtIrWvhB2518L
hn0pHkzRBnokwl4QnxoCG8VgfdXp6EisjjCZgf4lPCSnidDWBeotzR20WN4v
LalA0/EBnd296PwDhbrLfej3hgOBZq/QGJG2mT2Afkg1cfd6i14Pn/8wPYt2
vWJ6gjCHlsRyMxkLaFLKILHhM5qT38JL/Iaukiz01PxAL5eY7VetosWV0nYH
Nfpd7RBOsIk2btrhVm6jo9vONo5r0O2dyWqtFv0X2IEqcw==
            "]]}}}, AspectRatio -> 
        NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> True, 
        AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, Method -> {}, 
        PlotLabel -> FormBox[
          InterpretationBox[
          "\"\\!\\(TraditionalForm\\`a2\\): \\!\\(TraditionalForm\\`\\(\\\"rf\
\\\"(\\(\\(3, 700\\)\\))\\)\\)\"", 
           StringForm["``: ``", $CellContext`a2, 
            "rf"[3, 700]], Editable -> False], TraditionalForm], 
        PlotRange -> {{0, 16.37254761904762}, {0, 31.}}, PlotRangeClipping -> 
        True, PlotRangePadding -> {{0.3274509523809524, 0.3274509523809524}, {
         0.62, 0.62}}], 
       GraphicsBox[{{{}, 
          GraphicsComplexBox[CompressedData["
1:eJztVmlQU1cUTgKJYVG2AAaQHUF2hCJOxXdRRIxSlkGDChZwA5GpCkgYrIJS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           "], {{
             RGBColor[0.24720000000000014`, 0.24, 0.6], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 62], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 71], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 86], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 92], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 108], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 118], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 129], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 134], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 157], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 158], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 159], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 160], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 161], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 162], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 163], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 164], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 165], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 166], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 167], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 168], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 169], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 170], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 171], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 172], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 173], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 174], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 175], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 176], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 177], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 178], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 179], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 180], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 181], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 182], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 183], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 184], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 185], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 186], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 187], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 188], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 189], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 190], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 191], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 192], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 193], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 194], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 195], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 196], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 197], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 198], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 199], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 200], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 201], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 202], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 203], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 204], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 205], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 206], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 207], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 208], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 209], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 210], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 211], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 212], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 213], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 214], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 215], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 216], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 217], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 218], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 219], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 220], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 221], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 222], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 223], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 224], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 225], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 226], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 227], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 228], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 229], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 230], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 231], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 232], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 233], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 234], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 235], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 236], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 237], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 238], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 239], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 240], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 241], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 242], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 243], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 244], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 245], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 246], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 247], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 248], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 249], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 250], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 251], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 252], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 253], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 254], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 255], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 256], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 257], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 258], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 259], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 260], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 261], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 262], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 263], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 264], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 265], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 266], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 267], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 268], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 269], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 270], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 271], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 272], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 273], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 274], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 275], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 276], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 277], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 278], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 279], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 280], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 281], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 282], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 283], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 284], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 285], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 286], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 287], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 288]}, {}}], {}}, {{}, {}, {
           Hue[0.67, 0.6, 0.6], 
           Dashing[{Small, Small}], 
           LineBox[CompressedData["
1:eJxFxW0w03EcAPBxsurahR483M7DUpnT2WonLQw1zxtb5Ok40ew/D2EItTR0
wlaeLtVhOI9xhyZJbmnOQ5Sj5U24Q3d5uLoePLTQrHrh+3vxuY9VdBKXp4vD
4Vj//J9UrKmXmStddu/ZS7ZIxGoYuysz2xtssA54mJLC18f64TdSldcGfwIe
pef1fuXPwWOlMynL/O+wjwLPXuRr4XGCwz69CAPX3d2Lma+b/U1gnv0WgUqw
hFlk3s+jntawfOpW+qijDXzeyLZD77YdzN8uq24MocBJw0tnOlin4aIw/eOa
BBocM3Izloo5wEq8KSc+1BGmGoorVtLocNSasx07wQmukw0R1fdc4K779BkV
1xVOe+kcUO3nBvePNa4WhrvDAs9zCkHIBbiqhdodH3cRLl1T5CRnMOHF1vTr
mNADHvQoe5Sb6wnr+E9/KhZ7wTi35zq1Wd5wgbGapbrrAyeHxQyo83zhhRza
VcYDP/hw+ePpwjoW3GRgmzVSyYaVQgvmyTZ/WGZZS3QODIAVoi0cNom28sX/
ORbMgZ9NkCUfp9DS4R2KZQQXLk9diYuaRYuOmB8khV6Cn5D3jKXNo/XXdUyV
kYFwM+VptmwJTY5uZWsSg+AZ71550Be0qv7GKUbqZfh3F8eJtIrWvhB2518L
hn0pHkzRBnokwl4QnxoCG8VgfdXp6EisjjCZgf4lPCSnidDWBeotzR20WN4v
LalA0/EBnd296PwDhbrLfej3hgOBZq/QGJG2mT2Afkg1cfd6i14Pn/8wPYt2
vWJ6gjCHlsRyMxkLaFLKILHhM5qT38JL/Iaukiz01PxAL5eY7VetosWV0nYH
Nfpd7RBOsIk2btrhVm6jo9vONo5r0O2dyWqtFv0X2IEqcw==
            "]]}}}, AspectRatio -> 
        NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> True, 
        AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, Method -> {}, 
        PlotLabel -> FormBox[
          InterpretationBox[
          "\"\\!\\(TraditionalForm\\`a3\\): \\!\\(TraditionalForm\\`\\(\\\"lm\
\\\"()\\)\\)\"", 
           StringForm["``: ``", $CellContext`a3, 
            "lm"[]], Editable -> False], TraditionalForm], 
        PlotRange -> {{0, 13.256362067860879`}, {0, 15.75}}, 
        PlotRangeClipping -> True, 
        PlotRangePadding -> {{0.2651272413572176, 0.2651272413572176}, {0.315,
          0.315}}]}, {
       GraphicsBox[{{{}, 
          GraphicsComplexBox[CompressedData["
1:eJztln0w1GkcwHeXXetlcViuQpLkrLe8JHXXPuQwJ4m7QXVcdLWZi9TgwtlK
rrykcVmkF5eklImK6uh62ZOOokJFOUKSvGwrEbbldvXb79Psf83N3E03ntmZ
nc98v8/zfF+e7/f3nROy2Xc9hUQizSaTSNL/uxQmtXFCE5GIlVqq8Wuw/zhb
xkt9Jt3M5iqjDVNrhL0vmnVGtFAR9CkcQfY6n1HQN6zVHt6cSAf5+Zohq7jm
AZCHGz/RzNAfBN5Y981EjaMQmCnZbRv7in0wR7qoSN4+j6j5VWXfqhNMR+MV
9V9MMofZMvvivDYJbDZqEfKZKG+ecMInVA32NyTX/NJ5eQTu85W4l39JDPzV
0eKWNE8Genc/GWWHRpzW+00E8sjlwrW5hU3AbwwOhWU2kCE+bst4nB8thkFO
jXN6NGQsIvz5BMnHd+31gugce6z/UC2ryTHwNTCtkUuPiHoDHGtuk7rEGeuX
e7M8S/zfEixk53Cj4rMQGfxlje03DW+gILupNcTm5u00iEoaZtfVSpciKuKZ
cVZ29cN5Xdsv7hYO9cN5Kna5sQm5FDjP+9QikXCGBuHvBHtc7TKlK0gDzueP
5t5qvqIF+oG2z47N86MTciXU7p2WHa41yH7HIjZVozt5/L38n+/S8+Sem0Ho
ayDXewXOnC0UIh/KSP49MlPTA3QNFOC+7eLijKKL+P4iHV5qjxuOl6eq74oK
7hBwW04QM7iOBPZdDa4o6UqkgH86jz03WncMgb1eJ1Tc5mWSQS5fD30H2vmf
n8Pxb+SllGpMkoDDYuwdZ8XK/KGinVli/TVBWF++nhrmx0t+VJkcbTd8NWp7
VIG4n4ICW/ZuSebJmIY+lUSv65I6ktlbFVmoa+mO8+c6GlP99LYuwfpIe9tk
YWQIfl9mmlVumWexP05l1dFXZ5PB3oe9Ugfr5eq9B1g7geZUegfXi9nzc1/n
lChAvgp7PKwm83px/L1Xs+IX4XpUHu1+cMMO16PTwvs79LxFbFm8eXfOiFOM
lcG/xBbBFY+7OJ9D2v6/LxvA9WPUl3jYvAL7n31d5F6QQYP9zicZkY+vi9my
92u0TrDaZSk+b65eMGn4PXY2P3JA/7MRtuw9uku6x3ovmT2qSL7/WZl4SSqG
Au9ZdFtQU+miBDzVD5rE4B8/9eStEFUFkDs7NrSajk/A/cPi+9temIrZsv7k
0RGrU8yhEvHVRfL9dpnhdzSdJJzf8jSaULcax8Pabkzfvu0N+J989ywLCWT9
lILCzypkGibjeFaujvjepHYM9Nujtj7IXUGHeF59e4P5ciUDzrfwi4jZEqAC
bIkEDnq+OgQL3/UhCzXCfk3ErJ8IfcLC9bDmgY3SqxTsf0W6fUFn/zNg19RN
z0Wn+MDW6rfXt9n3AZvuGowg59cBS6/ffwK/1y+jevPznj7F+RaPRLUffgR8
7E++2C8R9+ut/p6ne5pe4H61JL9HlYHj63gvVOHIwn4iP0x00JlV6rX8Jciz
ydRjzYVv4XtVdmmVbcsA3v9Ts9tNv1Ey1Ldldkzj8TDcPxg3K6l7/ZSIemSg
emm6HDQIuRo6frptrOsPbF8mJUGrbAOV0NdGfMnz187A8etPCOJ2puB4BQWI
l7v3dwJ39ldympntwDvm8upbzuP6dSiQalTj/eStJeXpOL55e9uyLixuA477
welZ+EP8Pl0Gfl5ctQ/3/2J3yYO2wvdx1hS4Ou0SAOtbt5rQdrYCX1wZmPba
Upvw3wDddA89ecZ3JjCvo+ZChBDLu69RvR16mcCXC0qqinoowIpkxeGkQcwG
tqqP68eUgUtVxEnF8SrAh5jODK4xFTgk6Fr60W4asHq0Sd9gFRnYqo6vWvSc
BCxuDQibdQjrH+cs8GPtxud96Lw09b/Kksi3HfrY56WqYlJ50196RH8xQtPz
0ofNS5LpmUsXyuwxRP/1vNSyR/qBkfX7OeifzkuxL0wX0GvphNwCTc9LH9e8
5ONjM7BnB4mI12z0b89LPkYpaeYdSoS/xmh6Xpqel/7P89LfpE59FQ==
           "], {{
             RGBColor[0.24720000000000014`, 0.24, 0.6], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 11], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 24], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 44], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 53], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 58], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 86], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 94], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 155], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 156], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 157], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 158], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 159], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 160], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 161], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 162], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 163], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 164], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 165], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 166], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 167], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 168], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 169], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 170], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 171], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 172], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 173], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 174], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 175], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 176], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 177], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 178], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 179], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 180], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 181], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 182], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 183], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 184], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 185], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 186], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 187], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 188], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 189], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 190], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 191], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 192], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 193], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 194], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 195], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 196], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 197], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 198], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 199], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 200], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 201], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 202], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 203], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 204], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 205], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 206], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 207], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 208], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 209], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 210], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 211], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 212], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 213], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 214], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 215], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 216], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 217], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 218], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 219], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 220], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 221], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 222], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 223], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 224], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 225], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 226], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 227], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 228], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 229], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 230], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 231], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 232], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 233], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 234], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 235], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 236], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 237], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 238], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 239], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 240], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 241], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 242], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 243], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 244], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 245], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 246], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 247], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 248], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 249], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 250], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 251], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 252], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 253], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 254], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 255], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 256], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 257], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 258], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 259], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 260], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 261], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 262], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 263], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 264], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 265], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 266], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 267], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 268], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 269], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 270], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 271], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 272], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 273], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 274], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 275], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 276], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 277], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 278], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 279], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 280], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 281], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 282], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 283], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 284], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 285], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 286], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 287]}, {}}], {}}, {{}, {}, {
           Hue[0.67, 0.6, 0.6], 
           Dashing[{Small, Small}], 
           LineBox[CompressedData["
1:eJxFxW0w03EcAPBxsurahR483M7DUpnT2WonLQw1zxtb5Ok40ew/D2EItTR0
wlaeLtVhOI9xhyZJbmnOQ5Sj5U24Q3d5uLoePLTQrHrh+3vxuY9VdBKXp4vD
4Vj//J9UrKmXmStddu/ZS7ZIxGoYuysz2xtssA54mJLC18f64TdSldcGfwIe
pef1fuXPwWOlMynL/O+wjwLPXuRr4XGCwz69CAPX3d2Lma+b/U1gnv0WgUqw
hFlk3s+jntawfOpW+qijDXzeyLZD77YdzN8uq24MocBJw0tnOlin4aIw/eOa
BBocM3Izloo5wEq8KSc+1BGmGoorVtLocNSasx07wQmukw0R1fdc4K779BkV
1xVOe+kcUO3nBvePNa4WhrvDAs9zCkHIBbiqhdodH3cRLl1T5CRnMOHF1vTr
mNADHvQoe5Sb6wnr+E9/KhZ7wTi35zq1Wd5wgbGapbrrAyeHxQyo83zhhRza
VcYDP/hw+ePpwjoW3GRgmzVSyYaVQgvmyTZ/WGZZS3QODIAVoi0cNom28sX/
ORbMgZ9NkCUfp9DS4R2KZQQXLk9diYuaRYuOmB8khV6Cn5D3jKXNo/XXdUyV
kYFwM+VptmwJTY5uZWsSg+AZ71550Be0qv7GKUbqZfh3F8eJtIrWvhB2518L
hn0pHkzRBnokwl4QnxoCG8VgfdXp6EisjjCZgf4lPCSnidDWBeotzR20WN4v
LalA0/EBnd296PwDhbrLfej3hgOBZq/QGJG2mT2Afkg1cfd6i14Pn/8wPYt2
vWJ6gjCHlsRyMxkLaFLKILHhM5qT38JL/Iaukiz01PxAL5eY7VetosWV0nYH
Nfpd7RBOsIk2btrhVm6jo9vONo5r0O2dyWqtFv0X2IEqcw==
            "]]}}}, AspectRatio -> 
        NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> True, 
        AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, Method -> {}, 
        PlotLabel -> FormBox[
          InterpretationBox[
          "\"\\!\\(TraditionalForm\\`a4\\): \\!\\(TraditionalForm\\`\\(\\\"rf\
\\\"(\\(\\(3, 300\\)\\))\\)\\)\"", 
           StringForm["``: ``", $CellContext`a4, 
            "rf"[3, 300]], Editable -> False], TraditionalForm], 
        PlotRange -> {{0, 6.307361111111111}, {0, 7.25}}, PlotRangeClipping -> 
        True, PlotRangePadding -> {{0.12614722222222222`, 
         0.12614722222222222`}, {0.145, 0.145}}], 
       GraphicsBox[{{{}, 
          GraphicsComplexBox[CompressedData["
1:eJztVms41GkUZ9KNFabBzLjMjDHKpJrWyrj+jzyqtUWiGraismKRctnU0pJK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           "], {{
             RGBColor[0.24720000000000014`, 0.24, 0.6], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 58], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 59], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 73], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 145], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 146], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 147], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 148], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 149], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 150], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 151], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 152], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 153], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 154], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 155], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 156], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 157], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 158], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 159], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 160], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 161], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 162], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 163], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 164], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 165], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 166], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 167], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 168], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 169], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 170], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 171], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 172], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 173], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 174], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 175], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 176], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 177], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 178], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 179], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 180], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 181], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 182], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 183], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 184], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 185], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 186], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 187], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 188], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 189], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 190], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 191], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 192], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 193], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 194], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 195], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 196], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 197], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 198], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 199], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 200], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 201], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 202], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 203], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 204], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 205], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 206], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 207], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 208], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 209], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 210], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 211], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 212], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 213], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 214], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 215], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 216], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 217], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 218], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 219], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 220], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 221], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 222], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 223], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 224], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 225], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 226], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 227], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 228], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 229], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 230], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 231], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 232], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 233], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 234], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 235], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 236], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 237], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 238], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 239], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 240], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 241], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 242], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 243], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 244], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 245], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 246], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 247], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 248], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 249], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 250], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 251], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 252], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 253], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 254], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 255], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 256], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 257], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 258], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 259], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 260], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 261], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 262], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 263], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 264], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 265], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 266], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 267], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 268], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 269], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 270], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 271], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 272], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 273], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 274], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 275], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 276], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 277], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 278], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 279], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 280], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 281]}, {}}], {}}, {{}, {}, {
           Hue[0.67, 0.6, 0.6], 
           Dashing[{Small, Small}], 
           LineBox[CompressedData["
1:eJxFxW0w03EcAPBxsurahR483M7DUpnT2WonLQw1zxtb5Ok40ew/D2EItTR0
wlaeLtVhOI9xhyZJbmnOQ5Sj5U24Q3d5uLoePLTQrHrh+3vxuY9VdBKXp4vD
4Vj//J9UrKmXmStddu/ZS7ZIxGoYuysz2xtssA54mJLC18f64TdSldcGfwIe
pef1fuXPwWOlMynL/O+wjwLPXuRr4XGCwz69CAPX3d2Lma+b/U1gnv0WgUqw
hFlk3s+jntawfOpW+qijDXzeyLZD77YdzN8uq24MocBJw0tnOlin4aIw/eOa
BBocM3Izloo5wEq8KSc+1BGmGoorVtLocNSasx07wQmukw0R1fdc4K779BkV
1xVOe+kcUO3nBvePNa4WhrvDAs9zCkHIBbiqhdodH3cRLl1T5CRnMOHF1vTr
mNADHvQoe5Sb6wnr+E9/KhZ7wTi35zq1Wd5wgbGapbrrAyeHxQyo83zhhRza
VcYDP/hw+ePpwjoW3GRgmzVSyYaVQgvmyTZ/WGZZS3QODIAVoi0cNom28sX/
ORbMgZ9NkCUfp9DS4R2KZQQXLk9diYuaRYuOmB8khV6Cn5D3jKXNo/XXdUyV
kYFwM+VptmwJTY5uZWsSg+AZ71550Be0qv7GKUbqZfh3F8eJtIrWvhB2518L
hn0pHkzRBnokwl4QnxoCG8VgfdXp6EisjjCZgf4lPCSnidDWBeotzR20WN4v
LalA0/EBnd296PwDhbrLfej3hgOBZq/QGJG2mT2Afkg1cfd6i14Pn/8wPYt2
vWJ6gjCHlsRyMxkLaFLKILHhM5qT38JL/Iaukiz01PxAL5eY7VetosWV0nYH
Nfpd7RBOsIk2btrhVm6jo9vONo5r0O2dyWqtFv0X2IEqcw==
            "]]}}}, AspectRatio -> 
        NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> True, 
        AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, Method -> {}, 
        PlotLabel -> FormBox[
          InterpretationBox[
          "\"\\!\\(TraditionalForm\\`a5\\): \\!\\(TraditionalForm\\`\\(\\\"rf\
\\\"(\\(\\(3, 700\\)\\))\\)\\)\"", 
           StringForm["``: ``", $CellContext`a5, 
            "rf"[3, 700]], Editable -> False], TraditionalForm], 
        PlotRange -> {{0, 11.163904761904764`}, {0, 31.749999999999996`}}, 
        PlotRangeClipping -> True, 
        PlotRangePadding -> {{0.22327809523809528`, 0.22327809523809528`}, {
         0.6349999999999999, 0.6349999999999999}}], 
       GraphicsBox[{{{}, 
          GraphicsComplexBox[CompressedData["
1:eJztVn0w1HkYX1l5fwm7K0u71tqsl5Jd8pL2SUVK781FIlMYbx1OSrleqNOb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           "], {{
             RGBColor[0.24720000000000014`, 0.24, 0.6], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 2], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 25], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 26], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 46], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 52], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 54], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 55], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 57], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 72], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 82], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 157], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 158], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 159], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 160], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 161], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 162], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 163], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 164], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 165], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 166], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 167], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 168], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 169], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 170], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 171], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 172], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 173], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 174], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 175], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 176], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 177], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 178], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 179], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 180], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 181], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 182], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 183], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 184], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 185], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 186], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 187], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 188], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 189], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 190], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 191], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 192], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 193], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 194], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 195], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 196], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 197], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 198], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 199], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 200], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 201], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 202], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 203], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 204], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 205], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 206], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 207], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 208], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 209], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 210], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 211], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 212], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 213], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 214], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 215], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 216], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 217], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 218], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 219], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 220], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 221], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 222], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 223], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 224], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 225], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 226], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 227], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 228], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 229], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 230], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 231], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 232], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 233], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 234], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 235], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 236], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 237], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 238], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 239], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 240], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 241], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 242], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 243], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 244], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 245], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 246], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 247], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 248], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 249], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 250], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 251], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 252], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 253], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 254], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 255], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 256], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 257], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 258], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 259], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 260], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 261], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 262], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 263], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 264], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 265], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 266], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 267], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 268], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 269], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 270], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 271], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 272], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 273], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 274], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 275], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 276], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 277], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 278], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 279], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 280], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 281], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 282], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 283], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 284], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 285], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 286]}, {}}], {}}, {{}, {}, {
           Hue[0.67, 0.6, 0.6], 
           Dashing[{Small, Small}], 
           LineBox[CompressedData["
1:eJxFxW0w03EcAPBxsurahR483M7DUpnT2WonLQw1zxtb5Ok40ew/D2EItTR0
wlaeLtVhOI9xhyZJbmnOQ5Sj5U24Q3d5uLoePLTQrHrh+3vxuY9VdBKXp4vD
4Vj//J9UrKmXmStddu/ZS7ZIxGoYuysz2xtssA54mJLC18f64TdSldcGfwIe
pef1fuXPwWOlMynL/O+wjwLPXuRr4XGCwz69CAPX3d2Lma+b/U1gnv0WgUqw
hFlk3s+jntawfOpW+qijDXzeyLZD77YdzN8uq24MocBJw0tnOlin4aIw/eOa
BBocM3Izloo5wEq8KSc+1BGmGoorVtLocNSasx07wQmukw0R1fdc4K779BkV
1xVOe+kcUO3nBvePNa4WhrvDAs9zCkHIBbiqhdodH3cRLl1T5CRnMOHF1vTr
mNADHvQoe5Sb6wnr+E9/KhZ7wTi35zq1Wd5wgbGapbrrAyeHxQyo83zhhRza
VcYDP/hw+ePpwjoW3GRgmzVSyYaVQgvmyTZ/WGZZS3QODIAVoi0cNom28sX/
ORbMgZ9NkCUfp9DS4R2KZQQXLk9diYuaRYuOmB8khV6Cn5D3jKXNo/XXdUyV
kYFwM+VptmwJTY5uZWsSg+AZ71550Be0qv7GKUbqZfh3F8eJtIrWvhB2518L
hn0pHkzRBnokwl4QnxoCG8VgfdXp6EisjjCZgf4lPCSnidDWBeotzR20WN4v
LalA0/EBnd296PwDhbrLfej3hgOBZq/QGJG2mT2Afkg1cfd6i14Pn/8wPYt2
vWJ6gjCHlsRyMxkLaFLKILHhM5qT38JL/Iaukiz01PxAL5eY7VetosWV0nYH
Nfpd7RBOsIk2btrhVm6jo9vONo5r0O2dyWqtFv0X2IEqcw==
            "]]}}}, AspectRatio -> 
        NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> True, 
        AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, Method -> {}, 
        PlotLabel -> FormBox[
          InterpretationBox[
          "\"\\!\\(TraditionalForm\\`a6\\): \\!\\(TraditionalForm\\`\\(\\\"lm\
\\\"()\\)\\)\"", 
           StringForm["``: ``", $CellContext`a6, 
            "lm"[]], Editable -> False], TraditionalForm], 
        PlotRange -> {{0, 21.532234683652383`}, {0, 29.}}, PlotRangeClipping -> 
        True, PlotRangePadding -> {{0.4306446936730477, 0.4306446936730477}, {
         0.58, 0.58}}]}, {
       GraphicsBox[{{{}, 
          GraphicsComplexBox[CompressedData["
1:eJztlnk0lWkYwO+91nvtF/e6UVyHDKqpCGPU9ypHoVCZisYQcaiklJrSZsrS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           "], {{
             RGBColor[0.24720000000000014`, 0.24, 0.6], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 23], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 30], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 42], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 50], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 52], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 116], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 117], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 154], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 155], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 156], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 157], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 158], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 159], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 160], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 161], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 162], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 163], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 164], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 165], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 166], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 167], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 168], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 169], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 170], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 171], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 172], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 173], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 174], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 175], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 176], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 177], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 178], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 179], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 180], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 181], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 182], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 183], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 184], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 185], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 186], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 187], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 188], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 189], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 190], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 191], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 192], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 193], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 194], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 195], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 196], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 197], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 198], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 199], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 200], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 201], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 202], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 203], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 204], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 205], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 206], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 207], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 208], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 209], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 210], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 211], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 212], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 213], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 214], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 215], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 216], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 217], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 218], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 219], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 220], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 221], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 222], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 223], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 224], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 225], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 226], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 227], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 228], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 229], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 230], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 231], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 232], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 233], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 234], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 235], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 236], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 237], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 238], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 239], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 240], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 241], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 242], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 243], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 244], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 245], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 246], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 247], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 248], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 249], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 250], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 251], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 252], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 253], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 254], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 255], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 256], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 257], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 258], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 259], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 260], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 261], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 262], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 263], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 264], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 265], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 266], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 267], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 268], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 269], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 270], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 271], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 272], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 273], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 274], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 275], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 276], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 277], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 278], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 279], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 280], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 281], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 282], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 283], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 284], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 285], 
             InsetBox[
              StyleBox[
              "\"\[FilledCircle]\"", StripOnInput -> False, FontSize -> 
               Medium], 286]}, {}}], {}}, {{}, {}, {
           Hue[0.67, 0.6, 0.6], 
           Dashing[{Small, Small}], 
           LineBox[CompressedData["
1:eJxFxW0w03EcAPBxsurahR483M7DUpnT2WonLQw1zxtb5Ok40ew/D2EItTR0
wlaeLtVhOI9xhyZJbmnOQ5Sj5U24Q3d5uLoePLTQrHrh+3vxuY9VdBKXp4vD
4Vj//J9UrKmXmStddu/ZS7ZIxGoYuysz2xtssA54mJLC18f64TdSldcGfwIe
pef1fuXPwWOlMynL/O+wjwLPXuRr4XGCwz69CAPX3d2Lma+b/U1gnv0WgUqw
hFlk3s+jntawfOpW+qijDXzeyLZD77YdzN8uq24MocBJw0tnOlin4aIw/eOa
BBocM3Izloo5wEq8KSc+1BGmGoorVtLocNSasx07wQmukw0R1fdc4K779BkV
1xVOe+kcUO3nBvePNa4WhrvDAs9zCkHIBbiqhdodH3cRLl1T5CRnMOHF1vTr
mNADHvQoe5Sb6wnr+E9/KhZ7wTi35zq1Wd5wgbGapbrrAyeHxQyo83zhhRza
VcYDP/hw+ePpwjoW3GRgmzVSyYaVQgvmyTZ/WGZZS3QODIAVoi0cNom28sX/
ORbMgZ9NkCUfp9DS4R2KZQQXLk9diYuaRYuOmB8khV6Cn5D3jKXNo/XXdUyV
kYFwM+VptmwJTY5uZWsSg+AZ71550Be0qv7GKUbqZfh3F8eJtIrWvhB2518L
hn0pHkzRBnokwl4QnxoCG8VgfdXp6EisjjCZgf4lPCSnidDWBeotzR20WN4v
LalA0/EBnd296PwDhbrLfej3hgOBZq/QGJG2mT2Afkg1cfd6i14Pn/8wPYt2
vWJ6gjCHlsRyMxkLaFLKILHhM5qT38JL/Iaukiz01PxAL5eY7VetosWV0nYH
Nfpd7RBOsIk2btrhVm6jo9vONo5r0O2dyWqtFv0X2IEqcw==
            "]]}}}, AspectRatio -> 
        NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> True, 
        AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, Method -> {}, 
        PlotLabel -> FormBox[
          InterpretationBox[
          "\"\\!\\(TraditionalForm\\`a7\\): \\!\\(TraditionalForm\\`\\(\\\"rf\
\\\"(\\(\\(3, 500\\)\\))\\)\\)\"", 
           StringForm["``: ``", $CellContext`a7, 
            "rf"[3, 500]], Editable -> False], TraditionalForm], 
        PlotRange -> {{0, 7.337200000000001}, {0, 6.25}}, PlotRangeClipping -> 
        True, PlotRangePadding -> {{0.146744, 0.146744}, {0.125, 0.125}}], "",
        ""}}, AutoDelete -> False, 
     GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      GridBoxSpacings -> {"Columns" -> {{2}}}], "Grid"],StyleBox[
    TagBox[
     GridBox[{{
       "\"Actual vs. Predicted Values for Winning Models, by Alga\""}}, 
      DefaultBaseStyle -> "Column", 
      GridBoxAlignment -> {"Columns" -> {{Center}}}, 
      GridBoxItemSize -> {
       "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Column"], 
    StripOnInput -> False, FontFamily -> "Verdana", FontSize -> 14, 
    FontWeight -> Bold]},
  "Labeled",
  DisplayFunction->(GridBox[{{
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, 
    GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
    BaselinePosition -> {2, 1}]& ),
  InterpretationFunction->(RowBox[{"Labeled", "[", 
     RowBox[{#, ",", #2, ",", "Top"}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.586093474358692*^9, 3.586093736624013*^9, {3.5860938471836843`*^9, 
   3.586093935149309*^9}}]
}, {2}]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Summary", "Title",
 CellChangeTimes->CompressedData["
1:eJwdyltIkwEYh/E5odRSiDS9UZwtq4uYY5gmlmeiqVRTcAynNtRFLqaTDL3x
AHolDhR15QQTURL9FmsldDGdMBDP2oXkYRSEoswDpfipBL3/9+Lhd/PIDGZN
hVQikcgpqCwrDxn6upcx5Jlic36vj3vJ64VPBRg0mZg6Sx60SR/BEbfbCAu9
Ay/hrP35yBzZ6Zhgzz5snsN2nfICmvwJznnSttD8GbarnOZFskAsqYa1a54V
2PZvchWKH3f9cOZKwT7czk94t0T6KobZ94aYy8vkzbwN1uYyOg7Jn2+32OXa
lKUjUnD/ZaXCqzd/yNPcoDrofRLVA48aZOxm7O3ME3zf69n4JFXHKanVWNkG
v0khkhrBwwb4HndET+xlrAbUW+F50bUxOXmc1cpm71xS3CJHR/VsiSV3Hobp
oxdg+pdOZS9pUv9gixWmZPjN3s9ejWkchi26KbYq5UGljVS5oowwrq/qhp10
Bd6NhOXOT6Ww+nVaGQy/M9MLS59ts+riorB+8n6NlZX7ziLgsd4QCVP3ZQ+h
IdCdDl9cBI/DsS5RgA7xV/cg2WQO7YFz2nuWadJSp2b/A4f3Rh4=
  "]],

Cell[TextData[{
 "Although this extended example involved a small dataset, nevertheless it \
introduced us to a range of mining and analysis techniques and their ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " implementations:"
}], "Text",
 CellChangeTimes->{{3.586004018804718*^9, 3.586004059242861*^9}, {
  3.586004091481888*^9, 3.586004206695653*^9}, {3.5860045060846033`*^9, 
  3.586004526601112*^9}, {3.586004828692532*^9, 3.5860048291390047`*^9}}],

Cell[CellGroupData[{

Cell["Descriptive statistics", "Item",
 CellChangeTimes->{{3.585910275694837*^9, 3.585910281325943*^9}, {
  3.586004208655411*^9, 3.58600421987731*^9}}],

Cell["Basic visualization", "Item",
 CellChangeTimes->{{3.585910275694837*^9, 3.585910281325943*^9}, {
  3.586004208655411*^9, 3.586004225527378*^9}}],

Cell["Imputation", "Item",
 CellChangeTimes->{{3.585910275694837*^9, 3.585910281325943*^9}, 
   3.586004208655411*^9, {3.586004283166147*^9, 3.58600428317194*^9}}],

Cell[CellGroupData[{

Cell["Central", "Subitem",
 CellChangeTimes->{{3.585910275694837*^9, 3.585910281325943*^9}, 
   3.586004208655411*^9, {3.586004283166147*^9, 3.58600429822246*^9}}],

Cell["Correlations", "Subitem",
 CellChangeTimes->{{3.585910275694837*^9, 3.585910281325943*^9}, 
   3.586004208655411*^9, {3.586004283166147*^9, 3.5860043018935413`*^9}}],

Cell["knn", "Subitem",
 CellChangeTimes->{{3.585910275694837*^9, 3.585910281325943*^9}, 
   3.586004208655411*^9, {3.586004283166147*^9, 3.5860042916935387`*^9}}]
}, Open  ]],

Cell["Modeling", "Item",
 CellChangeTimes->{{3.585910275694837*^9, 3.58591028370125*^9}, {
  3.586003881335266*^9, 3.586003884198573*^9}, {3.5860042388387413`*^9, 
  3.586004238844528*^9}}],

Cell[CellGroupData[{

Cell["Multiple linear regression", "Subitem",
 CellChangeTimes->{{3.585910275694837*^9, 3.58591028370125*^9}, {
  3.586003881335266*^9, 3.586003884198573*^9}, {3.5860042388387413`*^9, 
  3.586004246101388*^9}}],

Cell["Classification and regression trees", "Subitem",
 CellChangeTimes->{{3.585910275694837*^9, 3.58591028370125*^9}, {
  3.586003881335266*^9, 3.586003884198573*^9}, {3.5860042388387413`*^9, 
  3.586004255828977*^9}}],

Cell["Random forests", "Subitem",
 CellChangeTimes->{{3.585910275694837*^9, 3.58591028370125*^9}, {
  3.586003881335266*^9, 3.586003884198573*^9}, {3.5860042388387413`*^9, 
  3.586004260309717*^9}}],

Cell["Evaluation metrics", "Subitem",
 CellChangeTimes->{{3.585910275694837*^9, 3.58591028370125*^9}, {
  3.586003881335266*^9, 3.586003884198573*^9}, {3.5860042388387413`*^9, 
  3.586004271123904*^9}}],

Cell["k-fold cross-validation", "Subitem",
 CellChangeTimes->{{3.585910275694837*^9, 3.58591028370125*^9}, {
  3.586003881335266*^9, 3.586003884198573*^9}, {3.5860042388387413`*^9, 
  3.586004276742076*^9}, {3.5860045503789*^9, 3.586004550385501*^9}}]
}, Open  ]],

Cell[TextData[{
 "Asides:  RLink, ",
 StyleBox["DataArray", "Input"],
 " (M10)"
}], "Item",
 CellChangeTimes->{{3.585910275694837*^9, 3.58591028370125*^9}, {
  3.586003881335266*^9, 3.586003884198573*^9}, {3.5860042388387413`*^9, 
  3.586004276742076*^9}, {3.5860045503789*^9, 3.586004555877818*^9}, {
  3.5860245505881443`*^9, 3.586024564006607*^9}}],

Cell["Workflow:  importing, what-if, self-documention", "Item",
 CellChangeTimes->{{3.585910275694837*^9, 3.585910286510211*^9}, {
  3.586004337894794*^9, 3.5860043620605583`*^9}, {3.586004577624226*^9, 
  3.586004592599737*^9}, {3.586004849116872*^9, 3.586004852690119*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Initialization", "Section",
 InitializationGroup->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"PrependTo", "[", 
   RowBox[{"$Path", ",", 
    RowBox[{"FileNameJoin", "[", 
     RowBox[{"{", 
      RowBox[{
      "\"\</Users\>\"", ",", "\"\<dillont\>\"", ",", "\"\<workspace\>\"", 
       ",", "\"\<DataStoreApplications\>\""}], "}"}], "]"}]}], "]"}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"PrependTo", "[", 
   RowBox[{"$Path", ",", 
    RowBox[{"FileNameJoin", "[", 
     RowBox[{"{", 
      RowBox[{
      "\"\</Users\>\"", ",", "\"\<dillont\>\"", ",", "\"\<workspace\>\"", 
       ",", "\"\<DataStore\>\""}], "}"}], "]"}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"PrependTo", "[", 
   RowBox[{"$Path", ",", 
    RowBox[{"FileNameJoin", "[", 
     RowBox[{"{", 
      RowBox[{
      "\"\</Users\>\"", ",", "\"\<dillont\>\"", ",", "\"\<workspace\>\"", 
       ",", "\"\<MapReduce\>\""}], "}"}], "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.576844792385281*^9, 3.576844838769115*^9}, 
   3.585415733143949*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Get", "[", "\"\<DataStore`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Get", "[", "\"\<MapReduce`\>\"", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Get", "[", "\"\<DataStoreApplications`\>\"", "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.576330858978149*^9, 3.5763308978630943`*^9}, 
   3.585415671504949*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.572346874129045*^9, 3.572346884416254*^9}, {
  3.572362046615838*^9, 3.572362052949614*^9}, {3.585407712995709*^9, 
  3.585407721065055*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"stylize", "[", "s_", "]"}], ":=", 
  RowBox[{"Style", "[", 
   RowBox[{"s", ",", 
    RowBox[{"FontFamily", "\[Rule]", "\"\<Verdana\>\""}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5076554547906446`*^9, 3.507655465999778*^9}}],

Cell[CellGroupData[{

Cell["Code", "Subsection",
 CellChangeTimes->{{3.5854979728300047`*^9, 3.585497979213703*^9}, {
  3.5860875533045187`*^9, 3.586087553951483*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"columns", "=", 
   RowBox[{"{", 
    RowBox[{
    "season", ",", "size", ",", "speed", ",", "mxPH", ",", "mnO2", ",", "Cl", 
     ",", "NO3", ",", "NH4", ",", "oPO4", ",", "PO4", ",", "Chla", ",", "a1", 
     ",", "a2", ",", "a3", ",", "a4", ",", "a5", ",", "a6", ",", "a7"}], 
    "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"numberedColumns", "=", 
   RowBox[{"Rule", "@@@", 
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"columns", ",", 
       RowBox[{"Range", "[", 
        RowBox[{"Length", "@", "columns"}], "]"}]}], "}"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"responseColumns", "=", 
   RowBox[{"Take", "[", 
    RowBox[{"columns", ",", 
     RowBox[{"-", "7"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"featureColumns", "=", 
   RowBox[{"Take", "[", 
    RowBox[{"columns", ",", "11"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.57416969531166*^9, 3.5741696978203545`*^9}, 
   3.5741707218938475`*^9, {3.574766526846483*^9, 3.574766557677246*^9}, {
   3.585414079115511*^9, 3.5854140839631567`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"applyForderings", "[", "set_", "]"}], ":=", 
  RowBox[{"(", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"fordering", "[", 
      RowBox[{"set", ",", "season"}], "]"}], "=", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3", ",", "1", ",", "4"}], "}"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"fordering", "[", 
      RowBox[{"set", ",", "size"}], "]"}], "=", 
     RowBox[{"{", 
      RowBox[{"3", ",", "2", ",", "1"}], "}"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"fordering", "[", 
      RowBox[{"set", ",", "speed"}], "]"}], "=", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3", ",", "1"}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", ")"}]}]], "Input",
 CellChangeTimes->{{3.585488242944191*^9, 3.585488247650591*^9}, {
  3.585488945823132*^9, 3.585489018990509*^9}, {3.5854981099721603`*^9, 
  3.5854981384625387`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "@", "columnize"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"columnize", "[", "set_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"sym", ",", "registerCol"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"sym", "[", "All", "]"}], "=", "set"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"sym", "[", 
       RowBox[{"All", ",", "\"\<nominals\>\""}], "]"}], "=", 
      RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"sym", "[", 
       RowBox[{"All", ",", "\"\<columns\>\""}], "]"}], "=", "columns"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"registerCol", "[", "col_", "]"}], ":=", 
      RowBox[{"Module", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"i", "=", 
          RowBox[{"col", "/.", "numberedColumns"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"sym", "[", 
           RowBox[{"col", ",", "\"\<raw\>\""}], "]"}], ":=", 
          RowBox[{
           RowBox[{"sym", "[", "All", "]"}], "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "i"}], "]"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"sym", "[", 
           RowBox[{"col", ",", "\"\<missing\>\""}], "]"}], "=", 
          RowBox[{"Position", "[", 
           RowBox[{
            RowBox[{"sym", "[", 
             RowBox[{"col", ",", "\"\<raw\>\""}], "]"}], ",", 
            RowBox[{"Missing", "[", "]"}]}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"sym", "[", "col", "]"}], ":=", 
          RowBox[{
           RowBox[{"sym", "[", 
            RowBox[{"col", ",", "\"\<raw\>\""}], "]"}], "[", 
           RowBox[{"[", 
            RowBox[{"Complement", "[", 
             RowBox[{
              RowBox[{"Range", "[", 
               RowBox[{"Length", "@", "set"}], "]"}], ",", 
              RowBox[{"Flatten", "@", 
               RowBox[{"sym", "[", 
                RowBox[{"col", ",", "\"\<missing\>\""}], "]"}]}]}], "]"}], 
            "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"sym", "[", 
           RowBox[{"col", ",", "\"\<factorized\>\""}], "]"}], "=", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"MatchQ", "[", 
             RowBox[{
              RowBox[{"sym", "[", "col", "]"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"_", "?", "NumericQ"}], ".."}], "}"}]}], "]"}], ",", 
            "\[IndentingNewLine]", "False", ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"With", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"u", "=", 
                 RowBox[{"Union", "[", 
                  RowBox[{"sym", "[", "col", "]"}], "]"}]}], "}"}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{
                 RowBox[{"fordering", "[", 
                  RowBox[{"sym", ",", "col"}], "]"}], "=", 
                 RowBox[{"Range", "[", 
                  RowBox[{"Length", "@", "u"}], "]"}]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"sym", "[", 
                  RowBox[{"col", ",", "\"\<factors\>\""}], "]"}], ":=", 
                 RowBox[{"u", "[", 
                  RowBox[{"[", 
                   RowBox[{"fordering", "[", 
                    RowBox[{"sym", ",", "col"}], "]"}], "]"}], "]"}]}], 
                ";"}]}], "\[IndentingNewLine]", "]"}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"AppendTo", "[", 
              RowBox[{
               RowBox[{"sym", "[", 
                RowBox[{"All", ",", "\"\<nominals\>\""}], "]"}], ",", "col"}],
               "]"}], ";", "\[IndentingNewLine]", "True"}]}], 
           "\[IndentingNewLine]", "]"}]}], ";"}]}], "\[IndentingNewLine]", 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"registerCol", "/@", "columns"}], ";", "\[IndentingNewLine]", 
     "sym"}]}], "\[IndentingNewLine]", "]"}]}]}], "Input",
 CellChangeTimes->{{3.574168756526001*^9, 3.5741688847877235`*^9}, {
   3.574168917997714*^9, 3.574168932293578*^9}, {3.5741690660351114`*^9, 
   3.5741690773133492`*^9}, {3.574169255963372*^9, 3.574169284173337*^9}, {
   3.5741694052270594`*^9, 3.5741694507605753`*^9}, {3.5741695041907873`*^9, 
   3.5741695049031878`*^9}, {3.574169638342758*^9, 3.574169711433272*^9}, {
   3.574169799026409*^9, 3.5741698035982246`*^9}, {3.5741700931344833`*^9, 
   3.5741701049865513`*^9}, {3.5741706884418125`*^9, 3.574170693689212*^9}, {
   3.574171086713773*^9, 3.5741711739570637`*^9}, {3.5741712087846613`*^9, 
   3.5741712662940254`*^9}, {3.5741713046712065`*^9, 3.574171305946041*^9}, {
   3.57417133603463*^9, 3.5741713360846233`*^9}, {3.5741713830377293`*^9, 
   3.5741713923445787`*^9}, {3.57476570787364*^9, 3.574765838745126*^9}, {
   3.5747659530846653`*^9, 3.5747659651883583`*^9}, {3.5747660665291543`*^9, 
   3.574766070194364*^9}, {3.5747661053933773`*^9, 3.574766127543644*^9}, {
   3.57476618778109*^9, 3.5747661940904503`*^9}, {3.5747662579951057`*^9, 
   3.5747662835565677`*^9}, {3.574766328218122*^9, 3.5747665001499557`*^9}, {
   3.57476656193149*^9, 3.574766641498041*^9}, {3.574766683290431*^9, 
   3.574766741381754*^9}, {3.5747669827335587`*^9, 3.5747670589609184`*^9}, {
   3.574767119448378*^9, 3.5747672155668755`*^9}, {3.5747672504108686`*^9, 
   3.574767256128196*^9}, {3.5747673688046403`*^9, 3.5747673983503304`*^9}, 
   3.57476764101521*^9, 3.5747677151164484`*^9, {3.5747678048345795`*^9, 
   3.574767813896098*^9}, {3.574767903782239*^9, 3.5747679058153553`*^9}, {
   3.57476827007219*^9, 3.574768302612051*^9}, {3.574768390606084*^9, 
   3.5747683956543727`*^9}, {3.5747684573219*^9, 3.574768468930564*^9}, {
   3.574768509857905*^9, 3.5747685125100565`*^9}, {3.5747685999810596`*^9, 
   3.5747686435075493`*^9}, {3.5747691206598406`*^9, 
   3.5747691447622194`*^9}, {3.574769419545936*^9, 3.5747694236001678`*^9}, {
   3.5747694870387964`*^9, 3.5747695003655586`*^9}, {3.574769597027087*^9, 
   3.5747696003532777`*^9}, {3.574769708430459*^9, 3.574769711749649*^9}, {
   3.574769755173133*^9, 3.5747697556791615`*^9}, {3.5747706555666323`*^9, 
   3.5747707270587215`*^9}, {3.5747707929054875`*^9, 3.574770820876087*^9}, {
   3.574793591784502*^9, 3.5747935985358887`*^9}, {3.5747936388181925`*^9, 
   3.5747936758333097`*^9}, {3.5747938105120125`*^9, 3.574793865411153*^9}, {
   3.5747944905989113`*^9, 3.574794498043337*^9}, {3.5747946234885125`*^9, 
   3.5747946236895237`*^9}, {3.5747947837496786`*^9, 
   3.5747947846937327`*^9}, {3.575025666508046*^9, 3.575025719939102*^9}, {
   3.585414386279875*^9, 3.5854143867034893`*^9}, {3.585485734883456*^9, 
   3.5854857432855587`*^9}, {3.5854890967067013`*^9, 3.585489116341618*^9}, {
   3.585489348097411*^9, 3.585489419935848*^9}, 3.5854894938614597`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"centralImpute", "[", 
   RowBox[{"set_", ",", "cols_"}], "]"}], ":=", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"m", ",", 
      RowBox[{"dat", "=", 
       RowBox[{"set", "[", "All", "]"}]}], ",", "holes"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Scan", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"holes", "=", 
           RowBox[{"Flatten", "@", 
            RowBox[{"set", "[", 
             RowBox[{"#", ",", "\"\<missing\>\""}], "]"}]}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"dat", "[", 
            RowBox[{"[", 
             RowBox[{"holes", ",", 
              RowBox[{"#", "/.", "numberedColumns"}]}], "]"}], "]"}], "=", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"set", "[", 
              RowBox[{"#", ",", "\"\<factorized\>\""}], "]"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"First", "@", 
              RowBox[{"Commonest", "[", 
               RowBox[{"set", "[", "#", "]"}], "]"}]}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"(*", " ", "else", " ", "*)"}], "\[IndentingNewLine]", 
             RowBox[{"Median", "[", 
              RowBox[{"set", "[", "#", "]"}], "]"}]}], "\[IndentingNewLine]", 
            "]"}]}], ";"}], ")"}], "&"}], ",", "\[IndentingNewLine]", 
       "cols"}], "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"columnize", "@", "dat"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->CompressedData["
1:eJwdyk0ogwEAh/Ftl83UdrCi5kIjKXNYZJy21WJtZTtstsiiMdO2Mq24+Sgj
hUStKSJLk9U+mK/CxeZVUz4ilpBNLa1pi5hi//fw9Ls8ZV1WlYFGoVBK80G5
yDWmWk2KBs9M43B49NsBt+nUScjhmxfghvrZBR03YTd8cidIKZrAFXSzCdKX
H2uBOu+l3siEn0sWFowup4qh0OfiQ5YzRJqNyAVQEmbUwSleUAirI9dN8MBb
JYayeglpVtkhhUSG2wIZvN9Z2ND9NwdjSrMPbtnaAnB+grtLfr3RPejdXD+G
zeUVJ3CA/k5Af8/ROdSt5NLkJ2FkoFGbKdTk9YwssuGhisqB93pODSSGagXQ
H58hTYecCmgzsVWQmYhrod1XpIMKWn9jZ95X2YMYerlsD7GTFFXmvkhTsRI/
7Pt4C8LTx/Z9GGqdvoCWtdAtNEjtd/Afj7vvIg==
  "]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "@", "reset"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"reset", "[", 
   RowBox[{"n_:", "4"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"raw", ",", "tooBad"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"raw", "=", 
      RowBox[{
       RowBox[{"Import", "[", 
        RowBox[{
         RowBox[{"FileNameJoin", "[", 
          RowBox[{"{", 
           RowBox[{"\"\<algae\>\"", ",", "\"\<Analysis.txt\>\""}], "}"}], 
          "]"}], ",", "\"\<Data\>\""}], "]"}], "/.", 
       RowBox[{"\"\<XXXXXXX\>\"", "\[Rule]", 
        RowBox[{"Missing", "[", "]"}]}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"med", "=", 
      RowBox[{"columnize", "@", "raw"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"tooBad", "=", 
      RowBox[{"Position", "[", 
       RowBox[{
        RowBox[{"med", "[", "All", "]"}], ",", 
        RowBox[{"x_", "/;", 
         RowBox[{
          RowBox[{"Count", "[", 
           RowBox[{"x", ",", 
            RowBox[{"Missing", "[", "]"}]}], "]"}], ">", "n"}]}]}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"trimmed", "=", 
      RowBox[{"columnize", "@", 
       RowBox[{"Delete", "[", 
        RowBox[{
         RowBox[{"med", "[", "All", "]"}], ",", "tooBad"}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"imputed", "=", 
      RowBox[{"centralImpute", "[", 
       RowBox[{"trimmed", ",", "featureColumns"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"applyForderings", "[", "#", "]"}], "&"}], "/@", 
      RowBox[{"{", 
       RowBox[{"med", ",", "trimmed", ",", "imputed"}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Print", "[", 
      RowBox[{"StringForm", "[", 
       RowBox[{"\"\<med dataset defined, `` rows\>\"", ",", " ", 
        RowBox[{"Length", "@", 
         RowBox[{"med", "[", "All", "]"}]}]}], "]"}], "]"}], ";", 
     RowBox[{"Print", "[", 
      RowBox[{"StringForm", "[", 
       RowBox[{"\"\<trimmed dataset defined, `` rows\>\"", ",", " ", 
        RowBox[{"Length", "@", 
         RowBox[{"trimmed", "[", "All", "]"}]}]}], "]"}], "]"}], ";", 
     RowBox[{"Print", "[", 
      RowBox[{"StringForm", "[", 
       RowBox[{"\"\<centrally imputed dataset defined, `` rows\>\"", ",", " ", 
        RowBox[{"Length", "@", 
         RowBox[{"imputed", "[", "All", "]"}]}]}], "]"}], "]"}], ";"}]}], 
   "\[IndentingNewLine]", "]"}]}]}], "Input",
 CellChangeTimes->{{3.574774280013939*^9, 3.5747742819520493`*^9}, {
  3.574774319694208*^9, 3.5747743761854396`*^9}, {3.5747745214527483`*^9, 
  3.5747745526075306`*^9}, {3.5747747470306506`*^9, 3.5747747961084576`*^9}, {
  3.5854977459236393`*^9, 3.585497770532607*^9}, {3.585497827036298*^9, 
  3.585497870755597*^9}, {3.585497924583564*^9, 3.585497930536949*^9}, {
  3.585498180291649*^9, 3.585498196924555*^9}, {3.585498542453302*^9, 
  3.5854985435411453`*^9}, {3.585575605100614*^9, 3.585575607085142*^9}}]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
Saveable->True,
WindowSize->{837, 1006},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->"Algae",
ShowSelection->True,
FrontEndVersion->"9.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (January 25, \
2013)",
StyleDefinitions->"Default.nb",
PrivateNotebookOptions -> {"NotebookAuthor" -> ""}
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "SlideShowHeader"->{
  Cell[1504, 36, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[5523, 146, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[11758, 311, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[22273, 551, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[30554, 780, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[36263, 944, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[51978, 1352, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[632098, 10064, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[699272, 11619, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[838291, 14307, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[17850065, 283117, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[17866290, 283518, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[17873476, 283690, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[17885900, 284006, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[17962509, 285720, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[17979781, 286130, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[18004639, 286745, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[18064371, 288176, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[18112262, 289315, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[18133652, 289783, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[18143983, 290031, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[18183645, 290809, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[18199187, 291120, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[18239914, 291909, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[18252306, 292199, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[18288855, 293049, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[18353155, 294276, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[18367233, 294638, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[18457077, 296554, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[18479288, 297066, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[18491120, 297349, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[18524094, 298138, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[18787708, 304229, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[18835737, 305430, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[19331901, 316955, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[19357422, 317515, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[19373945, 317929, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[19378307, 318038, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[19417964, 318766, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[19603079, 323412, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[19607315, 323521, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"SlideShowHeader", 19624288, 323939}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1504, 36, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[1571, 39, 332, 4, 92, "Title"],
Cell[1906, 45, 547, 10, 68, "Text"],
Cell[2456, 57, 409, 7, 49, "Text"],
Cell[2868, 66, 568, 11, 49, "Text"],
Cell[CellGroupData[{
Cell[3461, 81, 92, 1, 28, "Item"],
Cell[3556, 84, 138, 2, 28, "Item"],
Cell[3697, 88, 98, 1, 28, "Item"]
}, Open  ]],
Cell[3810, 92, 114, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[3949, 97, 531, 15, 28, "Input"],
Cell[4483, 114, 792, 20, 63, "Output"]
}, Open  ]],
Cell[5290, 137, 196, 4, 30, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5523, 146, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[5590, 149, 365, 5, 92, "Title"],
Cell[5958, 156, 364, 7, 49, "Text"],
Cell[CellGroupData[{
Cell[6347, 167, 561, 14, 46, "Input"],
Cell[6911, 183, 722, 12, 28, "Output"]
}, Open  ]],
Cell[7648, 198, 144, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[7817, 204, 257, 7, 28, "Input"],
Cell[8077, 213, 1753, 33, 97, "Output"]
}, Open  ]],
Cell[9845, 249, 361, 10, 31, "Text"],
Cell[10209, 261, 298, 8, 28, "Input"],
Cell[10510, 271, 182, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[10717, 279, 349, 9, 28, "Input"],
Cell[11069, 290, 640, 15, 28, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[11758, 311, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[11825, 314, 478, 6, 92, "Title"],
Cell[12306, 322, 291, 7, 31, "Text"],
Cell[CellGroupData[{
Cell[12622, 333, 230, 6, 28, "Input"],
Cell[12855, 341, 495, 11, 28, "Output"]
}, Open  ]],
Cell[13365, 355, 392, 7, 49, "Text"],
Cell[13760, 364, 1119, 29, 97, "Input"],
Cell[14882, 395, 298, 6, 49, "Text"],
Cell[15183, 403, 7053, 143, 403, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22273, 551, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[22340, 554, 541, 7, 92, "Title"],
Cell[22884, 563, 199, 5, 28, "Input"],
Cell[23086, 570, 279, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[23390, 579, 515, 13, 28, "Input"],
Cell[23908, 594, 2607, 67, 155, "Output"]
}, Open  ]],
Cell[26530, 664, 714, 21, 63, "Input"],
Cell[27247, 687, 108, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[27380, 692, 515, 13, 28, "Input"],
Cell[27898, 707, 2607, 67, 155, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[30554, 780, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[30621, 783, 577, 8, 92, "Title"],
Cell[31201, 793, 105, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[31331, 798, 152, 3, 28, "Input"],
Cell[31486, 803, 464, 10, 28, "Output"]
}, Open  ]],
Cell[31965, 816, 195, 2, 30, "Text"],
Cell[32163, 820, 176, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[32364, 826, 166, 3, 28, "Input"],
Cell[32533, 831, 237, 6, 28, "Output"]
}, Open  ]],
Cell[32785, 840, 229, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[33039, 847, 276, 7, 28, "Input"],
Cell[33318, 856, 213, 4, 28, "Output"]
}, Open  ]],
Cell[33546, 863, 128, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[33699, 868, 559, 14, 28, "Input"],
Cell[34261, 884, 269, 4, 28, "Output"]
}, Open  ]],
Cell[34545, 891, 177, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[34747, 897, 164, 3, 28, "Input"],
Cell[34914, 902, 257, 5, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[35208, 912, 167, 3, 28, "Input"],
Cell[35378, 917, 170, 2, 28, "Output"]
}, Open  ]],
Cell[35563, 922, 175, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[35763, 928, 164, 3, 28, "Input"],
Cell[35930, 933, 284, 5, 28, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[36263, 944, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[36330, 947, 101, 1, 92, "Title"],
Cell[36434, 950, 604, 9, 49, "Text"],
Cell[CellGroupData[{
Cell[37063, 963, 146, 2, 35, "Subsubsection"],
Cell[37212, 967, 341, 7, 70, "Text"],
Cell[37556, 976, 1837, 41, 70, "Input"],
Cell[39396, 1019, 3746, 90, 70, "Input"],
Cell[43145, 1111, 672, 18, 70, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[43854, 1134, 98, 1, 29, "Subsubsection"],
Cell[43955, 1137, 364, 6, 49, "Text"],
Cell[CellGroupData[{
Cell[44344, 1147, 465, 9, 28, "Input"],
Cell[44812, 1158, 7105, 187, 203, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[51978, 1352, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[52045, 1355, 151, 2, 92, "Title"],
Cell[52199, 1359, 444, 6, 30, "Text"],
Cell[CellGroupData[{
Cell[52668, 1369, 518, 13, 63, "Input"],
Cell[53189, 1384, 6602, 203, 224, "Output"]
}, Open  ]],
Cell[59806, 1590, 270, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[60101, 1597, 1312, 32, 114, "Input"],
Cell[61416, 1631, 570401, 8420, 336, "Output"]
}, {2}]],
Cell[631829, 10054, 232, 5, 30, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[632098, 10064, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[632165, 10067, 205, 3, 92, "Title"],
Cell[632373, 10072, 735, 11, 30, "Text"],
Cell[633111, 10085, 2784, 63, 233, "Input"],
Cell[635898, 10150, 230, 4, 49, "Text"],
Cell[636131, 10156, 992, 21, 46, "Input"],
Cell[CellGroupData[{
Cell[637148, 10181, 333, 8, 70, "Input"],
Cell[637484, 10191, 61742, 1422, 260, "Output"]
}, {2}]]
}, Open  ]],
Cell[CellGroupData[{
Cell[699272, 11619, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[699339, 11622, 294, 4, 92, "Title"],
Cell[699636, 11628, 261, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[699922, 11637, 1624, 40, 70, "Input"],
Cell[701549, 11679, 16554, 354, 224, 11111, 263, "CachedBoxData", "BoxData", \
"Output"]
}, {2}]],
Cell[718115, 12036, 160, 5, 31, "Text"],
Cell[CellGroupData[{
Cell[718300, 12045, 720, 15, 131, "Input"],
Cell[719023, 12062, 39235, 975, 247, "Output"]
}, {2}]],
Cell[CellGroupData[{
Cell[758292, 13042, 2263, 55, 182, "Input"],
Cell[760558, 13099, 77687, 1202, 318, "Output"]
}, {2}]]
}, Open  ]],
Cell[CellGroupData[{
Cell[838291, 14307, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[838358, 14310, 292, 4, 92, "Title"],
Cell[838653, 14316, 338, 6, 49, "Text"],
Cell[CellGroupData[{
Cell[839016, 14326, 7482, 171, 70, "Input"],
Cell[846501, 14499, 17002829, 268589, 193, "Output"]
}, {2}]],
Cell[CellGroupData[{
Cell[17849364, 283093, 199, 4, 28, "Input"],
Cell[17849566, 283099, 182, 5, 28, "Output"]
}, Open  ]],
Cell[17849763, 283107, 265, 5, 49, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17850065, 283117, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[17850132, 283120, 213, 3, 92, "Title"],
Cell[17850348, 283125, 655, 11, 30, "Text"],
Cell[17851006, 283138, 617, 8, 30, "Text"],
Cell[CellGroupData[{
Cell[17851648, 283150, 377, 9, 28, "Input"],
Cell[17852028, 283161, 118, 2, 28, "Output"]
}, Open  ]],
Cell[17852161, 283166, 124, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[17852310, 283171, 258, 7, 28, "Input"],
Cell[17852571, 283180, 2481, 34, 131, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17855089, 283219, 130, 2, 28, "Input"],
Cell[17855222, 283223, 5355, 135, 240, 3178, 98, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17860614, 283363, 424, 12, 28, "Input"],
Cell[17861041, 283377, 490, 9, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17861568, 283391, 299, 8, 28, "Input"],
Cell[17861870, 283401, 1503, 35, 47, "Output"]
}, Open  ]],
Cell[17863388, 283439, 247, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[17863660, 283448, 607, 16, 28, "Input"],
Cell[17864270, 283466, 1517, 32, 112, "Output"]
}, Open  ]],
Cell[17865802, 283501, 140, 1, 30, "Text"],
Cell[17865945, 283504, 308, 9, 28, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17866290, 283518, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[17866357, 283521, 265, 3, 92, "Title"],
Cell[17866625, 283526, 759, 12, 30, "Text"],
Cell[17867387, 283540, 765, 12, 30, "Text"],
Cell[CellGroupData[{
Cell[17868177, 283556, 180, 4, 28, "Input"],
Cell[17868360, 283562, 580, 10, 28, "Output"]
}, Open  ]],
Cell[17868955, 283575, 1983, 42, 148, "Input"],
Cell[17870941, 283619, 113, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[17871079, 283624, 290, 6, 28, "Input"],
Cell[17871372, 283632, 668, 10, 28, "Output"]
}, Open  ]],
Cell[17872055, 283645, 114, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[17872194, 283650, 243, 6, 28, "Input"],
Cell[17872440, 283658, 433, 10, 28, "Output"]
}, Open  ]],
Cell[17872888, 283671, 298, 6, 30, "Text"],
Cell[17873189, 283679, 250, 6, 28, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17873476, 283690, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[17873543, 283693, 296, 4, 92, "Title"],
Cell[17873842, 283699, 740, 11, 30, "Text"],
Cell[17874585, 283712, 2184, 52, 233, "Input"],
Cell[17876772, 283766, 342, 7, 28, "Input"],
Cell[CellGroupData[{
Cell[17877139, 283777, 367, 8, 28, "Input"],
Cell[17877509, 283787, 362, 8, 28, "Output"]
}, Open  ]],
Cell[17877886, 283798, 302, 6, 30, "Text"],
Cell[CellGroupData[{
Cell[17878213, 283808, 655, 16, 28, "Input"],
Cell[17878871, 283826, 1402, 31, 113, "Output"]
}, Open  ]],
Cell[17880288, 283860, 574, 9, 49, "Text"],
Cell[17880865, 283871, 3016, 71, 216, "Input"],
Cell[CellGroupData[{
Cell[17883906, 283946, 123, 2, 28, "Input"],
Cell[CellGroupData[{
Cell[17884054, 283952, 349, 7, 21, "Print"],
Cell[17884406, 283961, 357, 7, 21, "Print"],
Cell[17884766, 283970, 379, 8, 22, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[17885194, 283984, 396, 9, 28, "Input"],
Cell[17885593, 283995, 258, 5, 28, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[17885900, 284006, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[17885967, 284009, 298, 4, 92, "Title"],
Cell[17886268, 284015, 840, 13, 49, "Text"],
Cell[17887111, 284030, 507, 14, 28, "Input"],
Cell[17887621, 284046, 115, 1, 30, "Text"],
Cell[17887739, 284049, 294, 6, 28, "Input"],
Cell[CellGroupData[{
Cell[17888058, 284059, 2814, 65, 70, "Input"],
Cell[17890875, 284126, 71283, 1580, 553, "Output"]
}, {2}]],
Cell[17962170, 285709, 302, 6, 49, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17962509, 285720, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[17962576, 285723, 350, 5, 92, "Title"],
Cell[17962929, 285730, 195, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[17963149, 285738, 444, 9, 28, "Input"],
Cell[17963596, 285749, 177, 5, 28, "Output"]
}, Open  ]],
Cell[17963788, 285757, 121, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[17963934, 285762, 397, 9, 28, "Input"],
Cell[17964334, 285773, 307, 8, 28, "Output"]
}, Open  ]],
Cell[17964656, 285784, 365, 6, 49, "Text"],
Cell[CellGroupData[{
Cell[17965046, 285794, 683, 17, 80, "Input"],
Cell[17965732, 285813, 4290, 82, 42, "Output"]
}, Open  ]],
Cell[17970037, 285898, 95, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[17970157, 285903, 1806, 45, 70, "Input"],
Cell[17971966, 285950, 4801, 90, 237, "Output"]
}, {2}]],
Cell[17976779, 286043, 235, 5, 30, "Text"],
Cell[17977017, 286050, 1634, 39, 148, "Input"],
Cell[17978654, 286091, 235, 6, 28, "Input"],
Cell[CellGroupData[{
Cell[17978914, 286101, 552, 15, 28, "Input"],
Cell[17979469, 286118, 263, 6, 28, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[17979781, 286130, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[17979848, 286133, 450, 6, 92, "Title"],
Cell[17980301, 286141, 664, 10, 87, "Text"],
Cell[17980968, 286153, 4555, 110, 267, "Input"],
Cell[17985526, 286265, 141, 1, 30, "Text"],
Cell[17985670, 286268, 563, 9, 28, "Input"],
Cell[17986236, 286279, 93, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[17986354, 286284, 1456, 35, 70, "Input"],
Cell[17987813, 286321, 16780, 418, 232, "Output"]
}, {2}]]
}, Open  ]],
Cell[CellGroupData[{
Cell[18004639, 286745, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[18004706, 286748, 540, 7, 92, "Title"],
Cell[18005249, 286757, 160, 3, 30, "Text"],
Cell[18005412, 286762, 872, 15, 28, "Input"],
Cell[18006287, 286779, 110, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[18006422, 286784, 1209, 30, 131, "Input"],
Cell[18007634, 286816, 56691, 1354, 473, "Output"]
}, {2}]]
}, Open  ]],
Cell[CellGroupData[{
Cell[18064371, 288176, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[18064438, 288179, 661, 12, 92, "Title"],
Cell[CellGroupData[{
Cell[18065124, 288195, 2156, 49, 70, "Input"],
Cell[18067283, 288246, 43755, 1033, 333, "Output"]
}, {2}]],
Cell[18111050, 289282, 377, 7, 49, "Text"],
Cell[CellGroupData[{
Cell[18111452, 289293, 180, 4, 28, "Input"],
Cell[18111635, 289299, 578, 10, 28, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[18112262, 289315, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[18112329, 289318, 646, 9, 92, "Title"],
Cell[18112978, 289329, 268, 5, 49, "Text"],
Cell[18113249, 289336, 307, 6, 49, "Text"],
Cell[18113559, 289344, 375, 7, 49, "Text"],
Cell[18113937, 289353, 19678, 425, 1372, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18133652, 289783, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[18133719, 289786, 682, 9, 92, "Title"],
Cell[18134404, 289797, 105, 1, 30, "Text"],
Cell[18134512, 289800, 934, 16, 28, "Input"],
Cell[CellGroupData[{
Cell[18135471, 289820, 247, 5, 28, "Input"],
Cell[18135721, 289827, 461, 8, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18136219, 289840, 372, 8, 28, "Input"],
Cell[18136594, 289850, 444, 7, 28, "Output"]
}, Open  ]],
Cell[18137053, 289860, 392, 7, 30, "Text"],
Cell[18137448, 289869, 1233, 21, 28, "Input"],
Cell[CellGroupData[{
Cell[18138706, 289894, 370, 8, 28, "Input"],
Cell[18139079, 289904, 465, 7, 28, "Output"]
}, Open  ]],
Cell[18139559, 289914, 248, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[18139832, 289923, 351, 8, 28, "Input"],
Cell[18140186, 289933, 283, 6, 28, "Output"]
}, Open  ]],
Cell[18140484, 289942, 100, 1, 30, "Text"],
Cell[18140587, 289945, 230, 5, 28, "Input"],
Cell[18140820, 289952, 231, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[18141076, 289961, 749, 18, 28, "Input"],
Cell[18141828, 289981, 1542, 33, 113, "Output"]
}, Open  ]],
Cell[18143385, 290017, 561, 9, 68, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18143983, 290031, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[18144050, 290034, 747, 10, 92, "Title"],
Cell[CellGroupData[{
Cell[18144822, 290048, 353, 8, 46, "Input"],
Cell[CellGroupData[{
Cell[18145200, 290060, 398, 7, 21, "Print"],
Cell[18145601, 290069, 404, 7, 21, "Print"],
Cell[18146008, 290078, 428, 8, 22, "Print"]
}, Open  ]]
}, Open  ]],
Cell[18146463, 290090, 200, 4, 30, "Text"],
Cell[18146666, 290096, 653, 11, 69, "Text"],
Cell[CellGroupData[{
Cell[18147344, 290111, 716, 18, 46, "Input"],
Cell[18148063, 290131, 31224, 575, 42, "Output"]
}, Open  ]],
Cell[18179302, 290709, 303, 6, 49, "Text"],
Cell[CellGroupData[{
Cell[18179630, 290719, 247, 5, 28, "Input"],
Cell[18179880, 290726, 3440, 70, 279, "Output"]
}, Open  ]],
Cell[18183335, 290799, 273, 5, 49, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18183645, 290809, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[18183712, 290812, 841, 11, 92, "Title"],
Cell[18184556, 290825, 119, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[18184700, 290830, 466, 11, 28, "Input"],
Cell[18185169, 290843, 389, 8, 28, "Output"]
}, Open  ]],
Cell[18185573, 290854, 229, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[18185827, 290861, 398, 8, 28, "Input"],
Cell[18186228, 290871, 11392, 200, 247, 5641, 104, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]],
Cell[18197635, 291074, 159, 3, 30, "Text"],
Cell[18197797, 291079, 329, 8, 51, "Text"],
Cell[CellGroupData[{
Cell[18198151, 291091, 532, 12, 28, "Input"],
Cell[18198686, 291105, 452, 9, 28, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[18199187, 291120, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[18199254, 291123, 889, 12, 92, "Title"],
Cell[18200146, 291137, 896, 17, 88, "Text"],
Cell[CellGroupData[{
Cell[18201067, 291158, 240, 4, 28, "Input"],
Cell[18201310, 291164, 2169, 42, 231, "Output"]
}, Open  ]],
Cell[18203494, 291209, 166, 4, 31, "Text"],
Cell[CellGroupData[{
Cell[18203685, 291217, 1196, 32, 97, "Input"],
Cell[18204884, 291251, 27959, 486, 42, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18232880, 291742, 175, 4, 28, "Input"],
Cell[18233058, 291748, 2697, 56, 231, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18235792, 291809, 534, 12, 28, "Input"],
Cell[18236329, 291823, 556, 11, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18236922, 291839, 166, 3, 28, "Input"],
Cell[18237091, 291844, 2026, 39, 215, "Output"]
}, Open  ]],
Cell[18239132, 291886, 426, 10, 51, "Text"],
Cell[18239561, 291898, 316, 6, 49, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18239914, 291909, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[18239981, 291912, 935, 13, 92, "Title"],
Cell[18240919, 291927, 441, 7, 49, "Text"],
Cell[18241363, 291936, 4682, 106, 437, "Input"],
Cell[CellGroupData[{
Cell[18246070, 292046, 334, 9, 28, "Input"],
Cell[18246407, 292057, 260, 7, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18246704, 292069, 192, 3, 28, "Input"],
Cell[18246899, 292074, 2487, 51, 217, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18249423, 292130, 189, 3, 28, "Input"],
Cell[18249615, 292135, 1929, 38, 201, "Output"]
}, Open  ]],
Cell[18251559, 292176, 414, 9, 51, "Text"],
Cell[18251976, 292187, 293, 7, 28, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18252306, 292199, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[18252373, 292202, 418, 8, 92, "Title"],
Cell[18252794, 292212, 491, 9, 49, "Text"],
Cell[CellGroupData[{
Cell[18253310, 292225, 128, 2, 35, "Subsubsection"],
Cell[18253441, 292229, 513, 9, 30, "Text"],
Cell[18253957, 292240, 1012, 31, 80, "Input"],
Cell[18254972, 292273, 345, 6, 30, "Text"],
Cell[18255320, 292281, 12609, 286, 896, "Input"],
Cell[18267932, 292569, 1067, 28, 80, "Input"],
Cell[18269002, 292599, 107, 1, 30, "Text"],
Cell[18269112, 292602, 9722, 205, 488, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[18278871, 292812, 266, 3, 29, "Subsubsection"],
Cell[18279140, 292817, 182, 4, 30, "Text"],
Cell[18279325, 292823, 844, 23, 80, "Input"],
Cell[18280172, 292848, 240, 5, 30, "Text"],
Cell[18280415, 292855, 4056, 83, 199, "Input"],
Cell[CellGroupData[{
Cell[18284496, 292942, 196, 4, 28, "Input"],
Cell[18284695, 292948, 946, 13, 28, "Output"]
}, Open  ]],
Cell[18285656, 292964, 95, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[18285776, 292969, 150, 2, 28, "Input"],
Cell[18285929, 292973, 2865, 69, 114, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[18288855, 293049, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[18288922, 293052, 446, 8, 92, "Title"],
Cell[18289371, 293062, 253, 5, 49, "Text"],
Cell[18289627, 293069, 425, 9, 28, "Input"],
Cell[CellGroupData[{
Cell[18290077, 293082, 2185, 49, 70, "Input"],
Cell[18292265, 293133, 60844, 1137, 449, 22439, 508, "CachedBoxData", \
"BoxData", "Output"]
}, {2}]]
}, Open  ]],
Cell[CellGroupData[{
Cell[18353155, 294276, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[18353222, 294279, 451, 9, 92, "Title"],
Cell[18353676, 294290, 394, 6, 49, "Text"],
Cell[18354073, 294298, 522, 16, 28, "Input"],
Cell[18354598, 294316, 187, 2, 30, "Text"],
Cell[18354788, 294320, 292, 8, 28, "Input"],
Cell[18355083, 294330, 288, 8, 28, "Input"],
Cell[18355374, 294340, 251, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[18355650, 294349, 1040, 26, 46, "Input"],
Cell[18356693, 294377, 1392, 20, 28, "Output"]
}, Open  ]],
Cell[18358100, 294400, 272, 5, 49, "Text"],
Cell[18358375, 294407, 805, 12, 68, "Text"],
Cell[18359183, 294421, 304, 6, 49, "Text"],
Cell[18359490, 294429, 2254, 58, 148, "Input"],
Cell[CellGroupData[{
Cell[18361769, 294491, 307, 5, 28, "Input"],
Cell[18362079, 294498, 791, 15, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18362907, 294518, 1086, 29, 70, "Input"],
Cell[18363996, 294549, 2457, 60, 250, "Output"]
}, {2}]],
Cell[18366465, 294612, 121, 1, 30, "Text"],
Cell[18366589, 294615, 607, 18, 28, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18367233, 294638, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[18367300, 294641, 467, 9, 92, "Title"],
Cell[18367770, 294652, 127, 1, 30, "Text"],
Cell[18367900, 294655, 1129, 26, 46, "Input"],
Cell[18369032, 294683, 733, 20, 28, "Input"],
Cell[CellGroupData[{
Cell[18369790, 294707, 496, 11, 28, "Input"],
Cell[18370289, 294720, 567, 10, 28, "Output"]
}, Open  ]],
Cell[18370871, 294733, 138, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[18371034, 294738, 2748, 64, 70, "Input"],
Cell[18373785, 294804, 81564, 1699, 212, 59405, 1334, "CachedBoxData", \
"BoxData", "Output"]
}, {2}]],
Cell[18455361, 296506, 158, 2, 30, "Text"],
Cell[18455522, 296510, 370, 10, 28, "Input"],
Cell[CellGroupData[{
Cell[18455917, 296524, 545, 12, 28, "Input"],
Cell[18456465, 296538, 563, 10, 28, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[18457077, 296554, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[18457144, 296557, 543, 13, 92, "Title"],
Cell[18457690, 296572, 655, 12, 68, "Text"],
Cell[CellGroupData[{
Cell[18458370, 296588, 260, 9, 28, "Item"],
Cell[18458633, 296599, 375, 10, 28, "Item"],
Cell[18459011, 296611, 263, 7, 28, "Item"]
}, Open  ]],
Cell[18459289, 296621, 447, 8, 49, "Text"],
Cell[18459739, 296631, 5480, 114, 369, "Input"],
Cell[18465222, 296747, 204, 4, 30, "Text"],
Cell[18465429, 296753, 2746, 47, 63, "Input"],
Cell[CellGroupData[{
Cell[18468200, 296804, 667, 11, 28, "Input"],
Cell[18468870, 296817, 865, 14, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18469772, 296836, 148, 2, 35, "Subsubsection"],
Cell[18469923, 296840, 8202, 193, 70, "Input"],
Cell[CellGroupData[{
Cell[18478150, 297037, 398, 8, 70, "Input"],
Cell[18478551, 297047, 676, 12, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[18479288, 297066, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[18479355, 297069, 563, 14, 92, "Title"],
Cell[18479921, 297085, 858, 21, 68, "Text"],
Cell[18480782, 297108, 6398, 135, 488, "Input"],
Cell[CellGroupData[{
Cell[18487205, 297247, 298, 5, 35, "Subsubsection"],
Cell[18487506, 297254, 1672, 41, 70, "Input"],
Cell[18489181, 297297, 1890, 46, 70, "Input"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[18491120, 297349, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[18491187, 297352, 580, 14, 92, "Title"],
Cell[18491770, 297368, 282, 5, 49, "Text"],
Cell[18492055, 297375, 841, 20, 46, "Input"],
Cell[CellGroupData[{
Cell[18492921, 297399, 352, 8, 28, "Input"],
Cell[18493276, 297409, 9180, 195, 122, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18502493, 297609, 154, 3, 28, "Input"],
Cell[18502650, 297614, 21395, 518, 370, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[18524094, 298138, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[18524161, 298141, 617, 14, 92, "Title"],
Cell[18524781, 298157, 242, 5, 30, "Text"],
Cell[18525026, 298164, 1035, 24, 46, "Input"],
Cell[CellGroupData[{
Cell[18526086, 298192, 136, 2, 35, "Subsubsection"],
Cell[18526225, 298196, 113085, 2768, 70, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[18639347, 300969, 113, 1, 29, "Subsubsection"],
Cell[18639463, 300972, 569, 14, 28, "Input"],
Cell[CellGroupData[{
Cell[18640057, 300990, 1968, 42, 216, "Input"],
Cell[18642028, 301034, 140358, 3051, 579, "Output"]
}, {2}]],
Cell[18782398, 304088, 310, 5, 30, "Text"],
Cell[18782711, 304095, 1611, 37, 80, "Input"],
Cell[CellGroupData[{
Cell[18784347, 304136, 477, 13, 28, "Input"],
Cell[18784827, 304151, 1942, 52, 131, "Output"]
}, Open  ]],
Cell[18786784, 304206, 465, 8, 49, "Text"],
Cell[18787252, 304216, 407, 7, 49, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[18787708, 304229, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[18787775, 304232, 583, 11, 92, "Title"],
Cell[18788361, 304245, 279, 5, 49, "Text"],
Cell[18788643, 304252, 427, 7, 49, "Text"],
Cell[18789073, 304261, 1798, 36, 63, "Input"],
Cell[18790874, 304299, 299, 6, 49, "Text"],
Cell[18791176, 304307, 946, 23, 46, "Input"],
Cell[18792125, 304332, 749, 22, 63, "Input"],
Cell[CellGroupData[{
Cell[18792899, 304358, 164, 2, 35, "Subsubsection"],
Cell[18793066, 304362, 4445, 109, 70, "Input"],
Cell[18797514, 304473, 4836, 135, 70, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[18802387, 304613, 98, 1, 29, "Subsubsection"],
Cell[18802488, 304616, 111, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[18802624, 304621, 915, 21, 30, "Input"],
Cell[18803542, 304644, 1641, 26, 28, "Output"]
}, Open  ]],
Cell[18805198, 304673, 115, 1, 30, "Text"],
Cell[18805316, 304676, 358, 9, 28, "Input"],
Cell[CellGroupData[{
Cell[18805699, 304689, 120, 2, 28, "Input"],
Cell[18805822, 304693, 369, 8, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18806228, 304706, 1257, 32, 70, "Input"],
Cell[18807488, 304740, 28191, 683, 242, "Output"]
}, {2}]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[18835737, 305430, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[18835804, 305433, 596, 11, 92, "Title"],
Cell[18836403, 305446, 493, 8, 49, "Text"],
Cell[18836899, 305456, 1902, 40, 148, "Input"],
Cell[CellGroupData[{
Cell[18838826, 305500, 138, 2, 35, "Subsubsection"],
Cell[18838967, 305504, 223676, 5528, 70, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[19062680, 311037, 115, 1, 29, "Subsubsection"],
Cell[19062798, 311040, 785, 18, 28, "Input"],
Cell[CellGroupData[{
Cell[19063608, 311062, 2021, 42, 70, "Input"],
Cell[19065632, 311106, 261219, 5685, 540, "Output"]
}, {2}]],
Cell[19326863, 316794, 124, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[19327012, 316799, 527, 13, 28, "Input"],
Cell[19327542, 316814, 1636, 50, 131, "Output"]
}, Open  ]],
Cell[19329193, 316867, 158, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[19329376, 316873, 786, 23, 63, "Input"],
Cell[19330165, 316898, 1675, 50, 131, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[19331901, 316955, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[19331968, 316958, 659, 12, 92, "Title"],
Cell[19332630, 316972, 552, 10, 50, "Text"],
Cell[CellGroupData[{
Cell[19333207, 316986, 133, 2, 35, "Subsubsection"],
Cell[19333343, 316990, 5256, 119, 70, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[19338636, 317114, 101, 1, 29, "Subsubsection"],
Cell[19338740, 317117, 513, 8, 49, "Text"],
Cell[19339256, 317127, 929, 17, 28, "Input"],
Cell[19340188, 317146, 258, 5, 49, "Text"],
Cell[CellGroupData[{
Cell[19340471, 317155, 4085, 94, 70, "Input"],
Cell[19344559, 317251, 12805, 257, 153, "Output"]
}, {2}]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[19357422, 317515, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[19357489, 317518, 701, 13, 92, "Title"],
Cell[19358193, 317533, 127, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[19358345, 317538, 712, 16, 46, "Input"],
Cell[19359060, 317556, 605, 10, 28, "Output"]
}, Open  ]],
Cell[19359680, 317569, 120, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[19359825, 317574, 614, 15, 46, "Input"],
Cell[19360442, 317591, 239, 5, 28, "Output"]
}, Open  ]],
Cell[19360696, 317599, 118, 1, 30, "Text"],
Cell[19360817, 317602, 459, 10, 28, "Input"],
Cell[19361279, 317614, 118, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[19361422, 317619, 282, 7, 28, "Input"],
Cell[19361707, 317628, 6914, 184, 203, "Output"]
}, Open  ]],
Cell[19368636, 317815, 303, 6, 30, "Text"],
Cell[CellGroupData[{
Cell[19368964, 317825, 804, 18, 28, "Input"],
Cell[19369771, 317845, 3936, 72, 102, 1308, 28, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[19373722, 317920, 186, 4, 30, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19373945, 317929, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[19374012, 317932, 698, 13, 92, "Title"],
Cell[19374713, 317947, 484, 9, 69, "Text"],
Cell[19375200, 317958, 406, 10, 28, "Input"],
Cell[CellGroupData[{
Cell[19375631, 317972, 854, 19, 28, "Input"],
Cell[19376488, 317993, 1613, 34, 96, "Output"]
}, Open  ]],
Cell[19378116, 318030, 154, 3, 30, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19378307, 318038, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[19378374, 318041, 724, 13, 92, "Title"],
Cell[19379101, 318056, 144, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[19379270, 318062, 970, 24, 46, "Input"],
Cell[19380243, 318088, 1627, 47, 63, "Output"]
}, Open  ]],
Cell[19381885, 318138, 207, 4, 30, "Text"],
Cell[19382095, 318144, 1979, 46, 165, "Input"],
Cell[19384077, 318192, 303, 6, 30, "Text"],
Cell[19384383, 318200, 781, 22, 63, "Input"],
Cell[CellGroupData[{
Cell[19385189, 318226, 184, 3, 35, "Subsubsection"],
Cell[19385376, 318231, 1573, 39, 131, "Input"],
Cell[19386952, 318272, 30963, 488, 4194, "Input"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[19417964, 318766, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[19418031, 318769, 724, 13, 92, "Title"],
Cell[19418758, 318784, 294, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[19419077, 318792, 949, 19, 46, "Input"],
Cell[19420029, 318813, 2457, 64, 149, "Output"]
}, Open  ]],
Cell[19422501, 318880, 249, 5, 49, "Text"],
Cell[19422753, 318887, 112, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[19422890, 318892, 3350, 79, 301, "Input"],
Cell[19426243, 318973, 176790, 4433, 441, "Output"]
}, {2}]]
}, Open  ]],
Cell[CellGroupData[{
Cell[19603079, 323412, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[19603146, 323415, 669, 12, 92, "Title"],
Cell[19603818, 323429, 460, 9, 49, "Text"],
Cell[CellGroupData[{
Cell[19604303, 323442, 152, 2, 28, "Item"],
Cell[19604458, 323446, 150, 2, 28, "Item"],
Cell[19604611, 323450, 163, 2, 28, "Item"],
Cell[CellGroupData[{
Cell[19604799, 323456, 163, 2, 26, "Subitem"],
Cell[19604965, 323460, 171, 2, 26, "Subitem"],
Cell[19605139, 323464, 162, 2, 26, "Subitem"]
}, Open  ]],
Cell[19605316, 323469, 189, 3, 28, "Item"],
Cell[CellGroupData[{
Cell[19605530, 323476, 210, 3, 26, "Subitem"],
Cell[19605743, 323481, 219, 3, 26, "Subitem"],
Cell[19605965, 323486, 198, 3, 26, "Subitem"],
Cell[19606166, 323491, 202, 3, 26, "Subitem"],
Cell[19606371, 323496, 251, 3, 26, "Subitem"]
}, Open  ]],
Cell[19606637, 323502, 351, 8, 29, "Item"],
Cell[19606991, 323512, 275, 3, 28, "Item"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[19607315, 323521, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[19607404, 323526, 61, 1, 80, "Section",
 InitializationGroup->True],
Cell[19607468, 323529, 965, 27, 63, "Input"],
Cell[19608436, 323558, 372, 10, 63, "Input"],
Cell[19608811, 323570, 287, 6, 28, "Input"],
Cell[19609101, 323578, 263, 6, 28, "Input"],
Cell[CellGroupData[{
Cell[19609389, 323588, 145, 2, 44, "Subsection"],
Cell[19609537, 323592, 1119, 29, 97, "Input"],
Cell[19610659, 323623, 916, 24, 97, "Input"],
Cell[19611578, 323649, 7053, 143, 403, "Input"],
Cell[19618634, 323794, 2172, 52, 233, "Input"],
Cell[19620809, 323848, 3016, 71, 216, "Input"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature BxDGWVA2pdy5YCg5mtFojdBh *)
